Account

Struct Account 

pub struct Account<B: Bmc> { /* private fields */ }
Represents a Redfish ManagerAccount.

Implementations

Source

impl<B: Bmc> Account<B>

pub fn raw(&self) -> Arc<ManagerAccount>

Raw ManagerAccount data.

pub fn is_enabled(&self) -> bool

Account is enabled.

pub async fn update( &self, update: &ManagerAccountUpdate, ) -> Result<Option<Self>, Error<B>>

Update the account.

Returns the new (updated) account.

Errors

Returns an error if the server responds with an error or if the response cannot be parsed.

pub async fn update_password( &self, password: String, ) -> Result<Option<Self>, Error<B>>

Update the account’s password.

Returns the new (updated) account.

Errors

Returns an error if the server responds with an error or if the response cannot be parsed.

pub async fn update_user_name( &self, user_name: String, ) -> Result<Option<Self>, Error<B>>

Update the account’s user name.

Returns the new (updated) account.

Errors

Returns an error if the server responds with an error or if the response cannot be parsed.

pub async fn delete(&self) -> Result<Option<Self>, Error<B>>

Delete the current account.

Errors

Returns an error if deletion fails.