AccountCollection

Struct AccountCollection 

pub struct AccountCollection<B: Bmc> { /* private fields */ }
Account collection.

Provides functions to access collection members.

Implementations

Source

impl<B: Bmc> AccountCollection<B>

pub fn odata_id(&self) -> &ODataId

OData identifier of the account collection in Redfish.

Typically /redfish/v1/AccountService/Accounts.

pub async fn create_account( &self, create: ManagerAccountCreate, ) -> Result<Option<Account<B>>, Error<B>>

Create a new account.

Errors

Returns an error if creating a new account fails.

pub async fn all_accounts_data(&self) -> Result<Vec<Account<B>>, Error<B>>

Retrieve account data.

This method does not update the collection itself. It only retrieves all account data (if not already retrieved).

Errors

Returns an error if retrieving account data fails. This can occur if the account collection was not expanded.