pub struct AccountService<B: Bmc> { /* private fields */ }Expand description
Account service. Provides the ability to manage accounts via Redfish.
Implementations
Sourceimpl<B: Bmc> AccountService<B>
impl<B: Bmc> AccountService<B>
Sourcepub fn raw(&self) -> Arc<SchemaAccountService>
pub fn raw(&self) -> Arc<SchemaAccountService>
Get the raw schema data for this account service.
Returns an Arc to the underlying schema, allowing cheap cloning
and sharing of the data.