CarCache

Struct CarCache 

pub struct CarCache<K, V> { /* private fields */ }
CAR Cache implementation following the exact pseudocode

Implementations

Source

impl<K, V> CarCache<K, V>
where K: Eq + Hash + Clone,

pub fn new(capacity: usize) -> CarCache<K, V>

Create new CAR cache with given capacity

pub fn get(&mut self, key: &K) -> Option<&V>

Get value from cache Returns Some(value) if found, None if not in cache

pub fn put(&mut self, key: K, value: V) -> Option<Evicted<K, V>>

Insert/update value in cache following the exact pseudocode Returns Option<Evicted<K, V>> containing the evicted entry (key and value) if an entry was evicted from the cache, or None if no eviction occurred.

pub const fn len(&self) -> usize

Get current cache size (items in T1 + T2)

pub const fn is_empty(&self) -> bool

Check if cache is empty

pub const fn capacity(&self) -> usize

Get cache capacity

pub const fn adaptation_parameter(&self) -> usize

Get current adaptation parameter