NetworkAdapter

Struct NetworkAdapter 

pub struct NetworkAdapter<B: Bmc> { /* private fields */ }
Network Adapter.

Provides functions to access log entries and perform log operations.

Implementations

Source

impl<B: Bmc> NetworkAdapter<B>

pub fn raw(&self) -> Arc<NetworkAdapterSchema>

Get the raw schema data for this ethernet adapter.

pub fn hardware_id(&self) -> HardwareIdRef<'_, NetworkAdapterTag>

Get hardware identifier of the network adpater.

pub async fn network_device_functions( &self, ) -> Result<Option<NetworkDeviceFunctionCollection<B>>, Error<B>>

Get network device functions for this adapter.

Returns Ok(None) when the network device functions link is absent.

Errors

Returns an error if fetching network device functions data fails.