pub struct BiosAttributeRef<'a> { /* private fields */ }Expand description
Reference to a BIOS attribute.
Implementations
Sourceimpl<'a> BiosAttributeRef<'a>
impl<'a> BiosAttributeRef<'a>
Sourcepub const fn str_value(&self) -> Option<&str>
pub const fn str_value(&self) -> Option<&str>
Returns string value of the attribute if attribute is string.
Sourcepub const fn bool_value(&self) -> Option<bool>
pub const fn bool_value(&self) -> Option<bool>
Returns boolean value of the attribute if attribute is bool.
Sourcepub const fn integer_value(&self) -> Option<i64>
pub const fn integer_value(&self) -> Option<i64>
Returns integer value of the attribute if attribute is integer.
Sourcepub const fn decimal_value(&self) -> Option<f64>
pub const fn decimal_value(&self) -> Option<f64>
Returns decimal value of the attribute if attribute is decimal.