Drive

Struct Drive 

pub struct Drive<B: Bmc> { /* private fields */ }
Represents a drive (disk) in a storage controller.

Provides access to drive information and associated metrics/sensors.

Implementations

Source

impl<B: Bmc> Drive<B>

pub fn raw(&self) -> Arc<DriveSchema>

Get the raw schema data for this drive.

Returns an Arc to the underlying schema, allowing cheap cloning and sharing of the data.

pub async fn metrics(&self) -> Result<Option<Arc<DriveMetrics>>, Error<B>>

Get drive metrics.

Returns the drive’s performance and state metrics if available.

Errors

Returns an error if:

  • The drive does not have metrics
  • Fetching metrics data fails

Get the environment sensors for this drive.

Returns a vector of Sensor<B> obtained from environment metrics, if available.

Errors

Returns an error if get of environment metrics failed.

pub async fn environment_power_limit_control( &self, ) -> Result<Option<Control<B>>, Error<B>>

Get the environment power limit control for this drive.

Returns Ok(None) when environment metrics or PowerLimitWatts is absent.

Errors

Returns an error if fetching environment metrics or the control fails.