pub struct BootOption<B: Bmc> { /* private fields */ }Expand description
Boot option.
Provides functions to access boot option.
Implementations
Sourceimpl<B: Bmc> BootOption<B>
impl<B: Bmc> BootOption<B>
Sourcepub fn boot_reference(&self) -> BootOptionReference<&str>
pub fn boot_reference(&self) -> BootOptionReference<&str>
Boot option reference.
Sourcepub fn display_name(&self) -> Option<DisplayName<&str>>
pub fn display_name(&self) -> Option<DisplayName<&str>>
The user-readable display name of the boot option that appears in the boot order list in the user interface.
Sourcepub fn uefi_device_path(&self) -> Option<UefiDevicePath<&str>>
pub fn uefi_device_path(&self) -> Option<UefiDevicePath<&str>>
The UEFI device path to access this UEFI boot option.