ComputerSystem

Struct ComputerSystem 

pub struct ComputerSystem<B: Bmc> { /* private fields */ }
Represents a computer system in the BMC.

Provides access to system information and sub-resources such as processors.

Implementations

Source

impl<B: Bmc> ComputerSystem<B>

pub fn raw(&self) -> Arc<ComputerSystemSchema>

Get the raw schema data for this computer system.

Returns an Arc to the underlying schema, allowing cheap cloning and sharing of the data.

pub fn hardware_id(&self) -> HardwareIdRef<'_, ComputerSystemTag>

Get hardware identifier of the network adpater.

pub fn sku(&self) -> Option<TaggedType<&str, ComputerSystemSkuTag>>

The manufacturer SKU for this system.

pub fn power_state(&self) -> Option<PowerState>

Power state of this system.

pub fn boot_order(&self) -> Option<Vec<BootOptionReference<&str>>>

An array of BootOptionReference strings that represent the persistent boot order for with this computer system.

pub async fn set_boot_order( &self, boot_order: Vec<BootOptionReference<String>>, ) -> Result<Option<Self>, Error<B>>

Update the persistent boot order for this computer system.

Errors

Returns an error if updating the system fails.

pub async fn bios(&self) -> Result<Option<Bios<B>>, Error<B>>

Bios associated with this system.

Fetches the BIOS settings. Returns Ok(None) when the BIOS link is absent.

Errors

Returns an error if fetching BIOS data fails.

pub async fn processors(&self) -> Result<Option<Vec<Processor<B>>>, Error<B>>

Get processors associated with this system.

Fetches the processor collection and returns a list of Processor handles. Returns Ok(None) when the processors link is absent.

Errors

Returns an error if fetching processor data fails.

pub async fn secure_boot(&self) -> Result<Option<SecureBoot<B>>, Error<B>>

Get secure boot resource associated with this system.

Returns Ok(None) when the secure boot link is absent.

Errors

Returns an error if fetching secure boot data fails.

pub async fn storage_controllers( &self, ) -> Result<Option<Vec<Storage<B>>>, Error<B>>

Get storage controllers associated with this system.

Fetches the storage collection and returns a list of Storage handles. Returns Ok(None) when the storage link is absent.

Errors

Returns an error if fetching storage data fails.

pub async fn memory_modules(&self) -> Result<Option<Vec<Memory<B>>>, Error<B>>

Get memory modules associated with this system.

Fetches the memory collection and returns a list of Memory handles. Returns Ok(None) when the memory link is absent.

Errors

Returns an error if fetching memory data fails.

pub async fn log_services(&self) -> Result<Option<Vec<LogService<B>>>, Error<B>>

Get log services for this computer system.

Returns Ok(None) when the log services link is absent.

Errors

Returns an error if fetching log service data fails.

pub async fn ethernet_interfaces( &self, ) -> Result<Option<EthernetInterfaceCollection<B>>, Error<B>>

Get ethernet interfaces for this computer system.

Returns Ok(None) when the ethernet interfaces link is absent.

Errors

Returns an error if fetching ethernet interface data fails.

pub async fn boot_options( &self, ) -> Result<Option<BootOptionCollection<B>>, Error<B>>

Get collection of the UEFI boot options associated with this computer system.

Returns Ok(None) when boot options are not exposed.

Errors

Returns an error if fetching boot options data fails.

pub async fn oem_nvidia_bluefield( &self, ) -> Result<Option<NvidiaComputerSystem<B>>, Error<B>>

NVIDIA Bluefield OEM extension

Returns Ok(None) when the system does not include NVIDIA OEM extension data.

Errors

Returns an error if NVIDIA OEM data parsing/fetching fails.

pub fn oem_lenovo(&self) -> Result<Option<LenovoComputerSystem<B>>, Error<B>>

Lenovo OEM extension

Returns Ok(None) when the system does not include Lenovo OEM extension data.

Errors

Returns an error if Lenovo OEM data parsing fails.