pub struct Memory<B: Bmc> { /* private fields */ }Expand description
Represents a memory module (DIMM) in a computer system.
Provides access to memory module information and associated metrics/sensors.
Implementations
Sourceimpl<B: Bmc> Memory<B>
impl<B: Bmc> Memory<B>
Sourcepub fn raw(&self) -> Arc<MemorySchema>
pub fn raw(&self) -> Arc<MemorySchema>
Get the raw schema data for this memory module.
Returns an Arc to the underlying schema, allowing cheap cloning
and sharing of the data.