pub type SecureBootEnable = TaggedType<bool, SecureBootEnableTag>;Expand description
An indication of whether state of secure boot enable
Aliased Type
pub struct SecureBootEnable { /* private fields */ }pub type SecureBootEnable = TaggedType<bool, SecureBootEnableTag>;An indication of whether state of secure boot enable
pub struct SecureBootEnable { /* private fields */ }