ControlType

Enum ControlType 

pub enum ControlType {
Show 17 variants Temperature, Power, Frequency, FrequencyMhz, Pressure, PressurekPa, Valve, Percent, DutyCycle, LinearPosition, LinearVelocity, LinearAcceleration, RotationalPosition, RotationalVelocity, RotationalAcceleration, LiquidFlowLpm, UnsupportedValue,
}

Variants



Temperature

Temperature (C) control or thermostat.

This value shall indicate a control used to regulate temperature, in degree Celsius units, either to a single set point or within a range. The SetPointUnits property shall contain Cel.



Power

Power (W) control or power limit.

This value shall indicate a control used to regulate or limit maximum power consumption, in watt units, either to a single set point or within a range. The SetPointUnits property shall contain W.



Frequency

Frequency (Hz) control.

This value shall indicate a control used to limit the operating frequency, in hertz units, of a device, either to a single set point or within a range. The SetPointUnits property shall contain Hz.



FrequencyMhz

Frequency (MHz) control.

This value shall indicate a control used to limit the operating frequency, in megahertz units, of a device, either to a single set point or within a range. The SetPointUnits property shall contain MHz.



Pressure

Pressure (kPa) control.

This value shall indicate a control used to adjust pressure in a system, in kilopascal units. The SetPointUnits property shall contain kPa.



PressurekPa

Pressure (kPa) control.

This value shall indicate a control used to adjust pressure in a system, in kilopascal units. The SetPointUnits property shall contain kPa.



Valve

Valve (% open) control.

This value shall indicate a control used to adjust a valve in a system, in percent units. The SetPointUnits property shall contain %. A value of 100 shall indicate the valve is completely open, and a value of 0 shall indicate the valve is completely closed.



Percent

Percent-based control.

This value shall indicate a percent-based control, in percent units. The SetPointUnits property shall contain %.



DutyCycle

Duty cycle (%) control.

This value shall indicate a control used to adjust the duty cycle, such as a PWM-based control, in percent units. The SetPointUnits property shall contain %.



LinearPosition

Linear position or distance (m) control.

This value shall indicate a control used to adjust linear position or distance, in meter units. The SetPointUnits property shall contain m.



LinearVelocity

Linear velocity (m/s) control.

This value shall indicate a control used to adjust linear velocity, in meters per second units. The SetPointUnits property shall contain m/s.



LinearAcceleration

Linear acceleration (m/s^2) control.

This value shall indicate a control used to adjust linear acceleration, in meters per square second units. The SetPointUnits property shall contain m/s2.



RotationalPosition

Rotational position (rad) control.

This value shall indicate a control used to adjust rotational position, in radian units. The SetPointUnits property shall contain rad.



RotationalVelocity

Rotational velocity (rad/s) control.

This value shall indicate a control used to adjust rotational velocity, in radians per second units. The SetPointUnits property shall contain rad/s.



RotationalAcceleration

Rotational acceleration (rad/s^2) control.

This value shall indicate a control used to adjust rotational acceleration, in radians per square second units. The SetPointUnits property shall contain rad/s2.



LiquidFlowLpm

Liquid flow (L/min) control.

This value shall indicate a control used to adjust the volume of liquid per unit of time, in liters per minute units, that flows through a particular junction. The SetPointUnits property shall contain L/min.



UnsupportedValue

Fallback value for values that are not supported by current version of Redfish schema.