pub enum SetPointType {
Single,
Range,
Monitor,
UnsupportedValue,
}Variants
Single
Control uses a single set point.
This value shall indicate the control utilizes a single set point for its operation. The
SetPoint property shall be present for this control type. The SettingMin and SettingMax
properties shall not be present for this control type.
Range
Control uses a range of values.
This value shall indicate the control utilizes a set point range for its operation. The
SettingMin and SettingMax properties shall be present for this control type. The SetPoint
property shall not be present for this control type.
Monitor
Control only monitors a reading.
This value shall indicate the control provides only monitoring of a sensor reading, and does not
provide the ability to affect the reading. This value allows for multiple controls to be populated
while only some of those controls provide a set point. The SetPoint,SettingMinandSettingMaxproperties shall not be present for this control type. For example, a motion controller may provide both position-based and velocity-based control modes, where the selected mode provides theSetPoint`, and the control for the non-selected mode provides only a sensor reading.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.