pub struct ControlCollection<B: Bmc> { /* private fields */ }Expand description
Control collection.
This wraps the collection resource and its member links. Per-control
properties such as set point and allowable range are stored on each
Control returned by Self::members.
Example
ⓘ
let controls = control_collection.members().await?;
for control in controls {
let _control = control.raw();
}Implementations
Sourceimpl<B: Bmc> ControlCollection<B>
impl<B: Bmc> ControlCollection<B>