ActionTarget

Struct ActionTarget 

pub struct ActionTarget(/* private fields */);
URI reference for the target field of an action.

The Bmc implementation resolves this value when the action is run and may reject values that violate its outbound request policy before transport.

Implementations

Source

impl ActionTarget

pub const fn new(v: String) -> ActionTarget

Creates new ActionTarget.

pub fn as_str(&self) -> &str

Returns the action target URI reference.