pub enum ModificationResponse<T> {
Entity(T),
Task(AsyncTask),
Empty,
}Expand description
Outcome of a mutating Redfish operation.
Variants
Entity(T)
Request completed synchronously.
Task(AsyncTask)
Request is completing asynchronously with the provided task location.
Empty
Request completed successfully with no response body.
Implementations
Sourceimpl<T> ModificationResponse<T>
impl<T> ModificationResponse<T>
Sourcepub fn map_entity<U, F>(self, f: F) -> ModificationResponse<U>where
F: FnOnce(T) -> U,
pub fn map_entity<U, F>(self, f: F) -> ModificationResponse<U>where
F: FnOnce(T) -> U,
Maps an entity outcome while preserving task and empty outcomes.
Sourcepub fn try_map_entity<U, E, F>(self, f: F) -> Result<ModificationResponse<U>, E>
pub fn try_map_entity<U, E, F>(self, f: F) -> Result<ModificationResponse<U>, E>
Maps an entity outcome with a fallible function while preserving task and empty outcomes.
Errors
Returns the error produced by f when this response contains an entity.
Sourcepub async fn try_map_entity_async<U, E, F, Fut>(
self,
f: F,
) -> Result<ModificationResponse<U>, E>
pub async fn try_map_entity_async<U, E, F, Fut>( self, f: F, ) -> Result<ModificationResponse<U>, E>
Asynchronously maps an entity outcome with a fallible function while preserving task and empty outcomes.
Errors
Returns the error produced by f when this response contains an entity.