Action

Struct Action 

pub struct Action<T, R> {
    pub target: ActionTarget,
    /* private fields */
}
Defines a deserializable Action. It is almost always a member of the Actions struct in different parts of the Redfish object tree.

T is the type for parameters. R is the type for the return value.

Fields

target: ActionTarget

Path that is used to trigger the action.

Implementations

Source

impl<T, R> Action<T, R>
where T: Send + Sync + Serialize, R: Send + Sync + for<'a> Deserialize<'a>,

pub async fn run<B>( &self, bmc: &B, params: &T, ) -> Result<ModificationResponse<R>, <B as Bmc>::Error>
where B: Bmc,

Run specific action with parameters passed as argument.

Errors

Return error if BMC returned error on action.