pub enum LinkStatus {
LinkUp,
NoLink,
LinkDown,
}Variants
LinkUp
The link is available for communication on this interface.
NoLink
No link or connection is detected on this interface.
LinkDown
No link is detected on this interface, but the interface is connected.