pub struct LogService<B: Bmc> { /* private fields */ }Expand description
Log service.
Provides functions to access log entries and perform log operations.
Implementations
Sourceimpl<B: Bmc> LogService<B>
impl<B: Bmc> LogService<B>
Sourcepub fn raw(&self) -> Arc<LogServiceSchema>
pub fn raw(&self) -> Arc<LogServiceSchema>
Get the raw schema data for this log service.
Returns an Arc to the underlying schema, allowing cheap cloning
and sharing of the data.
Sourcepub async fn entries(&self) -> Result<Option<Vec<Arc<LogEntry>>>, Error<B>>
pub async fn entries(&self) -> Result<Option<Vec<Arc<LogEntry>>>, Error<B>>
List all log entries.
Errors
Returns an error if:
- The log service does not have a log entries collection
- Fetching log entries data fails
Sourcepub async fn filter_entries(
&self,
filter: FilterQuery,
) -> Result<Option<Vec<Arc<LogEntry>>>, Error<B>>
pub async fn filter_entries( &self, filter: FilterQuery, ) -> Result<Option<Vec<Arc<LogEntry>>>, Error<B>>
Filter log entries using OData filter query.
Errors
Returns an error if:
- The log service does not have a log entries collection
- Filtering log entries data fails
Sourcepub async fn clear_log(
&self,
log_entry_codes: Option<String>,
) -> Result<ModificationResponse<()>, Error<B>>where
B::Error: ActionError,
pub async fn clear_log(
&self,
log_entry_codes: Option<String>,
) -> Result<ModificationResponse<()>, Error<B>>where
B::Error: ActionError,