pub struct MacAddress<'a>(/* private fields */);Expand description
MAC address returned by the crate.
nv-redfish is not opionated about format of the MAC addresses. So, it returns whatever server returns. This type is only introduced to reduce number of untyped &str returned by functions.
Implementations
Sourceimpl MacAddress<'_>
impl MacAddress<'_>