pub struct LenovoComputerSystem<B: Bmc> { /* private fields */ }Expand description
Dell OEM Attributes.
Implementations
Sourceimpl<B: Bmc> LenovoComputerSystem<B>
impl<B: Bmc> LenovoComputerSystem<B>
Sourcepub fn raw(&self) -> Arc<LenovoSystemPropertiesSchema>
pub fn raw(&self) -> Arc<LenovoSystemPropertiesSchema>
Get the raw schema data for this Lenovo Computer system.
Returns an Arc to the underlying schema, allowing cheap cloning
and sharing of the data.
Sourcepub fn front_panel_mode(&self) -> Option<FpMode>
pub fn front_panel_mode(&self) -> Option<FpMode>
Front panel mode.
Sourcepub fn port_switching_to(&self) -> Option<PortSwitchingTo>
pub fn port_switching_to(&self) -> Option<PortSwitchingTo>
USB management port switching direction.