pub enum PowerState {
On,
Off,
PoweringOn,
PoweringOff,
Paused,
}Variants
On
The resource is powered on.
Off
The resource is powered off. The components within the resource might continue to have AUX power.
PoweringOn
A temporary state between off and on. The components within the resource can take time to process the power on action.
PoweringOff
A temporary state between on and off. The components within the resource can take time to process the power off action.
Paused
The resource is paused.