State

Enum State 

pub enum State {
Show 13 variants Enabled, Disabled, StandbyOffline, StandbySpare, InTest, Starting, Absent, UnavailableOffline, Deferring, Quiesced, Updating, Qualified, Degraded,
}

Variants



Enabled

This function or resource is enabled.

This value shall indicate that a function or resource is capable of operating.



Disabled

This function or resource is disabled.

This value shall indicate that a function or resource is unavailable.



StandbyOffline

This function or resource is enabled but awaits an external action to activate it.

This value shall indicate that a resource is temporarily unavailable but may become available through an external action.



StandbySpare

This function or resource is part of a redundancy set and awaits a failover or other external action to activate it.

This value shall indicate that a resource is unavailable but may become available automatically as part of a failover, through an external action, or in response to the change in state of another device or resource.



InTest

This function or resource is undergoing testing or is in the process of capturing information for debugging.

This value shall indicate that the component is undergoing testing or is in the process of capturing information for debugging.



Starting

This function or resource is starting.

This value shall indicate that the resource is attempting to transition to Enabled.



Absent

This function or device is not currently present or detected. This resource represents a capability or an available location where a device can be installed.

This value shall indicate that the function or device is absent as defined in the ‘Absent resources’ clause of the Redfish Specification.



UnavailableOffline

This function or resource is present but cannot be used.

This value shall indicate that a function or resource is present but not able to be used.



Deferring

The element does not process any commands but queues new requests.

This value shall indicate the element does not process any commands but queues new requests.



Quiesced

The element is enabled but only processes a restricted set of commands.

This value shall indicate the element is enabled but only processes a restricted set of commands.



Updating

The element is updating and might be unavailable or degraded.

This value shall indicate the element is updating. The element may become unavailable or operate at a degraded level of performance or functionality.



Qualified

The element quality is within the acceptable range of operation.

This value shall indicate the element is within the acceptable range of operation.



Degraded

The function or resource is degraded.

This value shall indicate the resource is enabled but operating in a degraded mode.