pub struct Status {
pub state: Option<State>,
pub health: Option<Health>,
pub health_rollup: Option<Health>,
}Expand description
The status and health of a resource and its children.
Fields
state: Option<State>The state of the resource.
health: Option<Health>The health state of this resource in the absence of its dependent resources.
health_rollup: Option<Health>The overall health state from the view of this resource.