BasicAuthState

Enum BasicAuthState 

pub enum BasicAuthState {
    Enabled,
    Unadvertised,
    Disabled,
    UnsupportedValue,
}

Variants



Enabled

HTTP Basic authentication is enabled.

This value shall indicate that HTTP Basic authentication is enabled for the service. The service shall include the WWW-Authenticate HTTP response header with the value including Basic when returning the HTTP 401 Unauthorized status code.



Unadvertised

HTTP Basic authentication is enabled, but is not advertised with the WWW-Authenticate response header.

This value shall indicate that HTTP Basic authentication is enabled for the service. The service shall not include Basic in the value of the WWW-Authenticate HTTP response header and may omit the header entirely from responses. The lack of advertisement prevents some clients from accessing the service with HTTP Basic authentication, such as web browsers.



Disabled

HTTP Basic authentication is disabled.

This value shall indicate that HTTP Basic authentication is disabled for the service.



UnsupportedValue

Fallback value for values that are not supported by current version of Redfish schema.