OneTimePasscode

Struct OneTimePasscode 

pub struct OneTimePasscode {
    pub enabled: Option<Option<Boolean>>,
}
Various settings for one-time passcode (OTP) multi-factor authentication.

This type shall contain settings for one-time passcode (OTP) multi-factor authentication.

Fields

enabled: Option<Option<Boolean>>

An indication of whether multi-factor authentication using a one-time passcode is enabled.

This property shall indicate whether multi-factor authentication using a one-time passcode is enabled. The passcode is sent to the delivery address associated with the account credentials provided in the request. If the credentials are associated with a ManagerAccount resource, the delivery address is specified by the OneTimePasscodeDeliveryAddress property. If the credentials are associated with a user from an LDAP account provider, the delivery address is contained in the LDAP attribute specified by the EmailAttribute property. An attempt to create a session when the Token property is not included in the request shall generate a message sent to the delivery address, using the SMTP settings from the Redfish event service, containing a one-time passcode. The service shall accept the one-time passcode as the valid value for the Token property in the next POST operation to create a session for the respective account.