pub struct TimeBasedOneTimePassword {
pub enabled: Option<Option<Boolean>>,
pub time_step_seconds: Option<Option<Int64>>,
}Expand description
Various settings for Time-based One-Time Password (TOTP) multi-factor authentication.
This type shall contain settings for RFC6238-defined Time-based One-Time Password (TOTP) multi-factor authentication.
Fields
enabled: Option<Option<Boolean>>An indication of whether multi-factor authentication with a Time-based One-Time Password (TOTP) is enabled.
This property shall indicate whether multi-factor authentication with an RFC6238-defined Time-based One-Time Password (TOTP) is enabled.
time_step_seconds: Option<Option<Int64>>The time step, in seconds, for calculating the one-time password.
This property shall contain the RFC6238-defined time step, in seconds, for calculating the one-time
password. If this property is not supported by the service, it shall be assumed to be 30.