Parameters

Struct Parameters 

pub struct Parameters {
Show 14 fields pub name: String, pub required: Option<Boolean>, pub data_type: Option<Option<ParameterTypes>>, pub object_data_type: Option<Option<String>>, pub allowable_values: Option<Option<Vec<String>>>, pub minimum_value: Option<Option<Decimal>>, pub maximum_value: Option<Option<Decimal>>, pub array_size_minimum: Option<Option<Int64>>, pub array_size_maximum: Option<Option<Int64>>, pub allowable_numbers: Option<Option<Vec<String>>>, pub allowable_pattern: Option<Option<String>>, pub allowable_value_descriptions: Option<Option<Vec<String>>>, pub default_value: Option<Option<String>>, pub no_default_value: Option<Option<Boolean>>,
}

Fields

name: String

The name of the parameter for this action.

This property shall contain the name of the parameter included in a Redfish action.

required: Option<Boolean>

An indication of whether the parameter is required to complete this action.

This property shall indicate whether the parameter is required to complete this action.

data_type: Option<Option<ParameterTypes>>

The JSON property type for this parameter.

This property shall contain the JSON property type for this parameter.

object_data_type: Option<Option<String>>

The data type of an object-based parameter.

This property shall describe the entity type definition in @odata.type format for the parameter. This property shall be required for parameters with a data type of Object or ObjectArray, and shall not be present for parameters with other data types.

allowable_values: Option<Option<Vec<String>>>

The allowable values for this parameter as applied to this action target.

This property shall indicate the allowable values for this parameter as applied to this action target. For arrays, this property shall represent the allowable values for each array member.

minimum_value: Option<Option<Decimal>>

The minimum supported value for this parameter.

This integer or number property shall contain the minimum value that this service supports. For arrays, this property shall represent the minimum value for each array member. This property shall not be present for non-integer or number parameters.

maximum_value: Option<Option<Decimal>>

The maximum supported value for this parameter.

This integer or number property shall contain the maximum value that this service supports. For arrays, this property shall represent the maximum value for each array member. This property shall not be present for non-integer or number parameters.

array_size_minimum: Option<Option<Int64>>

The minimum number of array elements required for this parameter.

This property shall contain the minimum number of array elements required by this service for this parameter. This property shall not be present for non-array parameters.

array_size_maximum: Option<Option<Int64>>

The maximum number of array elements allowed for this parameter.

This property shall contain the maximum number of array elements that this service supports for this parameter. This property shall not be present for non-array parameters.

allowable_numbers: Option<Option<Vec<String>>>

The allowable numeric values or duration values, inclusive ranges of values, and incremental step values for this parameter as applied to this action target.

This property shall indicate the allowable numeric values, inclusive ranges of values, and incremental step values for this parameter as applied to this action target, as defined in the ‘Allowable values for numbers and durations’ clause of the Redfish Specification. For arrays, this property shall represent the allowable values for each array member. This property shall only be present for numeric parameters or string parameters that specify a duration.

allowable_pattern: Option<Option<String>>

The allowable pattern for this parameter as applied to this action target.

This property shall contain a regular expression that describes the allowable values for this parameter as applied to this action target. For arrays, this property shall represent the allowable values for each array member. This property shall only be present for string parameters.

allowable_value_descriptions: Option<Option<Vec<String>>>

Descriptions of allowable values for this parameter.

This property shall contain the descriptions of allowable values for this parameter. The descriptions shall appear in the same array order as the AllowableValues property. For arrays, this property shall represent the descriptions of allowable values for each array member.

default_value: Option<Option<String>>

The default value for this parameter.

This property shall contain the default value for this parameter if the client does not provide the parameter. This property shall not be present if Required contains true. If DataType does not contain String, the service shall convert the value to an RFC8259-defined JSON string.

no_default_value: Option<Option<Boolean>>

Indicates that there is no default value for this parameter.

This property shall indicate that there is no default value for this parameter. For example, if username and password parameters are optional, the absence of the parameters indicates no credentials are used. This property shall not be present if Required contains true or if DefaultValue is present.