pub struct Assembly {
pub base: Resource,
pub actions: Option<Actions>,
pub assemblies: Option<Vec<NavProperty<AssemblyData>>>,
}Expand description
The Assembly schema defines an assembly. Assembly information contains details about a device,
such as part number, serial number, producer, vendor, and production date. It also provides access
to the original data for the assembly.
This resource shall represent an assembly for a Redfish implementation. Assembly information contains details about a device, such as part number, serial number, producer, vendor, and production date. It also provides access to the original data for the assembly.
Fields
base: ResourceBase type
actions: Option<Actions>The available actions for this resource.
This property shall contain the available actions for this resource.
assemblies: Option<Vec<NavProperty<AssemblyData>>>The assembly records.
These properties shall define assembly records for a Redfish implementation.