pub struct AssemblyData {Show 22 fields
pub base: ReferenceableMember,
pub name: Option<Option<String>>,
pub description: Option<Option<String>>,
pub model: Option<Option<String>>,
pub part_number: Option<Option<String>>,
pub spare_part_number: Option<Option<String>>,
pub sku: Option<Option<String>>,
pub vendor: Option<Option<String>>,
pub production_date: Option<Option<DateTimeOffset>>,
pub producer: Option<Option<String>>,
pub version: Option<Option<String>>,
pub engineering_change_level: Option<Option<String>>,
pub binary_data_uri: Option<Option<String>>,
pub actions: Option<AssemblyDataActions>,
pub status: Option<Status>,
pub serial_number: Option<Option<String>>,
pub physical_context: Option<PhysicalContext>,
pub location_indicator_active: Option<Option<Boolean>>,
pub location: Option<Location>,
pub replaceable: Option<Option<Boolean>>,
pub iso_country_code_of_origin: Option<Option<String>>,
pub ready_to_remove: Option<Option<Boolean>>,
}Fields
base: ReferenceableMemberBase type
name: Option<Option<String>>The name of the assembly.
This property shall contain the name of the assembly.
description: Option<Option<String>>The description of the assembly.
This property shall contain the description of the assembly.
model: Option<Option<String>>The model number of the assembly.
This property shall contain the name by which the vendor generally refers to the assembly.
part_number: Option<Option<String>>The part number of the assembly.
This property shall contain the part number of the assembly.
spare_part_number: Option<Option<String>>The spare part number of the assembly.
This property shall contain the spare part number of the assembly.
sku: Option<Option<String>>The SKU of the assembly.
This property shall contain the SKU of the assembly.
vendor: Option<Option<String>>The vendor of the assembly.
This property shall contain the name of the company that provides the final product that includes this assembly. This value shall be equal to the ‘Vendor’ field value in a PLDM FRU structure, if applicable, for the assembly.
production_date: Option<Option<DateTimeOffset>>The production date of the assembly.
This property shall contain the date of production or manufacture for the assembly. The time of
day portion of the property shall be 00:00:00Z, if the time of day is unknown.
producer: Option<Option<String>>The producer or manufacturer of the assembly.
This property shall contain the name of the company that produced or manufactured the assembly. This value shall be equal to the ‘Manufacturer’ field value in a PLDM FRU structure, if applicable, for the assembly.
version: Option<Option<String>>The hardware version of the assembly.
This property shall contain the hardware version of the assembly as determined by the vendor or supplier.
engineering_change_level: Option<Option<String>>The engineering change level of the assembly.
This property shall contain the engineering change level or revision of the assembly.
binary_data_uri: Option<Option<String>>The URI at which to access an image of the assembly information.
This property shall contain the URI at which to access an image of the assembly information, using
the Redfish protocol and authentication methods. The service provides this URI for the download of
the OEM-specific binary image of the assembly data. An HTTP GET from this URI shall return a
response payload of MIME type application/octet-stream. If the service supports it, an HTTP
PUT to this URI shall replace the binary image of the assembly.
actions: Option<AssemblyDataActions>The available actions for this resource.
This property shall contain the available actions for this resource.
status: Option<Status>The status and health of the resource and its subordinate or dependent resources.
This property shall contain any status or health properties of the resource.
serial_number: Option<Option<String>>The serial number of the assembly.
This property shall contain a manufacturer-allocated number that identifies the assembly.
physical_context: Option<PhysicalContext>The area or device to which the assembly data applies.
This property shall contain a description of the physical context for the assembly data.
location_indicator_active: Option<Option<Boolean>>An indicator allowing an operator to physically locate this resource.
This property shall contain the state of the indicator used to physically identify or locate this resource.
location: Option<Location>The location of the assembly.
This property shall contain the location information of the associated assembly.
replaceable: Option<Option<Boolean>>An indication of whether the component associated this assembly can be independently replaced as allowed by the vendor’s replacement policy.
This property shall indicate whether the component associated this assembly can be independently
replaced as allowed by the vendor’s replacement policy. A value of false indicates the component
needs to be replaced by policy as part of another component. If the LocationType property of
this assembly contains Embedded, this property shall contain false.
iso_country_code_of_origin: Option<Option<String>>The manufacturing country of origin, using the ISO 3166-1 country code.
This property shall contain the ISO 3166-1-defined alpha-2 or alpha-3 country code that reflects the manufacturing country of origin.
ready_to_remove: Option<Option<Boolean>>An indication of whether the assembly is prepared by the system for removal.
This property shall indicate whether the assembly is ready for removal. Setting the value to
true shall cause the service to perform appropriate actions to quiesce the device. A task may
spawn while the device is quiescing.