Attributes

Struct Attributes 

pub struct Attributes {
    pub dynamic_properties: DynamicProperties<PrimitiveType>,
}
The list of BIOS attributes and their values as determined by the manufacturer or provider.

This property shall contain the list of BIOS attributes and their values as determined by the manufacturer or provider. This object shall describe BIOS attribute settings as additional properties. If the object specifies a BIOS attribute registry, attributes shall be looked up in that attribute registry by their attribute name. Attributes in this attribute registry with the AttributeType of Enumeration shall use valid ValueName values in this object, as listed in that attribute registry.

Fields

dynamic_properties: DynamicProperties<PrimitiveType>