pub struct BootOptionCollection {
pub base: ResourceCollection,
pub members: Vec<NavProperty<BootOption>>,
}Expand description
The collection of BootOption resource instances.
This resource shall represent a resource collection of BootOption instances for a Redfish
implementation.
Fields
base: ResourceCollectionBase type
members: Vec<NavProperty<BootOption>>The members of this collection.
This property shall contain an array of links to the members of this collection.