pub enum IndicatorLed {
Unknown,
Lit,
Blinking,
Off,
UnsupportedValue,
}Variants
Unknown
The state of the indicator LED cannot be determined.
This value shall represent the indicator LED is in an unknown state. The service shall reject
PATCH or PUT requests containing this value by returning the HTTP 400 Bad Request status
code.
Lit
The indicator LED is lit.
This value shall represent the indicator LED is in a solid on state. If the service does not
support this value, it shall return the HTTP 400 Bad Request status code to reject PATCH or
PUT requests that contain this value.
Blinking
The indicator LED is blinking.
This value shall represent the indicator LED is in a blinking state where the LED is being turned
on and off in repetition. If the service does not support this value, it shall reject PATCH or
PUT requests containing this value by returning the HTTP 400 Bad Request status code.
Off
The indicator LED is off.
This value shall represent the indicator LED is in a solid off state. If the service does not
support this value, it shall reject PATCH or PUT requests containing this value by returning
the HTTP 400 Bad Request status code.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.