pub enum IntrusionSensor {
Normal,
HardwareIntrusion,
TamperingDetected,
UnsupportedValue,
}Variants
Normal
No physical security condition is detected at this time.
HardwareIntrusion
A door, lock, or other mechanism protecting the internal system hardware from being accessed is detected to be in an insecure state.
TamperingDetected
Physical tampering of the monitored entity is detected.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.