pub enum IntrusionSensorReArm {
Manual,
Automatic,
UnsupportedValue,
}Variants
Manual
A user is required to clear the sensor to restore it to the normal state.
This value shall indicate a user is required to set the IntrusionSensor property to Normal to
restore the sensor to its normal state.
Automatic
The sensor is automatically restored to the normal state when no security condition is detected.
This value shall indicate the service sets the IntrusionSensor property to Normal when no
security condition is detected.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.