pub enum RackMountWidth {
OpenU,
Eia310,
Eia310Telco,
HalfWidth,
UnsupportedValue,
}Variants
OpenU
Open Rack (21.0 in or 533.4 mm).
Rack mounting width and mounting hole spacing shall conform to the Open Rack standard for 21-inch racks.
Eia310
EIA-310 19-inch.
Rack mounting width and mounting hole spacing shall conform to the EIA-310 standard for 19-inch racks.
Eia310Telco
EIA-310 23-inch (Telco).
Rack mounting width and mounting hole spacing shall conform to the EIA-310 standard for 23-inch telecommunications equipment racks.
HalfWidth
Half-width (~9.5 in) Unit.
Rack mounting width and mounting hole spacing shall be approximately 9.5 inches in width, following de facto industry practice for a rack half the width of a 19-inch EIA-310 equipment racks.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.