pub enum ThermalDirection {
FrontToBack,
BackToFront,
TopExhaust,
Sealed,
UnsupportedValue,
}Variants
FrontToBack
A chassis with the air intake in the front and exhaust out the back.
This value shall indicate a chassis with the air intake generally from the front of the chassis and the air exhaust out the back of the chassis.
BackToFront
A chassis with the air intake in the back and exhaust out the front.
This value shall indicate a chassis with the air intake generally from the back of the chassis and the air exhaust out the front of the chassis.
TopExhaust
A chassis with air exhaust on the top.
This value shall indicate a chassis with the air exhaust out the top of the chassis.
Sealed
A sealed chassis with no air pathway.
This value shall indicate a sealed chassis with no air pathway through the chassis.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.