pub struct Chassis {Show 64 fields
pub base: Resource,
pub chassis_type: ChassisType,
pub manufacturer: Option<Option<String>>,
pub model: Option<Option<String>>,
pub sku: Option<Option<String>>,
pub serial_number: Option<Option<String>>,
pub part_number: Option<Option<String>>,
pub asset_tag: Option<Option<String>>,
pub indicator_led: Option<Option<IndicatorLed>>,
pub links: Option<Links>,
pub actions: Option<Actions>,
pub status: Option<Status>,
pub power_state: Option<Option<PowerState>>,
pub physical_security: Option<PhysicalSecurity>,
pub location: Option<Location>,
pub height_mm: Option<Option<Decimal>>,
pub width_mm: Option<Option<Decimal>>,
pub depth_mm: Option<Option<Decimal>>,
pub weight_kg: Option<Option<Decimal>>,
pub uuid: Option<Option<Uuid>>,
pub environmental_class: Option<Option<EnvironmentalClass>>,
pub max_power_watts: Option<Option<Decimal>>,
pub min_power_watts: Option<Option<Decimal>>,
pub location_indicator_active: Option<Option<Boolean>>,
pub measurements: Option<Vec<MeasurementBlock>>,
pub spare_part_number: Option<Option<String>>,
pub electrical_source_manager_uris: Option<Option<Vec<String>>>,
pub electrical_source_names: Option<Option<Vec<String>>>,
pub powered_by_parent: Option<Option<Boolean>>,
pub thermal_managed_by_parent: Option<Option<Boolean>>,
pub thermal_direction: Option<Option<ThermalDirection>>,
pub version: Option<Option<String>>,
pub hot_pluggable: Option<Option<Boolean>>,
pub replaceable: Option<Option<Boolean>>,
pub doors: Option<Doors>,
pub heating_cooling_manager_uris: Option<Option<Vec<String>>>,
pub heating_cooling_equipment_names: Option<Option<Vec<String>>>,
pub ready_to_remove: Option<Option<Boolean>>,
pub rack_mount_capacity_units: Option<Option<Decimal>>,
pub rack_units: Option<Option<RackUnits>>,
pub rack_mount_width: Option<Option<RackMountWidth>>,
pub rack_mount_depth_mm: Option<Option<Decimal>>,
pub height_rack_units: Option<Option<Decimal>>,
pub log_services: Option<NavProperty<LogServiceCollection>>,
pub thermal: Option<NavProperty<Thermal>>,
pub power: Option<NavProperty<Power>>,
pub network_adapters: Option<NavProperty<NetworkAdapterCollection>>,
pub assembly: Option<NavProperty<Assembly>>,
pub pcie_slots: Option<ReferenceLeaf>,
pub sensors: Option<NavProperty<SensorCollection>>,
pub pcie_devices: Option<NavProperty<PcieDeviceCollection>>,
pub media_controllers: Option<ReferenceLeaf>,
pub memory: Option<NavProperty<MemoryCollection>>,
pub memory_domains: Option<ReferenceLeaf>,
pub drives: Option<NavProperty<DriveCollection>>,
pub power_subsystem: Option<NavProperty<PowerSubsystem>>,
pub thermal_subsystem: Option<NavProperty<ThermalSubsystem>>,
pub environment_metrics: Option<NavProperty<EnvironmentMetrics>>,
pub certificates: Option<ReferenceLeaf>,
pub controls: Option<ReferenceLeaf>,
pub fabric_adapters: Option<ReferenceLeaf>,
pub trusted_components: Option<ReferenceLeaf>,
pub processors: Option<NavProperty<ProcessorCollection>>,
pub leak_detectors: Option<NavProperty<LeakDetectorCollection>>,
}Expand description
The Chassis schema represents the physical components of a system. This resource represents the
sheet-metal confined spaces and logical zones such as racks, enclosures, chassis and all other
containers. Subsystems, such as sensors, that operate outside of a system’s data plane are linked
either directly or indirectly through this resource. A subsystem that operates outside of a
system’s data plane are not accessible to software that runs on the system. It also describes the
location, such as a slot, socket, or bay, where a unit can be installed, by populating a resource
instance with an absent state if a unit is not present.
This resource shall represent a chassis or other physical enclosure for a Redfish implementation.
It may also represent a location, such as a slot, socket, or bay, where a unit may be installed,
but the State property within the Status property contains Absent.
Fields
base: ResourceBase type
chassis_type: ChassisTypeThe type of physical form factor of the chassis.
This property shall indicate the physical form factor for the type of chassis.
manufacturer: Option<Option<String>>The manufacturer of this chassis.
This property shall contain the name of the organization responsible for producing the chassis. This organization may be the entity from whom the chassis is purchased, but this is not necessarily true.
model: Option<Option<String>>The model number of the chassis.
This property shall contain the name by which the manufacturer generally refers to the chassis.
sku: Option<Option<String>>The SKU of the chassis.
This property shall contain the stock-keeping unit number for this chassis.
serial_number: Option<Option<String>>The serial number of the chassis.
This property shall contain a manufacturer-allocated number that identifies the chassis.
part_number: Option<Option<String>>The part number of the chassis.
This property shall contain a part number assigned by the organization that is responsible for producing or manufacturing the chassis.
asset_tag: Option<Option<String>>The user-assigned asset tag of this chassis.
This property shall contain an identifying string that tracks the chassis for inventory purposes.
Modifying this property may modify the AssetTag in the resource that represents the functional
view of this chassis, such as a ComputerSystem resource.
indicator_led: Option<Option<IndicatorLed>>The state of the indicator LED, which identifies the chassis.
This property shall contain the indicator light state for the indicator light associated with this system.
links: Option<Links>The links to other resources that are related to this resource.
This property shall contain links to resources that are related to but are not contained by, or subordinate to, this resource.
actions: Option<Actions>The available actions for this resource.
This property shall contain the available actions for this resource.
status: Option<Status>The status and health of the resource and its subordinate or dependent resources.
This property shall contain any status or health properties of the resource.
power_state: Option<Option<PowerState>>The current power state of the chassis.
This property shall contain the power state of the chassis.
physical_security: Option<PhysicalSecurity>The physical security state of the chassis.
This property shall contain the physical security state of the chassis. Services may construct this state from multiple physical sensors.
location: Option<Location>The location of the chassis.
This property shall contain the location information of the associated chassis.
height_mm: Option<Option<Decimal>>The height of the chassis.
This property shall represent the height of the chassis, in millimeter units, as specified by the manufacturer.
width_mm: Option<Option<Decimal>>The width of the chassis.
This property shall represent the width of the chassis, in millimeter units, as specified by the manufacturer.
depth_mm: Option<Option<Decimal>>The depth of the chassis.
This property shall represent the depth (length) of the chassis, in millimeter units, as specified by the manufacturer.
weight_kg: Option<Option<Decimal>>The weight of the chassis.
This property shall represent the published mass, commonly referred to as weight, of the chassis, in kilogram units.
uuid: Option<Option<Uuid>>The UUID for this chassis.
This property shall contain the universally unique identifier number for this chassis.
environmental_class: Option<Option<EnvironmentalClass>>The ASHRAE Environmental Class for this chassis.
This property shall contain the ASHRAE Environmental Class for this chassis, as defined by ASHRAE Thermal Guidelines for Data Processing Environments. These classes define respective environmental limits that include temperature, relative humidity, dew point, and maximum allowable elevation.
max_power_watts: Option<Option<Decimal>>The upper bound of the total power consumed by the chassis.
This property shall contain the upper bound of the total power consumed by the chassis.
min_power_watts: Option<Option<Decimal>>The lower bound of the total power consumed by the chassis.
This property shall contain the lower bound of the total power consumed by the chassis.
location_indicator_active: Option<Option<Boolean>>An indicator allowing an operator to physically locate this resource.
This property shall contain the state of the indicator used to physically identify or locate this
resource. A write to this property shall update the value of IndicatorLED in this resource, if
supported, to reflect the implementation of the locating function. Modifying this property may
modify the LocationIndicatorActive in the resource that represents the functional view of this
chassis, such as a ComputerSystem resource.
measurements: Option<Vec<MeasurementBlock>>An array of DSP0274-defined measurement blocks.
This property shall contain an array of DSP0274-defined measurement blocks.
spare_part_number: Option<Option<String>>The spare part number of the chassis.
This property shall contain the spare part number of the chassis.
electrical_source_manager_uris: Option<Option<Vec<String>>>The URIs of the management interfaces for the external electrical source connections for this chassis.
This property shall contain an array of URIs to the management applications or devices that provide monitoring or control of the external electrical sources that provide power to this chassis.
electrical_source_names: Option<Option<Vec<String>>>The names of the external electrical sources, such as circuits or outlets, connected to this chassis.
This property shall contain an array of strings that identify the external electrical sources, such as the names of circuits or outlets, that provide power to this chassis.
powered_by_parent: Option<Option<Boolean>>Indicates that the chassis receives power from the containing chassis.
This property shall indicate whether the chassis receives power from the chassis that contains it.
The value true shall indicate that the containing chassis provides power. The value false
shall indicate the chassis receives power from its own power subsystem, another chassis instance’s
power supplies, or outlets.
thermal_managed_by_parent: Option<Option<Boolean>>Indicates that the chassis is thermally managed by the parent chassis.
This property shall indicate whether the chassis relies on the containing chassis to provide
thermal management. The value true shall indicate that the chassis relies on the containing
chassis to provide thermal management. The value false shall indicate the chassis provides
thermal management, and may provide details in a ThermalSubsystem resource, or by populating the
Fans property in Links.
thermal_direction: Option<Option<ThermalDirection>>Indicates the thermal management path through the chassis.
This property shall indicate the general direction of the thermal management path through the chassis.
version: Option<Option<String>>The hardware version of this chassis.
This property shall contain the hardware version of this chassis as determined by the vendor or supplier.
hot_pluggable: Option<Option<Boolean>>An indication of whether this component can be inserted or removed while the equipment is in operation.
This property shall indicate whether the component can be inserted or removed while the underlying equipment otherwise remains in its current operational state. Components indicated as hot-pluggable shall allow the component to become operable without altering the operational state of the underlying equipment. Components that cannot be inserted or removed from equipment in operation, or components that cannot become operable without affecting the operational state of that equipment, shall be indicated as not hot-pluggable.
replaceable: Option<Option<Boolean>>An indication of whether this component can be independently replaced as allowed by the vendor’s replacement policy.
This property shall indicate whether this component can be independently replaced as allowed by the
vendor’s replacement policy. A value of false indicates the component needs to be replaced by
policy as part of another component. If the LocationType property of this component contains
Embedded, this property shall contain false.
doors: Option<Doors>The doors or access panels of the chassis.
This property shall contain information about the doors or access panels of the chassis.
heating_cooling_manager_uris: Option<Option<Vec<String>>>The URIs of the management interfaces for the external heating or cooling equipment for this chassis.
This property shall contain an array of URIs to the management applications or devices that provide monitoring or control of the external heating or cooling equipment that provide thermal management for this chassis.
heating_cooling_equipment_names: Option<Option<Vec<String>>>The names of the external heating or cooling equipment, such as coolant distribution units, connected to this chassis.
This property shall contain an array of strings that identify the external heating or cooling equipment, such as the names of specific coolant distribution units, that provide thermal management for this chassis.
ready_to_remove: Option<Option<Boolean>>An indication of whether the chassis is prepared by the system for removal.
This property shall indicate whether the chassis is ready for removal. Setting the value to true
shall cause the service to perform appropriate actions to quiesce the device. A task may spawn
while the device is quiescing.
rack_mount_capacity_units: Option<Option<Decimal>>The usable capacity of rack units provided by this chassis.
This property shall contain the amount of space, in RackUnits and including fractional units,
contained within this chassis that are usable to hold rack-mountable equipment. This property
shall not be present if ChassisType does not contain Rack.
rack_units: Option<Option<RackUnits>>The type of rack-mount units.
This property shall contain the type of units used to describe rack-mountable equipment.
rack_mount_width: Option<Option<RackMountWidth>>The width of the rack-mountable chassis or rack-mounting space.
This property shall contain the type of width that describes the rack-mountable equipment space.
rack_mount_depth_mm: Option<Option<Decimal>>The usable depth of the rack-mountable area of the chassis.
This property shall represent the depth (length) of the chassis, in millimeter units, that is available to contain rack-mounted equipment.
height_rack_units: Option<Option<Decimal>>The height of the rack-mountable chassis in rack units.
This property shall contain the height of the rack-mountable chassis, in rack units specified by
the value of RackUnits.
log_services: Option<NavProperty<LogServiceCollection>>The link to the logs for this chassis.
This property shall contain a link to a resource collection of type LogServiceCollection.
thermal: Option<NavProperty<Thermal>>The link to the thermal properties, such as fans, cooling, and sensors, for this chassis.
This property shall contain a link to a resource of type Thermal that represents the thermal
characteristics of this chassis.
power: Option<NavProperty<Power>>The link to the power properties, or power supplies, power policies, and sensors, for this chassis.
This property shall contain a link to a resource of type Power that represents the power
characteristics of this chassis.
network_adapters: Option<NavProperty<NetworkAdapterCollection>>The link to the collection of network adapters associated with this chassis.
This property shall contain a link to a resource collection of type NetworkAdapterCollection.
assembly: Option<NavProperty<Assembly>>The link to the assembly associated with this chassis.
This property shall contain a link to a resource of type Assembly.
pcie_slots: Option<ReferenceLeaf>sensors: Option<NavProperty<SensorCollection>>The link to the collection of sensors located in the equipment and sub-components.
This property shall contain a link to a resource collection of type SensorCollection that
contains the sensors located in the chassis and sub-components.
pcie_devices: Option<NavProperty<PcieDeviceCollection>>The link to the collection of PCIe devices located in this chassis.
This property shall contain a link to a resource collection of type PCIeDeviceCollection.
media_controllers: Option<ReferenceLeaf>memory: Option<NavProperty<MemoryCollection>>The link to the collection of memory located in this chassis that belong to fabric-related resource pools.
This property shall contain a link to a resource collection of type MemoryCollection that
represents memory in this chassis that belong to fabric-related resource pools.
memory_domains: Option<ReferenceLeaf>drives: Option<NavProperty<DriveCollection>>The link to the collection of drives within this chassis.
This property shall contain a link to a resource collection of type DriveCollection.
power_subsystem: Option<NavProperty<PowerSubsystem>>The link to the power subsystem properties for this chassis.
This property shall contain a link to a resource of type PowerSubsystem that represents the power
subsystem information for this chassis.
thermal_subsystem: Option<NavProperty<ThermalSubsystem>>The link to the thermal subsystem properties for this chassis.
This property shall contain a link to a resource of type ThermalSubsystem that represents the
thermal subsystem information for this chassis.
environment_metrics: Option<NavProperty<EnvironmentMetrics>>The link to the environment metrics for this chassis.
This property shall contain a link to a resource of type EnvironmentMetrics that specifies the
environment metrics for this chassis, all containing chassis, and devices contained by any of these
chassis instances. When determining power and energy readings, care should be taken to ensure any
reported values do not overlap or result in double-counting.
certificates: Option<ReferenceLeaf>controls: Option<ReferenceLeaf>fabric_adapters: Option<ReferenceLeaf>trusted_components: Option<ReferenceLeaf>processors: Option<NavProperty<ProcessorCollection>>The link to the collection of processors located in this chassis that belong to fabric-related resource pools.
This property shall contain a link to a resource collection of type ProcessorCollection that
represents processors in this chassis that belong to fabric-related resource pools.
leak_detectors: Option<NavProperty<LeakDetectorCollection>>The link to the collection of leak detectors located in this chassis.
This property shall contain a link to a resource collection of type LeakDetectorCollection.