Doors

Struct Doors 

pub struct Doors {
    pub front: Option<Option<Door>>,
    pub rear: Option<Option<Door>>,
}
The doors or access panels of the chassis.

This type shall describe the doors or access panels of the chassis.

Fields

front: Option<Option<Door>>

The front door of the chassis.

This property shall contain information related to the front door, as defined by the manufacturer, of the chassis.

rear: Option<Option<Door>>

The rear door of the chassis.

This property shall contain information related to the rear door, as defined by the manufacturer, of the chassis.