PhysicalSecurity

Struct PhysicalSecurity 

pub struct PhysicalSecurity {
    pub intrusion_sensor_number: Option<Option<Int64>>,
    pub intrusion_sensor: Option<Option<IntrusionSensor>>,
    pub intrusion_sensor_re_arm: Option<Option<IntrusionSensorReArm>>,
}
The physical security state of the chassis.

This type shall describe the physical security state of the chassis.

Fields

intrusion_sensor_number: Option<Option<Int64>>

A numerical identifier to represent the physical security sensor.

This property shall contain a numerical identifier for this physical security sensor that is unique within this resource.

intrusion_sensor: Option<Option<IntrusionSensor>>

The physical security state of the chassis, such as if hardware intrusion is detected.

This property shall contain the physical security state of the chassis. If the IntrusionSensorReArm property contains Manual, a client may set this property to Normal to reset the physical security state.

intrusion_sensor_re_arm: Option<Option<IntrusionSensorReArm>>

The policy that describes how the physical security state of the chassis returns to a normal state.

This property shall contain the policy that describes how the IntrusionSensor property returns to the Normal value.