pub struct ChassisCollection {
pub base: ResourceCollection,
pub members: Vec<NavProperty<Chassis>>,
}Expand description
The collection of Chassis resource instances.
This resource shall represent a resource collection of Chassis instances for a Redfish
implementation.
Fields
base: ResourceCollectionBase type
members: Vec<NavProperty<Chassis>>The members of this collection.
This property shall contain an array of links to the members of this collection.