PlugType

Enum PlugType 

pub enum PlugType {
Show 33 variants Nema515p, NemaL515p, Nema520p, NemaL520p, NemaL530p, Nema615p, NemaL615p, Nema620p, NemaL620p, NemaL630p, NemaL1420p, NemaL1430p, NemaL1520p, NemaL1530p, NemaL2120p, NemaL2130p, NemaL2220p, NemaL2230p, CaliforniaCs8265, CaliforniaCs8365, Iec60320C14, Iec60320C20, Iec60309316p6, Iec60309332p6, Iec60309363p6, Iec60309516p6, Iec60309532p6, Iec60309563p6, Iec60309460p9, Iec60309560p9, Field208v3p4w60a, Field400v3p5w32a, UnsupportedValue,
}

Variants



Nema515p

NEMA 5-15P (Single-phase 125V; 15A; 1P3W).

This value shall represent a plug that matches the NEMA specified 5-15 straight (non-locking) plug (Single-phase 125V; 15A; 1P3W).



NemaL515p

NEMA L5-15P (Single-phase 125V; 15A; 1P3W).

This value shall represent a plug that matches the NEMA specified locking L5-15 plug (Single-phase 125V; 15A; 1P3W).



Nema520p

NEMA 5-20P (Single-phase 125V; 20A; 1P3W).

This value shall represent a plug that matches the NEMA specified 5-20 straight (non-locking) plug that exhibits a T-slot (Single-phase 125V; 20A; 1P3W).



NemaL520p

NEMA L5-20P (Single-phase 125V; 20A; 1P3W).

This value shall represent a plug that matches the NEMA specified locking L5-20 plug (Single-phase 125V; 20A; 1P3W).



NemaL530p

NEMA L5-30P (Single-phase 125V; 30A; 1P3W).

This value shall represent a plug that matches the NEMA specified locking L5-30 plug (Single-phase 125V; 30A; 1P3W).



Nema615p

NEMA 6-15P (Single-phase 250V; 15A; 2P3W).

This value shall represent a plug that matches the NEMA specified 6-15 straight (non-locking) plug (Single-phase 250V; 15A; 2P3W).



NemaL615p

NEMA L6-15P (Single-phase 250V; 15A; 2P3W).

This value shall represent a plug that matches the NEMA specified locking L6-15 plug (Single-phase 250V; 15A; 2P3W).



Nema620p

NEMA 6-20P (Single-phase 250V; 20A; 2P3W).

This value shall represent a plug that matches the NEMA specified 6-20 straight (non-locking) plug (Single-phase 250V; 20A; 2P3W).



NemaL620p

NEMA L6-20P (Single-phase 250V; 20A; 2P3W).

This value shall represent a plug that matches the NEMA specified locking L6-20 plug (Single-phase 250V; 20A; 2P3W).



NemaL630p

NEMA L6-30P (Single-phase 250V; 30A; 2P3W).

This value shall represent a plug that matches the NEMA specified locking L6-30 plug (Single-phase 250V; 30A; 2P3W).



NemaL1420p

NEMA L14-20P (Split-phase 125/250V; 20A; 2P4W).

This value shall represent a plug that matches the NEMA specified locking L14-20 plug (Split-phase 125/250V; 20A; 2P4W).



NemaL1430p

NEMA L14-30P (Split-phase 125/250V; 30A; 2P4W).

This value shall represent a plug that matches the NEMA specified locking L14-30 plug (Split-phase 125/250V; 30A; 2P4W).



NemaL1520p

NEMA L15-20P (Three-phase 250V; 20A; 3P4W).

This value shall represent a plug that matches the NEMA specified locking L15-20 plug (Three-phase 250V; 20A; 3P4W).



NemaL1530p

NEMA L15-30P (Three-phase 250V; 30A; 3P4W).

This value shall represent a plug that matches the NEMA specified locking L15-30 plug (Three-phase 250V; 30A; 3P4W).



NemaL2120p

NEMA L21-20P (Three-phase 120/208V; 20A; 3P5W).

This value shall represent a plug that matches the NEMA specified locking L21-20 plug (Three-phase 120/208V; 20A; 3P5W).



NemaL2130p

NEMA L21-30P (Three-phase 120/208V; 30A; 3P5W).

This value shall represent a plug that matches the NEMA specified locking L21-30 plug (Three-phase 120/208V; 30A; 3P5W).



NemaL2220p

NEMA L22-20P (Three-phase 277/480V; 20A; 3P5W).

This value shall represent a plug that matches the NEMA specified locking L22-20 plug (Three-phase 277/480V; 20A; 3P5W).



NemaL2230p

NEMA L22-30P (Three-phase 277/480V; 30A; 3P5W).

This value shall represent a plug that matches the NEMA specified locking L22-30 plug (Three-phase 277/480V; 30A; 3P5W).



CaliforniaCs8265

California Standard CS8265 (Single-phase 250V; 50A; 2P3W).

This value shall represent a plug that matches the ‘California Standard’ CS8265 style plug (Single-phase 250V; 50A; 2P3W).



CaliforniaCs8365

California Standard CS8365 (Three-phase 250V; 50A; 3P4W).

This value shall represent a plug that matches the ‘California Standard’ CS8365 style plug (Three-phase 250V; 50A; 3P4W).



Iec60320C14

IEC C14 (Single-phase 250V; 10A; 1P3W).

This value shall represent a plug that matches the IEC 60320 specified C14 input (Single-phase 250V; 10A; 1P3W).



Iec60320C20

IEC C20 (Single-phase 250V; 16A; 1P3W).

This value shall represent a plug that matches the IEC 60320 specified C20 input (Single-phase 250V; 16A; 1P3W).



Iec60309316p6

IEC 60309 316P6 (Single-phase 200-250V; 16A; 1P3W; Blue, 6-hour).

This value shall represent a plug that matches the IEC 60309 316P6 plug (Single-phase 200-250V; 16A; 1P3W; Blue, 6-hour).



Iec60309332p6

IEC 60309 332P6 (Single-phase 200-250V; 32A; 1P3W; Blue, 6-hour).

This value shall represent a plug that matches the IEC 60309 332P6 plug (Single-phase 200-250V; 32A; 1P3W; Blue, 6-hour).



Iec60309363p6

IEC 60309 363P6 (Single-phase 200-250V; 63A; 1P3W; Blue, 6-hour).

This value shall represent a plug that matches the IEC 60309 363P6 plug (Single-phase 200-250V; 63A; 1P3W; Blue, 6-hour).



Iec60309516p6

IEC 60309 516P6 (Three-phase 200-240/346-415V; 16A; 3P5W; Red; 6-hour).

This value shall represent a plug that matches the IEC 60309 516P6 plug (Three-phase 200-240/346-415V; 16A; 3P5W; Red; 6-hour).



Iec60309532p6

IEC 60309 532P6 (Three-phase 200-240/346-415V; 32A; 3P5W; Red; 6-hour).

This value shall represent a plug that matches the IEC 60309 plug 532P6 (Three-phase 200-240/346-415V; 32A; 3P5W; Red; 6-hour).



Iec60309563p6

IEC 60309 563P6 (Three-phase 200-240/346-415V; 63A; 3P5W; Red; 6-hour).

This value shall represent a plug that matches the IEC 60309 563P6 plug (Three-phase 200-240/346-415V; 63A; 3P5W; Red; 6-hour).



Iec60309460p9

IEC 60309 460P9 (Three-phase 200-250V; 60A; 3P4W; Blue; 9-hour).

This value shall represent a plug that matches the IEC 60309 460P9 plug (Three-phase 200-250V; 60A; 3P4W; Blue; 9-hour).



Iec60309560p9

IEC 60309 560P9 (Three-phase 120-144/208-250V; 60A; 3P5W; Blue; 9-hour).

This value shall represent a plug that matches the IEC 60309 plug 560P9 (Three-phase 120-144/208-250V; 60A; 3P5W; Blue; 9-hour).



Field208v3p4w60a

Field-wired; Three-phase 200-250V; 60A; 3P4W.

This value shall represent field-wired input that is three-phase 200-250V; 60A; 3P4W.



Field400v3p5w32a

Field-wired; Three-phase 200-240/346-415V; 32A; 3P5W.

This value shall represent field-wired input that is three-phase 200-240/346-415V; 32A; 3P5W.



UnsupportedValue

Fallback value for values that are not supported by current version of Redfish schema.