pub enum AutomaticRetryConfig {
Disabled,
RetryAttempts,
RetryAlways,
UnsupportedValue,
}Variants
Disabled
Disable automatic retrying of booting.
This value shall indicate that automatic retrying of booting is disabled.
RetryAttempts
Automatic retrying of booting is based on a specified retry count.
This value shall indicate that the number of retries of booting is based on the
AutomaticRetryAttempts property, and the RemainingAutomaticRetryAttempts property indicates the
number of remaining attempts.
RetryAlways
Always automatically retry booting.
This value shall indicate that the system will always automatically retry booting.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.