pub enum BootOrderTypes {
BootOrder,
AliasBootOrder,
UnsupportedValue,
}Expand description
The enumerations of BootOrderTypes specify the choice of boot order property to use when controller the persistent boot order for this computer system.
Variants
BootOrder
The system uses the BootOrder property to specify the persistent boot order.
AliasBootOrder
The system uses the AliasBootOrder property to specify the persistent boot order.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.