pub enum BootProgressTypes {
None,
PrimaryProcessorInitializationStarted,
BusInitializationStarted,
MemoryInitializationStarted,
SecondaryProcessorInitializationStarted,
PciResourceConfigStarted,
SystemHardwareInitializationComplete,
SetupEntered,
OsBootStarted,
OsRunning,
Oem,
UnsupportedValue,
}Variants
None
The system is not booting.
This value shall indicate that the system is not booting or running, such as the system is powered off.
PrimaryProcessorInitializationStarted
The system has started initializing the primary processor.
This value shall indicate that the system has started to initialize the primary processor.
BusInitializationStarted
The system has started initializing the buses.
This value shall indicate that the system has started to initialize the buses.
MemoryInitializationStarted
The system has started initializing the memory.
This value shall indicate that the system has started to initialize the memory.
SecondaryProcessorInitializationStarted
The system has started initializing the remaining processors.
This value shall indicate that the system has started to initialize the secondary processors.
PciResourceConfigStarted
The system has started initializing the PCI resources.
This value shall indicate that the system has started to initialize the PCI resources.
SystemHardwareInitializationComplete
The system has completed initializing all hardware.
This value shall indicate that the system has completed initializing all hardware.
SetupEntered
The system has entered the setup utility.
This value shall indicate that the system has entered the setup utility.
OsBootStarted
The operating system has started booting.
This value shall indicate that the operating system has started to boot.
OsRunning
The operating system is running.
This value shall indicate that the operating system is running and shall indicate the final boot progress state.
Oem
A boot progress state in an OEM-defined format.
This value shall indicate an OEM-defined boot progress state.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.