pub enum BootSource {
Show 17 variants
None,
Pxe,
Floppy,
Cd,
Usb,
Hdd,
BiosSetup,
Utilities,
Diags,
UefiShell,
UefiTarget,
SdCard,
UefiHttp,
RemoteDrive,
UefiBootNext,
Recovery,
UnsupportedValue,
}Variants
None
Boot from the normal boot device.
Pxe
Boot from the Pre-boot eXecution Environment (PXE).
Floppy
Boot from the floppy disk drive.
Cd
Boot from the CD or DVD.
Usb
Boot from a system BIOS-specified USB device.
Hdd
Boot from a hard drive.
BiosSetup
Boot to the BIOS setup utility.
Utilities
Boot to the manufacturer’s utilities program or programs.
Diags
Boot to the manufacturer’s diagnostics program.
UefiShell
Boot to the UEFI Shell.
UefiTarget
Boot to the UEFI device specified in the UefiTargetBootSourceOverride property.
SdCard
Boot from an SD card.
UefiHttp
Boot from a UEFI HTTP network location.
RemoteDrive
Boot from a remote drive, such as an iSCSI target.
UefiBootNext
Boot to the UEFI device that the BootNext property specifies.
Recovery
Boot to a system-designated recovery process or image.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.