pub enum BootSourceOverrideEnabled {
Disabled,
Once,
Continuous,
UnsupportedValue,
}Variants
Disabled
The system boots normally.
Once
On its next boot cycle, the system boots one time to the boot source override target. Then, the BootSourceOverrideEnabled value is reset to Disabled.
Continuous
The system boots to the target specified in the BootSourceOverrideTarget property until this property is Disabled.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.