pub enum Component {
All,
Manager,
Bios,
Network,
Storage,
UnsupportedValue,
}Variants
All
Export configuration data for all devices attached to the system including OEM components.
The service shall export all available configuration data from the system including OEM components.
Manager
Export configuration data associated with the manager of the system.
The service shall export configuration data associated with any managers in the system.
Bios
Export configuration data associated with the BIOS for the system.
The service shall export configuration data associated with the BIOS for the system.
Network
Export configuration data associated with the all network devices of the system.
The service shall export configuration data associated with the network devices for the system.
Storage
Export configuration data associated with the all storage devices of the system.
The service shall export configuration data associated with the storage devices for the system.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.