pub enum CompositionUseCase {
ResourceBlockCapable,
ExpandableSystem,
UnsupportedValue,
}Variants
ResourceBlockCapable
This computer system supports being registered as a resource block in order for it to participate in composition requests.
This value shall indicate the computer system supports being registered as a resource block in order for it to participate in composition requests.
ExpandableSystem
This computer system supports expandable system composition and is associated with a resource block.
This value shall indicate the computer system supports expandable system composition and is associated with a resource block.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.