pub enum DecommissionType {
All,
UserData,
ManagerConfig,
BiosConfig,
NetworkConfig,
StorageConfig,
Logs,
Tpm,
UnsupportedValue,
}Variants
All
Remove all possible data from the server.
This value shall indicate the service removes all the data that it can from the system. This shall include all possible OEM data as well.
UserData
Remove all possible data from block devices and other user or operating system accessible storage attached to the system.
This value shall indicate the service removes all the data from block devices or other operating
system accessible storage. If the RequireSecureErase parameter contains true, this shall be
equivalent to performing the SecureErase action on each drive.
ManagerConfig
Reset all manager settings to factory defaults.
This value shall indicate the service resets all associated managers to factory defaults. This
shall be equivalent to performing the ResetToDefaults action on each Manager resource with the
ResetType parameter of ResetAll.
BiosConfig
Reset all BIOS settings to factory defaults.
This value shall indicate the service resets all BIOS settings to factory defaults. This shall be
equivalent to performing the ResetBios action on each Bios resource.
NetworkConfig
Reset all network settings to factory defaults.
This value shall indicate the service resets all network settings on all network devices to factory defaults.
StorageConfig
Reset all storage controller settings to factory defaults. This will leave the user data intact unless that is also specified.
This value shall indicate the service resets all storage controller settings to factory defaults.
This shall be equivalent to performing the ResetToDefaults action on each Storage resource with
the ResetType parameter of PreserveVolumes.
Logs
Clear all logs.
This value shall indicate the service clears all logs. This shall be equivalent to performing the
ClearLog action on each LogService resource.
Tpm
Reset all user-accessible TPM settings to factory defaults.
This value shall indicate the service resets all user-accessible TPM device settings to factory defaults. All sensitive data stored within the applicable TPMs shall be erased.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.