pub enum ExportSecurity {
IncludeSensitiveData,
HashedDataOnly,
ExcludeSensitiveData,
UnsupportedValue,
}Variants
IncludeSensitiveData
Export all data regardless of the sensitivity.
The service shall export all requested data regardless of the sensitivity.
HashedDataOnly
Export hashed passwords, but exclude other sensitive data.
The service shall export requested data including hashed passwords, but shall exclude other sensitive data.
ExcludeSensitiveData
Export only non-sensitive data.
The service shall export only non-sensitive data.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.