pub enum HostingRole {
ApplicationServer,
StorageServer,
Switch,
Appliance,
BareMetalServer,
VirtualMachineServer,
ContainerServer,
UnsupportedValue,
}Expand description
The enumerations of HostingRole specify different features that the hosting computer system supports.
Variants
ApplicationServer
The system hosts functionality that supports general purpose applications.
StorageServer
The system hosts functionality that supports the system acting as a storage server.
Switch
The system hosts functionality that supports the system acting as a switch.
Appliance
The system hosts functionality that supports the system acting as an appliance.
BareMetalServer
The system hosts functionality that supports the system acting as a bare-metal server.
VirtualMachineServer
The system hosts functionality that supports the system acting as a virtual machine server.
ContainerServer
The system hosts functionality that supports the system acting as a container server.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.