pub enum KmipCachePolicy {
None,
AfterFirstUse,
UnsupportedValue,
}Variants
None
The system does not cache KMIP data.
AfterFirstUse
The system caches KMIP data after first use for the duration specified by the CacheDuration property.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.