pub enum MemoryMirroring {
System,
Dimm,
Hybrid,
None,
UnsupportedValue,
}Variants
System
The system supports DIMM mirroring at the system level. Individual DIMMs are not paired for mirroring in this mode.
Dimm
The system supports DIMM mirroring at the DIMM level. Individual DIMMs can be mirrored.
Hybrid
The system supports a hybrid mirroring at the system and DIMM levels. Individual DIMMs can be mirrored.
None
The system does not support DIMM mirroring.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.