pub enum StopBootOnFault {
Never,
AnyFault,
UnsupportedValue,
}Variants
Never
The system performs any normal recovery actions during boot if a fault occurs.
This value shall indicate the system will continue to attempt to boot if a fault occurs.
AnyFault
The system should stop the boot on any fault.
This value shall indicate the system will stop the boot if a fault occurs. This includes, but is not limited to, faults that affect performance, fault tolerance, or capacity.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.