pub enum SystemType {
Physical,
Virtual,
Os,
PhysicallyPartitioned,
VirtuallyPartitioned,
Composed,
Dpu,
UnsupportedValue,
}Variants
Physical
A computer system.
A SystemType of Physical typically represents the hardware aspects of a system, such as a
management controller.
Virtual
A virtual machine instance running on this system.
A SystemType of Virtual typically represents a system that is actually a virtual machine
instance. Responses should contain the ProcessorSummary and MemorySummary properties to show
the processor and memory resources allocated to the virtual machine.
Os
An operating system instance.
A SystemType of OS typically represents an OS or hypervisor view of the system.
PhysicallyPartitioned
A hardware-based partition of a computer system.
A SystemType of PhysicallyPartitioned typically represents a single system constructed from one
or more physical systems through a firmware or hardware-based service.
VirtuallyPartitioned
A virtual or software-based partition of a computer system.
A SystemType of VirtuallyPartitioned typically represents a single system constructed from one
or more virtual systems through a software-based service.
Composed
A computer system constructed by binding resource blocks together.
A SystemType of Composed typically represents a single system constructed from disaggregated
resources through the Redfish composition service.
Dpu
A computer system that performs the functions of a data processing unit, such as a SmartNIC.
A SystemType of DPU typically represents a single system that performs offload computation as a
data processing unit, such as a SmartNIC.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.