pub enum WatchdogTimeoutActions {
None,
ResetSystem,
PowerCycle,
PowerDown,
Oem,
UnsupportedValue,
}Expand description
The enumerations of WatchdogTimeoutActions specify the choice of action to take when the host watchdog timer reaches its timeout value.
Variants
None
No action taken.
ResetSystem
Reset the system.
PowerCycle
Power cycle the system.
PowerDown
Power down the system.
Oem
Perform an OEM-defined action.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.