pub enum WatchdogWarningActions {
None,
DiagnosticInterrupt,
Smi,
MessagingInterrupt,
Sci,
Oem,
UnsupportedValue,
}Expand description
The enumerations of WatchdogWarningActions specify the choice of action to take when the host watchdog timer is close (typically 3-10 seconds) to reaching its timeout value.
Variants
None
No action taken.
DiagnosticInterrupt
Raise a (typically non-maskable) Diagnostic Interrupt.
Smi
Raise a Systems Management Interrupt (SMI).
MessagingInterrupt
Raise a legacy IPMI messaging interrupt.
Sci
Raise an interrupt using the ACPI System Control Interrupt (SCI).
Oem
Perform an OEM-defined action.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.