pub struct Composition {
pub use_cases: Option<Option<Vec<CompositionUseCase>>>,
}Expand description
Information about the composition capabilities and state of a computer system.
This type shall contain information about the composition capabilities and state of a computer system.
Fields
use_cases: Option<Option<Vec<CompositionUseCase>>>The composition use cases in which this computer system can participate.
This property shall contain the composition use cases in which this computer system can participate.