pub struct ComputerSystem {Show 62 fields
pub base: Resource,
pub system_type: Option<SystemType>,
pub links: Option<Links>,
pub asset_tag: Option<Option<String>>,
pub manufacturer: Option<Option<String>>,
pub model: Option<Option<String>>,
pub sku: Option<Option<String>>,
pub serial_number: Option<Option<String>>,
pub part_number: Option<Option<String>>,
pub uuid: Option<Option<Uuid>>,
pub host_name: Option<Option<String>>,
pub indicator_led: Option<Option<IndicatorLed>>,
pub power_state: Option<Option<PowerState>>,
pub boot: Option<Boot>,
pub bios_version: Option<Option<String>>,
pub processor_summary: Option<ProcessorSummary>,
pub memory_summary: Option<MemorySummary>,
pub actions: Option<Actions>,
pub status: Option<Status>,
pub trusted_modules: Option<Vec<TrustedModules>>,
pub hosting_roles: Option<Vec<HostingRole>>,
pub hosted_services: Option<HostedServices>,
pub host_watchdog_timer: Option<WatchdogTimer>,
pub sub_model: Option<Option<String>>,
pub power_restore_policy: Option<PowerRestorePolicyTypes>,
pub last_reset_time: Option<DateTimeOffset>,
pub location_indicator_active: Option<Option<Boolean>>,
pub boot_progress: Option<Option<BootProgress>>,
pub power_on_delay_seconds: Option<Option<Decimal>>,
pub power_off_delay_seconds: Option<Option<Decimal>>,
pub power_cycle_delay_seconds: Option<Option<Decimal>>,
pub serial_console: Option<HostSerialConsole>,
pub graphical_console: Option<HostGraphicalConsole>,
pub virtual_media_config: Option<VirtualMediaConfig>,
pub measurements: Option<Vec<MeasurementBlock>>,
pub power_mode: Option<Option<PowerMode>>,
pub idle_power_saver: Option<Option<IdlePowerSaver>>,
pub key_management: Option<Option<KeyManagement>>,
pub composition: Option<Option<Composition>>,
pub manufacturing_mode: Option<Option<Boolean>>,
pub last_reset_cause: Option<LastResetCauses>,
pub ipmi_host_interface: Option<IpmiHostInterface>,
pub multipart_import_configuration_push_uri: Option<String>,
pub processors: Option<NavProperty<ProcessorCollection>>,
pub ethernet_interfaces: Option<NavProperty<EthernetInterfaceCollection>>,
pub simple_storage: Option<ReferenceLeaf>,
pub log_services: Option<NavProperty<LogServiceCollection>>,
pub secure_boot: Option<NavProperty<SecureBoot>>,
pub bios: Option<NavProperty<Bios>>,
pub memory: Option<NavProperty<MemoryCollection>>,
pub storage: Option<NavProperty<StorageCollection>>,
pub pcie_devices: Option<Vec<NavProperty<PcieDevice>>>,
pub pcie_functions: Option<Vec<ReferenceLeaf>>,
pub memory_domains: Option<ReferenceLeaf>,
pub network_interfaces: Option<ReferenceLeaf>,
pub redundancy: Option<Vec<ReferenceLeaf>>,
pub fabric_adapters: Option<ReferenceLeaf>,
pub virtual_media: Option<ReferenceLeaf>,
pub certificates: Option<ReferenceLeaf>,
pub graphics_controllers: Option<ReferenceLeaf>,
pub usb_controllers: Option<ReferenceLeaf>,
pub operating_system: Option<ReferenceLeaf>,
}Expand description
The ComputerSystem schema represents a computer or system instance and the software-visible
resources, or items within the data plane, such as memory, CPU, and other devices that it can
access. Details of those resources or subsystems are also linked through this resource.
This resource shall represent a computing system in the Redfish Specification.
Fields
base: ResourceBase type
system_type: Option<SystemType>The type of computer system that this resource represents.
An enumeration that indicates the kind of system that this resource represents.
links: Option<Links>The links to other resources that are related to this resource.
This property shall contain links to resources that are related to but are not contained by, or subordinate to, this resource.
asset_tag: Option<Option<String>>The user-definable tag that can track this computer system for inventory or other client purposes.
This property shall contain the system asset tag value. Modifying this property may modify the
AssetTag in the containing Chassis resource.
manufacturer: Option<Option<String>>The manufacturer or OEM of this system.
This property shall contain a value that represents the manufacturer of the system.
model: Option<Option<String>>The product name for this system, without the manufacturer name.
This property shall describe how the manufacturer refers to this system. Typically, this value is the product name for this system without the manufacturer name.
sku: Option<Option<String>>The manufacturer SKU for this system.
This property shall contain the SKU for the system.
serial_number: Option<Option<String>>The serial number for this system.
This property shall contain the serial number for the system.
part_number: Option<Option<String>>The part number for this system.
This property shall contain the manufacturer-defined part number for the system.
uuid: Option<Option<Uuid>>The UUID for this system.
This property shall contain the universally unique identifier number for this system. RFC4122
describes methods to create this value. The value should be considered to be opaque. Client
software should only treat the overall value as a UUID and should not interpret any subfields
within the UUID. If the system supports SMBIOS, the property value should follow the SMBIOS 2.6
and later recommendation for converting the SMBIOS 16-byte UUID structure into the Redfish
canonical xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx string format, so that the property value matches
the byte order presented by current OS APIs, such as WMI and dmidecode. For additional property
requirements, see the corresponding definition in the Redfish Data Model Specification.
host_name: Option<Option<String>>The DNS host name, without any domain information.
This property shall contain the host name for this system, as reported by the operating system or
hypervisor. A service running in the host operating system typically reports this value to the
manager. Modifying this property may modify the HostName in one or more EthernetInterface
resources contained in this system.
indicator_led: Option<Option<IndicatorLed>>The state of the indicator LED, which identifies the system.
This property shall contain the state of the indicator light, which identifies this system.
power_state: Option<Option<PowerState>>The current power state of the system.
This property shall contain the power state of the system.
boot: Option<Boot>The boot settings for this system.
This property shall contain the boot settings for this system.
bios_version: Option<Option<String>>The version of the system BIOS or primary system firmware.
This property shall contain the version string of the currently installed and running BIOS for x86 systems. For other systems, the property may contain a version string that represents the primary system firmware.
processor_summary: Option<ProcessorSummary>The central processors of the system in general detail.
This property shall describe the central processors for this resource. Processors described by this property shall be limited to the processors that execute system code, and shall not include processors used for offload functionality.
memory_summary: Option<MemorySummary>The central memory of the system in general detail.
This property shall describe the central memory for this resource.
actions: Option<Actions>The available actions for this resource.
This property shall contain the available actions for this resource.
status: Option<Status>The status and health of the resource and its subordinate or dependent resources.
This property shall contain any status or health properties of the resource.
trusted_modules: Option<Vec<TrustedModules>>An array of trusted modules in the system.
This object shall contain an array of objects with properties that describe the trusted modules for this resource.
hosting_roles: Option<Vec<HostingRole>>The hosting roles that this computer system supports.
This property shall contain the hosting roles that this computer system supports.
hosted_services: Option<HostedServices>The services that this computer system supports.
This property shall describe services that this computer system supports.
host_watchdog_timer: Option<WatchdogTimer>The host watchdog timer functionality for this system.
This object shall contain properties that describe the host watchdog timer functionality for this system.
sub_model: Option<Option<String>>The sub-model for this system.
This property shall contain the information about the sub-model (or configuration) of the system. This shall not include the model/product name or the manufacturer name.
power_restore_policy: Option<PowerRestorePolicyTypes>The desired power state of the system when power is restored after a power loss.
This property shall indicate the desired power state of the system when power is applied to the
system. The LastState value shall return the system to the PowerState property value it was in
when power was lost.
last_reset_time: Option<DateTimeOffset>The date and time when the system was last reset or rebooted.
This property shall contain the date and time when the system last came out of a reset or was rebooted.
location_indicator_active: Option<Option<Boolean>>An indicator allowing an operator to physically locate this resource.
This property shall contain the state of the indicator used to physically identify or locate this
resource. A write to this property shall update the value of IndicatorLED in this resource, if
supported, to reflect the implementation of the locating function. Modifying this property may
modify the LocationIndicatorActive in the containing Chassis resource.
boot_progress: Option<Option<BootProgress>>This object describes the last boot progress state.
This object shall contain the last boot progress state and time.
power_on_delay_seconds: Option<Option<Decimal>>The number of seconds to delay power on after an externally performed power cycle or during a reset. Zero seconds indicates no delay to power up.
This property shall contain the number of seconds to delay power on after an externally performed
power cycle or during a reset. The value 0 shall indicate no delay to power on.
power_off_delay_seconds: Option<Option<Decimal>>The number of seconds to delay power off during a reset. Zero seconds indicates no delay to power off.
This property shall contain the number of seconds to delay power off during a reset. The value 0
shall indicate no delay to power off.
power_cycle_delay_seconds: Option<Option<Decimal>>The number of seconds to delay power on after a Reset action requesting PowerCycle or
FullPowerCycle. Zero seconds indicates no delay.
This property shall contain the number of seconds to delay power on after a Reset action
requesting PowerCycle or FullPowerCycle. The value 0 shall indicate no delay to power on.
serial_console: Option<HostSerialConsole>The serial console services that this system provides.
This property shall contain information about the serial console services of this system.
graphical_console: Option<HostGraphicalConsole>The information about the graphical console (KVM-IP) service of this system.
This property shall contain the information about the graphical console (KVM-IP) service of this system.
virtual_media_config: Option<VirtualMediaConfig>The information about the virtual media service of this system.
This property shall contain the information about the virtual media service of this system.
measurements: Option<Vec<MeasurementBlock>>An array of DSP0274-defined measurement blocks.
This property shall contain an array of DSP0274-defined measurement blocks.
power_mode: Option<Option<PowerMode>>The power mode setting of the computer system.
This property shall contain the computer system power mode setting.
idle_power_saver: Option<Option<IdlePowerSaver>>The idle power saver settings of the computer system.
This property shall contain the idle power saver settings of the computer system.
key_management: Option<Option<KeyManagement>>The key management settings of the computer system.
This property shall contain the key management settings of the computer system.
composition: Option<Option<Composition>>Information about the composition capabilities and state of the computer system.
This property shall contain information about the composition capabilities and state of the computer system.
manufacturing_mode: Option<Option<Boolean>>An indication of whether the system is in manufacturing mode. Manufacturing mode is a special boot mode, not normally available to end users, that modifies features and settings for use while the system is being manufactured and tested.
This property shall indicate whether the system is in manufacturing mode. If the system supports SMBIOS, the value shall match the ‘Manufacturing mode is enabled’ setting from the ‘BIOS Characteristics’ entry.
last_reset_cause: Option<LastResetCauses>The last reset cause of the system.
This property shall contain the cause when the system last came out of a reset or was rebooted.
ipmi_host_interface: Option<IpmiHostInterface>The information about the in-band IPMI service of this system.
This property shall contain the information about the in-band IPMI service of this system.
multipart_import_configuration_push_uri: Option<String>The URI used to perform a Redfish Specification-defined multipart HTTP or HTTPS push import of a vendor-specific configuration file.
This property shall contain a URI used to perform a multipart HTTP or HTTPS POST of a
vendor-specific configuration file for the purpose of importing the configuration contained within
the file as defined by the ‘Import configuration data’ clause of the Redfish Specification. The
value of this property should not contain a URI of a Redfish resource. See the ‘Redfish-defined
URIs and relative reference rules’ clause in the Redfish Specification.
processors: Option<NavProperty<ProcessorCollection>>The link to the collection of processors associated with this system.
This property shall contain a link to a resource collection of type ProcessorCollection.
ethernet_interfaces: Option<NavProperty<EthernetInterfaceCollection>>The link to the collection of Ethernet interfaces associated with this system.
This property shall contain a link to a resource collection of type EthernetInterfaceCollection.
simple_storage: Option<ReferenceLeaf>log_services: Option<NavProperty<LogServiceCollection>>The link to the collection of log services associated with this system.
This property shall contain a link to a resource collection of type LogServiceCollection.
secure_boot: Option<NavProperty<SecureBoot>>The link to the UEFI Secure Boot associated with this system.
This property shall contain a link to a resource of type SecureBoot.
bios: Option<NavProperty<Bios>>The link to the BIOS settings associated with this system.
This property shall contain a link to a resource of type Bios that lists the BIOS settings for
this system.
memory: Option<NavProperty<MemoryCollection>>The link to the collection of memory associated with this system.
This property shall contain a link to a resource collection of type MemoryCollection.
storage: Option<NavProperty<StorageCollection>>The link to the collection of storage devices associated with this system.
This property shall contain a link to a resource collection of type StorageCollection.
pcie_devices: Option<Vec<NavProperty<PcieDevice>>>The link to a collection of PCIe devices that this computer system uses.
This property shall contain an array of links to resources of type PCIeDevice.
pcie_functions: Option<Vec<ReferenceLeaf>>memory_domains: Option<ReferenceLeaf>network_interfaces: Option<ReferenceLeaf>redundancy: Option<Vec<ReferenceLeaf>>fabric_adapters: Option<ReferenceLeaf>virtual_media: Option<ReferenceLeaf>certificates: Option<ReferenceLeaf>graphics_controllers: Option<ReferenceLeaf>usb_controllers: Option<ReferenceLeaf>operating_system: Option<ReferenceLeaf>