pub struct ComputerSystemDecommissionAction {
pub decommission_types: Option<Vec<DecommissionType>>,
pub oem_decommission_types: Option<Vec<String>>,
pub computer_system_etag: Option<String>,
pub require_secure_erase: Option<Boolean>,
}Expand description
This action decommissions a system.
This action shall remove all specified data from a system in preparation to decommission the system.
Fields
decommission_types: Option<Vec<DecommissionType>>The types of data to remove from the system.
This parameter shall contain a list of the types of data to remove from the system.
oem_decommission_types: Option<Vec<String>>The OEM-specific types of data to remove from the system.
This parameter shall contain any OEM-specific types of data to remove from the system.
computer_system_etag: Option<String>The current ETag of the system.
This parameter shall contain the current ETag of the system. If the client-provided ETag does not
match the current ETag of the system, the service shall return the HTTP 428 Precondition Required
status code to reject the request.
require_secure_erase: Option<Boolean>Ensure secure erasure of all devices and fail the request if not possible.
This parameter shall indicate if a secure erase is required. If the parameter contains true and
a secure erase to the level of NIST 800-88 Clear or Purge for all specified components cannot be
performed the service shall return the HTTP 501 Not Implemented status code. This failure may
occur after the process has already started. If not provided by the client, the value shall be
assumed to be false.