ComputerSystemExportConfigurationAction

Struct ComputerSystemExportConfigurationAction 

pub struct ComputerSystemExportConfigurationAction {
    pub export_type: Option<ExportType>,
    pub components: Option<Vec<Component>>,
    pub oem_components: Option<Vec<String>>,
    pub security: Option<ExportSecurity>,
    pub encryption_passphrase: Option<String>,
}
This action exports the configuration of a system in a vendor-specific format.

This action shall export the specified configuration of a system in a vendor-specific format. Upon successful completion of the action and any asynchronous processing, the Location header in the response shall contain a URI to a file that contains the configuration data.

Fields

export_type: Option<ExportType>

The types of export to perform.

This parameter shall contain the type of export to perform.

components: Option<Vec<Component>>

The components of the system for which to export configuration data.

This parameter shall contain an array of components of the system for which to export configuration data.

oem_components: Option<Vec<String>>

The OEM-specific components of the system for which to export configuration data.

This parameter shall contain an array of OEM-specific components of the system for which to export configuration data.

security: Option<ExportSecurity>

The policy to apply when exporting secure information.

This parameter shall contain the policy to apply when exporting secure information.

encryption_passphrase: Option<String>

The encryption passphrase for the exported file.

This parameter shall contain the encryption passphrase for the exported file. If this parameter is specified and has a non-zero length, the service shall encrypt the exported file with the passphrase. Otherwise, the service shall not encrypt the exported file.