ComputerSystemResetAction

Struct ComputerSystemResetAction 

pub struct ComputerSystemResetAction {
    pub reset_type: Option<ResetType>,
}
This action resets the system.

This action shall reset the system represented by the resource. For systems that implement ACPI Power Button functionality, the PushPowerButton value shall perform or emulate an ACPI Power Button Push, and the ForceOff value shall perform an ACPI Power Button Override, commonly known as a four-second hold of the power button.

Fields

reset_type: Option<ResetType>

The type of reset.

This parameter shall contain the type of reset. The service can accept a request without the parameter and perform an implementation-specific default reset. Services should include the @Redfish.AllowableValues annotation for this parameter to ensure compatibility with clients, even when ActionInfo has been implemented.