pub struct HostGraphicalConsole {
pub service_enabled: Option<Boolean>,
pub port: Option<Option<Int64>>,
pub connect_types_supported: Option<Vec<GraphicalConnectTypesSupported>>,
pub max_concurrent_sessions: Option<Int64>,
}Expand description
The information about a graphical console service for this system.
This type shall describe a graphical console service for a computer system.
Fields
service_enabled: Option<Boolean>An indication of whether the service is enabled for this system.
This property shall indicate whether the protocol for the service is enabled.
port: Option<Option<Int64>>The protocol port.
This property shall contain the port assigned to the service.
connect_types_supported: Option<Vec<GraphicalConnectTypesSupported>>This property enumerates the graphical console connection types that the implementation allows.
This property shall contain an array of the enumerations. KVMIP shall be included if a
vendor-defined KVM-IP protocol is supported.
max_concurrent_sessions: Option<Int64>The maximum number of service sessions, regardless of protocol, that this system can support.
This property shall contain the maximum number of concurrent service sessions that this implementation supports.