pub struct HostSerialConsole {
pub max_concurrent_sessions: Option<Int64>,
pub ssh: Option<SerialConsoleProtocol>,
pub telnet: Option<SerialConsoleProtocol>,
pub ipmi: Option<SerialConsoleProtocol>,
pub web_socket: Option<WebSocketConsole>,
}Fields
max_concurrent_sessions: Option<Int64>The maximum number of service sessions, regardless of protocol, that this system can support.
This property shall contain the maximum number of concurrent service sessions that this implementation supports.
ssh: Option<SerialConsoleProtocol>The connection details for an SSH serial console service.
This property shall contain connection details for a serial console service that uses the Secure Shell (SSH) protocol.
telnet: Option<SerialConsoleProtocol>The connection details for a Telnet serial console service.
This property shall contain connection details for a serial console service that uses the Telnet protocol.
ipmi: Option<SerialConsoleProtocol>The connection details for an IPMI Serial-over-LAN service.
This property shall contain connection details for a serial console service that uses the IPMI Serial-over-LAN (SOL) protocol.
web_socket: Option<WebSocketConsole>The connection details for a WebSocket serial console service.
This property shall contain connection details for a serial console service that uses WebSockets as defined by the ‘WebSocket inbound access’ clause of the Redfish Specification. Services shall send WebSocket packetized bytes in a manner that emulates a pty (pseudoterminal).