pub struct HostedServices {
pub oem: Option<Oem>,
pub storage_services: Option<ReferenceLeaf>,
}Expand description
The services that might be running or installed on the system.
This type shall describe services that a computer system supports.
Fields
oem: Option<Oem>The OEM extension property.
This property shall contain the OEM extensions. All values for properties contained in this object shall conform to the Redfish Specification-described requirements.
storage_services: Option<ReferenceLeaf>Trait Implementations
Sourceimpl Debug for HostedServices
impl Debug for HostedServices
Sourceimpl<'de> Deserialize<'de> for HostedServices
impl<'de> Deserialize<'de> for HostedServices
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Send for HostedServices
SAFETY: All generated data types are Send
impl Sync for HostedServices
SAFETY: All generated data types are Sync