IdlePowerSaver

Struct IdlePowerSaver 

pub struct IdlePowerSaver {
    pub enabled: Option<Boolean>,
    pub enter_utilization_percent: Option<Option<Decimal>>,
    pub enter_dwell_time_seconds: Option<Option<Int64>>,
    pub exit_utilization_percent: Option<Option<Decimal>>,
    pub exit_dwell_time_seconds: Option<Option<Int64>>,
}
The idle power saver settings of a computer system.

This object shall contain the idle power saver settings of a computer system.

Fields

enabled: Option<Boolean>

An indication of whether idle power saver is enabled.

The value of this property shall indicate if idle power saver is enabled.

enter_utilization_percent: Option<Option<Decimal>>

The percentage of utilization when the computer system enters idle power save. If the computer system’s utilization goes below this value, it enters idle power save.

This property shall contain the percentage of utilization, typically 0 to 100, when the computer system enters idle power save. If the computer system’s utilization goes below this value for the duration specified by EnterDwellTimeSeconds, it shall enter idle power save.

enter_dwell_time_seconds: Option<Option<Int64>>

The duration in seconds the computer system is below the EnterUtilizationPercent value before the idle power save is activated.

This property shall contain the duration in seconds the computer system is below the EnterUtilizationPercent value before the idle power save is activated.

exit_utilization_percent: Option<Option<Decimal>>

The percentage of utilization when the computer system exits idle power save. If the computer system’s utilization goes above this value, it exits idle power save.

This property shall contain the percentage of utilization, typically 0 to 100, when the computer system exits idle power save. If the computer system’s utilization goes above this value for the duration specified by ExitDwellTimeSeconds, it shall exit idle power save.

exit_dwell_time_seconds: Option<Option<Int64>>

The duration in seconds the computer system is above the ExitUtilizationPercent value before the idle power save is stopped.

This property shall contain the duration in seconds the computer system is above the ExitUtilizationPercent value before the idle power save is stopped.