pub struct KmipServer {
pub address: Option<Option<String>>,
pub port: Option<Option<Int64>>,
pub username: Option<Option<String>>,
pub cache_policy: Option<Option<KmipCachePolicy>>,
pub cache_duration: Option<Option<Duration>>,
}Fields
address: Option<Option<String>>The KMIP server address.
This property shall contain the KMIP server address.
port: Option<Option<Int64>>The KMIP server port.
This property shall contain the KMIP server port.
username: Option<Option<String>>The username to access the KMIP server.
This property shall contain the username to access the KMIP server.
cache_policy: Option<Option<KmipCachePolicy>>The cache policy to control how KMIP data is cached.
This property shall contain the cache policy to control how KMIP data is cached.
cache_duration: Option<Option<Duration>>The duration the system caches KMIP data.
This property shall contain the duration that the system caches KMIP data.