Links

Struct Links 

pub struct Links {
Show 13 fields pub base: Links, pub chassis: Option<Vec<NavProperty<Chassis>>>, pub managed_by: Option<Vec<NavProperty<Manager>>>, pub powered_by: Option<Vec<ReferenceLeaf>>, pub cooled_by: Option<Vec<ReferenceLeaf>>, pub endpoints: Option<Vec<ReferenceLeaf>>, pub resource_blocks: Option<Vec<ReferenceLeaf>>, pub consuming_computer_systems: Option<Vec<NavProperty<ComputerSystem>>>, pub supplying_computer_systems: Option<Vec<NavProperty<ComputerSystem>>>, pub offloaded_network_device_functions: Option<Vec<NavProperty<NetworkDeviceFunction>>>, pub trusted_components: Option<Vec<ReferenceLeaf>>, pub hosting_computer_system: Option<NavProperty<ComputerSystem>>, pub virtual_machines: Option<Vec<NavProperty<ComputerSystem>>>,
}

Fields

base: Links

Base type

chassis: Option<Vec<NavProperty<Chassis>>>

An array of links to the chassis that contains this system.

This property shall contain an array of links to resources of type Chassis that represent the physical containers associated with this resource.

managed_by: Option<Vec<NavProperty<Manager>>>

An array of links to the managers responsible for this system.

This property shall contain an array of links to resources of type Manager that represent the resources with management responsibility for this resource.

powered_by: Option<Vec<ReferenceLeaf>>cooled_by: Option<Vec<ReferenceLeaf>>endpoints: Option<Vec<ReferenceLeaf>>resource_blocks: Option<Vec<ReferenceLeaf>>consuming_computer_systems: Option<Vec<NavProperty<ComputerSystem>>>

An array of links to computer systems that are realized, in whole or in part, from this computer system.

The value shall be an array of links to computer systems that are realized, in whole or in part, from this computer system.

supplying_computer_systems: Option<Vec<NavProperty<ComputerSystem>>>

An array of links to computer systems that contribute, in whole or in part, to the implementation of this computer system.

The value shall be an array of links to computer systems that contribute, in whole or in part, to the implementation of this computer system.

offloaded_network_device_functions: Option<Vec<NavProperty<NetworkDeviceFunction>>>

The network device functions to which this system performs offload computation, such as with a SmartNIC.

This property shall contain an array of links to resources of type NetworkDeviceFunction that represent the network device functions to which this system performs offload computation, such as with a SmartNIC. This property shall not be present if the SystemType property does not contain DPU.

trusted_components: Option<Vec<ReferenceLeaf>>hosting_computer_system: Option<NavProperty<ComputerSystem>>

The link to the system that is hosting this virtual machine.

This property shall contain a link to a resource of type ComputerSystem that represents the system that is hosting this virtual machine. This property shall only be present if SystemType contains Virtual.

virtual_machines: Option<Vec<NavProperty<ComputerSystem>>>

An array of links to the virtual machines this system is hosting.

This property shall contain an array of links to resources of type ComputerSystem that represent the virtual machines this system is hosting.