pub struct MemorySummary {
pub total_system_memory_gi_b: Option<Option<Decimal>>,
pub status: Option<Status>,
pub memory_mirroring: Option<Option<MemoryMirroring>>,
pub total_system_persistent_memory_gi_b: Option<Option<Decimal>>,
pub metrics: Option<NavProperty<MemoryMetrics>>,
}Fields
total_system_memory_gi_b: Option<Option<Decimal>>The total configured operating system-accessible memory (RAM), measured in GiB.
This property shall contain the amount of configured system general purpose volatile (RAM) memory as measured in gibibytes.
status: Option<Status>The status and health of the resource and its subordinate or dependent resources.
This property shall contain any status or health properties of the resource.
memory_mirroring: Option<Option<MemoryMirroring>>The ability and type of memory mirroring that this computer system supports.
This property shall contain the ability and type of memory mirroring that this computer system supports.
total_system_persistent_memory_gi_b: Option<Option<Decimal>>The total configured, system-accessible persistent memory, measured in GiB.
This property shall contain the total amount of configured persistent memory available to the system as measured in gibibytes.
metrics: Option<NavProperty<MemoryMetrics>>The link to the metrics associated with all memory in this system.
This property shall contain a link to the metrics associated with all memory in this system.