pub struct SerialConsoleProtocol {
pub service_enabled: Option<Boolean>,
pub port: Option<Option<Int64>>,
pub shared_with_manager_cli: Option<Boolean>,
pub console_entry_command: Option<Option<String>>,
pub hot_key_sequence_display: Option<Option<String>>,
}Expand description
The information about a serial console service that this system provides.
This type shall describe a serial console service for a computer system.
Fields
service_enabled: Option<Boolean>An indication of whether the service is enabled for this system.
This property shall indicate whether the protocol for the service is enabled.
port: Option<Option<Int64>>The protocol port.
This property shall contain the port assigned to the protocol.
Indicates whether the serial console service is shared with access to the manager’s command-line interface (CLI).
This property shall indicate whether the serial console service is shared with access to the manager’s command-line interface (CLI).
console_entry_command: Option<Option<String>>The command string passed to the service to select or enter the system’s serial console.
This property shall contain a command string that can be provided by a client to select or enter the system’s serial console, when the console is shared among several systems or a manager CLI.
hot_key_sequence_display: Option<Option<String>>The hotkey sequence available for the user to exit the serial console session.
This property shall contain a string that can be provided to a user to describe the hotkey sequence used to exit the serial console session, or, if shared with a manager CLI, to return to the CLI.