pub struct TrustedModules {
pub firmware_version: Option<Option<String>>,
pub interface_type: Option<Option<InterfaceType>>,
pub status: Option<Status>,
pub oem: Option<Oem>,
pub firmware_version2: Option<Option<String>>,
pub interface_type_selection: Option<Option<InterfaceTypeSelection>>,
}Fields
firmware_version: Option<Option<String>>The firmware version of this Trusted Module.
This property shall contain the firmware version as defined by the manufacturer for the Trusted Module.
interface_type: Option<Option<InterfaceType>>The interface type of the Trusted Module.
This property shall contain the interface type of the installed Trusted Module.
status: Option<Status>The status and health of the resource and its subordinate or dependent resources.
This property shall contain any status or health properties of the resource.
oem: Option<Oem>The OEM extension property.
This property shall contain the OEM extensions. All values for properties contained in this object shall conform to the Redfish Specification-described requirements.
firmware_version2: Option<Option<String>>The second firmware version of this Trusted Module, if applicable.
This property shall contain the 2nd firmware version, if applicable, as defined by the manufacturer for the Trusted Module.
interface_type_selection: Option<Option<InterfaceTypeSelection>>The interface type selection supported by this Trusted Module.
This property shall contain the interface type Selection method (for example to switch between
TPM1_2 and TPM2_0) that is supported by this Trusted Module.