pub struct VirtualMediaConfig {
pub service_enabled: Option<Boolean>,
pub port: Option<Option<Int64>>,
}Expand description
The information about virtual media service for this system.
This type shall describe a virtual media service for a computer system.
Fields
service_enabled: Option<Boolean>An indication of whether the service is enabled for this system.
This property shall indicate whether the protocol for the service is enabled.
port: Option<Option<Int64>>The protocol port.
This property shall contain the port assigned to the service.