WebSocketConsole

Struct WebSocketConsole 

pub struct WebSocketConsole {
    pub service_enabled: Option<Boolean>,
    pub console_uri: Option<String>,
    pub interactive: Option<Boolean>,
}
The information about a WebSocket serial console service that this system provides.

This type shall describe a WebSocket serial console service for a computer system.

Fields

service_enabled: Option<Boolean>

An indication of whether the service is enabled for this system.

This property shall indicate whether the protocol for the service is enabled.

console_uri: Option<String>

The URI at which to access the WebSocket serial console.

This property shall contain the URI at which to access the WebSocket serial console, using the Redfish protocol and authentication methods. See the ‘WebSocket inbound access’ clause in the Redfish Specification.

interactive: Option<Boolean>

Indicates if the WebSocket serial console allows interactive input.

This property shall indicate if the WebSocket serial console allows interactive input. If true, the WebSocket is bidirectional. If false, the WebSocket only allows console output from the service.