pub struct ComputerSystemCollection {
pub base: ResourceCollection,
pub members: Vec<NavProperty<ComputerSystem>>,
}Expand description
The collection of ComputerSystem resource instances.
This resource shall represent a resource collection of ComputerSystem instances for a Redfish
implementation.
Fields
base: ResourceCollectionBase type
members: Vec<NavProperty<ComputerSystem>>The members of this collection.
This property shall contain an array of links to the members of this collection.