pub struct Control {Show 29 fields
pub base: Resource,
pub control_type: Option<Option<ControlType>>,
pub set_point_type: Option<Option<SetPointType>>,
pub status: Option<Status>,
pub control_mode: Option<Option<ControlMode>>,
pub set_point: Option<Option<Decimal>>,
pub setting_min: Option<Option<Decimal>>,
pub setting_max: Option<Option<Decimal>>,
pub allowable_numeric_values: Option<Option<Vec<Decimal>>>,
pub set_point_units: Option<Option<String>>,
pub dead_band: Option<Option<Decimal>>,
pub control_delay_seconds: Option<Option<Decimal>>,
pub allowable_max: Option<Option<Decimal>>,
pub allowable_min: Option<Option<Decimal>>,
pub increment: Option<Option<Decimal>>,
pub accuracy: Option<Option<Decimal>>,
pub physical_context: Option<Option<PhysicalContext>>,
pub physical_sub_context: Option<Option<PhysicalSubContext>>,
pub implementation: Option<Option<ImplementationType>>,
pub set_point_update_time: Option<Option<DateTimeOffset>>,
pub control_loop: Option<ControlLoop>,
pub location: Option<Location>,
pub actions: Option<Actions>,
pub default_set_point: Option<Option<Decimal>>,
pub set_point_accuracy: Option<Option<Decimal>>,
pub set_point_error: Option<Option<Decimal>>,
pub related_item: Option<Vec<ReferenceLeaf>>,
pub sensor: Option<SensorExcerpt>,
pub associated_sensors: Option<Vec<NavProperty<Sensor>>>,
}Expand description
The Control schema describes a control point and its properties.
This resource shall represent a control point for a Redfish implementation.
Fields
base: ResourceBase type
control_type: Option<Option<ControlType>>The type of control.
This property shall contain the type of the control.
set_point_type: Option<Option<SetPointType>>The set point type used to operate the control.
This property shall contain the type of set point definitions used to describe this control.
status: Option<Status>The status and health of the resource and its subordinate or dependent resources.
This property shall contain any status or health properties of the resource.
control_mode: Option<Option<ControlMode>>The current operating mode of the control.
This property shall contain the operating mode of the control.
set_point: Option<Option<Decimal>>The desired set point of the control.
This property shall contain the desired set point control value. The units shall follow the value
of SetPointUnits. If the DefaultSetPoint property is not supported and if a user-defined set
point is not configured, the property may contain null in responses.
setting_min: Option<Option<Decimal>>The minimum set point in the allowed range.
This property shall contain the minimum desired set point within the acceptable range. The service
shall reject values less than the value of AllowableMin. The units shall follow the value of
SetPointUnits.
setting_max: Option<Option<Decimal>>The maximum set point in the allowed range.
This property shall contain the maximum desired set point within the acceptable range. The service
shall reject values greater than the value of AllowableMax. The units shall follow the value of
SetPointUnits.
allowable_numeric_values: Option<Option<Vec<Decimal>>>The supported values for the set point.
This property shall contain the supported values for this control. The units shall follow the
value of SetPointUnits. This property should only be present when the set point or range has a
limited set of supported values that cannot be accurately described using the Increment property.
set_point_units: Option<Option<String>>The units of the set point and related properties in UCUM c/s format.
This property shall contain the units of the control’s set point and related properties. The value shall follow the case-sensitive symbol format defined by the Unified Code for Units of Measure (UCUM), as specified by the ‘Units of measure annotation’ clause of the Redfish Specification.
dead_band: Option<Option<Decimal>>The maximum deviation from the set point allowed before the control will activate.
This property shall contain the maximum deviation value allowed above or below the value of
SetPoint before the control will activate.
control_delay_seconds: Option<Option<Decimal>>The time delay in seconds before the control will activate once the value has deviated from the set point.
This property shall contain the time in seconds that will elapse after the control value deviates
above or below the value of SetPoint before the control will activate.
allowable_max: Option<Option<Decimal>>The maximum possible setting for this control.
This property shall indicate the maximum possible value of the SetPoint or SettingMax
properties for this control. Services shall not accept values for SetPoint or SettingMax above
this value.
allowable_min: Option<Option<Decimal>>The minimum possible setting for this control.
This property shall indicate the minimum possible value of the SetPoint or SettingMin
properties for this control. Services shall not accept values for SetPoint or SettingMin below
this value.
increment: Option<Option<Decimal>>The smallest increment supported for the set point.
This property shall contain the smallest change allowed to the value of the SetPoint,
SettingMin, or SettingMax properties. The units shall follow the value of SetPointUnits.
accuracy: Option<Option<Decimal>>The estimated percent error of measured versus actual values.
This property shall contain the percent error of the measured versus actual values of the
SetPoint property.
physical_context: Option<Option<PhysicalContext>>The area or device to which this control applies.
This property shall contain a description of the affected component or region within the equipment to which this control applies.
physical_sub_context: Option<Option<PhysicalSubContext>>The usage or location within a device to which this control applies.
This property shall contain a description of the usage or sub-region within the equipment to which
this control applies. This property generally differentiates multiple controls within the same
PhysicalContext instance.
implementation: Option<Option<ImplementationType>>The implementation of the control.
This property shall contain the implementation of the control.
set_point_update_time: Option<Option<DateTimeOffset>>The date and time that the set point was changed.
This property shall contain the date and time that the value of SetPoint was last changed.
control_loop: Option<ControlLoop>The control loop details.
This property shall contain the details for the control loop described by this resource.
location: Option<Location>The location information for this control.
This property shall indicate the location information for this control.
actions: Option<Actions>The available actions for this resource.
This property shall contain the available actions for this resource.
default_set_point: Option<Option<Decimal>>The default set point of the control.
This property shall contain the default set point control value. The units shall follow the value
of SetPointUnits. Services apply this value to the SetPoint property under certain conditions,
such as a reset of the manager or a ResetToDefaults action.
set_point_accuracy: Option<Option<Decimal>>Accuracy (+/-) of the set point.
This property shall contain the accuracy of the value of the SetPoint for this control. The
value shall be the absolute value of the maximum deviation of the SetPoint from its actual value.
The value shall be in units that follow the SetPointUnits for this control.
set_point_error: Option<Option<Decimal>>The error (difference) from the desired set point of the control.
This property shall contain the error, or difference, of the related Sensor Reading value from
the value of the SetPoint. The units shall follow the value of SetPointUnits.
sensor: Option<SensorExcerpt>The sensor reading associated with this control.
This property shall contain the Sensor excerpt directly associated with this control. The value
of the DataSourceUri property shall reference a resource of type Sensor. This property shall
not be present if multiple sensors are associated with a single control.
associated_sensors: Option<Vec<NavProperty<Sensor>>>An array of links to the sensors associated with this control.
This property shall contain an array of links to resources of type Sensor that represent the
sensors related to this control.