ControlExcerptRange

Struct ControlExcerptRange 

pub struct ControlExcerptRange {
    pub data_source_uri: Option<Option<String>>,
    pub control_mode: Option<Option<ControlMode>>,
    pub setting_min: Option<Option<Decimal>>,
    pub setting_max: Option<Option<Decimal>>,
    pub allowable_numeric_values: Option<Option<Vec<Decimal>>>,
    pub allowable_max: Option<Option<Decimal>>,
    pub allowable_min: Option<Option<Decimal>>,
    pub reading: Option<Option<Decimal>>,
}

Fields

data_source_uri: Option<Option<String>>

The link to the resource that provides the data for this control.

This property shall contain a URI to the resource that provides the source of the excerpt contained within this copy. If no source resource is implemented, meaning the excerpt represents the only available data, this property shall not be present.

control_mode: Option<Option<ControlMode>>

The current operating mode of the control.

This property shall contain the operating mode of the control.

setting_min: Option<Option<Decimal>>

The minimum set point in the allowed range.

This property shall contain the minimum desired set point within the acceptable range. The service shall reject values less than the value of AllowableMin. The units shall follow the value of SetPointUnits.

setting_max: Option<Option<Decimal>>

The maximum set point in the allowed range.

This property shall contain the maximum desired set point within the acceptable range. The service shall reject values greater than the value of AllowableMax. The units shall follow the value of SetPointUnits.

allowable_numeric_values: Option<Option<Vec<Decimal>>>

The supported values for the set point.

This property shall contain the supported values for this control. The units shall follow the value of SetPointUnits. This property should only be present when the set point or range has a limited set of supported values that cannot be accurately described using the Increment property.

allowable_max: Option<Option<Decimal>>

The maximum possible setting for this control.

This property shall indicate the maximum possible value of the SetPoint or SettingMax properties for this control. Services shall not accept values for SetPoint or SettingMax above this value.

allowable_min: Option<Option<Decimal>>

The minimum possible setting for this control.

This property shall indicate the minimum possible value of the SetPoint or SettingMin properties for this control. Services shall not accept values for SetPoint or SettingMin below this value.

reading: Option<Option<Decimal>>

The reading of the sensor associated with this control.

This property shall contain the value of the Reading property of the Sensor resource directly associated with this control. This property shall not be present if multiple sensors are associated with a single control.