ControlLoop

Struct ControlLoop 

pub struct ControlLoop {
    pub proportional: Option<Option<Decimal>>,
    pub integral: Option<Option<Decimal>>,
    pub differential: Option<Option<Decimal>>,
    pub coefficient_update_time: Option<Option<DateTimeOffset>>,
}
The details and coefficients used to operate a control loop.

This type shall describe the details of a control loop.

Fields

proportional: Option<Option<Decimal>>

The proportional coefficient.

This property shall contain the coefficient for the proportional factor in a control loop.

integral: Option<Option<Decimal>>

The integral coefficient.

This property shall contain the coefficient for the integral factor in a control loop.

differential: Option<Option<Decimal>>

The differential coefficient.

This property shall contain the coefficient for the differential factor in a control loop.

coefficient_update_time: Option<Option<DateTimeOffset>>

The date and time that the control loop coefficients were changed.

This property shall contain the date and time that any of the coefficients for the control loop were last changed.