pub struct ControlCollection {
pub base: ResourceCollection,
pub members: Vec<NavProperty<Control>>,
}Expand description
The collection of Control resource instances.
This resource shall represent a resource collection of Control instances for a Redfish
implementation.
Fields
base: ResourceCollectionBase type
members: Vec<NavProperty<Control>>The members of this collection.
This property shall contain an array of links to the members of this collection.