pub enum StorageAccessCapability {
Read,
Write,
WriteOnce,
Append,
Streaming,
Execute,
UnsupportedValue,
}Expand description
Values of StorageAccessCapability describe abilities to read or write storage.
StorageAccessCapability enumeration literals may be used to describe abilities to read or write storage.
Variants
Read
Read.
This enumeration literal shall indicate that the storage may be read.
Write
Write Many.
This enumeration literal shall indicate that the storage may be written multiple times.
WriteOnce
WriteOnce.
This enumeration literal shall indicate that the storage may be written only once.
Append
AppendOnly.
This enumeration literal shall indicate that the storage may be written only to append.
Streaming
Streaming.
This enumeration literal shall indicate that the storage may be read sequentially.
Execute
Execute access is allowed by the file share.
This value shall indicate that Execute access is allowed by the file share.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.