pub enum ConfigLockOptions {
Unlocked,
Locked,
LockdownUnsupported,
CommandUnsupported,
UnsupportedValue,
}Variants
Unlocked
The command is supported, able to be locked, and is currently unlocked.
Locked
The command is supported and is currently locked.
LockdownUnsupported
The command is supported but is not able to be locked.
CommandUnsupported
The command is not supported, therefore lockdown does not apply.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.