pub enum DataSanitizationType {
BlockErase,
CryptographicErase,
Overwrite,
UnsupportedValue,
}Variants
BlockErase
Delete all logical block addresses, including those that are not currently mapping to active addresses, but leaving the data on the drive.
This value shall indicate sanitization is performed by deleting all logical block addresses, including those that are not currently mapping to active addresses, but leaving the data on the drive.
CryptographicErase
Erase the target data’s encryption key leaving only the ciphertext on the drive. For more information, see NIST800-88 and ISO/IEC 27040.
This value shall indicate sanitization is performed by erasing the target data’s encryption key leaving only the ciphertext on the drive. For more information, see NIST800-88 and ISO/IEC 27040.
Overwrite
Overwrite data by writing an implementation-specific pattern onto all sectors of the drive.
This value shall indicate sanitization is performed by overwriting data by writing an implementation-specific pattern onto all sectors of the drive.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.