pub enum EncryptionStatus {
Unecrypted,
Unlocked,
Locked,
Foreign,
Unencrypted,
UnsupportedValue,
}Variants
Unecrypted
The drive is not currently encrypted.
Unlocked
The drive is currently encrypted but the data is accessible to the user in unencrypted form.
Locked
The drive is currently encrypted and the data is not accessible to the user. However, the system can unlock the drive automatically.
Foreign
The drive is currently encrypted, the data is not accessible to the user, and the system requires user intervention to expose the data.
Unencrypted
The drive is not currently encrypted.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.