FormFactor

Enum FormFactor 

pub enum FormFactor {
Show 19 variants Drive35, Drive25, Edsff, Edsff1uLong, Edsff1uShort, EdsffE3Short, EdsffE3Long, M2, M22230, M22242, M22260, M22280, M222110, U2, PcieSlotFullLength, PcieSlotLowProfile, PcieHalfLength, Oem, UnsupportedValue,
}

Variants



Drive35

A 3.5 inch drive.

This value shall indicate the drive is approximately 3.5 inches in width and no more than 1.1 inches in height.



Drive25

A 2.5 inch drive.

This value shall indicate the drive is approximately 2.5 inches in width and no more than 0.8 inches in height and is not a U.2 drive.



Edsff

An EDSFF drive.

This value shall indicate the drive corresponds to one of SNIA’s SFF specifications with an unspecified form factor. The SlotFormFactor property should not contain this value.



Edsff1uLong

An EDSFF 1U Long (E1.L) drive.

This value shall indicate the drive corresponds to the SFF-TA-1007 Specification.



Edsff1uShort

An EDSFF 1U Short (E1.S) drive.

This value shall indicate the drive corresponds to the SFF-TA-1006 Specification.



EdsffE3Short

An EDSFF E3 Short (E3.S) drive.

This value shall indicate the drive corresponds to the SFF-TA-1008 Specification and is approximately 112.75 mm in length.



EdsffE3Long

An EDSFF E3 Long (E3.L) drive.

This value shall indicate the drive corresponds to the SFF-TA-1008 Specification and is approximately 142.2 mm in length.



M2

An M.2 drive.

This value shall indicate the drive corresponds to the PCI Express M.2 Specification with an unspecified form factor. The SlotFormFactor property should not contain this value.



M22230

An M.2 2230 drive.

This value shall indicate the drive corresponds to the PCI Express M.2 Specification and is approximately 22 mm in width and 30 mm in length.



M22242

An M.2 2242 drive.

This value shall indicate the drive corresponds to the PCI Express M.2 Specification and is approximately 22 mm in width and 42 mm in length.



M22260

An M.2 2260 drive.

This value shall indicate the drive corresponds to the PCI Express M.2 Specification and is approximately 22 mm in width and 60 mm in length.



M22280

An M.2 2280 drive.

This value shall indicate the drive corresponds to the PCI Express M.2 Specification and is approximately 22 mm in width and 80 mm in length.



M222110

An M.2 22110 drive.

This value shall indicate the drive corresponds to the PCI Express M.2 Specification and is approximately 22 mm in width and 110 mm in length.



U2

A U.2 drive.

This value shall indicate the drive corresponds to the PCI Express SFF-8639 Module Specification.



PcieSlotFullLength

A full-length PCIe add-in card.

This value shall indicate the drive is an add-in card greater than 7 inches in length.



PcieSlotLowProfile

A low-profile PCIe add-in card.

This value shall indicate the drive is an add-in card less than 2.5 inches in height.



PcieHalfLength

A half-length PCIe add-in card.

This value shall indicate the drive is an add-in card less than 7 inches in length.



Oem

An OEM-defined form factor.

This value shall indicate the drive is an OEM-defined form factor.



UnsupportedValue

Fallback value for values that are not supported by current version of Redfish schema.