pub enum MediaType {
Hdd,
Ssd,
Smr,
UnsupportedValue,
}Variants
Hdd
The drive media type is traditional magnetic platters.
Ssd
The drive media type is solid state or flash memory.
Smr
The drive media type is shingled magnetic recording.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.