pub enum TargetConfigurationLockLevel {
Baseline,
UnsupportedValue,
}Variants
Baseline
The standard configuration lock level, corresponding to applying firmware, updating security keys, and modifying other hardware settings. It does not include managing the volumes or data on the drive.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.