Actions

Struct Actions 

pub struct Actions {
    pub oem: Option<OemActions>,
    pub freeze_personality: Option<Action<DriveFreezePersonalityAction, ()>>,
    pub get_personality_nonce: Option<Action<DriveGetPersonalityNonceAction, GetPersonalityNonceResponse>>,
    pub reset: Option<Action<DriveResetAction, ()>>,
    pub revert_personalities_to_defaults: Option<Action<DriveRevertPersonalitiesToDefaultsAction, ()>>,
    pub revert_to_original_factory_state: Option<Action<DriveRevertToOriginalFactoryStateAction, ()>>,
    pub secure_erase: Option<Action<DriveSecureEraseAction, ()>>,
    pub set_personality_key: Option<Action<DriveSetPersonalityKeyAction, ()>>,
    pub unfreeze_personality: Option<Action<DriveUnfreezePersonalityAction, ()>>,
}
The available actions for this resource.

This type shall contain the available actions for this resource.

Fields

oem: Option<OemActions>

The available OEM-specific actions for this resource.

This property shall contain the available OEM-specific actions for this resource.

freeze_personality: Option<Action<DriveFreezePersonalityAction, ()>>get_personality_nonce: Option<Action<DriveGetPersonalityNonceAction, GetPersonalityNonceResponse>>reset: Option<Action<DriveResetAction, ()>>revert_personalities_to_defaults: Option<Action<DriveRevertPersonalitiesToDefaultsAction, ()>>revert_to_original_factory_state: Option<Action<DriveRevertToOriginalFactoryStateAction, ()>>secure_erase: Option<Action<DriveSecureEraseAction, ()>>set_personality_key: Option<Action<DriveSetPersonalityKeyAction, ()>>unfreeze_personality: Option<Action<DriveUnfreezePersonalityAction, ()>>

Implementations

Source

impl Actions

pub async fn freeze_personality<B: Bmc>( &self, bmc: &B, personality: Option<Int64>, ) -> Result<ModificationResponse<()>, B::Error>
where B::Error: ActionError,

This action freezes a personality for the NVMe subsystem.

This action shall freeze a personality for the NVMe subsystem as defined by the ‘Configurable Device Personality’ feature in the NVMe Base Specification.

Errors
pub async fn get_personality_nonce<B: Bmc>( &self, bmc: &B, ) -> Result<ModificationResponse<GetPersonalityNonceResponse>, B::Error>
where B::Error: ActionError,

This action obtains a nonce required to unfreeze personalities with a programmed key.

This action shall obtain a nonce required to unfreeze personalities with a programmed key as defined by the ‘CDP Random Nonce Data’ clause in the NVMe Base Specification.

Errors
pub async fn reset<B: Bmc>( &self, bmc: &B, reset_type: Option<ResetType>, ) -> Result<ModificationResponse<()>, B::Error>
where B::Error: ActionError,

This action resets this drive.

This action shall reset this drive.

Errors
pub async fn revert_personalities_to_defaults<B: Bmc>( &self, bmc: &B, ) -> Result<ModificationResponse<()>, B::Error>
where B::Error: ActionError,

This action reverts all personalities to their manufacturing default state for the NVMe subsystem.

This action shall revert all personalities to their manufacturing default state for the NVMe subsystem as defined by the ‘Manufacturing Default Personality’ clause of the NVMe Base Specification.

Errors
pub async fn revert_to_original_factory_state<B: Bmc>( &self, bmc: &B, physical_secure_id: Option<String>, ) -> Result<ModificationResponse<()>, B::Error>
where B::Error: ActionError,

This action reverts a self-encrypting drive (SED) to the original factory state.

This action shall revert a self-encrypting drive (SED) to the original factory state. Upon successful completion of this action, the drive data shall be securely erased and the EncryptionStatus property shall contain Unencrypted.

Errors
pub async fn secure_erase<B: Bmc>( &self, bmc: &B, sanitization_type: Option<DataSanitizationType>, overwrite_passes: Option<Int64>, ) -> Result<ModificationResponse<()>, B::Error>
where B::Error: ActionError,

This action securely erases the contents of the drive.

This action shall securely erase the drive.

Errors
pub async fn set_personality_key<B: Bmc>( &self, bmc: &B, algorithm: Option<NmvePersonalityKeyAlgorithm>, key: Option<String>, ) -> Result<ModificationResponse<()>, B::Error>
where B::Error: ActionError,

This action sets the personality key for the NVMe subsystem.

This action shall set the personality key for the NVMe subsystem as defined by the ‘Programmable Key Authentication Considerations’ clause in the NVMe Base Specification.

Errors
pub async fn unfreeze_personality<B: Bmc>( &self, bmc: &B, t: &DriveUnfreezePersonalityAction, ) -> Result<ModificationResponse<()>, B::Error>
where B::Error: ActionError,

This action unfreezes a personality for the NVMe subsystem.

This action shall unfreeze a personality for the NVMe subsystem as defined by the ‘Authenticated Unfreeze Operation’ clause in the NVMe Base Specification.

Errors