pub struct Drive {Show 50 fields
pub base: Resource,
pub status_indicator: Option<Option<StatusIndicator>>,
pub indicator_led: Option<Option<IndicatorLed>>,
pub model: Option<Option<String>>,
pub revision: Option<Option<String>>,
pub status: Option<Status>,
pub capacity_bytes: Option<Option<Int64>>,
pub failure_predicted: Option<Option<Boolean>>,
pub protocol: Option<Option<Protocol>>,
pub media_type: Option<Option<MediaType>>,
pub manufacturer: Option<Option<String>>,
pub sku: Option<Option<String>>,
pub serial_number: Option<Option<String>>,
pub part_number: Option<Option<String>>,
pub asset_tag: Option<Option<String>>,
pub identifiers: Option<Vec<Identifier>>,
pub location: Option<Vec<Location>>,
pub hotspare_type: Option<Option<HotspareType>>,
pub encryption_ability: Option<Option<EncryptionAbility>>,
pub encryption_status: Option<Option<EncryptionStatus>>,
pub rotation_speed_rpm: Option<Option<Decimal>>,
pub block_size_bytes: Option<Option<Int64>>,
pub capable_speed_gbs: Option<Option<Decimal>>,
pub negotiated_speed_gbs: Option<Option<Decimal>>,
pub predicted_media_life_left_percent: Option<Option<Decimal>>,
pub links: Option<Links>,
pub actions: Option<Actions>,
pub operations: Option<Vec<Operations>>,
pub physical_location: Option<Location>,
pub hotspare_replacement_mode: Option<Option<HotspareReplacementModeType>>,
pub write_cache_enabled: Option<Option<Boolean>>,
pub multipath: Option<Option<Boolean>>,
pub ready_to_remove: Option<Option<Boolean>>,
pub location_indicator_active: Option<Option<Boolean>>,
pub measurements: Option<Vec<MeasurementBlock>>,
pub slot_form_factor: Option<Option<FormFactor>>,
pub drive_form_factor: Option<Option<FormFactor>>,
pub slot_capable_protocols: Option<Option<Vec<Protocol>>>,
pub firmware_version: Option<Option<String>>,
pub spare_part_number: Option<Option<String>>,
pub configuration_lock: Option<Option<ConfigurationLock>>,
pub block_security_id_enabled: Option<Option<Boolean>>,
pub target_configuration_lock_level: Option<Option<TargetConfigurationLockLevel>>,
pub nvme: Option<Option<Nvme>>,
pub hardware_version: Option<Option<String>>,
pub security_id_owned: Option<Option<Boolean>>,
pub assembly: Option<NavProperty<Assembly>>,
pub environment_metrics: Option<NavProperty<EnvironmentMetrics>>,
pub certificates: Option<ReferenceLeaf>,
pub metrics: Option<NavProperty<DriveMetrics>>,
}Expand description
The Drive schema represents a single physical drive for a system, including links to associated
volumes. It also describes the location, such as a slot, socket, or bay, where a unit can be
installed, by populating a resource instance with an absent state if a unit is not present.
This resource shall represent a drive or other physical storage medium for a Redfish
implementation. It may also represent a location, such as a slot, socket, or bay, where a unit may
be installed, but the State property within the Status property contains Absent.
Fields
base: ResourceBase type
status_indicator: Option<Option<StatusIndicator>>The state of the status indicator, which communicates status information about this drive.
This property shall contain the status indicator state for the status indicator associated with
this drive. The @Redfish.AllowableValues annotation specifies the valid values for this
property.
indicator_led: Option<Option<IndicatorLed>>The state of the indicator LED, that identifies the drive.
This property shall contain the state for the indicator light associated with this drive.
model: Option<Option<String>>The model number for the drive.
This property shall contain the name by which the manufacturer generally refers to the drive.
revision: Option<Option<String>>The revision of a SCSI-based drive, as returned from the ‘Inquiry’ command, which can be the
firmware or hardware version. For other types of drives, the HardwareVersion and
FirmwareVersion properties are recommended in favor of this property.
This property shall contain the manufacturer-defined revision for a SCSI-based drive, as returned
in the ‘Product Revision Level’ field from the ‘Inquiry’ command, which can be the firmware or
hardware version. For other types of drives, this property should not be present and services
should support the HardwareVersion and FirmwareVersion properties in favor of this property.
If this property is present for drives that are not SCSI-based, the value may contain a firmware
version, hardware version, or a combination.
status: Option<Status>The status and health of the resource and its subordinate or dependent resources.
This property shall contain any status or health properties of the resource.
capacity_bytes: Option<Option<Int64>>The size, in bytes, of this drive.
This property shall contain the raw size, in bytes, of the associated drive.
failure_predicted: Option<Option<Boolean>>An indication of whether this drive currently predicts a failure in the near future.
This property shall indicate whether this drive currently predicts a manufacturer-defined failure.
protocol: Option<Option<Protocol>>The protocol that this drive currently uses to communicate to the storage controller.
This property shall contain the protocol that the associated drive currently uses to communicate to the storage controller for this system.
media_type: Option<Option<MediaType>>The type of media contained in this drive.
This property shall contain the type of media contained in the associated drive.
manufacturer: Option<Option<String>>The manufacturer of this drive.
This property shall contain the name of the organization responsible for producing the drive. This organization may be the entity from whom the drive is purchased, but this is not necessarily true.
sku: Option<Option<String>>The SKU for this drive.
This property shall contain the stock-keeping unit (SKU) number for this drive.
serial_number: Option<Option<String>>The serial number for this drive.
This property shall contain the manufacturer-allocated number that identifies the drive.
part_number: Option<Option<String>>The part number for this drive.
This property shall contain the part number assigned by the organization that is responsible for producing or manufacturing the drive.
asset_tag: Option<Option<String>>The user-assigned asset tag for this drive.
This property shall track the drive for inventory purposes.
identifiers: Option<Vec<Identifier>>The durable names for the drive.
This property shall contain a list of all known durable names for the associated drive.
location: Option<Vec<Location>>The location of the drive.
This property shall contain the location information of the associated drive.
hotspare_type: Option<Option<HotspareType>>The type of hot spare that this drive serves as.
This property shall contain the hot spare type for the associated drive. If the drive currently
serves as a hot spare, the State property in Status shall contain StandbySpare and Enabled
when it is part of a volume.
encryption_ability: Option<Option<EncryptionAbility>>The encryption ability of this drive.
This property shall contain the encryption ability for the associated drive.
encryption_status: Option<Option<EncryptionStatus>>The status of the encryption of this drive.
This property shall contain the encryption status for the associated drive.
rotation_speed_rpm: Option<Option<Decimal>>The rotation speed of this drive, in revolutions per minute (RPM) units.
This property shall contain the rotation speed, in revolutions per minute (RPM) units, of the associated drive.
block_size_bytes: Option<Option<Int64>>The size, in bytes, of the smallest addressable unit, or block.
This property shall contain the size of the smallest addressable unit of the associated drive.
capable_speed_gbs: Option<Option<Decimal>>The speed, in gigabits per second (Gbit/s) units, at which this drive can communicate to a storage controller in ideal conditions.
This property shall contain fastest capable bus speed, in gigabits per second (Gbit/s) units, of the associated drive.
negotiated_speed_gbs: Option<Option<Decimal>>The speed, in gigabits per second (Gbit/s) units, at which this drive currently communicates to the storage controller.
This property shall contain current bus speed, in gigabits per second (Gbit/s) units, of the associated drive.
predicted_media_life_left_percent: Option<Option<Decimal>>The percentage of reads and writes that are predicted to be available for the media.
This property shall contain an indicator of the percentage, typically 0 to 100, of life
remaining in the drive’s media.
links: Option<Links>The links to other resources that are related to this resource.
This property shall contain links to resources that are related to but are not contained by, or subordinate to, this resource.
actions: Option<Actions>The available actions for this resource.
This property shall contain the available actions for this resource.
operations: Option<Vec<Operations>>The operations currently running on the drive.
This property shall contain a list of all operations currently running on the drive.
physical_location: Option<Location>The location of the drive. This property is equivalent to the Location property common to other
standard Redfish resources.
This property shall contain the location information of the associated drive.
hotspare_replacement_mode: Option<Option<HotspareReplacementModeType>>The replacement mode for the hot spare drive.
This property shall indicate whether a commissioned hot spare continues to serve as a hot spare after the failed drive is replaced.
write_cache_enabled: Option<Option<Boolean>>An indication of whether the drive write cache is enabled.
This property shall indicate whether the drive write cache is enabled.
multipath: Option<Option<Boolean>>An indication of whether the drive is accessible from multiple paths.
This property shall indicate whether the drive is accessible by an initiator from multiple paths allowing for failover capabilities upon a path failure.
ready_to_remove: Option<Option<Boolean>>An indication of whether the drive is prepared by the system for removal.
This property shall indicate whether the system is prepared for the removal of this drive.
location_indicator_active: Option<Option<Boolean>>An indicator allowing an operator to physically locate this resource.
This property shall contain the state of the indicator used to physically identify or locate this
resource. A write to this property shall update the value of IndicatorLED in this resource, if
supported, to reflect the implementation of the locating function.
measurements: Option<Vec<MeasurementBlock>>An array of DSP0274-defined measurement blocks.
This property shall contain an array of DSP0274-defined measurement blocks.
slot_form_factor: Option<Option<FormFactor>>The form factor of the slot.
This property shall contain the form factor of the slot.
drive_form_factor: Option<Option<FormFactor>>The form factor of the drive inserted in this slot.
This property shall contain the form factor of the drive inserted in this slot.
slot_capable_protocols: Option<Option<Vec<Protocol>>>The drive protocols capable in this slot.
This property shall contain the drive protocols capable in this slot. The value of this property depends upon the connector in this slot, the storage controllers connected to this slot, the configuration of the system, and other constraints that determine if a particular protocol is capable at a given time.
firmware_version: Option<Option<String>>The firmware version for this drive.
This property shall contain the firmware version as defined by the manufacturer for this drive.
spare_part_number: Option<Option<String>>The spare part number of the drive.
This property shall contain the spare part number of the drive.
configuration_lock: Option<Option<ConfigurationLock>>Indicates whether in-band configuration requests to the drive are locked. Other properties, such
as ConfigurationLockState, contain additional information regarding the status of the
configuration lock.
This property shall indicate whether configuration requests to the drive are locked. Services
shall reject modification requests that contain the value Partial.
block_security_id_enabled: Option<Option<Boolean>>Indicates if establishment of a TCG-defined security ID (SID) on the drive is blocked.
This property shall indicate if establishment of a TCG-defined security ID (SID) on the drive is
blocked. The value true shall indicate the TCG-defined ‘Block SID’ command is sent to the drive
during each drive boot sequence.
target_configuration_lock_level: Option<Option<TargetConfigurationLockLevel>>Indicates the target configuration lock level for the drive based upon the state of the
ConfigurationLock property. Other properties, such as ConfigurationLockState, contain
additional information regarding the status of the configuration lock.
This property shall contain the target configuration lock level for the drive. For NVMe drives, services shall implement the locking requirements specified by SNIA’s Swordfish NVMe Model Overview and Mapping Guide.
nvme: Option<Option<Nvme>>NVMe properties for this drive.
This property shall contain NVMe-specific properties of this drive.
hardware_version: Option<Option<String>>The hardware version of this drive.
This property shall contain the hardware version of this drive as determined by the vendor or supplier.
security_id_owned: Option<Option<Boolean>>Indicates if the TCG-defined security ID (SID) was changed from its default value, flagging the drive as owned.
This property shall indicate if a TCG-defined security ID (SID) differs from the TCG-defined
manufacturing security ID (MSID) on the drive, flagging the drive as owned. The value true shall
indicate that the MSID and SID differ. This property should not be present for non-self-encrypting
(SED) drives.
assembly: Option<NavProperty<Assembly>>The link to the assembly associated with this drive.
This property shall contain a link to a resource of type Assembly.
environment_metrics: Option<NavProperty<EnvironmentMetrics>>The link to the environment metrics for this drive.
This property shall contain a link to a resource of type EnvironmentMetrics that specifies the
environment metrics for this drive.
certificates: Option<ReferenceLeaf>metrics: Option<NavProperty<DriveMetrics>>The link to the metrics associated with this drive.
This property shall contain a link to the metrics associated with this drive.