pub struct DriveSetPersonalityKeyAction {
pub algorithm: Option<NmvePersonalityKeyAlgorithm>,
pub key: Option<String>,
}Expand description
This action sets the personality key for the NVMe subsystem.
This action shall set the personality key for the NVMe subsystem as defined by the ‘Programmable Key Authentication Considerations’ clause in the NVMe Base Specification.
Fields
algorithm: Option<NmvePersonalityKeyAlgorithm>The type of authentication algorithm for the key.
This parameter shall contain the type of authentication algorithm for the key as defined by the ‘CDP Authentication Algorithm’ field in the NVMe Base Specification.
key: Option<String>The personality key to set on the NVMe subsystem.
This parameter shall contain the personality key to set on the NVMe subsystem as a hex-encoded string.