pub struct Operations {
pub operation_name: Option<Option<String>>,
pub percentage_complete: Option<Option<Int64>>,
pub operation: Option<Option<OperationType>>,
pub associated_task: Option<ReferenceLeaf>,
}Fields
operation_name: Option<Option<String>>The name of the operation.
This property shall contain a string of the name of the operation.
percentage_complete: Option<Option<Int64>>The percentage of the operation that has been completed.
This property shall contain an integer of the percentage, 0 to 100, of the operation that has
been completed.
operation: Option<Option<OperationType>>The type of the operation.
This property shall contain the type of the operation.
associated_task: Option<ReferenceLeaf>Trait Implementations
Sourceimpl Debug for Operations
impl Debug for Operations
Sourceimpl<'de> Deserialize<'de> for Operations
impl<'de> Deserialize<'de> for Operations
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more