pub struct DriveCollection {
pub base: ResourceCollection,
pub members: Vec<NavProperty<Drive>>,
}Expand description
The collection of Drive resource instances.
This resource shall represent a resource collection of Drive instances for a Redfish
implementation.
Fields
base: ResourceCollectionBase type
members: Vec<NavProperty<Drive>>The members of this collection.
This property shall contain an array of links to the members of this collection.