pub enum DhcpFallback {
Static,
AutoConfig,
None,
UnsupportedValue,
}Variants
Static
Fall back to a static address specified by IPv4StaticAddresses.
DHCP shall fall back to a static address specified by IPv4StaticAddresses.
AutoConfig
Fall back to an autoconfigured address.
DHCP shall fall back to an address generated by the implementation.
None
Continue attempting DHCP without a fallback address.
DHCP shall continue trying to obtain an address without falling back to a fixed address.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.