pub enum EthernetDeviceType {
Physical,
Virtual,
UnsupportedValue,
}Variants
Physical
A physical Ethernet interface.
This value shall indicate a physical traditional network interface.
Virtual
A virtual Ethernet interface.
This value shall indicate a network device function has multiple VLANs and is representing one of
them as a virtual Ethernet interface. The NetworkDeviceFunction property within Links shall
contain the locator for the parent network device function.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.