pub enum TeamMode {
None,
RoundRobin,
ActiveBackup,
Xor,
Broadcast,
Ieee8023ad,
AdaptiveTransmitLoadBalancing,
AdaptiveLoadBalancing,
UnsupportedValue,
}Variants
None
No teaming.
RoundRobin
Packets are transmitted in sequential order from the teamed interfaces.
ActiveBackup
One interface in the team is active and the others are kept in standby until a failure occurs.
Xor
Transmitting is determined based upon a hash policy.
Broadcast
Packets are transmitted on all interfaces in the team.
Ieee8023ad
The interfaces in the team create an IEEE802.3ad link aggregation group.
AdaptiveTransmitLoadBalancing
Packets are transmitted based upon the current load of each interface in the team.
AdaptiveLoadBalancing
Packets are transmitted and received based upon the current load of each interface in the team.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.