EthernetInterface

Struct EthernetInterface 

pub struct EthernetInterface {
Show 34 fields pub base: Resource, pub uefi_device_path: Option<Option<String>>, pub status: Option<Status>, pub interface_enabled: Option<Option<Boolean>>, pub permanent_mac_address: Option<Option<MacAddress>>, pub mac_address: Option<Option<MacAddress>>, pub speed_mbps: Option<Option<Int64>>, pub auto_neg: Option<Option<Boolean>>, pub full_duplex: Option<Option<Boolean>>, pub mtu_size: Option<Option<Int64>>, pub host_name: Option<Option<String>>, pub fqdn: Option<Option<String>>, pub max_ipv6static_addresses: Option<Option<Int64>>, pub vlan: Option<Vlan>, pub ipv4addresses: Option<Vec<Ipv4address>>, pub ipv6address_policy_table: Option<Option<Vec<Ipv6addressPolicyEntry>>>, pub ipv6addresses: Option<Vec<Ipv6address>>, pub ipv6static_addresses: Option<Option<Vec<Ipv6staticAddress>>>, pub ipv6default_gateway: Option<Option<String>>, pub name_servers: Option<Vec<String>>, pub link_status: Option<Option<LinkStatus>>, pub links: Option<Links>, pub actions: Option<Actions>, pub dhcpv4: Option<Dhcpv4configuration>, pub dhcpv6: Option<Dhcpv6configuration>, pub stateless_address_auto_config: Option<StatelessAddressAutoConfiguration>, pub ipv6static_default_gateways: Option<Option<Vec<Ipv6gatewayStaticAddress>>>, pub static_name_servers: Option<Option<Vec<Option<String>>>>, pub ipv4static_addresses: Option<Option<Vec<Ipv4address>>>, pub ethernet_interface_type: Option<Option<EthernetDeviceType>>, pub team_mode: Option<Option<TeamMode>>, pub routing_scope: Option<Option<RoutingScope>>, pub ipv6enabled: Option<Option<Boolean>>, pub vlans: Option<ReferenceLeaf>,
}
The EthernetInterface schema represents a single, logical Ethernet interface or network interface controller (NIC).

This resource contains NIC resources as part of the Redfish Specification.

Fields

base: Resource

Base type

uefi_device_path: Option<Option<String>>

The UEFI device path for this interface.

This property shall contain the UEFI device path to the device that implements this interface, or port.

status: Option<Status>

The status and health of the resource and its subordinate or dependent resources.

This property shall contain any status or health properties of the resource.

interface_enabled: Option<Option<Boolean>>

An indication of whether this interface is enabled.

This property shall indicate whether this interface is enabled. If this interface is also a host interface, modifying this property may modify the InterfaceEnabled property in the HostInterface resource for this interface.

permanent_mac_address: Option<Option<MacAddress>>

The permanent MAC address assigned to this interface, or port.

This property shall contain the permanent MAC address of this interface, or port. Typically, this value is programmed during manufacturing. This address is not assignable.

mac_address: Option<Option<MacAddress>>

The currently configured MAC address of the interface, or logical port.

This property shall contain the effective current MAC address of this interface. If an assignable MAC address is not supported, this value is a read-only alias of the PermanentMACAddress.

speed_mbps: Option<Option<Int64>>

The current speed, in Mbit/s, of this interface.

This property shall contain the link speed of the interface, in megabits per second (Mbit/s) units. This property shall be writable only when the AutoNeg property is false.

auto_neg: Option<Option<Boolean>>

An indication of whether the speed and duplex are automatically negotiated and configured on this interface.

This property shall indicate whether the speed and duplex are automatically negotiated and configured on this interface.

full_duplex: Option<Option<Boolean>>

An indication of whether full-duplex mode is enabled on the Ethernet connection for this interface.

This property shall indicate whether full-duplex mode is enabled on the Ethernet connection for this interface.

mtu_size: Option<Option<Int64>>

The currently configured maximum transmission unit (MTU), in bytes, on this interface.

This property shall contain the size, in bytes, of the largest protocol data unit (PDU) that can be passed in an Ethernet (MAC) frame on this interface, as currently configured by the operating system or driver.

host_name: Option<Option<String>>

The DNS host name, without any domain information.

This property shall contain the DNS host name for this interface. Modifying this property may modify the HostName in one or more EthernetInterface resources that belong to the same system, manager, or other device. If this interface is subordinate to a ComputerSystem resource, modifying this property may modify the HostName of the ComputerSystem resource that contains this interface. If this interface is subordinate to a Manager resource, modifying this property may modify the HostName of the ManagerNetworkProtocol resource of the Manager resource that contains this interface. Services should ignore this property in modification requests if FQDN is also provided in the same request.

fqdn: Option<Option<String>>

The complete, fully qualified domain name that DNS obtains for this interface.

This property shall contain the fully qualified domain name that DNS obtains for this interface.

max_ipv6static_addresses: Option<Option<Int64>>

The maximum number of static IPv6 addresses that can be configured on this interface.

This property shall indicate the number of array items supported by IPv6StaticAddresses, or the maximum number of static IPv6 addresses that can be configured on this interface.

vlan: Option<Vlan>

If this network interface supports more than one VLAN, this property is absent. VLAN collections appear in the Links property of this resource.

This property shall contain the VLAN for this interface. If this interface supports more than one VLAN, the VLAN property shall be absent and, instead, the VLAN collection link shall be present.

ipv4addresses: Option<Vec<Ipv4address>>

The IPv4 addresses currently in use by this interface.

This property shall contain an array of objects that represent the IPv4 connection characteristics currently in use by this interface for any value of AddressOrigin. It is recommended that this property be regarded as read-only with configuration of static addresses performed by updating the values within IPv4StaticAddresses. Services may reject updates to this array for this reason. This property should contain an empty array if there are no active IPv4 addresses.

ipv6address_policy_table: Option<Option<Vec<Ipv6addressPolicyEntry>>>

An array that represents the RFC6724-defined address selection policy table.

This property shall contain an array of objects that represent the RFC6724-defined address selection policy table.

ipv6addresses: Option<Vec<Ipv6address>>

The IPv6 addresses currently in use by this interface.

This property shall contain an array of objects that represent the IPv6 connection characteristics for this interface for any value of AddressOrigin. This property should contain an empty array if there are no active IPv6 addresses.

ipv6static_addresses: Option<Option<Vec<Ipv6staticAddress>>>

The IPv6 static addresses assigned to this interface. See IPv6Addresses for the addresses in use by this interface.

This property shall contain an array of objects that represent the IPv6 static connection characteristics for this interface. Services should represent static addresses that are not configured as null values, as described by the ‘PATCH on array properties’ clause of the Redfish Specification. Services should not represent static addresses that are not configured as invalid IP addresses, such as ::.

ipv6default_gateway: Option<Option<String>>

The IPv6 default gateway address in use on this interface.

This property shall contain the current IPv6 default gateway address in use on this interface.

name_servers: Option<Vec<String>>

The DNS servers in use on this interface.

This property shall contain the DNS servers in use on this interface.

link_status: Option<Option<LinkStatus>>

The link status of this interface, or port.

This property shall contain the link status of this interface, or port.

links: Option<Links>

The links to other resources that are related to this resource.

This property shall contain links to resources that are related to but are not contained by, or subordinate to, this resource.

actions: Option<Actions>

The available actions for this resource.

This property shall contain the available actions for this resource.

dhcpv4: Option<Dhcpv4configuration>

DHCPv4 configuration for this interface.

This property shall contain the configuration of DHCP v4.

dhcpv6: Option<Dhcpv6configuration>

DHCPv6 configuration for this interface.

This property shall contain the configuration of DHCP v6.

stateless_address_auto_config: Option<StatelessAddressAutoConfiguration>

Stateless address autoconfiguration (SLAAC) parameters for this interface.

This object shall contain the IPv4 and IPv6 stateless address automatic configuration (SLAAC) properties for this interface.

ipv6static_default_gateways: Option<Option<Vec<Ipv6gatewayStaticAddress>>>

The IPv6 static default gateways for this interface.

The values in this array shall represent the IPv6 static default gateway addresses for this interface.

static_name_servers: Option<Option<Vec<Option<String>>>>

The statically-defined set of DNS server IPv4 and IPv6 addresses.

This property shall contain the statically-defined set of DNS server IP addresses to use when DHCP provisioning is not enabled for name server configuration. As an implementation option, they can be used in addition to DHCP-provided addresses, or in cases where the DHCP server provides no DNS assignments.

ipv4static_addresses: Option<Option<Vec<Ipv4address>>>

The IPv4 static addresses assigned to this interface. See IPv4Addresses for the addresses in use by this interface.

This property shall contain an array of objects that represent all IPv4 static addresses assigned to, but not necessarily in use by, this interface. The IPv4Addresses property shall also list the addresses that this interface uses. Services should represent static addresses that are not configured as null values, as described by the ‘PATCH on array properties’ clause of the Redfish Specification. Services should not represent static addresses that are not configured as invalid IP addresses, such as 0.0.0.0.

ethernet_interface_type: Option<Option<EthernetDeviceType>>

The type of interface.

This property shall contain the type of interface.

team_mode: Option<Option<TeamMode>>

The team mode for this interface.

This property shall contain the team mode for this interface. If this property is not present, the value shall be assumed to be None.

routing_scope: Option<Option<RoutingScope>>

The routing scope for this interface.

This property shall contain the routing scope for this interface. This property shall only be present if this interface belongs to a virtual machine or container.

ipv6enabled: Option<Option<Boolean>>

An indication of whether IPv6 is enabled on this interface.

This property shall indicate whether IPv6 is enabled on this interface. If this property contains false, the interface shall not contain any assigned IPv6 addresses, shall not initiate DHCPv6 requests, and shall not send or process ICMPv6 packets. If this property is not present, but this interface contains other IPv6 properties, the value shall be assumed to be true.

vlans: Option<ReferenceLeaf>