Links

Struct Links 

pub struct Links {
    pub base: Links,
    pub endpoints: Option<Vec<ReferenceLeaf>>,
    pub host_interface: Option<NavProperty<HostInterface>>,
    pub chassis: Option<NavProperty<Chassis>>,
    pub network_device_function: Option<NavProperty<NetworkDeviceFunction>>,
    pub network_device_functions: Option<Vec<NavProperty<NetworkDeviceFunction>>>,
    pub ports: Option<Vec<ReferenceLeaf>>,
    pub related_interfaces: Option<Vec<NavProperty<EthernetInterface>>>,
    pub affiliated_interfaces: Option<Vec<NavProperty<EthernetInterface>>>,
}

Fields

base: Links

Base type

endpoints: Option<Vec<ReferenceLeaf>>host_interface: Option<NavProperty<HostInterface>>

The link to a Host Interface that is associated with this Ethernet interface.

This property shall contain a link to a resource of type HostInterface that represents the interface that a host uses to communicate with a manager.

chassis: Option<NavProperty<Chassis>>

The link to the chassis that contains this Ethernet interface.

This property shall contain a link to a resource of type Chassis that represent the physical container associated with this Ethernet interface.

network_device_function: Option<NavProperty<NetworkDeviceFunction>>

The link to the parent network device function and is only used when representing one of the VLANs on that network device function, such as is done in Unix.

This property shall contain a link to a resource of type NetworkDeviceFunction and only be populated with the EthernetInterfaceType property is Virtual.

network_device_functions: Option<Vec<NavProperty<NetworkDeviceFunction>>>

The link to the network device functions that constitute this Ethernet interface.

This property shall contain an array of links to resources of type NetworkDeviceFunction.

ports: Option<Vec<ReferenceLeaf>>related_interfaces: Option<Vec<NavProperty<EthernetInterface>>>

The links to the Ethernet interfaces that constitute this Ethernet interface.

This property shall contain an array of links to resources of type EthernetInterface. If TeamMode contains None, this property shall contain one member that represents the parent interface for the VLAN. For other values of TeamMode, this property shall contain the members of the team.

affiliated_interfaces: Option<Vec<NavProperty<EthernetInterface>>>

The links to the Ethernet interfaces that are affiliated with this interface, such as a VLAN or a team that uses this interface.

This property shall contain an array of links to resources of type EthernetInterface that represent the Ethernet interfaces that are affiliated with this interface. EthernetInterface resources referenced in this property shall reference this resource in their RelatedInterfaces property.