pub struct EthernetInterfaceCollection {
pub base: ResourceCollection,
pub members: Vec<NavProperty<EthernetInterface>>,
}Expand description
The collection of EthernetInterface resource instances.
This resource shall represent a resource collection of EthernetInterface instances for a Redfish
implementation.
Fields
base: ResourceCollectionBase type
members: Vec<NavProperty<EthernetInterface>>The members of this collection.
This property shall contain an array of links to the members of this collection.