pub enum DiagnosticDataTypes {
Manager,
PreOs,
Os,
Oem,
Cper,
CperSection,
UnsupportedValue,
}Variants
Manager
Manager diagnostic data.
PreOs
Pre-OS diagnostic data.
Os
Operating system (OS) diagnostic data.
Oem
OEM diagnostic data.
Cper
UEFI Common Platform Error Record.
This value shall indicate the data provided at the URI specified by the AdditionalDataURI
property is a complete UEFI Specification-defined Common Platform Error Record. The CPER data
shall contain a Record Header and at least one Section as defined by the UEFI Specification.
CperSection
A Section of a UEFI Common Platform Error Record.
This value shall indicate the data provided at the URI specified by the AdditionalDataURI
property is a single Section of a UEFI Specification-defined Common Platform Error Record. The
CPER data shall contain one Section as defined by the UEFI Specification, with no Record Header.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.