pub enum EventType {
StatusChange,
ResourceUpdated,
ResourceAdded,
ResourceRemoved,
Alert,
MetricReport,
Other,
UnsupportedValue,
}Variants
StatusChange
The status of a resource has changed.
ResourceUpdated
A resource has been updated.
ResourceAdded
A resource has been added.
ResourceRemoved
A resource has been removed.
Alert
A condition requires attention.
MetricReport
The telemetry service is sending a metric report.
Events of type MetricReport shall be sent to a client in accordance with the MetricReport
schema definition.
Other
Because EventType is deprecated as of Redfish Specification v1.6, the event is based on a
registry or resource but not an EventType.
Events of type Other shall be sent to a client in accordance with subscriptions to
RegistryPrefixes or ResourceTypes.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.