EventRecord

Struct EventRecord 

pub struct EventRecord {
Show 27 fields pub base: ReferenceableMember, pub event_type: EventType, pub event_id: Option<String>, pub event_timestamp: Option<DateTimeOffset>, pub severity: Option<String>, pub message: Option<String>, pub message_id: String, pub message_args: Option<Vec<String>>, pub context: Option<String>, pub actions: Option<EventRecordActions>, pub event_group_id: Option<Int64>, pub message_severity: Option<Health>, pub specific_event_exists_in_group: Option<Boolean>, pub cper: Option<Cper>, pub diagnostic_data: Option<Option<String>>, pub diagnostic_data_type: Option<Option<DiagnosticDataTypes>>, pub additional_data_size_bytes: Option<Option<Int64>>, pub additional_data_uri: Option<Option<String>>, pub resolution: Option<String>, pub oem_diagnostic_data_type: Option<Option<String>>, pub resolution_steps: Option<Vec<ResolutionStep>>, pub username: Option<Option<String>>, pub user_authentication_source: Option<Option<String>>, pub origin_of_condition_unavailable: Option<Option<Boolean>>, pub origin_address: Option<Option<String>>, pub origin_of_condition: Option<ReferenceLeaf>, pub log_entry: Option<NavProperty<LogEntry>>,
}

Fields

base: ReferenceableMember

Base type

event_type: EventType

The type of event.

This property shall indicate the type of event.

event_id: Option<String>

The unique instance identifier of an event.

This property shall contain a service-defined unique identifier for the event.

event_timestamp: Option<DateTimeOffset>

The time the event occurred.

This property shall indicate the time the event occurred where the value shall be consistent with the Redfish service time that is also used for the values of the Modified property.

severity: Option<String>

The severity of the event.

This property shall contain the severity of the event, as defined in the ‘Status’ clause of the Redfish Specification. Services can replace the value defined in the message registry with a value more applicable to the implementation.

message: Option<String>

The human-readable event message.

This property shall contain a human-readable event message.

message_id: String

The identifier for the message.

This property shall contain a MessageId, as defined in the ‘MessageId format’ clause of the Redfish Specification.

message_args: Option<Vec<String>>

An array of message arguments that are substituted for the arguments in the message when looked up in the message registry.

This property shall contain an array of message arguments that are substituted for the arguments in the message when looked up in the message registry. It has the same semantics as the MessageArgs property in the Redfish MessageRegistry schema. If the corresponding ParamType value contains number, the service shall convert the number to a string representation of the number.

context: Option<String>

A context can be supplied at subscription time. This property is the context value supplied by the subscriber.

This property shall contain a client supplied context for the event destination to which this event is being sent.

actions: Option<EventRecordActions>

The available actions for this resource.

This property shall contain the available actions for this resource.

event_group_id: Option<Int64>

The identifier that correlates events with the same root cause. If 0, no other event is related to this event.

This property shall indicate that events are related and shall have the same value when multiple event messages are produced by the same root cause. Implementations shall use separate values for events with a separate root cause. This property value shall not imply an ordering of events. The 0 value shall indicate that this event is not grouped with any other event.

message_severity: Option<Health>

The severity of the message in this event.

This property shall contain the severity of the message in this event. Services can replace the value defined in the message registry with a value more applicable to the implementation.

specific_event_exists_in_group: Option<Boolean>

Indicates this event is equivalent to a more specific event in this event group.

This property shall indicate that the event is equivalent to another event, with a more specific definition, within the same EventGroupId. For example, the DriveFailed message from the Storage Device Message Registry is more specific than the ResourceStatusChangedCritical message from the Resource Event Message Registry, when both occur with the same EventGroupId. This property shall contain true if a more specific event is available, and shall contain false if no equivalent event exists in the same EventGroupId. If this property is absent, the value shall be assumed to be false.

cper: Option<Cper>

Details for a CPER section or record associated with this event.

This property shall contain the details for a CPER section or record that is the source of this event.

diagnostic_data: Option<Option<String>>

A Base64-encoded set of diagnostic data associated with this event.

This property shall contain a Base64-encoded string, with padding characters, that represents the diagnostic data associated with this event. The contents shall depend on the value of the DiagnosticDataType property. The length of the value should not exceed 4 KB. Larger diagnostic data payloads should omit this property and use the AdditionalDataURI property to reference the data. If both DiagnosticData and AdditionalDataURI are present, DiagnosticData shall contain the Base64-encoding of the data retrieved from the URI specified by the AdditionalDataURI property.

diagnostic_data_type: Option<Option<DiagnosticDataTypes>>

The type of data available in the DiagnosticData property or retrieved from the URI specified by the AdditionalDataURI property.

This property shall contain the type of data available in the DiagnosticData property or retrieved from the URI specified by the AdditionalDataURI property.

additional_data_size_bytes: Option<Option<Int64>>

The size of the additional data for this event.

This property shall contain the size of the additional data retrieved from the URI specified by the AdditionalDataURI property for this event.

additional_data_uri: Option<Option<String>>

The URI at which to access the additional data for the event, such as diagnostic data, image captures, or other files.

This property shall contain the URI at which to access the additional data for the event, using the Redfish protocol and authentication methods. If both DiagnosticData and AdditionalDataURI are present, DiagnosticData shall contain a Base64-encoded string, with padding characters, of the data retrieved from the URI specified by the AdditionalDataURI property.

resolution: Option<String>

Used to provide suggestions on how to resolve the situation that caused the event.

This property shall contain the resolution of the event. Services should replace the resolution defined in the message registry with a more specific resolution in the event.

oem_diagnostic_data_type: Option<Option<String>>

The OEM-defined type of data available in the DiagnosticData property or retrieved from the URI specified by the AdditionalDataURI property.

This property shall contain the OEM-defined type of data available in the DiagnosticData property or retrieved from the URI specified by the AdditionalDataURI property. This property shall be present if DiagnosticDataType is OEM.

resolution_steps: Option<Vec<ResolutionStep>>

The list of recommended steps to resolve the cause of the event.

This property shall contain an array of recommended steps to resolve the cause of the event. This property shall not be present if the MessageSeverity or Severity properties contain OK. A client can stop executing the resolution steps once the Resolved property in the associated LogEntry resource contains true or the Health property in the associated resource referenced by the OriginOfCondition property contains OK.

username: Option<Option<String>>

The username of the account associated with the event record.

This property shall contain the username of the account associated with the event record. This should be used for events that result from a user action.

user_authentication_source: Option<Option<String>>

The source of authentication for the username property associated with the event record.

This property shall contain the URL to the authentication service that is associated with the username property. This should be used for events that result from a user action.

origin_of_condition_unavailable: Option<Option<Boolean>>

Indicates whether the OriginOfCondition link is unavailable, such as due to the deletion of the resource.

This property shall indicate whether the OriginOfCondition link is unavailable. If true, services shall not expand the OriginOfCondition link. If this property is not present, the value shall be assumed to be false.

origin_address: Option<Option<String>>

The IP address, with scheme, of the user associated with the log entry.

This property shall contain the IP address, with scheme, of the user associated with the log entry. This should be used for audit logs that result from a user action.

origin_of_condition: Option<ReferenceLeaf>log_entry: Option<NavProperty<LogEntry>>

The link to a log entry if an entry was created for this event.

This property shall contain a link to a resource of type LogEntry that represents the log entry created for this event.