pub struct EventServiceTestEventSubscriptionAction {}Expand description
This action generates a test event using the pre-defined test message.
This action shall send an event containing the TestMessage message from the Resource Event
Message Registry to all appropriate event destinations.