Module host_interface

Module host_interface 

Generated schema of HostInterface namespace

Structs

Actions
The available actions for this resource.
CredentialBootstrapping
The credential bootstrapping settings for this interface.
CredentialBootstrappingUpdate
Update struct corresponding to CredentialBootstrapping
HostInterface
The HostInterface schema contains properties associated with a Redfish host interface. A Redfish host interface is a connection between host software and a Redfish service.
HostInterfaceUpdate
Update struct corresponding to HostInterface
Links
LinksUpdate
Update struct corresponding to Links
OemActions
The available OEM-specific actions for this resource.

Enums

AuthenticationMode
HostInterfaceType