CredentialBootstrapping

Struct CredentialBootstrapping 

pub struct CredentialBootstrapping {
    pub enabled: Option<Option<Boolean>>,
    pub enable_after_reset: Option<Option<Boolean>>,
    pub role_id: Option<String>,
}
The credential bootstrapping settings for this interface.

This type shall contain settings for the Redfish Host Interface Specification-defined ‘credential bootstrapping via IPMI commands’ feature for this interface.

Fields

enabled: Option<Option<Boolean>>

An indication of whether credential bootstrapping is enabled for this interface.

This property shall indicate whether credential bootstrapping is enabled for this interface.

enable_after_reset: Option<Option<Boolean>>

An indication of whether credential bootstrapping is enabled after a reset for this interface.

This property shall indicate whether credential bootstrapping is enabled after a reset for this interface. If true, services shall set the Enabled property to true after a reset of the host or the service.

role_id: Option<String>

The role used for the bootstrap account created for this interface.

This property shall contain the Id property of the Role resource that is used for the bootstrap account created for this interface.