Links

Struct Links 

pub struct Links {
    pub base: Links,
    pub computer_systems: Option<Vec<NavProperty<ComputerSystem>>>,
    pub kernel_auth_role: Option<ReferenceLeaf>,
    pub firmware_auth_role: Option<ReferenceLeaf>,
    pub auth_none_role: Option<ReferenceLeaf>,
    pub credential_bootstrapping_role: Option<ReferenceLeaf>,
}

Fields

base: Links

Base type

computer_systems: Option<Vec<NavProperty<ComputerSystem>>>

An array of links to the computer systems connected to this host interface.

This property shall contain an array of links to resources of type ComputerSystem that are connected to this host interface.

kernel_auth_role: Option<ReferenceLeaf>firmware_auth_role: Option<ReferenceLeaf>auth_none_role: Option<ReferenceLeaf>credential_bootstrapping_role: Option<ReferenceLeaf>