pub struct HostInterfaceCollection {
pub base: ResourceCollection,
pub members: Vec<NavProperty<HostInterface>>,
}Expand description
The collection of HostInterface resource instances.
This resource shall represent a resource collection of HostInterface instances for a Redfish
implementation.
Fields
base: ResourceCollectionBase type
members: Vec<NavProperty<HostInterface>>The members of this collection.
This property shall contain an array of links to the members of this collection.