Cper

Struct Cper 

pub struct Cper {
    pub notification_type: Option<Option<Guid>>,
    pub section_type: Option<Option<Guid>>,
    pub oem: Option<Oem>,
}
Details for a CPER section or record associated with a log entry.

This object shall contain the details for a CPER section or record that is the source of a log entry.

Fields

notification_type: Option<Option<Guid>>

The CPER Notification Type for a CPER record.

This property shall contain the CPER Notification Type for a CPER record that corresponds to the contents of the DiagnosticData property or data retrieved from the URI specified by the AdditionalDataURI property. This property shall only be present if DiagnosticDataType contains CPER.

section_type: Option<Option<Guid>>

The CPER Section Type.

This property shall contain the CPER Section Type for a CPER section that corresponds to the contents of the DiagnosticData property or data retrieved from the URI specified by the AdditionalDataURI property. This property shall only be present if DiagnosticDataType contains CPERSection.

oem: Option<Oem>

The OEM extension property.

This property shall contain the OEM extensions. All values for properties contained in this object shall conform to the Redfish Specification-described requirements.