pub struct LogEntryCollection {
pub base: ResourceCollection,
pub members: Vec<NavProperty<LogEntry>>,
}Expand description
The collection of LogEntry resource instances.
This resource shall represent a resource collection of LogEntry instances for a Redfish
implementation.
Fields
base: ResourceCollectionBase type
members: Vec<NavProperty<LogEntry>>The members of this collection.
This property shall contain an array of links to the members of this collection.