pub enum LogEntryTypes {
Event,
Sel,
Multiple,
Oem,
Cxl,
UnsupportedValue,
}Variants
Event
The log contains Redfish-defined messages.
Sel
The log contains legacy IPMI System Event Log (SEL) entries.
Multiple
The log contains multiple log entry types and, therefore, the log service cannot guarantee a single entry type.
Oem
The log contains entries in an OEM-defined format.
Cxl
The log contains CXL log entries.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.