pub enum OverWritePolicy {
Unknown,
WrapsWhenFull,
NeverOverWrites,
UnsupportedValue,
}Variants
Unknown
The overwrite policy is not known or is undefined.
WrapsWhenFull
When full, new entries to the log overwrite earlier entries.
NeverOverWrites
When full, new entries to the log are discarded.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.