LogService

Struct LogService 

pub struct LogService {
Show 18 fields pub base: Resource, pub service_enabled: Option<Option<Boolean>>, pub max_number_of_records: Option<Int64>, pub over_write_policy: Option<OverWritePolicy>, pub date_time: Option<Option<DateTimeOffset>>, pub date_time_local_offset: Option<Option<String>>, pub actions: Option<Actions>, pub status: Option<Status>, pub log_entry_type: Option<Option<LogEntryTypes>>, pub syslog_filters: Option<Option<Vec<SyslogFilter>>>, pub auto_dst_enabled: Option<Boolean>, pub log_purposes: Option<Option<Vec<LogPurpose>>>, pub oem_log_purpose: Option<Option<String>>, pub persistency: Option<Boolean>, pub overflow: Option<Boolean>, pub diagnostic_data_details: Option<Option<Vec<DiagnosticDataDetails>>>, pub auto_clear_resolved_entries: Option<Option<AutoClearResolvedEntries>>, pub entries: Option<NavProperty<LogEntryCollection>>,
}
The LogService schema contains properties for monitoring and configuring a log service. When the Id property contains DeviceLog, the log contains device-resident log entries that follow the physical device when moved from system-to-system, and not a replication or subset of a system event log.

This resource shall represent a log service for a Redfish implementation. When the Id property contains DeviceLog, the log shall contain log entries that migrate with the device.

Fields

base: Resource

Base type

service_enabled: Option<Option<Boolean>>

An indication of whether this service is enabled.

This property shall indicate whether this service is enabled.

max_number_of_records: Option<Int64>

The maximum number of log entries that this service can have.

This property shall contain the maximum number of LogEntry resources in the LogEntryCollection resource for this service.

over_write_policy: Option<OverWritePolicy>

The overwrite policy for this service that takes place when the log is full.

This property shall indicate the policy of the log service when the MaxNumberOfRecords has been reached.

date_time: Option<Option<DateTimeOffset>>

The current date and time with UTC offset of the log service.

This property shall contain the current date and time with UTC offset of the log service.

date_time_local_offset: Option<Option<String>>

The time offset from UTC that the DateTime property is in +HH:MM format.

This property shall contain the offset from UTC time that the DateTime property contains. If both DateTime and DateTimeLocalOffset are provided in modification requests, services shall apply DateTimeLocalOffset after DateTime is applied.

actions: Option<Actions>

The available actions for this resource.

This property shall contain the available actions for this resource.

status: Option<Status>

The status and health of the resource and its subordinate or dependent resources.

This property shall contain any status or health properties of the resource.

log_entry_type: Option<Option<LogEntryTypes>>

The format of the log entries.

This property shall contain the value for the EntryType property of all LogEntry resources contained in the LogEntryCollection resource for this log service. If the service cannot determine or guarantee a single EntryType value for all LogEntry resources, this property shall contain the value Multiple.

syslog_filters: Option<Option<Vec<SyslogFilter>>>

A list of syslog message filters to be logged locally.

This property shall describe all desired syslog messages to be logged locally. If this property contains an empty array, all messages shall be logged.

auto_dst_enabled: Option<Boolean>

An indication of whether the log service is configured for automatic Daylight Saving Time (DST) adjustment.

This property shall indicate whether the log service is configured for automatic Daylight Saving Time (DST) adjustment. DST adjustment shall not modify the timestamp of existing log entries.

log_purposes: Option<Option<Vec<LogPurpose>>>

The purposes of the log.

This property shall contain the purposes of the log.

oem_log_purpose: Option<Option<String>>

The OEM-specified purpose of the log if LogPurposes contains OEM.

This property shall contain the OEM-specified purpose of the log if LogPurposes contains OEM.

persistency: Option<Boolean>

Indicates whether the log service is persistent across a cold reset.

This property shall indicate whether the log service is persistent across a cold reset of the device.

overflow: Option<Boolean>

Indicates whether the log service has overflowed.

This property shall indicate whether the log service has overflowed and is no longer able to store new logs.

diagnostic_data_details: Option<Option<Vec<DiagnosticDataDetails>>>

The detailed information for the data collected with the CollectDiagnosticData action.

This property shall contain the detailed information for the data collected with the CollectDiagnosticData action.

auto_clear_resolved_entries: Option<Option<AutoClearResolvedEntries>>

Indicates if this log service automatically clears the resolved log entries.

This property shall indicate if this log service automatically clears the resolved log entries found in the LogEntryCollection resource. If this property is not present, the value shall be assumed to be None.

entries: Option<NavProperty<LogEntryCollection>>

The link to the log entry collection.

This property shall contain a link to a resource collection of type LogEntryCollection.