SyslogFilter

Struct SyslogFilter 

pub struct SyslogFilter {
    pub lowest_severity: Option<Option<SyslogSeverity>>,
    pub log_facilities: Option<Option<Vec<SyslogFacility>>>,
}
A syslog filter.

This type shall contain the filter for a syslog message. The filter shall describe the desired syslog message to be enabled locally.

Fields

lowest_severity: Option<Option<SyslogSeverity>>

The lowest severity level message that will be logged.

This property shall contain the lowest syslog severity level that will be logged. The service shall log all messages equal to or greater than the value in this property. The value All shall indicate all severities.

log_facilities: Option<Option<Vec<SyslogFacility>>>

The types of programs that can log messages.

This property shall contain the types of programs that can log messages. If this property contains an empty array or is absent, all facilities shall be indicated.