pub enum DateTimeSource {
Rtc,
Firmware,
Host,
Ntp,
Ptp,
UnsupportedValue,
}Variants
Rtc
The date and time is retrieved from the manager’s real time clock (RTC).
Firmware
The date and time is set and held by firmware.
Host
The date and time is retrieved from the host.
Ntp
The date and time source is a Network Time Protocol (NTP) server.
Ptp
The date and time source is a Precision Time Protocol (PTP) server.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.