pub enum GraphicalConnectTypesSupported {
Kvmip,
Oem,
UnsupportedValue,
}Variants
Kvmip
The controller supports a graphical console connection through a KVM-IP (redirection of Keyboard, Video, Mouse over IP) protocol.
Oem
The controller supports a graphical console connection through an OEM-specific protocol.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.