pub enum ManagerType {
ManagementController,
EnclosureManager,
Bmc,
RackManager,
AuxiliaryController,
Service,
FabricManager,
UnsupportedValue,
}Variants
ManagementController
A controller that primarily monitors or manages the operation of a device or system.
EnclosureManager
A controller that provides management functions for a chassis, group of devices, or group of systems with their own BMCs (baseboard management controllers). An example of this is a manager that aggregates and orchestrates management functions across multiple BMCs in an enclosure.
Bmc
A controller that provides management functions for one or more computer systems. Commonly known as a BMC (baseboard management controller). Examples of this include a BMC dedicated to one system or a multi-host manager providing BMC capabilities to multiple systems.
RackManager
A controller that provides management functions for a whole or part of a rack. An example of this is a manager that aggregates and orchestrates management functions across multiple managers, such as enclosure managers and BMCs (baseboard management controllers), in a rack.
AuxiliaryController
A controller that provides management functions for a particular subsystem or group of devices as part of a larger system.
Service
A software-based service that provides management functions.
FabricManager
A controller that primarily monitors or manages the operation of a group of fabric attached nodes and switches.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.