pub enum ResetToDefaultsType {
ResetAll,
PreserveNetworkAndUsers,
PreserveNetwork,
UnsupportedValue,
}Variants
ResetAll
Reset all settings to factory defaults.
PreserveNetworkAndUsers
Reset all settings except network and local usernames/passwords to factory defaults.
PreserveNetwork
Reset all settings except network settings to factory defaults.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.