pub enum SerialConnectTypesSupported {
Ssh,
Telnet,
Ipmi,
Oem,
UnsupportedValue,
}Variants
Ssh
The controller supports a serial console connection through the SSH protocol.
Telnet
The controller supports a serial console connection through the Telnet protocol.
Ipmi
The controller supports a serial console connection through the IPMI Serial Over LAN (SOL) protocol.
Oem
The controller supports a serial console connection through an OEM-specific protocol.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.