Actions

Struct Actions 

pub struct Actions {
    pub oem: Option<OemActions>,
    pub force_failover: Option<Action<ManagerForceFailoverAction, ()>>,
    pub modify_redundancy_set: Option<Action<ManagerModifyRedundancySetAction, ()>>,
    pub reset: Option<Action<ManagerResetAction, ()>>,
    pub reset_to_defaults: Option<Action<ManagerResetToDefaultsAction, ()>>,
    pub update_security_mode: Option<Action<ManagerUpdateSecurityModeAction, ()>>,
}
The available actions for this resource.

This type shall contain the available actions for this resource.

Fields

oem: Option<OemActions>

The available OEM-specific actions for this resource.

This property shall contain the available OEM-specific actions for this resource.

force_failover: Option<Action<ManagerForceFailoverAction, ()>>modify_redundancy_set: Option<Action<ManagerModifyRedundancySetAction, ()>>reset: Option<Action<ManagerResetAction, ()>>reset_to_defaults: Option<Action<ManagerResetToDefaultsAction, ()>>update_security_mode: Option<Action<ManagerUpdateSecurityModeAction, ()>>

Implementations

Source

impl Actions

pub async fn force_failover<B: Bmc>( &self, bmc: &B, new_manager: Option<Reference>, ) -> Result<ModificationResponse<()>, B::Error>
where B::Error: ActionError,

The ForceFailover action forces a failover of this manager to the manager used in the parameter.

This action shall perform a forced failover of the manager’s redundancy to the manager supplied as a parameter.

Errors
pub async fn modify_redundancy_set<B: Bmc>( &self, bmc: &B, add: Option<Vec<Reference>>, remove: Option<Vec<Reference>>, ) -> Result<ModificationResponse<()>, B::Error>
where B::Error: ActionError,

The ModifyRedundancySet operation adds members to or removes members from a redundant group of managers.

The ModifyRedundancySet operation shall add members to or remove members from a redundant group of managers.

Errors
pub async fn reset<B: Bmc>( &self, bmc: &B, reset_type: Option<ResetType>, ) -> Result<ModificationResponse<()>, B::Error>
where B::Error: ActionError,

The reset action resets/reboots the manager.

This action shall reset the manager. If this manager provides the Redfish service, the service shall send the action response before resetting to prevent client timeouts.

Errors
pub async fn reset_to_defaults<B: Bmc>( &self, bmc: &B, reset_type: Option<ResetToDefaultsType>, ) -> Result<ModificationResponse<()>, B::Error>
where B::Error: ActionError,

The reset action resets the manager settings to factory defaults. This can cause the manager to reset.

This action shall reset the manager settings. This action may impact other resources.

Errors
pub async fn update_security_mode<B: Bmc>( &self, bmc: &B, security_mode: Option<SecurityModeTypes>, oem_security_mode: Option<String>, ) -> Result<ModificationResponse<()>, B::Error>
where B::Error: ActionError,

The update security mode action updates the security mode for the manager. This can cause the manager to reset and reset other settings to factory defaults. Services might require the ResetToDefaults action to clear the security mode.

This action shall update the security mode for the manager. Services may reset other settings to factory defaults. Services may require the ResetToDefaults action to clear security settings. This action may impact other resources.

Errors