CommandShell

Struct CommandShell 

pub struct CommandShell {
    pub base: ManagerService,
    pub connect_types_supported: Option<Vec<CommandConnectTypesSupported>>,
}
The information about a command shell service that this manager provides.

This type shall describe a command shell service for a manager.

Fields

base: ManagerService

Base type

connect_types_supported: Option<Vec<CommandConnectTypesSupported>>

This property enumerates the command shell connection types that the implementation allows.

This property shall contain an array of the enumerations. SSH shall be included if the Secure Shell (SSH) protocol is supported. Telnet shall be included if the Telnet protocol is supported. IPMI shall be included if the IPMI Serial Over LAN (SOL) protocol is supported.