DaylightSavingTime

Struct DaylightSavingTime 

pub struct DaylightSavingTime {
    pub start_date_time: Option<DateTimeOffset>,
    pub end_date_time: Option<DateTimeOffset>,
    pub offset_minutes: Option<Int64>,
    pub time_zone_name: Option<String>,
}
The daylight saving time settings for a manager.

This type shall contain the daylight saving time settings for a manager.

Fields

start_date_time: Option<DateTimeOffset>

The start date and time with UTC offset of daylight saving time.

This property shall contain the start date and time with UTC offset of daylight saving time for this manager. Services shall update the UTC offset based on changes made to DateTimeLocalOffset. This property shall be read-only if the service contains time zone databases.

end_date_time: Option<DateTimeOffset>

The end date and time with UTC offset of daylight saving time.

This property shall contain the end date and time with UTC offset of daylight saving time for this manager. If daylight saving time is permanent, specify a sufficiently distant end date and time. Services shall update the UTC offset based on changes made to DateTimeLocalOffset. This property shall be read-only if the service contains time zone databases.

offset_minutes: Option<Int64>

The daylight saving time offset in minutes.

This property shall contain the number of minutes added to the DateTime value when the DateTime value is between the values of StartDateTime and EndDateTime. This offset shall be applied only if AutoDSTEnabled is true. This property shall be read-only if the service contains time zone databases.

time_zone_name: Option<String>

The time zone of the manager when daylight saving time is in effect.

This property shall contain the time zone of the manager when daylight saving time is in effect. When daylight saving time is in effect, the service shall update the TimeZoneName property in the root of the resource. When daylight saving time is no longer in effect, the service shall restore the original value of the TimeZoneName property in the root of the resource. The time zone shall be either the ‘Name’ or the ‘Format’ for the zone as defined in the IANA Time Zone Database. The value of this property is used for display purposes, especially to enhance the display of time. This property shall be read-only if the service contains time zone databases.