GraphicalConsole

Struct GraphicalConsole 

pub struct GraphicalConsole {
    pub base: ManagerService,
    pub connect_types_supported: Option<Vec<GraphicalConnectTypesSupported>>,
}
The information about a graphical console service that this manager provides.

This type shall describe a graphical console service for a manager.

Fields

base: ManagerService

Base type

connect_types_supported: Option<Vec<GraphicalConnectTypesSupported>>

This property enumerates the graphical console connection types that the implementation allows.

This property shall contain an array of the enumerations. RDP shall be included if the Remote Desktop (RDP) protocol is supported. KVMIP shall be included if a vendor-defined KVM-IP protocol is supported.