Links

Struct Links 

pub struct Links {
    pub base: Links,
    pub manager_for_servers: Option<Vec<NavProperty<ComputerSystem>>>,
    pub manager_for_chassis: Option<Vec<NavProperty<Chassis>>>,
    pub manager_in_chassis: Option<NavProperty<Chassis>>,
    pub manager_for_switches: Option<Vec<ReferenceLeaf>>,
    pub active_software_image: Option<NavProperty<SoftwareInventory>>,
    pub software_images: Option<Vec<NavProperty<SoftwareInventory>>>,
    pub managed_by: Option<Vec<NavProperty<Manager>>>,
    pub manager_for_managers: Option<Vec<NavProperty<Manager>>>,
    pub selected_network_port: Option<ReferenceLeaf>,
    pub manager_for_fabrics: Option<Vec<ReferenceLeaf>>,
}

Fields

base: Links

Base type

manager_for_servers: Option<Vec<NavProperty<ComputerSystem>>>

An array of links to the systems that this manager controls.

This property shall contain an array of links to computer systems over which this manager instance has control.

manager_for_chassis: Option<Vec<NavProperty<Chassis>>>

An array of links to the chassis this manager controls.

This property shall contain an array of links to chassis over which this manager instance has control.

manager_in_chassis: Option<NavProperty<Chassis>>

The link to the chassis where this manager is located.

This property shall contain a link to the chassis where this manager is located.

manager_for_switches: Option<Vec<ReferenceLeaf>>active_software_image: Option<NavProperty<SoftwareInventory>>

The link to the software inventory resource that represents the active firmware image for this manager.

This property shall contain a link to a resource of type SoftwareInventory that represents the active firmware image for this manager.

software_images: Option<Vec<NavProperty<SoftwareInventory>>>

The images that are associated with this manager.

This property shall contain an array of links to resources of type SoftwareInventory that represent the firmware images that apply to this manager.

managed_by: Option<Vec<NavProperty<Manager>>>

The array of links to the managers responsible for managing this manager.

This property shall contain an array of links to resources of type Manager that represent the managers for this manager.

manager_for_managers: Option<Vec<NavProperty<Manager>>>

An array of links to the managers that are managed by this manager.

This property shall contain an array of links to resources of type Manager that represent the managers being managed by this manager.

selected_network_port: Option<ReferenceLeaf>manager_for_fabrics: Option<Vec<ReferenceLeaf>>