pub struct ManagerForceFailoverAction {
pub new_manager: Option<Reference>,
}Expand description
The ForceFailover action forces a failover of this manager to the manager used in the parameter.
This action shall perform a forced failover of the manager’s redundancy to the manager supplied as a parameter.
Fields
new_manager: Option<Reference>The manager to which to fail over.
This parameter shall contain the manager to which to fail over.