pub struct ManagerModifyRedundancySetAction {
pub add: Option<Vec<Reference>>,
pub remove: Option<Vec<Reference>>,
}Expand description
The ModifyRedundancySet operation adds members to or removes members from a redundant group of
managers.
The ModifyRedundancySet operation shall add members to or remove members from a redundant group
of managers.
Fields
add: Option<Vec<Reference>>An array of managers to add to the redundancy set.
This parameter shall contain an array of managers to add to the redundancy set.
remove: Option<Vec<Reference>>An array of managers to remove from the redundancy set.
This parameter shall contain an array of managers to remove from the redundancy set.