pub struct ManagerResetAction {
pub reset_type: Option<ResetType>,
}Expand description
The reset action resets/reboots the manager.
This action shall reset the manager. If this manager provides the Redfish service, the service shall send the action response before resetting to prevent client timeouts.
Fields
reset_type: Option<ResetType>The type of reset.
This parameter shall contain the type of reset. The service can accept a request without the
parameter and perform an implementation-specific default reset. Services should include the
@Redfish.AllowableValues annotation for this parameter to ensure compatibility with clients, even
when ActionInfo has been implemented.