ManagerResetToDefaultsAction

Struct ManagerResetToDefaultsAction 

pub struct ManagerResetToDefaultsAction {
    pub reset_type: Option<ResetToDefaultsType>,
}
The reset action resets the manager settings to factory defaults. This can cause the manager to reset.

This action shall reset the manager settings. This action may impact other resources.

Fields

reset_type: Option<ResetToDefaultsType>

The type of reset to defaults.

This parameter shall contain the type of reset to defaults.