ManagerUpdateSecurityModeAction

Struct ManagerUpdateSecurityModeAction 

pub struct ManagerUpdateSecurityModeAction {
    pub security_mode: Option<SecurityModeTypes>,
    pub oem_security_mode: Option<String>,
}
The update security mode action updates the security mode for the manager. This can cause the manager to reset and reset other settings to factory defaults. Services might require the ResetToDefaults action to clear the security mode.

This action shall update the security mode for the manager. Services may reset other settings to factory defaults. Services may require the ResetToDefaults action to clear security settings. This action may impact other resources.

Fields

security_mode: Option<SecurityModeTypes>

The security mode to apply to the manager.

This parameter shall contain the security mode to apply to the manager.

oem_security_mode: Option<String>

The OEM-specific security mode to apply to the manager.

This parameter shall contain the OEM-specific security mode to apply to the manager. This parameter shall be required if SecurityMode is OEM.