SerialConsole

Struct SerialConsole 

pub struct SerialConsole {
    pub base: ManagerService,
    pub connect_types_supported: Option<Vec<SerialConnectTypesSupported>>,
}
The information about a serial console service that this manager provides.

This type shall describe a serial console service for a manager.

Fields

base: ManagerService

Base type

connect_types_supported: Option<Vec<SerialConnectTypesSupported>>

This property enumerates the serial console connection types that the implementation allows.

This property shall contain an array of the enumerations. SSH shall be included if the Secure Shell (SSH) protocol is supported. Telnet shall be included if the Telnet protocol is supported. IPMI shall be included if the IPMI Serial Over LAN (SOL) protocol is supported.