pub enum SnmpEncryptionProtocols {
None,
CbcDes,
Cfb128Aes128,
Cfb128Aes192,
Cfb128Aes256,
UnsupportedValue,
}Variants
None
No encryption.
This value shall indicate there is no encryption.
CbcDes
CBC-DES encryption.
This value shall indicate encryption conforms to the RFC3414-defined CBC-DES encryption protocol.
Cfb128Aes128
CFB128-AES-128 encryption.
This value shall indicate encryption conforms to the RFC3826-defined CFB128-AES-128 encryption protocol.
Cfb128Aes192
CFB128-AES-192 encryption.
This value shall indicate encryption conforms to the CFB128-AES-192 encryption protocol, extended from RFC3826.
Cfb128Aes256
CFB128-AES-256 encryption.
This value shall indicate encryption conforms to the CFB128-AES-256 encryption protocol, extended from RFC3826.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.