pub struct GenerateSecretKeyResponse {
pub secret_key: Option<String>,
}Expand description
The response body for the GenerateSecretKey action.
This type shall contain the properties found in the response body for the GenerateSecretKey
action.
Fields
secret_key: Option<String>The secret key generated for Time-based One-Time Password (TOTP) multi-factor authentication.
This property shall contain secret key generated for RFC6238-defined Time-based One-Time Password (TOTP) multi-factor authentication. Clients shall retain the value of this property to generate tokens for future session creation requests.