pub struct ManagerAccountVerifyTimeBasedOneTimePasswordAction {
pub time_based_one_time_password: Option<String>,
}Expand description
This action verifies a user-provided Time-based One-Time Password (TOTP). This is to ensure the client’s copy of the secret key is aligned with the secret key stored by the service.
This action shall verify a user-provided RFC6238-defined Time-based One-Time Password (TOTP).
Fields
time_based_one_time_password: Option<String>The Time-based One-Time Password (TOTP) to verify.
This parameter shall contain the Time-based One-Time Password (TOTP) to verify. If the Time-based
One-Time Password (TOTP) is not valid, the service shall return the HTTP 400 Bad Request status
code.