pub struct ManagerCollection {
pub base: ResourceCollection,
pub members: Vec<NavProperty<Manager>>,
}Expand description
The collection of Manager resource instances.
This resource shall represent a resource collection of Manager instances for a Redfish
implementation.
Fields
base: ResourceCollectionBase type
members: Vec<NavProperty<Manager>>The members of this collection.
This property shall contain an array of links to the members of this collection.