pub enum NotifyIpv6scope {
Link,
Site,
Organization,
UnsupportedValue,
}Variants
Link
SSDP NOTIFY messages are sent to addresses in the IPv6 local link scope.
Site
SSDP NOTIFY messages are sent to addresses in the IPv6 local site scope.
Organization
SSDP NOTIFY messages are sent to addresses in the IPv6 local organization scope.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.