NtpProtocol

Struct NtpProtocol 

pub struct NtpProtocol {
    pub base: Protocol,
    pub ntp_servers: Option<Option<Vec<String>>>,
    pub network_supplied_servers: Option<Option<Vec<String>>>,
}

Fields

base: Protocol

Base type

ntp_servers: Option<Option<Vec<String>>>

Indicates to which user-supplied NTP servers this manager is subscribed.

This property shall contain all the user-supplied NTP servers for which this manager is using to obtain time. NetworkSuppliedServers is used for NTP servers supplied by other network protocols such as DHCP.

network_supplied_servers: Option<Option<Vec<String>>>

The NTP servers supplied by other network protocols to this manager.

This property shall contain the NTP servers supplied by other network protocols to this manager. DHCP is an example of a protocol that can supply NTP servers to this manager.