pub struct Protocol {
pub protocol_enabled: Option<Option<Boolean>>,
pub port: Option<Option<Int64>>,
}Expand description
The settings for a network protocol associated with a manager.
This type shall describe information about a protocol setting for a manager.
Fields
protocol_enabled: Option<Option<Boolean>>An indication of whether the protocol is enabled.
This property shall indicate whether the protocol is enabled.
port: Option<Option<Int64>>The protocol port.
This property shall contain the port assigned to the protocol.