pub enum ErrorCorrection {
NoEcc,
SingleBitEcc,
MultiBitEcc,
AddressParity,
UnsupportedValue,
}Variants
NoEcc
No ECC available.
SingleBitEcc
Single bit data errors can be corrected by ECC.
MultiBitEcc
Multibit data errors can be corrected by ECC.
AddressParity
Address parity errors can be corrected.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.