pub enum SecurityStates {
Enabled,
Disabled,
Unlocked,
Locked,
Frozen,
Passphraselimit,
UnsupportedValue,
}Variants
Enabled
Secure mode is enabled and access to the data is allowed.
Disabled
Secure mode is disabled.
Unlocked
Secure mode is enabled and access to the data is unlocked.
Locked
Secure mode is enabled and access to the data is locked.
Frozen
Secure state is frozen and cannot be modified until reset.
Passphraselimit
Number of attempts to unlock the memory exceeded limit.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.