pub struct Actions {Show 13 fields
pub oem: Option<OemActions>,
pub disable_master_passphrase: Option<Action<MemoryDisableMasterPassphraseAction, ()>>,
pub disable_passphrase: Option<Action<MemoryDisablePassphraseAction, ()>>,
pub freeze_security_state: Option<Action<MemoryFreezeSecurityStateAction, ()>>,
pub inject_persistent_poison: Option<Action<MemoryInjectPersistentPoisonAction, ()>>,
pub overwrite_unit: Option<Action<MemoryOverwriteUnitAction, ()>>,
pub reset: Option<Action<MemoryResetAction, ()>>,
pub reset_to_defaults: Option<Action<MemoryResetToDefaultsAction, ()>>,
pub scan_media: Option<Action<MemoryScanMediaAction, ()>>,
pub secure_erase_unit: Option<Action<MemorySecureEraseUnitAction, ()>>,
pub set_master_passphrase: Option<Action<MemorySetMasterPassphraseAction, ()>>,
pub set_passphrase: Option<Action<MemorySetPassphraseAction, ()>>,
pub unlock_unit: Option<Action<MemoryUnlockUnitAction, ()>>,
}Expand description
The available actions for this resource.
This type shall contain the available actions for this resource.
Fields
oem: Option<OemActions>The available OEM-specific actions for this resource.
This property shall contain the available OEM-specific actions for this resource.
disable_master_passphrase: Option<Action<MemoryDisableMasterPassphraseAction, ()>>disable_passphrase: Option<Action<MemoryDisablePassphraseAction, ()>>freeze_security_state: Option<Action<MemoryFreezeSecurityStateAction, ()>>inject_persistent_poison: Option<Action<MemoryInjectPersistentPoisonAction, ()>>overwrite_unit: Option<Action<MemoryOverwriteUnitAction, ()>>reset: Option<Action<MemoryResetAction, ()>>reset_to_defaults: Option<Action<MemoryResetToDefaultsAction, ()>>scan_media: Option<Action<MemoryScanMediaAction, ()>>secure_erase_unit: Option<Action<MemorySecureEraseUnitAction, ()>>set_master_passphrase: Option<Action<MemorySetMasterPassphraseAction, ()>>set_passphrase: Option<Action<MemorySetPassphraseAction, ()>>unlock_unit: Option<Action<MemoryUnlockUnitAction, ()>>Implementations
Sourceimpl Actions
impl Actions
Sourcepub async fn disable_master_passphrase<B: Bmc>(
&self,
bmc: &B,
region_id: Option<String>,
passphrase: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn disable_master_passphrase<B: Bmc>(
&self,
bmc: &B,
region_id: Option<String>,
passphrase: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
Disables the master passphrase for the given region.
This action shall disable the master passphrase on the supplied region provided the supplied master passphrase matches that of the region.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn disable_passphrase<B: Bmc>(
&self,
bmc: &B,
region_id: Option<String>,
passphrase: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn disable_passphrase<B: Bmc>(
&self,
bmc: &B,
region_id: Option<String>,
passphrase: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
Disable passphrase for the given region.
This action shall disable the need for passphrases on the supplied region provided the supplied passphrase matches that of the region.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn freeze_security_state<B: Bmc>(
&self,
bmc: &B,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn freeze_security_state<B: Bmc>(
&self,
bmc: &B,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
Freezes the security state of the memory device.
This action shall freeze the security state of the memory device.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn inject_persistent_poison<B: Bmc>(
&self,
bmc: &B,
physical_address: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn inject_persistent_poison<B: Bmc>(
&self,
bmc: &B,
physical_address: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
Injects poison to a specific persistent memory address in the memory device.
This action shall inject poison to a specific persistent memory address in the memory device.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn overwrite_unit<B: Bmc>(
&self,
bmc: &B,
region_id: Option<String>,
passphrase: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn overwrite_unit<B: Bmc>(
&self,
bmc: &B,
region_id: Option<String>,
passphrase: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
This contains the action for securely erasing given regions using the NIST SP800-88 Purge: Overwrite.
This action shall securely erase the supplied region provided the supplied passphrase matches that
of the given region using the NIST SP800-88 Purge: Overwrite. Use the SecureEraseUnit method to
perform NIST SP800-88 Purge: Cryptographic Erase.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn reset<B: Bmc>(
&self,
bmc: &B,
reset_type: Option<ResetType>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn reset<B: Bmc>(
&self,
bmc: &B,
reset_type: Option<ResetType>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
This action resets this memory device.
This action shall reset this memory device.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn reset_to_defaults<B: Bmc>(
&self,
bmc: &B,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn reset_to_defaults<B: Bmc>(
&self,
bmc: &B,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
The action resets the values of writable properties to factory defaults.
This action shall reset the values of writable properties in this resource to their default values as specified by the manufacturer.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn scan_media<B: Bmc>(
&self,
bmc: &B,
physical_address: Option<String>,
length: Option<Int64>,
no_event_log: Option<Boolean>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn scan_media<B: Bmc>(
&self,
bmc: &B,
physical_address: Option<String>,
length: Option<Int64>,
no_event_log: Option<Boolean>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
Scans the media of the memory device.
This action shall scan the media of the memory device.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn secure_erase_unit<B: Bmc>(
&self,
bmc: &B,
region_id: Option<String>,
passphrase: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn secure_erase_unit<B: Bmc>(
&self,
bmc: &B,
region_id: Option<String>,
passphrase: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
This contains the action for securely erasing given regions using the NIST SP800-88 Purge: Cryptographic Erase.
This action shall securely erase the supplied region provided the supplied passphrase matches that
of the given region using the NIST SP800-88 Purge: Cryptographic Erase. Use the OverwriteUnit
method to perform NIST SP800-88 Purge: Overwrite.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn set_master_passphrase<B: Bmc>(
&self,
bmc: &B,
region_id: Option<String>,
passphrase: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn set_master_passphrase<B: Bmc>(
&self,
bmc: &B,
region_id: Option<String>,
passphrase: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
Sets the master passphrase for the given region.
This action shall set the supplied master passphrase to the supplied region.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn set_passphrase<B: Bmc>(
&self,
bmc: &B,
region_id: Option<String>,
passphrase: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn set_passphrase<B: Bmc>(
&self,
bmc: &B,
region_id: Option<String>,
passphrase: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
Set passphrase for the given regions.
This action shall apply the supplied passphrase to the supplied region.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn unlock_unit<B: Bmc>(
&self,
bmc: &B,
region_id: Option<String>,
passphrase: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn unlock_unit<B: Bmc>(
&self,
bmc: &B,
region_id: Option<String>,
passphrase: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
This contains the action for unlocking given regions.
This action shall apply the supplied passphrase to the supplied region for the purpose of unlocking the given regions.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.