pub struct HealthData {
pub predicted_media_life_left_percent: Option<Option<Decimal>>,
}Expand description
The health data of a memory device.
This type shall contain the health data of a memory device.
Fields
predicted_media_life_left_percent: Option<Option<Decimal>>The current health of the memory device as a percentage.
This property shall contain the current health of the memory device as a percentage, 0 to 100.