Links

Struct Links 

pub struct Links {
    pub base: Links,
    pub chassis: Option<NavProperty<Chassis>>,
    pub processors: Option<Vec<NavProperty<Processor>>>,
    pub batteries: Option<Vec<ReferenceLeaf>>,
    pub endpoints: Option<Vec<ReferenceLeaf>>,
    pub memory_media_sources: Option<Vec<ReferenceLeaf>>,
    pub memory_region_media_sources: Option<Vec<ReferenceLeaf>>,
}

Fields

base: Links

Base type

chassis: Option<NavProperty<Chassis>>

The link to the chassis that contains this memory device.

This property shall contain a link to a resource of type Chassis that represents the physical container associated with this memory device.

processors: Option<Vec<NavProperty<Processor>>>

An array of links to the processors associated with this memory device.

This property shall contain an array of links to resources of type Processor that are associated with this memory device.

batteries: Option<Vec<ReferenceLeaf>>endpoints: Option<Vec<ReferenceLeaf>>memory_media_sources: Option<Vec<ReferenceLeaf>>memory_region_media_sources: Option<Vec<ReferenceLeaf>>