pub struct Memory {Show 74 fields
pub base: Resource,
pub memory_type: Option<Option<MemoryType>>,
pub memory_device_type: Option<Option<MemoryDeviceType>>,
pub base_module_type: Option<Option<BaseModuleType>>,
pub memory_media: Option<Vec<MemoryMedia>>,
pub capacity_mi_b: Option<Option<Int64>>,
pub data_width_bits: Option<Option<Int64>>,
pub bus_width_bits: Option<Option<Int64>>,
pub manufacturer: Option<Option<String>>,
pub serial_number: Option<Option<String>>,
pub part_number: Option<Option<String>>,
pub allowed_speeds_mhz: Option<Vec<Int64>>,
pub firmware_revision: Option<Option<String>>,
pub firmware_api_version: Option<Option<String>>,
pub function_classes: Option<Vec<String>>,
pub vendor_id: Option<Option<String>>,
pub device_id: Option<Option<String>>,
pub subsystem_vendor_id: Option<Option<String>>,
pub subsystem_device_id: Option<Option<String>>,
pub max_tdp_milli_watts: Option<Vec<Int64>>,
pub security_capabilities: Option<SecurityCapabilities>,
pub spare_device_count: Option<Option<Int64>>,
pub rank_count: Option<Option<Int64>>,
pub device_locator: Option<Option<String>>,
pub memory_location: Option<MemoryLocation>,
pub error_correction: Option<Option<ErrorCorrection>>,
pub operating_speed_mhz: Option<Option<Int64>>,
pub volatile_region_size_limit_mi_b: Option<Option<Int64>>,
pub persistent_region_size_limit_mi_b: Option<Option<Int64>>,
pub regions: Option<Vec<RegionSet>>,
pub operating_memory_modes: Option<Vec<OperatingMemoryModes>>,
pub power_management_policy: Option<PowerManagementPolicy>,
pub is_spare_device_enabled: Option<Option<Boolean>>,
pub is_rank_spare_enabled: Option<Option<Boolean>>,
pub actions: Option<Actions>,
pub status: Option<Status>,
pub volatile_region_number_limit: Option<Option<Int64>>,
pub persistent_region_number_limit: Option<Option<Int64>>,
pub volatile_region_size_max_mi_b: Option<Option<Int64>>,
pub persistent_region_size_max_mi_b: Option<Option<Int64>>,
pub allocation_increment_mi_b: Option<Option<Int64>>,
pub allocation_alignment_mi_b: Option<Option<Int64>>,
pub links: Option<Links>,
pub module_manufacturer_id: Option<Option<String>>,
pub module_product_id: Option<Option<String>>,
pub memory_subsystem_controller_manufacturer_id: Option<Option<String>>,
pub memory_subsystem_controller_product_id: Option<Option<String>>,
pub volatile_size_mi_b: Option<Option<Int64>>,
pub non_volatile_size_mi_b: Option<Option<Int64>>,
pub cache_size_mi_b: Option<Option<Int64>>,
pub logical_size_mi_b: Option<Option<Int64>>,
pub location: Option<Location>,
pub security_state: Option<Option<SecurityStates>>,
pub configuration_locked: Option<Option<Boolean>>,
pub location_indicator_active: Option<Option<Boolean>>,
pub spare_part_number: Option<Option<String>>,
pub model: Option<Option<String>>,
pub measurements: Option<Vec<MeasurementBlock>>,
pub enabled: Option<Boolean>,
pub poison_list_max_media_error_records: Option<Int64>,
pub cxl: Option<Cxl>,
pub volatile_size_limit_mi_b: Option<Int64>,
pub non_volatile_size_limit_mi_b: Option<Int64>,
pub security_states: Option<SecurityStateInfo>,
pub health_data: Option<HealthData>,
pub cache_level: Option<Int64>,
pub power_management_ic_manufacturer_id: Option<Option<String>>,
pub power_management_ic_revision_id: Option<Option<String>>,
pub production_date: Option<Option<DateTimeOffset>>,
pub metrics: Option<NavProperty<MemoryMetrics>>,
pub assembly: Option<NavProperty<Assembly>>,
pub environment_metrics: Option<NavProperty<EnvironmentMetrics>>,
pub certificates: Option<ReferenceLeaf>,
pub log: Option<NavProperty<LogService>>,
}Expand description
The Memory schema represents a memory device, such as a DIMM, and its configuration. It also
describes the location, such as a slot, socket, or bay, where a unit can be installed, by
populating a resource instance with an absent state if a unit is not present.
This resource shall represent a memory device in a Redfish implementation. It may also represent a
location, such as a slot, socket, or bay, where a unit may be installed, but the State property
within the Status property contains Absent.
Fields
base: ResourceBase type
memory_type: Option<Option<MemoryType>>The type of memory device.
This property shall contain the type of memory device that this resource represents.
memory_device_type: Option<Option<MemoryDeviceType>>Type details of the memory device.
This property shall contain the Memory Device Type as defined by SMBIOS.
base_module_type: Option<Option<BaseModuleType>>The base module type of the memory device.
This property shall contain the base module type of the memory device.
memory_media: Option<Vec<MemoryMedia>>Media of this memory device.
This property shall contain the media types of this memory device.
capacity_mi_b: Option<Option<Int64>>Memory capacity in mebibytes (MiB).
This property shall contain the memory capacity in MiB.
data_width_bits: Option<Option<Int64>>Data width in bits.
This property shall contain the data width in bits.
bus_width_bits: Option<Option<Int64>>The bus width, in bits.
This property shall contain the bus width, in bits.
manufacturer: Option<Option<String>>The memory device manufacturer.
This property shall contain the manufacturer of the memory device.
serial_number: Option<Option<String>>The product serial number of this device.
This property shall indicate the serial number as provided by the manufacturer of this memory device.
part_number: Option<Option<String>>The product part number of this device.
This property shall indicate the part number as provided by the manufacturer of this memory device.
allowed_speeds_mhz: Option<Vec<Int64>>Speeds supported by this memory device.
This property shall contain the speeds supported by this memory device.
firmware_revision: Option<Option<String>>Revision of firmware on the memory controller.
This property shall contain the revision of firmware on the memory controller.
firmware_api_version: Option<Option<String>>Version of API supported by the firmware.
This property shall contain the version of API supported by the firmware.
function_classes: Option<Vec<String>>Function classes by the memory device.
This property shall contain the function classes by the memory device.
vendor_id: Option<Option<String>>Vendor ID.
This property shall contain the vendor ID of the memory device.
device_id: Option<Option<String>>Device ID.
This property shall contain the device ID of the memory device.
subsystem_vendor_id: Option<Option<String>>SubSystem vendor ID.
This property shall contain the subsystem vendor ID of the memory device.
subsystem_device_id: Option<Option<String>>Subsystem device ID.
This property shall contain the subsystem device ID of the memory device.
max_tdp_milli_watts: Option<Vec<Int64>>Set of maximum power budgets supported by the memory device in milliwatt units.
This property shall contain an array of maximum power budgets supported by the memory device in milliwatt units.
security_capabilities: Option<SecurityCapabilities>Security capabilities of the memory device.
This property shall contain properties that describe the security capabilities of the memory device.
spare_device_count: Option<Option<Int64>>Number of unused spare devices available in the memory device.
This property shall contain the number of unused spare devices available in the memory device. If the memory device fails, the spare devices could be used.
rank_count: Option<Option<Int64>>Number of ranks available in the memory device.
This property shall contain the number of ranks available in the memory device. The ranks could be used for spare or interleave.
device_locator: Option<Option<String>>Location of the memory device in the platform.
This property shall contain the location of the memory device in the platform, typically marked in the silk screen.
memory_location: Option<MemoryLocation>Memory connection information to sockets and memory controllers.
This object shall contain properties that describe the memory connection information to sockets and memory controllers.
error_correction: Option<Option<ErrorCorrection>>Error correction scheme supported for this memory device.
This property shall contain the error correction scheme supported for this memory device.
operating_speed_mhz: Option<Option<Int64>>Operating speed of the memory device in MHz or MT/s as appropriate.
This property shall contain the operating speed of the memory device in MHz or MT/s (mega-transfers per second) as reported by the memory device. Memory devices that operate at their bus speed shall report the operating speed in MHz (bus speed), while memory devices that transfer data faster than their bus speed, such as DDR memory, shall report the operating speed in MT/s (mega-transfers/second). The reported value shall match the conventionally reported values for the technology used by the memory device.
volatile_region_size_limit_mi_b: Option<Option<Int64>>Total size of volatile regions in mebibytes (MiB).
This property shall contain the total size of volatile regions in MiB.
persistent_region_size_limit_mi_b: Option<Option<Int64>>Total size of persistent regions in mebibytes (MiB).
This property shall contain the total size of persistent regions in MiB.
regions: Option<Vec<RegionSet>>Memory regions information within the memory device.
This property shall contain the memory region information within the memory device.
operating_memory_modes: Option<Vec<OperatingMemoryModes>>Memory modes supported by the memory device.
This property shall contain the memory modes supported by the memory device.
power_management_policy: Option<PowerManagementPolicy>Power management policy information.
This object shall contain properties that describe the power management policy for this resource.
is_spare_device_enabled: Option<Option<Boolean>>An indication of whether a spare device is enabled for this memory device.
This property shall indicate whether the spare device is enabled.
is_rank_spare_enabled: Option<Option<Boolean>>An indication of whether rank spare is enabled for this memory device.
This property shall indicate whether rank spare is enabled for this memory device.
actions: Option<Actions>The available actions for this resource.
This property shall contain the available actions for this resource.
status: Option<Status>The status and health of the resource and its subordinate or dependent resources.
This property shall contain any status or health properties of the resource.
volatile_region_number_limit: Option<Option<Int64>>Total number of volatile regions this memory device can support.
This property shall contain the total number of volatile regions this memory device can support.
persistent_region_number_limit: Option<Option<Int64>>Total number of persistent regions this memory device can support.
This property shall contain the total number of persistent regions this memory device can support.
volatile_region_size_max_mi_b: Option<Option<Int64>>Maximum size of a single volatile region in mebibytes (MiB).
This property shall contain the maximum size of a single volatile regions in MiB.
persistent_region_size_max_mi_b: Option<Option<Int64>>Maximum size of a single persistent region in mebibytes (MiB).
This property shall contain the maximum size of a single persistent regions in MiB.
allocation_increment_mi_b: Option<Option<Int64>>The size of the smallest unit of allocation for a memory region in mebibytes (MiB).
This property shall contain the allocation increment for regions, measured in MiB.
allocation_alignment_mi_b: Option<Option<Int64>>The boundary that memory regions are allocated on, measured in mebibytes (MiB).
This property shall contain the alignment boundary on which memory regions are allocated, measured in MiB.
links: Option<Links>The links to other resources that are related to this resource.
This property shall contain links to resources that are related to but are not contained by, or subordinate to, this resource.
module_manufacturer_id: Option<Option<String>>The manufacturer ID of this memory device.
This property shall contain the two byte manufacturer ID of this memory device as defined by JEDEC in JEP-106.
module_product_id: Option<Option<String>>The product ID of this memory device.
This property shall contain the two byte product ID of this memory device as defined by the manufacturer.
memory_subsystem_controller_manufacturer_id: Option<Option<String>>The manufacturer ID of the memory subsystem controller of this memory device.
This property shall contain the two byte manufacturer ID of the memory subsystem controller of this memory device as defined by JEDEC in JEP-106.
memory_subsystem_controller_product_id: Option<Option<String>>The product ID of the memory subsystem controller of this memory device.
This property shall contain the two byte product ID of the memory subsystem controller of this memory device as defined by the manufacturer.
volatile_size_mi_b: Option<Option<Int64>>Total size of the volatile portion memory in MiB.
This property shall contain the total size of the volatile portion memory in MiB.
non_volatile_size_mi_b: Option<Option<Int64>>Total size of the non-volatile portion memory in MiB.
This property shall contain the total size of the non-volatile portion memory in MiB.
cache_size_mi_b: Option<Option<Int64>>Total size of the cache portion memory in MiB.
This property shall contain the total size of the cache portion memory in MiB. If the MemoryType
property contains the value Cache, the CacheSizeMiB property shall be absent and the
CapacityMiB property shall be present.
logical_size_mi_b: Option<Option<Int64>>Total size of the logical memory in MiB.
This property shall contain the total size of the logical memory in MiB.
location: Option<Location>The location of the memory device.
This property shall contain the location information of the associated memory device.
security_state: Option<Option<SecurityStates>>The current security state of this memory device.
This property shall contain the current security state of this memory device.
configuration_locked: Option<Option<Boolean>>An indication of whether the configuration of this memory device is locked and cannot be altered.
This property shall indicate whether the configuration of this memory device is locked and cannot be altered.
location_indicator_active: Option<Option<Boolean>>An indicator allowing an operator to physically locate this resource.
This property shall contain the state of the indicator used to physically identify or locate this
resource. A write to this property shall update the value of IndicatorLED in this resource, if
supported, to reflect the implementation of the locating function.
spare_part_number: Option<Option<String>>The spare part number of the memory.
This property shall contain the spare part number of the memory.
model: Option<Option<String>>The product model number of this device.
This property shall indicate the model information as provided by the manufacturer of this memory.
measurements: Option<Vec<MeasurementBlock>>An array of DSP0274-defined measurement blocks.
This property shall contain an array of DSP0274-defined measurement blocks.
enabled: Option<Boolean>An indication of whether this memory is enabled.
The value of this property shall indicate if this memory is enabled.
poison_list_max_media_error_records: Option<Int64>The maximum number of media error records this device can track in its poison list.
This property shall contain the maximum number of media error records this device can track in its poison list.
cxl: Option<Cxl>CXL properties for this memory device.
This property shall contain CXL-specific properties for this memory device.
volatile_size_limit_mi_b: Option<Int64>The total volatile memory capacity in mebibytes (MiB).
This property shall contain the total volatile memory capacity in mebibytes (MiB).
non_volatile_size_limit_mi_b: Option<Int64>The total non-volatile memory capacity in mebibytes (MiB).
This property shall contain the total non-volatile memory capacity in mebibytes (MiB).
security_states: Option<SecurityStateInfo>The security states of this memory device.
This property shall contain the security states of this memory device.
health_data: Option<HealthData>The health data of this memory device.
This property shall contain the health data of this memory device.
cache_level: Option<Int64>The level of the cache memory.
This value shall contain the level of the cache memory. This property shall only be present if the
MemoryType contains the value Cache.
power_management_ic_manufacturer_id: Option<Option<String>>The manufacturer ID of the Power Management Integrated Controller on this memory device.
This property shall contain the two byte manufacturer ID of the Power Management Integrated Controller on this memory device as defined by JEDEC in JESD301.
power_management_ic_revision_id: Option<Option<String>>The revision ID of the Power Management Integrated Controller on this memory device.
This property shall contain the two byte revision ID of the Power Management Integrated Controller on this memory device as defined by JEDEC in JESD301.
production_date: Option<Option<DateTimeOffset>>The production or manufacturing date of this memory device.
This property shall contain the date of production or manufacture for this memory device.
metrics: Option<NavProperty<MemoryMetrics>>The link to the metrics associated with this memory device.
The link to the metrics associated with this memory device.
assembly: Option<NavProperty<Assembly>>The link to the assembly resource associated with this memory device.
This property shall contain a link to a resource of type Assembly.
environment_metrics: Option<NavProperty<EnvironmentMetrics>>The link to the environment metrics for this memory.
This property shall contain a link to a resource of type EnvironmentMetrics that specifies the
environment metrics for this memory.
certificates: Option<ReferenceLeaf>log: Option<NavProperty<LogService>>The link to the log service associated with this memory.
This property shall contain a link to a resource of type LogService.