MemoryDisableMasterPassphraseAction

Struct MemoryDisableMasterPassphraseAction 

pub struct MemoryDisableMasterPassphraseAction {
    pub region_id: Option<String>,
    pub passphrase: Option<String>,
}
Disables the master passphrase for the given region.

This action shall disable the master passphrase on the supplied region provided the supplied master passphrase matches that of the region.

Fields

region_id: Option<String>

The memory region ID to which to disable the master passphrase.

This parameter shall contain the memory region ID to which to disable the master passphrase.

passphrase: Option<String>

The master passphrase for the specified region.

This parameter shall contain the master passphrase for the specified region.