MemoryDisablePassphraseAction

Struct MemoryDisablePassphraseAction 

pub struct MemoryDisablePassphraseAction {
    pub region_id: Option<String>,
    pub passphrase: Option<String>,
}
Disable passphrase for the given region.

This action shall disable the need for passphrases on the supplied region provided the supplied passphrase matches that of the region.

Fields

region_id: Option<String>

The memory region ID to which to apply this action.

This property shall contain the memory region ID to which to apply this action.

passphrase: Option<String>

Passphrase for doing the operation.

This property shall contain the passphrase used in this action.