MemoryInjectPersistentPoisonAction

Struct MemoryInjectPersistentPoisonAction 

pub struct MemoryInjectPersistentPoisonAction {
    pub physical_address: Option<String>,
}
Injects poison to a specific persistent memory address in the memory device.

This action shall inject poison to a specific persistent memory address in the memory device.

Fields

physical_address: Option<String>

The device persistent physical address in which to perform a poison injection as a hex-encoded string.

This parameter shall contain the device persistent physical address in which to perform a poison injection as a hex-encoded string.