MemoryScanMediaAction

Struct MemoryScanMediaAction 

pub struct MemoryScanMediaAction {
    pub physical_address: Option<String>,
    pub length: Option<Int64>,
    pub no_event_log: Option<Boolean>,
}
Scans the media of the memory device.

This action shall scan the media of the memory device.

Fields

physical_address: Option<String>

The starting device physical address to scan as a hex-encoded string.

This parameter shall contain the starting device physical address to scan as a hex-encoded string.

length: Option<Int64>

The length of the target region to scan in bytes from the physical address.

This parameter shall contain the length of the target region to scan in bytes from the PhysicalAddress parameter.

no_event_log: Option<Boolean>

Indicates whether events related to the media scan are not logged.

This parameter shall indicate whether events related to the media scan are not logged. If not provided by the client, the value shall be assumed to be false.