pub struct MemorySecureEraseUnitAction {
pub region_id: Option<String>,
pub passphrase: Option<String>,
}Expand description
This contains the action for securely erasing given regions using the NIST SP800-88 Purge: Cryptographic Erase.
This action shall securely erase the supplied region provided the supplied passphrase matches that
of the given region using the NIST SP800-88 Purge: Cryptographic Erase. Use the OverwriteUnit
method to perform NIST SP800-88 Purge: Overwrite.
Fields
region_id: Option<String>The memory region ID to which to apply this action.
This property shall contain the memory region ID to which to apply this action.
passphrase: Option<String>Passphrase for doing the operation.
This property shall contain the passphrase used in this action.