pub struct MemorySetPassphraseAction {
pub region_id: Option<String>,
pub passphrase: Option<String>,
}Expand description
Set passphrase for the given regions.
This action shall apply the supplied passphrase to the supplied region.
Fields
region_id: Option<String>The memory region ID to which to apply this action.
This property shall contain the memory region ID to which to apply this action.
passphrase: Option<String>Passphrase for doing the operation.
This property shall contain the passphrase used in this action.