pub struct MemoryUnlockUnitAction {
pub region_id: Option<String>,
pub passphrase: Option<String>,
}Expand description
This contains the action for unlocking given regions.
This action shall apply the supplied passphrase to the supplied region for the purpose of unlocking the given regions.
Fields
region_id: Option<String>The memory region ID to which to apply this action.
This property shall contain the memory region ID to which to apply this action.
passphrase: Option<String>The passphrase required to complete the operation.
This property shall contain the passphrase required to complete this action.