pub struct PowerManagementPolicy {
pub policy_enabled: Option<Option<Boolean>>,
pub max_tdp_milli_watts: Option<Option<Int64>>,
pub peak_power_budget_milli_watts: Option<Option<Int64>>,
pub average_power_budget_milli_watts: Option<Option<Int64>>,
}Expand description
Power management policy information.
This type shall contain properties that describe the power management policy for this resource.
Fields
policy_enabled: Option<Option<Boolean>>An indication of whether the power management policy is enabled.
This property shall indicate whether the power management policy is enabled.
max_tdp_milli_watts: Option<Option<Int64>>Maximum TDP in milliwatt units.
This property shall contain the maximum TDP in milliwatt units.
peak_power_budget_milli_watts: Option<Option<Int64>>Peak power budget, in milliwatt units.
This property shall contain the peak power budget, in milliwatt units.
average_power_budget_milli_watts: Option<Option<Int64>>Average power budget, in milliwatt units.
This property shall contain the average power budget, in milliwatt units.