pub struct RegionSet {
pub region_id: Option<Option<String>>,
pub memory_classification: Option<Option<MemoryClassification>>,
pub offset_mi_b: Option<Option<Int64>>,
pub size_mi_b: Option<Option<Int64>>,
pub passphrase_state: Option<Option<Boolean>>,
pub passphrase_enabled: Option<Option<Boolean>>,
pub master_passphrase_enabled: Option<Option<Boolean>>,
}Fields
region_id: Option<Option<String>>Unique region ID representing a specific region within the memory device.
This property shall contain the unique region ID representing a specific region within the memory device.
memory_classification: Option<Option<MemoryClassification>>The classification of memory that the memory region occupies.
This property shall contain the classification of memory that the memory region occupies.
offset_mi_b: Option<Option<Int64>>Offset within the memory that corresponds to the start of this memory region in mebibytes (MiB).
This property shall contain the offset within the memory that corresponds to the start of this memory region in MiB.
size_mi_b: Option<Option<Int64>>Size of this memory region in mebibytes (MiB).
This property shall contain the size of this memory region in MiB.
passphrase_state: Option<Option<Boolean>>An indication of whether the state of the passphrase for this region is enabled.
This property shall indicate whether the state of the passphrase for this region is enabled.
passphrase_enabled: Option<Option<Boolean>>An indication of whether the passphrase is enabled for this region.
This property shall indicate whether the passphrase is enabled for this region.
master_passphrase_enabled: Option<Option<Boolean>>An indication of whether the master passphrase is enabled for this region.
This property shall indicate whether the master passphrase is enabled for this region.