pub struct SecurityStateInfo {
pub user_passphrase_attempt_count_reached: Option<Option<Boolean>>,
pub master_passphrase_attempt_count_reached: Option<Option<Boolean>>,
}Expand description
The security states of a memory device.
This type shall contain the security states of a memory device.
Fields
user_passphrase_attempt_count_reached: Option<Option<Boolean>>An indication of whether an incorrect user passphrase attempt count has been reached.
This property shall indicate whether an incorrect user passphrase attempt count has been reached.
master_passphrase_attempt_count_reached: Option<Option<Boolean>>An indication of whether an incorrect master passphrase attempt count has been reached.
This property shall indicate whether an incorrect master passphrase attempt count has been reached.