pub struct MemoryCollection {
pub base: ResourceCollection,
pub members: Vec<NavProperty<Memory>>,
}Expand description
The collection of Memory resource instances.
This resource shall represent a resource collection of Memory instances for a Redfish
implementation.
Fields
base: ResourceCollectionBase type
members: Vec<NavProperty<Memory>>The members of this collection.
This property shall contain an array of links to the members of this collection.