HealthData

Struct HealthData 

pub struct HealthData {
    pub remaining_spare_block_percentage: Option<Option<Decimal>>,
    pub last_shutdown_success: Option<Option<Boolean>>,
    pub data_loss_detected: Option<Option<Boolean>>,
    pub performance_degraded: Option<Option<Boolean>>,
    pub alarm_trips: Option<AlarmTrips>,
    pub predicted_media_life_left_percent: Option<Option<Decimal>>,
}

Fields

remaining_spare_block_percentage: Option<Option<Decimal>>

The remaining spare blocks, as a percentage.

This property shall contain the remaining spare blocks as a percentage, 0 to 100. When this resource is subordinate to the MemorySummary object, this property shall be the RemainingSpareBlockPercentage over all memory.

last_shutdown_success: Option<Option<Boolean>>

An indication of whether the last shutdown succeeded.

This property shall indicate whether the last shutdown succeeded.

data_loss_detected: Option<Option<Boolean>>

An indication of whether data loss was detected.

This property shall indicate whether data loss was detected. When this resource is subordinate to the MemorySummary object, this property shall indicate whether any data loss was detected in any area of memory.

performance_degraded: Option<Option<Boolean>>

An indication of whether performance has degraded.

This property shall indicate whether performance has degraded. When this resource is subordinate to the MemorySummary object, this property shall indicate whether degraded performance mode status is detected in any area of memory.

alarm_trips: Option<AlarmTrips>

Alarm trip information about the memory.

This object shall contain properties describe the types of alarms that have been raised by the memory. When this resource is subordinate to the MemorySummary object, this property shall indicate whether an alarm of a given type have been raised by any area of memory.

predicted_media_life_left_percent: Option<Option<Decimal>>

The percentage of reads and writes that are predicted to still be available for the media.

This property shall contain an indicator of the percentage, 0 to 100, of life remaining in the media.