pub enum CalculationAlgorithmEnum {
Average,
Maximum,
Minimum,
Oem,
UnsupportedValue,
}Variants
Average
The metric is calculated as the average metric reading over a sliding time interval.
The metric shall be calculated as the average metric reading over a sliding time interval. The
time interval shall contain the CalculationTimeInterval property value.
Maximum
The metric is calculated as the maximum metric reading over during a time interval.
The metric shall be calculated as the maximum metric reading over a sliding time interval. The
time interval shall contain the CalculationTimeInterval property value.
Minimum
The metric is calculated as the minimum metric reading over a sliding time interval.
The metric shall be calculated as the minimum metric reading over a sliding time interval. The
time interval shall contain the CalculationTimeInterval property value.
Oem
The metric is calculated as specified by an OEM.
The metric shall be calculated as specified by an OEM. The OEMCalculationAlgorithm property
shall contain the specific OEM calculation algorithm.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.