pub enum CalculationAlgorithmEnum {
Average,
Maximum,
Minimum,
Summation,
UnsupportedValue,
}Expand description
The function to apply to the list of metric properties.
This type shall specify the function to apply to the list of metric properties.
Variants
Average
The metric is calculated as the average metric reading over a duration.
This value shall indicate the metric is calculated as the average metric reading over a duration.
The duration shall be the CollectionDuration property value.
Maximum
The metric is calculated as the maximum metric reading over a duration.
This value shall indicate the metric is calculated as the maximum metric reading over a duration.
The duration shall be the CollectionDuration property value.
Minimum
The metric is calculated as the minimum metric reading over a duration.
This value shall indicate the metric is calculated as the minimum metric reading over a duration.
The duration shall be the CollectionDuration property value.
Summation
The metric is calculated as the sum of the values over a duration.
This value shall indicate the metric is calculated as the sum of the specified metric reading over
a duration. The duration shall be the CollectionDuration property value.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.