pub struct Actions {
pub oem: Option<OemActions>,
pub reset: Option<Action<NetworkAdapterResetAction, ()>>,
pub reset_settings_to_default: Option<Action<NetworkAdapterResetSettingsToDefaultAction, ()>>,
}Expand description
The available actions for this resource.
This type shall contain the available actions for this resource.
Fields
oem: Option<OemActions>The available OEM-specific actions for this resource.
This property shall contain the available OEM-specific actions for this resource.
reset: Option<Action<NetworkAdapterResetAction, ()>>reset_settings_to_default: Option<Action<NetworkAdapterResetSettingsToDefaultAction, ()>>Implementations
Sourceimpl Actions
impl Actions
Sourcepub async fn reset<B: Bmc>(
&self,
bmc: &B,
reset_type: Option<ResetType>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn reset<B: Bmc>(
&self,
bmc: &B,
reset_type: Option<ResetType>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
This action resets the network adapter.
This action shall reset a network adapter.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn reset_settings_to_default<B: Bmc>(
&self,
bmc: &B,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn reset_settings_to_default<B: Bmc>(
&self,
bmc: &B,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
This action is to clear the settings back to factory defaults.
This action shall reset of all active and pending settings back to factory default settings upon reset of the network adapter.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.