ControllerCapabilities

Struct ControllerCapabilities 

pub struct ControllerCapabilities {
    pub network_port_count: Option<Option<Int64>>,
    pub network_device_function_count: Option<Option<Int64>>,
    pub data_center_bridging: Option<DataCenterBridging>,
    pub virtualization_offload: Option<VirtualizationOffload>,
    pub npiv: Option<Npiv>,
    pub npar: Option<NicPartitioning>,
}

Fields

network_port_count: Option<Option<Int64>>

The number of physical ports on this controller.

This property shall contain the number of physical ports on this controller.

network_device_function_count: Option<Option<Int64>>

The maximum number of physical functions available on this controller.

This property shall contain the number of physical functions available on this controller.

data_center_bridging: Option<DataCenterBridging>

Data center bridging (DCB) for this controller.

This property shall contain capability, status, and configuration values related to data center bridging (DCB) for this controller.

virtualization_offload: Option<VirtualizationOffload>

Virtualization offload for this controller.

This property shall contain capability, status, and configuration values related to virtualization offload for this controller.

npiv: Option<Npiv>

N_Port ID Virtualization (NPIV) capabilities for this controller.

This property shall contain N_Port ID Virtualization (NPIV) capabilities for this controller.

npar: Option<NicPartitioning>

NIC Partitioning (NPAR) capabilities for this controller.

This property shall contain capability, status, and configuration values related to NIC partitioning for this controller.