pub struct Controllers {
pub firmware_package_version: Option<Option<String>>,
pub links: Option<ControllerLinks>,
pub controller_capabilities: Option<ControllerCapabilities>,
pub location: Option<Location>,
pub pcie_interface: Option<PcieInterface>,
pub identifiers: Option<Vec<Identifier>>,
}Fields
firmware_package_version: Option<Option<String>>The version of the user-facing firmware package.
This property shall contain the version number of the user-facing firmware package.
links: Option<ControllerLinks>The links to other resources that are related to this resource.
This property shall contain links to resources that are related to but are not contained by, or subordinate to, this resource.
controller_capabilities: Option<ControllerCapabilities>The capabilities of this controller.
This property shall contain the capabilities of this controller.
location: Option<Location>The location of the network adapter controller.
This property shall contain the location information of the controller associated with the network adapter.
pcie_interface: Option<PcieInterface>The PCIe interface details for this controller.
This property shall contain details for the PCIe interface that connects this PCIe-based controller to its host.
identifiers: Option<Vec<Identifier>>The durable names for the network adapter controller.
This property shall contain a list of all known durable names for the controller associated with the network adapter.