pub struct NetworkAdapter {Show 23 fields
pub base: Resource,
pub status: Option<Status>,
pub manufacturer: Option<Option<String>>,
pub model: Option<Option<String>>,
pub sku: Option<Option<String>>,
pub serial_number: Option<Option<String>>,
pub part_number: Option<Option<String>>,
pub controllers: Option<Vec<Controllers>>,
pub actions: Option<Actions>,
pub location: Option<Location>,
pub identifiers: Option<Vec<Identifier>>,
pub measurements: Option<Vec<MeasurementBlock>>,
pub lldp_enabled: Option<Boolean>,
pub port_splitting: Option<Option<PortSplitting>>,
pub port_aggregation: Option<Option<PortAggregation>>,
pub network_ports: Option<ReferenceLeaf>,
pub network_device_functions: Option<NavProperty<NetworkDeviceFunctionCollection>>,
pub assembly: Option<NavProperty<Assembly>>,
pub ports: Option<ReferenceLeaf>,
pub certificates: Option<ReferenceLeaf>,
pub metrics: Option<ReferenceLeaf>,
pub environment_metrics: Option<NavProperty<EnvironmentMetrics>>,
pub processors: Option<NavProperty<ProcessorCollection>>,
}Expand description
The NetworkAdapter schema represents a physical network adapter capable of connecting to a
computer network. Examples include but are not limited to Ethernet, Fibre Channel, and converged
network adapters.
This resource shall represent a physical network adapter capable of connecting to a computer
network in a Redfish implementation. Services should represent adapters that contain multiple
controllers with independent management interfaces as multiple NetworkAdapter resources.
Fields
base: ResourceBase type
status: Option<Status>The status and health of the resource and its subordinate or dependent resources.
This property shall contain any status or health properties of the resource.
manufacturer: Option<Option<String>>The manufacturer or OEM of this network adapter.
This property shall contain a value that represents the manufacturer of the network adapter.
model: Option<Option<String>>The model string for this network adapter.
This property shall contain the information about how the manufacturer refers to this network adapter.
sku: Option<Option<String>>The manufacturer SKU for this network adapter.
This property shall contain the SKU for the network adapter.
serial_number: Option<Option<String>>The serial number for this network adapter.
This property shall contain the serial number for the network adapter.
part_number: Option<Option<String>>Part number for this network adapter.
This property shall contain the part number for the network adapter as defined by the manufacturer.
controllers: Option<Vec<Controllers>>The set of network controllers ASICs that make up this NetworkAdapter.
This property shall contain the set of network controllers ASICs that make up this network adapter.
actions: Option<Actions>The available actions for this resource.
This property shall contain the available actions for this resource.
location: Option<Location>The location of the network adapter.
This property shall contain the location information of the network adapter.
identifiers: Option<Vec<Identifier>>The durable names for the network adapter.
This property shall contain a list of all known durable names for the network adapter.
measurements: Option<Vec<MeasurementBlock>>An array of DSP0274-defined measurement blocks.
This property shall contain an array of DSP0274-defined measurement blocks.
lldp_enabled: Option<Boolean>Enable or disable LLDP globally for an adapter.
This property shall contain the state indicating whether LLDP is globally enabled on a network
adapter. If set to false, the LLDPEnabled value for the ports associated with this adapter
shall be disregarded.
port_splitting: Option<Option<PortSplitting>>The port splitting capabilities for this controller.
This property shall contain capability, status, and configuration values related to physically subdividing the lanes of ports on this controller.
port_aggregation: Option<Option<PortAggregation>>The port aggregation capabilities for this controller.
This property shall contain capability, status, and configuration values related to aggregating ports on this controller.
network_ports: Option<ReferenceLeaf>network_device_functions: Option<NavProperty<NetworkDeviceFunctionCollection>>The link to the collection of network device functions associated with this network adapter.
This property shall contain a link to a resource collection of type
NetworkDeviceFunctionCollection.
assembly: Option<NavProperty<Assembly>>The link to the assembly resource associated with this adapter.
This property shall contain a link to a resource of type Assembly.
ports: Option<ReferenceLeaf>certificates: Option<ReferenceLeaf>metrics: Option<ReferenceLeaf>environment_metrics: Option<NavProperty<EnvironmentMetrics>>The link to the environment metrics for this network adapter.
This property shall contain a link to a resource of type EnvironmentMetrics that specifies the
environment metrics for this network adapter.
processors: Option<NavProperty<ProcessorCollection>>The link to the collection of offload processors contained in this network adapter.
This property shall contain a link to a resource collection of type ProcessorCollection that
represent the offload processors contained in this network adapter.