pub struct NetworkAdapterResetSettingsToDefaultAction {}Expand description
This action is to clear the settings back to factory defaults.
This action shall reset of all active and pending settings back to factory default settings upon reset of the network adapter.