NicPartitioning

Struct NicPartitioning 

pub struct NicPartitioning {
    pub npar_capable: Option<Option<Boolean>>,
    pub npar_enabled: Option<Option<Boolean>>,
}
NIC Partitioning capability, status, and configuration for a controller.

This type shall contain the capability, status, and configuration values for a controller.

Fields

npar_capable: Option<Option<Boolean>>

An indication of whether the controller supports NIC function partitioning.

This property shall indicate whether the controller supports NIC function partitioning.

npar_enabled: Option<Option<Boolean>>

An indication of whether NIC function partitioning is active on this controller.

This property shall indicate whether NIC function partitioning is active on this controller.