pub struct PortSplitting {
pub maximum_subports: Option<Option<Int64>>,
pub maximum_subports_per_port: Option<Option<Int64>>,
pub supported_configurations: Option<Vec<PortSplittingSubconfigurationList>>,
pub current_configuration: Option<Vec<PortSplittingSubconfiguration>>,
}Expand description
The port splitting capabilities for a controller.
This type shall contain capability, status, and configuration values related to physically subdividing the lanes of ports on a controller.
Fields
maximum_subports: Option<Option<Int64>>The maximum number of subdivided ports that this controller supports.
This property shall contain the maximum number of subdivided ports that this controller supports.
maximum_subports_per_port: Option<Option<Int64>>The maximum number of subdivided ports split from a single physical port that this controller supports.
This property shall contain the maximum number of subdivided ports split from a single physical port that this controller supports.
supported_configurations: Option<Vec<PortSplittingSubconfigurationList>>The port splitting configurations this controller supports.
This property shall contain the port splitting configurations that this controller supports. Properties contained in this property shall be read-only.
current_configuration: Option<Vec<PortSplittingSubconfiguration>>The current port splitting configuration for this controller.
This property shall contain the current port splitting configuration for this controller.