PortSplittingSubconfiguration

Struct PortSplittingSubconfiguration 

pub struct PortSplittingSubconfiguration {
    pub starting_physical_port: Option<Option<Int64>>,
    pub ending_physical_port: Option<Option<Int64>>,
    pub first_subport_id: Option<Option<Int64>>,
    pub subports_per_port: Option<Option<Int64>>,
    pub lanes: Option<Option<Vec<Int64>>>,
    pub link_speed_gbps: Option<Option<Vec<Int64>>>,
}
A port splitting subconfiguration for one or more physical ports on a controller.

This type shall contain a port splitting subconfiguration for one or more physical ports on a controller.

Fields

starting_physical_port: Option<Option<Int64>>

The first physical port to which this subconfiguration applies.

This property shall contain the first physical port to which this subconfiguration applies.

ending_physical_port: Option<Option<Int64>>

The last physical port to which this subconfiguration applies.

This property shall contain the last physical port to which this subconfiguration applies. Specifically, the splitting for ports StartPort through EndPort, inclusive, is characterized by this subconfiguration. Each set of subconfigurations shall cover all physical ports on the controller and shall describe splitting for each port exactly once.

first_subport_id: Option<Option<Int64>>

The first identifier to assign to subports in this subconfiguration. Subport identifiers are assigned sequentially to the subports starting with those for StartPort and working through to those for EndPort.

This property shall contain the first identifier to assign to subports in this subconfiguration. Subport identifiers shall be assigned sequentially to the subports starting with those for StartPort and working through to those for EndPort.

subports_per_port: Option<Option<Int64>>

The number of subports created from each port in this subconfiguration.

This property shall contain the number of subports created from each port in this subconfiguration.

lanes: Option<Option<Vec<Int64>>>

The number of lanes for each subport.

This property shall contain the number of lanes for each subport. The number of members in this array shall equal the value contained in SubportsPerPort in the enclosing subconfiguration.

link_speed_gbps: Option<Option<Vec<Int64>>>

The configured link speed for each subport.

This property shall contain the configured link speed for each subport. The number of members in this array shall equal the value contained in SubportsPerPort in the enclosing subconfiguration.