pub struct NetworkAdapterCollection {
pub base: ResourceCollection,
pub members: Vec<NavProperty<NetworkAdapter>>,
}Expand description
The collection of NetworkAdapter resource instances.
This resource shall represent a resource collection of NetworkAdapter instances for a Redfish
implementation.
Fields
base: ResourceCollectionBase type
members: Vec<NavProperty<NetworkAdapter>>The members of this collection.
This property shall contain an array of links to the members of this collection.