Module network_device_function

Module network_device_function 

Generated schema of NetworkDeviceFunction namespace

Structs

Actions
The available actions for this resource.
BootTargets
A Fibre Channel boot target configured for a network device function.
BootTargetsUpdate
Update struct corresponding to BootTargets
Ethernet
EthernetUpdate
Update struct corresponding to Ethernet
FibreChannel
FibreChannelUpdate
Update struct corresponding to FibreChannel
HttpBoot
The HTTP and HTTPS boot capabilities, status, and configuration for a network device function.
HttpBootUpdate
Update struct corresponding to HttpBoot
InfiniBand
This type describes InfiniBand capabilities, status, and configuration of a network device function.
InfiniBandUpdate
Update struct corresponding to InfiniBand
IscsiBoot
The iSCSI boot capabilities, status, and configuration for a network device function.
IscsiBootUpdate
Update struct corresponding to IscsiBoot
Limit
This type describes the packet and byte limit of a network device function.
LimitUpdate
Update struct corresponding to Limit
Links
NetworkDeviceFunction
The NetworkDeviceFunction schema represents a logical interface that a network adapter exposes.
NetworkDeviceFunctionUpdate
Update struct corresponding to NetworkDeviceFunction
OemActions
The available OEM-specific actions for this resource.

Enums

AuthenticationMethod
BootMode
DataDirection
IpAddressType
NetworkDeviceTechnology
WwnSource