pub enum BootMode {
Disabled,
Pxe,
Iscsi,
FibreChannel,
FibreChannelOverEthernet,
Http,
UnsupportedValue,
}Variants
Disabled
Do not indicate to UEFI/BIOS that this device is bootable.
Pxe
Boot this device by using the embedded PXE support. Only applicable if the NetDevFuncType is Ethernet or InfiniBand.
Iscsi
Boot this device by using the embedded iSCSI boot support and configuration. Only applicable if the NetDevFuncType is iSCSI or Ethernet.
FibreChannel
Boot this device by using the embedded Fibre Channel support and configuration. Only applicable if the NetDevFuncType is FibreChannel.
FibreChannelOverEthernet
Boot this device by using the embedded Fibre Channel over Ethernet (FCoE) boot support and configuration. Only applicable if the NetDevFuncType is FibreChannelOverEthernet.
Http
Boot this device by using the embedded HTTP/HTTPS support. Only applicable if the NetDevFuncType is Ethernet.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.