pub enum DataDirection {
None,
Ingress,
Egress,
UnsupportedValue,
}Variants
None
Indicates that this limit not enforced.
Ingress
Indicates that this limit is enforced on packets and bytes received by the network device function.
Egress
Indicates that this limit is enforced on packets and bytes transmitted by the network device function.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.