pub enum NetworkDeviceTechnology {
Disabled,
Ethernet,
FibreChannel,
Iscsi,
FibreChannelOverEthernet,
InfiniBand,
UnsupportedValue,
}Variants
Disabled
Neither enumerated nor visible to the operating system.
Ethernet
Appears to the operating system as an Ethernet device.
FibreChannel
Appears to the operating system as a Fibre Channel device.
Iscsi
Appears to the operating system as an iSCSI device.
FibreChannelOverEthernet
Appears to the operating system as an FCoE device.
InfiniBand
Appears to the operating system as an InfiniBand device.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.