pub enum WwnSource {
ConfiguredLocally,
ProvidedByFabric,
UnsupportedValue,
}Variants
ConfiguredLocally
The set of FC/FCoE boot targets was applied locally through API or UI.
ProvidedByFabric
The set of FC/FCoE boot targets was applied by the Fibre Channel fabric.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.