Ethernet

Struct Ethernet 

pub struct Ethernet {
    pub permanent_mac_address: Option<Option<String>>,
    pub mac_address: Option<Option<String>>,
    pub mtu_size: Option<Option<Int64>>,
    pub vlan: Option<Vlan>,
    pub mtu_size_maximum: Option<Option<Int64>>,
    pub additional_protocols: Option<Vec<Protocol>>,
    pub vlans: Option<ReferenceLeaf>,
    pub ethernet_interfaces: Option<NavProperty<EthernetInterfaceCollection>>,
}

Fields

permanent_mac_address: Option<Option<String>>

The permanent MAC address assigned to this function.

This property shall contain the permanent MAC Address of this function. Typically, this value is programmed during manufacturing. This address is not assignable.

mac_address: Option<Option<String>>

The currently configured MAC address.

This property shall contain the effective current MAC address of this network device function. If an assignable MAC address is not supported, this is a read-only alias of the PermanentMACAddress.

mtu_size: Option<Option<Int64>>

The hardware maximum transmission unit (MTU) configured for this network device function.

The hardware maximum transmission unit (MTU) configured for this network device function. This value serves as a default for the OS driver when booting, but may be overridden by the OS. After the OS boots and while the driver is loaded, the effective MTU size may be found in the associated EthernetInterface resource.

vlan: Option<Vlan>

The VLAN information for this interface. If this network interface supports more than one VLAN, this property is not present.

This property shall contain the VLAN for this interface. If this interface supports more than one VLAN, the VLAN property shall not be present and the VLANs property shall be present instead.

mtu_size_maximum: Option<Option<Int64>>

The largest maximum transmission unit (MTU) size supported for this network device function.

This property shall contain the largest maximum transmission unit (MTU) size supported for this network device function.

additional_protocols: Option<Vec<Protocol>>

The protocols supported by the hardware or firmware on the device.

This property shall contain the list of protocols supported by the hardware or firmware on the device.

vlans: Option<ReferenceLeaf>ethernet_interfaces: Option<NavProperty<EthernetInterfaceCollection>>

The Ethernet interface collection that contains the interfaces on this network device function.

This property shall contain a link to a collection of type EthernetInterfaceCollection that represent the Ethernet interfaces present on this network device function. This property shall only be present if this NetworkDeviceFunction is not associated with a ComputerSystem, such as when in a ResourcePool or representing an Ethernet based storage device.