pub struct HttpBoot {
pub boot_media_uri: Option<Option<String>>,
}Expand description
The HTTP and HTTPS boot capabilities, status, and configuration for a network device function.
This type shall describe the HTTP and HTTPS boot capabilities, status, and configuration values for a network device function.
Fields
boot_media_uri: Option<Option<String>>The URI of the boot media loaded with this network device function.
This property shall contain the URI of the boot media loaded with this network device function. An
empty string shall indicate no boot media is configured. All other values shall begin with
http:// or https://.