pub struct InfiniBand {
pub permanent_port_guid: Option<Option<String>>,
pub permanent_node_guid: Option<Option<String>>,
pub permanent_system_guid: Option<Option<String>>,
pub port_guid: Option<Option<String>>,
pub node_guid: Option<Option<String>>,
pub system_guid: Option<Option<String>>,
pub supported_mtu_sizes: Option<Option<Vec<Int64>>>,
pub mtu_size: Option<Option<Int64>>,
}Expand description
This type describes InfiniBand capabilities, status, and configuration of a network device function.
This type shall describe the InfiniBand capabilities, status, and configuration values for a network device function.
Fields
permanent_port_guid: Option<Option<String>>The permanent port GUID assigned to this network device function.
This property shall contain the permanent port GUID of this network device function. Typically, this value is programmed during manufacturing. This address is not assignable.
permanent_node_guid: Option<Option<String>>The permanent node GUID assigned to this network device function.
This property shall contain the permanent node GUID of this network device function. Typically, this value is programmed during manufacturing. This address is not assignable.
permanent_system_guid: Option<Option<String>>The permanent system GUID assigned to this network device function.
This property shall contain the permanent system GUID of this network device function. Typically, this value is programmed during manufacturing. This address is not assignable.
port_guid: Option<Option<String>>The currently configured port GUID of the network device function.
This property shall contain the effective current virtual port GUID of this network device function. If an assignable port GUID is not supported, this is a read-only alias of the PermanentPortGUID.
node_guid: Option<Option<String>>This is the currently configured node GUID of the network device function.
This property shall contain the effective current node GUID of this virtual port of this network device function. If an assignable node GUID is not supported, this is a read-only alias of the PermanentNodeGUID.
system_guid: Option<Option<String>>This is the currently configured system GUID of the network device function.
This property shall contain the effective current system GUID of this virtual port of this network device function. If an assignable system GUID is not supported, this is a read-only alias of the PermanentSystemGUID.
supported_mtu_sizes: Option<Option<Vec<Int64>>>The maximum transmission unit (MTU) sizes supported for this network device function.
This property shall contain an array of the maximum transmission unit (MTU) sizes supported for this network device function.
mtu_size: Option<Option<Int64>>The maximum transmission unit (MTU) configured for this network device function.
The maximum transmission unit (MTU) configured for this network device function.