IscsiBoot

Struct IscsiBoot 

pub struct IscsiBoot {
Show 27 fields pub ip_address_type: Option<Option<IpAddressType>>, pub initiator_ip_address: Option<Option<String>>, pub initiator_name: Option<Option<String>>, pub initiator_default_gateway: Option<Option<String>>, pub initiator_netmask: Option<Option<String>>, pub target_info_via_dhcp: Option<Option<Boolean>>, pub primary_target_name: Option<Option<String>>, pub primary_target_ip_address: Option<Option<String>>, pub primary_target_tcp_port: Option<Option<Int64>>, pub primary_lun: Option<Option<Int64>>, pub primary_vlan_enable: Option<Option<Boolean>>, pub primary_vlanid: Option<Option<Int64>>, pub primary_dns: Option<Option<String>>, pub secondary_target_name: Option<Option<String>>, pub secondary_target_ip_address: Option<Option<String>>, pub secondary_target_tcp_port: Option<Option<Int64>>, pub secondary_lun: Option<Option<Int64>>, pub secondary_vlan_enable: Option<Option<Boolean>>, pub secondary_vlanid: Option<Option<Int64>>, pub secondary_dns: Option<Option<String>>, pub ip_mask_dns_via_dhcp: Option<Option<Boolean>>, pub router_advertisement_enabled: Option<Option<Boolean>>, pub authentication_method: Option<Option<AuthenticationMethod>>, pub chap_username: Option<Option<String>>, pub chap_secret: Option<Option<String>>, pub mutual_chap_username: Option<Option<String>>, pub mutual_chap_secret: Option<Option<String>>,
}
The iSCSI boot capabilities, status, and configuration for a network device function.

This type shall describe the iSCSI boot capabilities, status, and configuration values for a network device function.

Fields

ip_address_type: Option<Option<IpAddressType>>

The type of IP address being populated in the iSCSIBoot IP address fields.

This property shall contain the type of IP address being populated in the iSCSIBoot IP address fields. Mixing IPv6 and IPv4 addresses on the same network device function shall not be permissible.

initiator_ip_address: Option<Option<String>>

The IPv6 or IPv4 address of the iSCSI initiator.

This property shall contain the IPv6 or IPv4 address of the iSCSI boot initiator.

initiator_name: Option<Option<String>>

The iSCSI initiator name.

This property shall contain the iSCSI boot initiator name. This property should match formats defined in RFC3720 or RFC3721.

initiator_default_gateway: Option<Option<String>>

The IPv6 or IPv4 iSCSI boot default gateway.

This property shall contain the IPv6 or IPv4 iSCSI boot default gateway.

initiator_netmask: Option<Option<String>>

The IPv6 or IPv4 netmask of the iSCSI boot initiator.

This property shall contain the IPv6 or IPv4 netmask of the iSCSI boot initiator.

target_info_via_dhcp: Option<Option<Boolean>>

An indication of whether the iSCSI boot target name, LUN, IP address, and netmask should be obtained from DHCP.

This property shall indicate whether the iSCSI boot target name, LUN, IP address, and netmask should be obtained from DHCP.

primary_target_name: Option<Option<String>>

The name of the iSCSI primary boot target.

This property shall contain the name of the primary iSCSI boot target. This property should match formats defined in RFC3720 or RFC3721.

primary_target_ip_address: Option<Option<String>>

The IPv4 or IPv6 address for the primary iSCSI boot target.

This property shall contain the IPv4 or IPv6 address for the primary iSCSI boot target.

primary_target_tcp_port: Option<Option<Int64>>

The TCP port for the primary iSCSI boot target.

This property shall contain the TCP port for the primary iSCSI boot target.

primary_lun: Option<Option<Int64>>

The logical unit number (LUN) for the primary iSCSI boot target.

This property shall contain the logical unit number (LUN) for the primary iSCSI boot target.

primary_vlan_enable: Option<Option<Boolean>>

An indication of whether the primary VLAN is enabled.

This property shall indicate whether this VLAN is enabled for the primary iSCSI boot target.

primary_vlanid: Option<Option<Int64>>

The 802.1q VLAN ID to use for iSCSI boot from the primary target.

This property shall contain the 802.1q VLAN ID to use for iSCSI boot from the primary target. This VLAN ID is only used if PrimaryVLANEnable is true.

primary_dns: Option<Option<String>>

The IPv6 or IPv4 address of the primary DNS server for the iSCSI boot initiator.

This property shall contain the IPv6 or IPv4 address of the primary DNS server for the iSCSI boot initiator.

secondary_target_name: Option<Option<String>>

The name of the iSCSI secondary boot target.

This property shall contain the name of the secondary iSCSI boot target. This property should match formats defined in RFC3720 or RFC3721.

secondary_target_ip_address: Option<Option<String>>

The IPv4 or IPv6 address for the secondary iSCSI boot target.

This property shall contain the IPv4 or IPv6 address for the secondary iSCSI boot target.

secondary_target_tcp_port: Option<Option<Int64>>

The TCP port for the secondary iSCSI boot target.

This property shall contain the TCP port for the secondary iSCSI boot target.

secondary_lun: Option<Option<Int64>>

The logical unit number (LUN) for the secondary iSCSI boot target.

This property shall contain the logical unit number (LUN) for the secondary iSCSI boot target.

secondary_vlan_enable: Option<Option<Boolean>>

An indication of whether the secondary VLAN is enabled.

This property shall indicate whether this VLAN is enabled for the secondary iSCSI boot target.

secondary_vlanid: Option<Option<Int64>>

The 802.1q VLAN ID to use for iSCSI boot from the secondary target.

This property shall contain the 802.1q VLAN ID to use for iSCSI boot from the secondary target. This VLAN ID is only used if SecondaryVLANEnable is true.

secondary_dns: Option<Option<String>>

The IPv6 or IPv4 address of the secondary DNS server for the iSCSI boot initiator.

This property shall contain the IPv6 or IPv4 address of the secondary DNS server for the iSCSI boot initiator.

ip_mask_dns_via_dhcp: Option<Option<Boolean>>

An indication of whether the iSCSI boot initiator uses DHCP to obtain the initiator name, IP address, and netmask.

This property shall indicate whether the iSCSI boot initiator uses DHCP to obtain the initiator name, IP address, and netmask.

router_advertisement_enabled: Option<Option<Boolean>>

An indication of whether IPv6 router advertisement is enabled for the iSCSI boot target.

This property shall indicate whether IPv6 router advertisement is enabled for the iSCSI boot target. This setting shall apply to only IPv6 configurations.

authentication_method: Option<Option<AuthenticationMethod>>

The iSCSI boot authentication method for this network device function.

This property shall contain the iSCSI boot authentication method for this network device function.

chap_username: Option<Option<String>>

The username for CHAP authentication.

This property shall contain the username for CHAP authentication.

chap_secret: Option<Option<String>>

The shared secret for CHAP authentication.

This property shall contain the shared secret for CHAP authentication.

mutual_chap_username: Option<Option<String>>

The CHAP username for two-way CHAP authentication.

This property shall contain the CHAP username for two-way CHAP authentication.

mutual_chap_secret: Option<Option<String>>

The CHAP secret for two-way CHAP authentication.

This property shall contain the CHAP secret for two-way CHAP authentication.