Links

Struct Links 

pub struct Links {
    pub base: Links,
    pub pcie_function: Option<ReferenceLeaf>,
    pub endpoints: Option<Vec<ReferenceLeaf>>,
    pub physical_port_assignment: Option<ReferenceLeaf>,
    pub ethernet_interface: Option<NavProperty<EthernetInterface>>,
    pub physical_network_port_assignment: Option<ReferenceLeaf>,
    pub ethernet_interfaces: Option<Vec<NavProperty<EthernetInterface>>>,
    pub offload_system: Option<NavProperty<ComputerSystem>>,
    pub offload_processors: Option<Vec<NavProperty<Processor>>>,
}

Fields

base: Links

Base type

pcie_function: Option<ReferenceLeaf>endpoints: Option<Vec<ReferenceLeaf>>physical_port_assignment: Option<ReferenceLeaf>ethernet_interface: Option<NavProperty<EthernetInterface>>

The link to a virtual Ethernet interface that was created when one of the network device function VLANs is represented as a virtual NIC for the purpose of showing the IP address associated with that VLAN.

This property shall contain a link to a resource of type EthernetInterface that represents a virtual interface that was created when one of the network device function VLANs is represented as a virtual NIC for the purpose of showing the IP address associated with that VLAN. The EthernetInterfaceType property of that resource shall contain the value Virtual.

physical_network_port_assignment: Option<ReferenceLeaf>ethernet_interfaces: Option<Vec<NavProperty<EthernetInterface>>>

The system Ethernet interfaces that use this network device function. This includes physical Ethernet interfaces or VLANs. Each member of this property is subordinate a ComputerSystem resource.

This property shall contain an array of links to resources of type EthernetInterface that represent physical or VLAN Ethernet interfaces for systems that use this network device funciton. The members shall be subordinate to a ComputerSystem resource.

offload_system: Option<NavProperty<ComputerSystem>>

The system that performs offload computation for this network function, such as with a SmartNIC.

This property shall contain a link to a resource of type ComputerSystem that represents the system that performs offload computation for this network function, such as with a SmartNIC. The SystemType property contained in the referenced ComputerSystem resource should contain the value DPU. This property shall not be present if OffloadProcessors is present.

offload_processors: Option<Vec<NavProperty<Processor>>>

The processors that perform offload computation for this network function, such as with a SmartNIC.

This property shall contain an array of links to resources of type Processor that represent the processors that performs offload computation for this network function, such as with a SmartNIC. This property shall not be present if OffloadSystem is present.