pub struct NetworkDeviceFunctionCollection {
pub base: ResourceCollection,
pub members: Vec<NavProperty<NetworkDeviceFunction>>,
}Expand description
The collection of NetworkDeviceFunction resource instances.
This resource shall represent a resource collection of NetworkDeviceFunction instances for a
Redfish implementation.
Fields
base: ResourceCollectionBase type
members: Vec<NavProperty<NetworkDeviceFunction>>The members of this collection.
This property shall contain an array of links to the members of this collection.