pub enum DeviceType {
SingleFunction,
MultiFunction,
Simulated,
Retimer,
UnsupportedValue,
}Variants
SingleFunction
A single-function PCIe device.
MultiFunction
A multi-function PCIe device.
Simulated
A PCIe device that is not currently physically present, but is being simulated by the PCIe infrastructure.
Retimer
A PCIe retimer device.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.