pub enum PowerLimitException {
NoAction,
HardPowerOff,
LogEventOnly,
Oem,
UnsupportedValue,
}Variants
NoAction
Take no action when the limit is exceeded.
HardPowerOff
Turn the power off immediately when the limit is exceeded.
LogEventOnly
Log an event when the limit is exceeded, but take no further action.
Oem
Take an OEM-defined action.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.