pub struct Actions {
pub oem: Option<OemActions>,
pub power_supply_reset: Option<Action<PowerPowerSupplyResetAction, ()>>,
}Expand description
The available actions for this resource.
This type shall contain the available actions for this resource.
Fields
oem: Option<OemActions>The available OEM-specific actions for this resource.
This property shall contain the available OEM-specific actions for this resource.
power_supply_reset: Option<Action<PowerPowerSupplyResetAction, ()>>Implementations
Sourceimpl Actions
impl Actions
Sourcepub async fn power_supply_reset<B: Bmc>(
&self,
bmc: &B,
reset_type: Option<ResetType>,
member_id: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn power_supply_reset<B: Bmc>(
&self,
bmc: &B,
reset_type: Option<ResetType>,
member_id: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
This action resets the targeted power supply.
This action shall reset a power supply specified by the MemberId from the PowerSupplies array.
A GracefulRestart ResetType shall reset the power supply but shall not affect the power output.
A ForceRestart ResetType can affect the power supply output.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.