InputRange

Struct InputRange 

pub struct InputRange {
    pub input_type: Option<Option<InputType>>,
    pub minimum_voltage: Option<Option<Decimal>>,
    pub maximum_voltage: Option<Option<Decimal>>,
    pub minimum_frequency_hz: Option<Option<Decimal>>,
    pub maximum_frequency_hz: Option<Option<Decimal>>,
    pub output_wattage: Option<Option<Decimal>>,
    pub oem: Option<Oem>,
}
This type describes an input range for a power supply.

This type shall describe an input range that the associated power supply can utilize.

Fields

input_type: Option<Option<InputType>>

The Input type (AC or DC).

This property shall contain the input type (AC or DC) of the associated range.

minimum_voltage: Option<Option<Decimal>>

The minimum line input voltage at which this power supply input range is effective.

This property shall contain the value, in volt units, of the minimum line input voltage that the power supply is capable of consuming for this range.

maximum_voltage: Option<Option<Decimal>>

The maximum line input voltage at which this power supply input range is effective.

This property shall contain the value, in volt units, of the maximum line input voltage that the power supply is capable of consuming for this range.

minimum_frequency_hz: Option<Option<Decimal>>

The minimum line input frequency at which this power supply input range is effective.

This property shall contain the value, in hertz units, of the minimum line input frequency that the power supply is capable of consuming for this range.

maximum_frequency_hz: Option<Option<Decimal>>

The maximum line input frequency at which this power supply input range is effective.

This property shall contain the value, in hertz units, of the maximum line input frequency that the power supply is capable of consuming for this range.

output_wattage: Option<Option<Decimal>>

The maximum capacity of this power supply when operating in this input range.

This property shall contain the maximum amount of power, in watt units, that the associated power supply is rated to deliver while operating in this input range.

oem: Option<Oem>

The OEM extension property.

This property shall contain the OEM extensions. All values for properties contained in this object shall conform to the Redfish Specification-described requirements.