pub struct Power {
pub base: Resource,
pub actions: Option<Actions>,
pub power_control: Option<Vec<NavProperty<PowerControl>>>,
pub voltages: Option<Vec<NavProperty<Voltage>>>,
pub power_supplies: Option<Vec<NavProperty<PowerSupply>>>,
pub redundancy: Option<Vec<ReferenceLeaf>>,
}Expand description
The Power schema describes power metrics and represents the properties for power consumption and
power limiting.
This resource shall contain the power metrics for a Redfish implementation.
Fields
base: ResourceBase type
actions: Option<Actions>The available actions for this resource.
This property shall contain the available actions for this resource.
power_control: Option<Vec<NavProperty<PowerControl>>>The set of power control functions, including power reading and limiting.
This property shall contain the set of power control readings and settings.
voltages: Option<Vec<NavProperty<Voltage>>>The set of voltage sensors for this chassis.
This property shall contain the set of voltage sensors for this chassis.
power_supplies: Option<Vec<NavProperty<PowerSupply>>>The set of power supplies associated with this system or device.
This property shall contain the set of power supplies associated with this system or device.
redundancy: Option<Vec<ReferenceLeaf>>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Power
impl<'de> Deserialize<'de> for Power
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl EntityTypeRef for Power
impl EntityTypeRef for Power
Sourceimpl Expandable for Power
impl Expandable for Power
Sourceimpl RedfishSettings<Power> for Power
impl RedfishSettings<Power> for Power
Sourcefn settings_object(&self) -> Option<NavProperty<Self>>
fn settings_object(&self) -> Option<NavProperty<Self>>
Sourceimpl Updatable<PowerUpdate> for Power
impl Updatable<PowerUpdate> for Power
impl Send for Power
SAFETY: All generated data types are Send
impl Sync for Power
SAFETY: All generated data types are Sync