pub struct PowerLimit {
pub limit_in_watts: Option<Option<Decimal>>,
pub limit_exception: Option<Option<PowerLimitException>>,
pub correction_in_ms: Option<Option<Int64>>,
}Expand description
The power limit status and configuration information for the chassis.
This type shall contain power limit status and configuration information for this chassis.
Fields
limit_in_watts: Option<Option<Decimal>>The power limit, in watt units. If null, power capping is disabled.
This property shall represent the power capping limit, in watt units, for the resource. If null,
power capping shall be disabled.
limit_exception: Option<Option<PowerLimitException>>The action that is taken if the power cannot be maintained below the LimitInWatts.
This property shall represent the action to be taken if the resource power consumption cannot be limited below the specified limit after several correction time periods.
correction_in_ms: Option<Option<Int64>>The time required for the limiting process to reduce power consumption to below the limit.
This property shall represent the time interval in ms required for the limiting process to react and reduce the power consumption below the limit.