pub enum LineStatus {
Normal,
LossOfInput,
OutOfRange,
UnsupportedValue,
}Variants
Normal
Line input is within normal operating range.
LossOfInput
No power detected at line input.
OutOfRange
Line input voltage or current is outside of normal operating range.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.