Module processor

Module processor 

Generated schema of Processor namespace

Structs

Actions
The available actions for this resource.
EthernetInterface
This type defines an Ethernet interface.
EthernetInterfaceUpdate
Update struct corresponding to EthernetInterface
Fpga
The properties of the FPGA device.
FpgaReconfigurationSlot
This type describes the FPGA reconfiguration slot. An FPGA uses a reconfiguration slot to contain an acceleration function that can change as the FPGA is provisioned.
FpgaReconfigurationSlotUpdate
Update struct corresponding to FpgaReconfigurationSlot
FpgaUpdate
Update struct corresponding to Fpga
Links
MemorySummary
MemorySummaryUpdate
Update struct corresponding to MemorySummary
OemActions
The available OEM-specific actions for this resource.
Processor
The Processor schema describes the information about a single processor that a system contains. A processor includes both performance characteristics, clock speed, architecture, core count, and so on, and compatibility, such as the CPU ID instruction results. It also describes the location, such as a slot, socket, or bay, where a unit can be installed, by populating a resource instance with an absent state if a unit is not present.
ProcessorId
ProcessorInterface
This type describes an interface between the system, or external connection, and the processor.
ProcessorInterfaceUpdate
Update struct corresponding to ProcessorInterface
ProcessorMemory
This type describes the memory directly attached or integrated within a processor.
ProcessorResetAction
This action resets the processor.
ProcessorResetToDefaultsAction
The action resets the values of writable properties to factory defaults.
ProcessorUpdate
Update struct corresponding to Processor
UaLink
The UALink attributes of a processor.
UaLinkUpdate
Update struct corresponding to UaLink

Enums

BaseSpeedPriorityState
FpgaType
ProcessorMemoryType
ProcessorType
SystemInterfaceType
ThrottleCause
TurboState

Type Aliases

InstructionSet
ProcessorArchitecture