pub enum FpgaType {
Integrated,
Discrete,
UnsupportedValue,
}Variants
Integrated
The FPGA device integrated with other processor in the single chip.
Discrete
The discrete FPGA device.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.