pub enum ThrottleCause {
PowerLimit,
ThermalLimit,
ClockLimit,
ManagementDetectedFault,
Unknown,
Oem,
UnsupportedValue,
}Variants
PowerLimit
The cause of the processor being throttled is a power limit.
ThermalLimit
The cause of the processor being throttled is a thermal limit.
ClockLimit
The cause of the processor being throttled is a clock limit.
ManagementDetectedFault
The cause of the processor being throttled is a fault detected by management hardware or firmware.
Unknown
The cause of the processor being throttled is not known.
Oem
The cause of the processor being throttled is OEM-specific.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.