Actions

Struct Actions 

pub struct Actions {
    pub oem: Option<OemActions>,
    pub reset: Option<Action<ProcessorResetAction, ()>>,
    pub reset_to_defaults: Option<Action<ProcessorResetToDefaultsAction, ()>>,
}
The available actions for this resource.

This type shall contain the available actions for this resource.

Fields

oem: Option<OemActions>

The available OEM-specific actions for this resource.

This property shall contain the available OEM-specific actions for this resource.

reset: Option<Action<ProcessorResetAction, ()>>reset_to_defaults: Option<Action<ProcessorResetToDefaultsAction, ()>>

Implementations

Source

impl Actions

pub async fn reset<B: Bmc>( &self, bmc: &B, reset_type: Option<ResetType>, ) -> Result<ModificationResponse<()>, B::Error>
where B::Error: ActionError,

This action resets the processor.

This action shall reset the processor.

Errors
pub async fn reset_to_defaults<B: Bmc>( &self, bmc: &B, ) -> Result<ModificationResponse<()>, B::Error>
where B::Error: ActionError,

The action resets the values of writable properties to factory defaults.

This action shall reset the values of writable properties in this resource to their default values as specified by the manufacturer.

Errors