EthernetInterface

Struct EthernetInterface 

pub struct EthernetInterface {
    pub oem: Option<Oem>,
    pub max_speed_mbps: Option<Option<Int64>>,
    pub max_lanes: Option<Option<Int64>>,
}
This type defines an Ethernet interface.

These properties shall contain the definition for an Ethernet interface for a Redfish implementation.

Fields

oem: Option<Oem>

The OEM extension property.

This property shall contain the OEM extensions. All values for properties contained in this object shall conform to the Redfish Specification-described requirements.

max_speed_mbps: Option<Option<Int64>>

The maximum speed supported by this interface.

This property shall contain the maximum speed supported by this interface.

max_lanes: Option<Option<Int64>>

The number of lanes supported by this interface.

This property shall contain the maximum number of lanes supported by this interface.