FpgaReconfigurationSlot

Struct FpgaReconfigurationSlot 

pub struct FpgaReconfigurationSlot {
    pub slot_id: Option<Option<String>>,
    pub uuid: Option<Option<Uuid>>,
    pub programmable_from_host: Option<Option<Boolean>>,
    pub acceleration_function: Option<ReferenceLeaf>,
}
This type describes the FPGA reconfiguration slot. An FPGA uses a reconfiguration slot to contain an acceleration function that can change as the FPGA is provisioned.

This type shall contain information about the FPGA reconfiguration slot.

Fields

slot_id: Option<Option<String>>

The FPGA reconfiguration slot identifier.

This property shall contain the FPGA reconfiguration slot identifier.

uuid: Option<Option<Uuid>>

The UUID for this reconfiguration slot.

This property shall contain a universally unique identifier number for the reconfiguration slot.

programmable_from_host: Option<Option<Boolean>>

An indication of whether the reconfiguration slot can be reprogrammed from the host by using system software.

This property shall indicate whether the reconfiguration slot can be reprogrammed from the host by using system software. If false, system software shall not be able to program the reconfiguration slot from the system interface. In either state, a management controller may be able to program the reconfiguration slot by using the sideband interface.

acceleration_function: Option<ReferenceLeaf>