MemorySummary

Struct MemorySummary 

pub struct MemorySummary {
    pub total_cache_size_mi_b: Option<Option<Int64>>,
    pub total_memory_size_mi_b: Option<Option<Int64>>,
    pub ecc_mode_enabled: Option<Option<Boolean>>,
    pub metrics: Option<NavProperty<MemoryMetrics>>,
}

Fields

total_cache_size_mi_b: Option<Option<Int64>>

Total size of cache memory of this processor.

This property shall contain the total size of cache memory of this processor.

total_memory_size_mi_b: Option<Option<Int64>>

Total size of non-cache volatile or non-volatile memory attached to this processor. Examples include DRAMs and NV-DIMMs that are not configured as block storage.

This property shall contain the total size of non-cache volatile or non-volatile memory attached to this processor. Examples include DRAMs and NV-DIMMs that are not configured as block storage. This value indicates the size of memory directly attached or with strong affinity to this processor, not the total memory accessible by the processor. This property shall not be present for implementations where all processors have equal memory performance or access characteristics, such as hop count, for all system memory.

ecc_mode_enabled: Option<Option<Boolean>>

An indication of whether memory ECC mode is enabled for this processor.

The value of this property shall indicate if memory ECC mode is enabled for this processor. This value shall not affect system memory ECC mode.

metrics: Option<NavProperty<MemoryMetrics>>

The link to the memory metrics associated with all memory of this processor.

This property shall contain a link to a resource of type MemoryMetrics that contains the metrics associated with all memory of this processor.