Processor

Struct Processor 

pub struct Processor {
Show 58 fields pub base: Resource, pub socket: Option<Option<String>>, pub processor_type: Option<Option<ProcessorType>>, pub processor_architecture: Option<Option<ProcessorArchitecture>>, pub instruction_set: Option<Option<InstructionSet>>, pub processor_id: Option<ProcessorId>, pub status: Option<Status>, pub manufacturer: Option<Option<String>>, pub model: Option<Option<String>>, pub max_speed_mhz: Option<Option<Int64>>, pub total_cores: Option<Option<Int64>>, pub total_threads: Option<Option<Int64>>, pub links: Option<Links>, pub actions: Option<Actions>, pub location: Option<Location>, pub tdp_watts: Option<Option<Int64>>, pub max_tdp_watts: Option<Option<Int64>>, pub uuid: Option<Option<Uuid>>, pub processor_memory: Option<Vec<ProcessorMemory>>, pub fpga: Option<Fpga>, pub total_enabled_cores: Option<Option<Int64>>, pub serial_number: Option<Option<String>>, pub part_number: Option<Option<String>>, pub version: Option<Option<String>>, pub firmware_version: Option<String>, pub system_interface: Option<ProcessorInterface>, pub operating_speed_mhz: Option<Option<Int64>>, pub min_speed_mhz: Option<Option<Int64>>, pub turbo_state: Option<Option<TurboState>>, pub base_speed_priority_state: Option<Option<BaseSpeedPriorityState>>, pub high_speed_core_ids: Option<Option<Vec<Int64>>>, pub location_indicator_active: Option<Option<Boolean>>, pub base_speed_mhz: Option<Option<Int64>>, pub speed_limit_mhz: Option<Option<Int64>>, pub speed_locked: Option<Option<Boolean>>, pub memory_summary: Option<MemorySummary>, pub spare_part_number: Option<Option<String>>, pub measurements: Option<Vec<MeasurementBlock>>, pub enabled: Option<Boolean>, pub additional_firmware_versions: Option<AdditionalVersions>, pub replaceable: Option<Option<Boolean>>, pub throttled: Option<Option<Boolean>>, pub throttle_causes: Option<Option<Vec<ThrottleCause>>>, pub processor_index: Option<Option<Int64>>, pub family: Option<Option<String>>, pub power_state: Option<Option<PowerState>>, pub total_enabled_threads: Option<Option<Int64>>, pub ua_link: Option<UaLink>, pub assembly: Option<NavProperty<Assembly>>, pub sub_processors: Option<NavProperty<ProcessorCollection>>, pub metrics: Option<NavProperty<ProcessorMetrics>>, pub acceleration_functions: Option<ReferenceLeaf>, pub operating_configs: Option<ReferenceLeaf>, pub applied_operating_config: Option<ReferenceLeaf>, pub environment_metrics: Option<NavProperty<EnvironmentMetrics>>, pub certificates: Option<ReferenceLeaf>, pub ports: Option<ReferenceLeaf>, pub cache_memory: Option<NavProperty<MemoryCollection>>,
}
The Processor schema describes the information about a single processor that a system contains. A processor includes both performance characteristics, clock speed, architecture, core count, and so on, and compatibility, such as the CPU ID instruction results. It also describes the location, such as a slot, socket, or bay, where a unit can be installed, by populating a resource instance with an absent state if a unit is not present.

This resource shall represent a single processor that a system contains. A processor includes both performance characteristics, clock speed, architecture, core count, and so on, and compatibility, such as the CPU ID instruction results. It may also represent a location, such as a slot, socket, or bay, where a unit may be installed, but the State property within the Status property contains Absent.

Fields

base: Resource

Base type

socket: Option<Option<String>>

The socket or location of the processor.

This property shall contain the string that identifies the physical location or socket of the processor.

processor_type: Option<Option<ProcessorType>>

The type of processor.

This property shall contain the string that identifies the type of processor contained in this socket.

processor_architecture: Option<Option<ProcessorArchitecture>>

The architecture of the processor.

This property shall contain the string that identifies the architecture of the processor contained in this socket.

instruction_set: Option<Option<InstructionSet>>

The instruction set of the processor.

This property shall contain the string that identifies the instruction set of the processor contained in this socket.

processor_id: Option<ProcessorId>

The identification information for this processor.

This object shall contain identification information for this processor. For additional property requirements, see the corresponding definition in the Redfish Data Model Specification.

status: Option<Status>

The status and health of the resource and its subordinate or dependent resources.

This property shall contain any status or health properties of the resource.

manufacturer: Option<Option<String>>

The processor manufacturer.

This property shall contain a string that identifies the manufacturer of the processor.

model: Option<Option<String>>

The product model number of this device.

This property shall indicate the model information as provided by the manufacturer of this processor.

max_speed_mhz: Option<Option<Int64>>

The maximum clock speed of the processor.

This property shall indicate the maximum rated clock speed of the processor in MHz.

total_cores: Option<Option<Int64>>

The total number of cores that this processor contains.

This property shall indicate the total count of independent processor cores, including disabled cores, contained within this processor.

total_threads: Option<Option<Int64>>

The total number of execution threads that this processor supports.

This property shall indicate the total count of independent execution threads, including disabled threads, that this processor supports.

links: Option<Links>

The links to other resources that are related to this resource.

This property shall contain links to resources that are related to but are not contained by, or subordinate to, this resource.

actions: Option<Actions>

The available actions for this resource.

This property shall contain the available actions for this resource.

location: Option<Location>

The location of the processor.

This property shall contain the location information of the associated processor.

tdp_watts: Option<Option<Int64>>

The nominal Thermal Design Power (TDP) in watt units.

This property shall contain the nominal Thermal Design Power (TDP) in watt units.

max_tdp_watts: Option<Option<Int64>>

The maximum Thermal Design Power (TDP) in watt units.

This property shall contain the maximum Thermal Design Power (TDP) in watt units.

uuid: Option<Option<Uuid>>

The UUID for this processor.

This property shall contain a universally unique identifier number for the processor. RFC4122 describes methods to use to create the value. The value should be considered to be opaque. Client software should only treat the overall value as a universally unique identifier and should not interpret any subfields within the UUID.

processor_memory: Option<Vec<ProcessorMemory>>

The memory directly attached or integrated within this processor. Examples include internal cache, dedicated memory for the processor, and system memory.

This property shall contain the memory directly attached or integrated within this processor.

fpga: Option<Fpga>

The properties for processors of the FPGA type.

This property shall contain an object containing properties for processors of type FPGA.

total_enabled_cores: Option<Option<Int64>>

The total number of enabled cores that this processor contains.

This property shall indicate the total count of enabled independent processor cores contained within this processor.

serial_number: Option<Option<String>>

The serial number of the processor.

This property shall contain a manufacturer-allocated number that identifies the processor.

part_number: Option<Option<String>>

The part number of the processor.

This property shall contain a part number assigned by the organization that is responsible for producing or manufacturing the processor.

version: Option<Option<String>>

The hardware version of the processor.

This property shall contain the hardware version of the processor as determined by the vendor or supplier.

firmware_version: Option<String>

The firmware version of the processor.

This property shall contain a string describing the firmware version of the processor as provided by the manufacturer.

system_interface: Option<ProcessorInterface>

The interface between the system and the processor.

This property shall contain an object that describes the connectivity between the host system and the processor.

operating_speed_mhz: Option<Option<Int64>>

Operating speed of the processor in MHz.

This property shall contain the operating speed of the processor in MHz. The operating speed of the processor may change more frequently than the manager is able to monitor.

min_speed_mhz: Option<Option<Int64>>

The minimum clock speed of the processor in MHz.

This property shall indicate the minimum rated clock speed of the processor in MHz.

turbo_state: Option<Option<TurboState>>

The state of turbo for this processor.

This property shall contain the state of turbo for this processor.

base_speed_priority_state: Option<Option<BaseSpeedPriorityState>>

The state of the base frequency settings of the operation configuration applied to this processor.

This property shall contain the state of the base frequency settings of the operating configuration applied to this processor.

high_speed_core_ids: Option<Option<Vec<Int64>>>

The list of core identifiers corresponding to the cores that have been configured with the higher clock speed from the operating configuration applied to this processor.

This property shall contain an array of core identifiers corresponding to the cores that have been configured with the higher clock speed from the operating configuration applied to this processor.

location_indicator_active: Option<Option<Boolean>>

An indicator allowing an operator to physically locate this resource.

This property shall contain the state of the indicator used to physically identify or locate this resource. A write to this property shall update the value of IndicatorLED in this resource, if supported, to reflect the implementation of the locating function.

base_speed_mhz: Option<Option<Int64>>

The base (nominal) clock speed of the processor in MHz.

This property shall contain the base (nominal) clock speed of the processor in MHz.

speed_limit_mhz: Option<Option<Int64>>

The clock limit of the processor in MHz.

This property shall contain the clock limit of the processor in MHz. This value shall be within the range of MinSpeedMHz and MaxSpeedMHz as provided by the manufacturer of this processor.

speed_locked: Option<Option<Boolean>>

Indicates whether the clock speed of the processor is fixed at the value specified in the SpeedLimitMHz property.

This property shall indicate whether the clock speed of the processor is fixed, where a value true shall indicate that the clock speed is fixed at the value specified in the SpeedLimitMHz property.

memory_summary: Option<MemorySummary>

The summary of all memory associated with this processor.

This property shall contain properties that describe the summary of all memory that is associated with this processor.

spare_part_number: Option<Option<String>>

The spare part number of the processor.

This property shall contain the spare part number of the processor.

measurements: Option<Vec<MeasurementBlock>>

An array of DSP0274-defined measurement blocks.

This property shall contain an array of DSP0274-defined measurement blocks.

enabled: Option<Boolean>

An indication of whether this processor is enabled.

The value of this property shall indicate if this processor is enabled.

additional_firmware_versions: Option<AdditionalVersions>

The additional firmware versions of the processor.

This property shall contain the additional firmware versions of the processor.

replaceable: Option<Option<Boolean>>

An indication of whether this component can be independently replaced as allowed by the vendor’s replacement policy.

This property shall indicate whether this component can be independently replaced as allowed by the vendor’s replacement policy. A value of false indicates the component needs to be replaced by policy as part of another component. If the LocationType property of this component contains Embedded, this property shall contain false.

throttled: Option<Option<Boolean>>

An indication of whether the processor is throttled.

This property shall indicate whether the processor is throttled.

throttle_causes: Option<Option<Vec<ThrottleCause>>>

The causes of the processor being throttled.

This property shall contain the causes of the processor being throttled. If Throttled contains false, this property shall contain an empty array.

processor_index: Option<Option<Int64>>

The logical index of this processor within the system.

This property shall contain the zero-based index of the processor, indexed within the next unit of containment. The value of this property shall match the ordering in the operating system topology interfaces, with offset adjustments, if needed.

family: Option<Option<String>>

The processor family.

This property shall contain a string that identifies the processor family, as specified by the combination of the EffectiveFamily and EffectiveModel properties.

power_state: Option<Option<PowerState>>

The current power state of the processor.

This property shall contain the power state of the processor. If the PowerState property in the associated Chassis resource contains the value Off, this property shall contain Off.

total_enabled_threads: Option<Option<Int64>>

The total number of enabled execution threads contained in this processor.

This property shall indicate the total count of enabled independent execution threads contained within this processor.

ua_link: Option<UaLink>

The UALink properties of the processor.

This property shall contain UALink attributes of the processor.

assembly: Option<NavProperty<Assembly>>

The link to an assembly associated with this processor.

This property shall contain a link to a resource of type Assembly.

sub_processors: Option<NavProperty<ProcessorCollection>>

The link to the collection of sub-processors associated with this processor, such as cores or threads, that are part of a processor.

This property shall contain a link to a resource collection of type ProcessorCollection.

metrics: Option<NavProperty<ProcessorMetrics>>

The link to the metrics associated with this processor.

This property shall contain a link to a resource of type ProcessorMetrics that contains the metrics associated with this processor.

acceleration_functions: Option<ReferenceLeaf>operating_configs: Option<ReferenceLeaf>applied_operating_config: Option<ReferenceLeaf>environment_metrics: Option<NavProperty<EnvironmentMetrics>>

The link to the environment metrics for this processor.

This property shall contain a link to a resource of type EnvironmentMetrics that specifies the environment metrics for this processor.

certificates: Option<ReferenceLeaf>ports: Option<ReferenceLeaf>cache_memory: Option<NavProperty<MemoryCollection>>

The link to the collection of cache memory associated with this processor.

This property shall contain a link to a resource collection of type MemoryCollection that represents the cache memory of this processor.