ProcessorResetToDefaultsAction

Struct ProcessorResetToDefaultsAction 

pub struct ProcessorResetToDefaultsAction {}
The action resets the values of writable properties to factory defaults.

This action shall reset the values of writable properties in this resource to their default values as specified by the manufacturer.