pub struct UaLink {
pub accelerator_id: Option<Int64>,
}Expand description
The UALink attributes of a processor.
This type shall contain information about UALink fabric and port management within the processor.
Fields
accelerator_id: Option<Int64>The UALink Accelerator ID of the processor.
This property shall contain an integer that is unique within a UALink Pod and that serves as the Source and Destination Accelerator ID on the UALink network.