pub struct ProcessorCollection {
pub base: ResourceCollection,
pub members: Vec<NavProperty<Processor>>,
}Expand description
The collection of Processor resource instances.
This resource shall represent a resource collection of Processor instances for a Redfish
implementation.
Fields
base: ResourceCollectionBase type
members: Vec<NavProperty<Processor>>The members of this collection.
This property shall contain an array of links to the members of this collection.