pub struct Actions {
pub oem: Option<OemActions>,
pub clear_current_period: Option<Action<ProcessorMetricsClearCurrentPeriodAction, ()>>,
}Expand description
The available actions for this resource.
This type shall contain the available actions for this resource.
Fields
oem: Option<OemActions>The available OEM-specific actions for this resource.
This property shall contain the available OEM-specific actions for this resource.
clear_current_period: Option<Action<ProcessorMetricsClearCurrentPeriodAction, ()>>Implementations
Sourceimpl Actions
impl Actions
Sourcepub async fn clear_current_period<B: Bmc>(
&self,
bmc: &B,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn clear_current_period<B: Bmc>(
&self,
bmc: &B,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
This action sets the CurrentPeriod property’s values to 0.
This action shall set the CurrentPeriod property’s values to 0.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.