pub struct CacheMetrics {
pub level: Option<Option<String>>,
pub cache_miss: Option<Option<Decimal>>,
pub hit_ratio: Option<Option<Decimal>>,
pub cache_misses_per_instruction: Option<Option<Decimal>>,
pub occupancy_bytes: Option<Option<Int64>>,
pub occupancy_percent: Option<Option<Decimal>>,
}Expand description
The processor core metrics.
This type shall contain properties that describe cache metrics of a processor or core.
Fields
level: Option<Option<String>>The cache level.
This property shall contain the level of the cache in the processor or core.
cache_miss: Option<Option<Decimal>>The number of cache line misses in millions.
This property shall contain the number of cache line misses of the processor or core in millions.
hit_ratio: Option<Option<Decimal>>The cache line hit ratio.
This property shall contain the cache hit ratio of the processor or core.
cache_misses_per_instruction: Option<Option<Decimal>>The number of cache misses per instruction.
This property shall contain the number of cache misses per instruction of the processor or core.
occupancy_bytes: Option<Option<Int64>>The total cache level occupancy in bytes.
This property shall contain the total cache occupancy of the processor or core in bytes.
occupancy_percent: Option<Option<Decimal>>The total cache occupancy percentage.
This property shall contain the total cache occupancy percentage, 0 to 100, of the processor or
core.