pub struct CacheMetricsTotal {
pub current_period: Option<CurrentPeriod>,
pub life_time: Option<LifeTime>,
}Expand description
The total cache metrics for a processor.
This property shall contain properties that describe the metrics for all of the cache memory for a processor.
Fields
current_period: Option<CurrentPeriod>The cache metrics since the last reset or ClearCurrentPeriod action for this processor.
This property shall contain properties that describe the metrics for the current period of cache memory for this processor.
life_time: Option<LifeTime>The cache metrics for the lifetime of this processor.
This property shall contain properties that describe the metrics for the lifetime of the cache memory for this processor.