Protocol

Enum Protocol 

pub enum Protocol {
Show 44 variants Pcie, Ahci, Uhci, Sas, Sata, Usb, Nvme, Fc, Iscsi, FcoE, Fcp, Ficon, NvmeOverFabrics, Smb, Nfsv3, Nfsv4, Http, Https, Ftp, Sftp, Iwarp, RoCe, RoCev2, I2c, Tcp, Udp, Tftp, GenZ, MultiProtocol, InfiniBand, Ethernet, NvLink, Oem, DisplayPort, Hdmi, Vga, Dvi, Cxl, Upi, Qpi, Emmc, Uet, UaLink, UnsupportedValue,
}

Variants



Pcie

PCI Express.

This value shall indicate conformance to the PCI-SIG PCI Express Base Specification.



Ahci

Advanced Host Controller Interface (AHCI).

This value shall indicate conformance to the Intel Advanced Host Controller Interface (AHCI) Specification.



Uhci

Universal Host Controller Interface (UHCI).

This value shall indicate conformance to the Intel Universal Host Controller Interface (UHCI) Specification, Enhanced Host Controller Interface Specification, or the Extensible Host Controller Interface Specification.



Sas

Serial Attached SCSI.

This value shall indicate conformance to the T10 SAS Protocol Layer Specification.



Sata

Serial AT Attachment.

This value shall indicate conformance to the Serial ATA International Organization Serial ATA Specification.



Usb

Universal Serial Bus (USB).

This value shall indicate conformance to the USB Implementers Forum Universal Serial Bus Specification.



Nvme

Non-Volatile Memory Express (NVMe).

This value shall indicate conformance to the Non-Volatile Memory Host Controller Interface Specification.



Fc

Fibre Channel.

This value shall indicate conformance to the T11 Fibre Channel Physical and Signaling Interface Specification.



Iscsi

Internet SCSI.

This value shall indicate conformance to the IETF Internet Small Computer Systems Interface (iSCSI) Specification.



FcoE

Fibre Channel over Ethernet (FCoE).

This value shall indicate conformance to the T11 FC-BB-5 Specification.



Fcp

Fibre Channel Protocol for SCSI.

This value shall indicate conformance to the INCITS 481: Information Technology - Fibre Channel Protocol for SCSI.



Ficon

FIbre CONnection (FICON).

This value shall indicate conformance to the ANSI FC-SB-3 Single-Byte Command Code Sets-3 Mapping Protocol for the Fibre Channel (FC) protocol. Fibre Connection (FICON) is the IBM-proprietary name for this protocol.



NvmeOverFabrics

NVMe over Fabrics.

This value shall indicate conformance to the NVM Express over Fabrics Specification.



Smb

Server Message Block (SMB). Also known as the Common Internet File System (CIFS).

This value shall indicate conformance to the Server Message Block (SMB), or Common Internet File System (CIFS), protocol.



Nfsv3

Network File System (NFS) version 3.

This value shall indicate conformance to the RFC1813-defined Network File System (NFS) protocol.



Nfsv4

Network File System (NFS) version 4.



Http

Hypertext Transport Protocol (HTTP).

This value shall indicate conformance to the Hypertext Transport Protocol (HTTP) as defined by RFC3010 or RFC5661.



Https

Hypertext Transfer Protocol Secure (HTTPS).

This value shall indicate conformance to the Hypertext Transfer Protocol Secure (HTTPS) as defined by RFC2068 or RFC2616, which uses Transport Layer Security (TLS) as defined by RFC5246 or RFC6176.



Ftp

File Transfer Protocol (FTP).

This value shall indicate conformance to the RFC114-defined File Transfer Protocol (FTP).



Sftp

SSH File Transfer Protocol (SFTP).

This value shall indicate conformance to the RFC114-defined SSH File Transfer Protocol (SFTP) that uses Transport Layer Security (TLS) as defined by RFC5246 or RFC6176.



Iwarp

Internet Wide Area RDMA Protocol (iWARP).

This value shall indicate conformance to the RFC5042-defined Internet Wide Area RDMA Protocol (iWARP) that uses the transport layer mechanisms as defined by RFC5043 or RFC5044.



RoCe

RDMA over Converged Ethernet Protocol.

This value shall indicate conformance to the InfiniBand Architecture Specification-defined RDMA over Converged Ethernet Protocol.



RoCev2

RDMA over Converged Ethernet Protocol Version 2.

This value shall indicate conformance to the InfiniBand Architecture Specification-defined RDMA over Converged Ethernet Protocol version 2.



I2c

Inter-Integrated Circuit Bus.

This value shall indicate conformance to the NXP Semiconductors I2C-bus Specification.



Tcp

Transmission Control Protocol (TCP).

This value shall indicate conformance to the IETF-defined Transmission Control Protocol (TCP). For example, RFC7414 defines the roadmap of the TCP specification.



Udp

User Datagram Protocol (UDP).

This value shall indicate conformance to the IETF-defined User Datagram Protocol (UDP). For example, RFC768 defines the core UDP specification.



Tftp

Trivial File Transfer Protocol (TFTP).

This value shall indicate conformance to the IETF-defined Trivial File Transfer Protocol (TFTP). For example, RFC1350 defines the core TFTP version 2 specification.



GenZ

GenZ.

This value shall indicate conformance to the Gen-Z Core Specification.



MultiProtocol

Multiple Protocols.

This value shall indicate conformance to multiple protocols.



InfiniBand

InfiniBand.

This value shall indicate conformance to the InfiniBand Architecture Specification-defined InfiniBand protocol.



Ethernet

Ethernet.

This value shall indicate conformance to the IEEE 802.3 Ethernet specification.

NVLink.

This value shall indicate conformance to the NVIDIA NVLink protocol.



Oem

OEM-specific.

This value shall indicate conformance to an OEM-specific architecture, and the OEM section may include additional information.



DisplayPort

DisplayPort.

This value shall indicate conformance to the VESA DisplayPort Specification.



Hdmi

HDMI.

This value shall indicate conformance to the HDMI Forum HDMI Specification.



Vga

VGA.

This value shall indicate conformance to the VESA SVGA Specification.



Dvi

DVI.

This value shall indicate conformance to the Digital Display Working Group DVI-A, DVI-D, or DVI-I Specification.



Cxl

Compute Express Link.

This value shall indicate conformance to the Compute Express Link Specification.



Upi

Intel UltraPath Interconnect (UPI).

This value shall indicate conformance to the Intel UltraPath Interconnect (UPI) protocol.



Qpi

Intel QuickPath Interconnect (QPI).

This value shall indicate conformance to the Intel QuickPath Interconnect (QPI) protocol.



Emmc

Embedded MultiMediaCard (e.MMC).

This value shall indicate conformance to the JEDEC JESD84-B51A specification.



Uet

Ultra Ethernet Transport.

This value shall indicate conformance to the Ultra Ethernet specifications.

Ultra Accelerator Link (UALink).

This value shall indicate conformance to the Ultra Accelerator Link specifications.



UnsupportedValue

Fallback value for values that are not supported by current version of Redfish schema.