ResolutionStep

Struct ResolutionStep 

pub struct ResolutionStep {
    pub resolution_type: Option<ResolutionType>,
    pub priority: Option<Option<Int64>>,
    pub action_uri: Option<String>,
    pub action_parameters: Option<Option<Vec<Parameters>>>,
    pub target_component_uri: Option<Option<String>>,
    pub retry_interval_seconds: Option<Option<Int64>>,
    pub retry_count: Option<Option<Int64>>,
    pub oem: Option<Oem>,
}

Fields

resolution_type: Option<ResolutionType>

The type of the resolution step.

This property shall contain the type of the resolution step.

priority: Option<Option<Int64>>

The priority in the set of resolution steps.

This property shall contain the priority in the set of resolution steps. The value 0 shall indicate the highest priority. Increasing values shall represent decreasing priority. If two or more resolution steps have the same priority, the execution order of the resolution steps shall be in array order. If a resolution step does not have a priority assignment, the default is 0. The priority is used to determine the execution order of the resolution steps.

action_uri: Option<String>

The action URI for a resolution step.

This property shall contain the action URI for a resolution step.

action_parameters: Option<Option<Vec<Parameters>>>

The parameters of the action URI for a resolution step.

This property shall contain the parameters of the action URI for a resolution step.

target_component_uri: Option<Option<String>>

The target URI of the component for a resolution step.

This property shall contain the target URI of the component for a resolution step. This property shall be present if the ActionURI property is not supported.

retry_interval_seconds: Option<Option<Int64>>

The interval between retries for a resolution step.

This property shall contain the interval, in seconds, between the retries for a resolution step.

retry_count: Option<Option<Int64>>

The number of retries for a resolution step.

This property shall contain the number of the retries for a resolution step.

oem: Option<Oem>

The OEM extension property.

This property shall contain the OEM extensions. All values for properties contained in this object shall conform to the Redfish Specification-described requirements.