pub enum ConditionType {
Alert,
Informational,
Subsystem,
UnsupportedValue,
}Variants
Alert
The condition is an alert.
This value shall indicate a condition that requires correction, such as a fault.
Informational
The condition is informational.
This value shall indicate a condition that requires attention, maintenance, or some other user intervention, such as performing a reset to activate new firmware.
Subsystem
The condition is the health of a subsystem.
This value shall indicate a condition that contains the health of a subsystem. If supported by the service, the service shall always provide this condition in responses.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.