IndicatorLed

Enum IndicatorLed 

pub enum IndicatorLed {
    Lit,
    Blinking,
    Off,
    UnsupportedValue,
}

Variants



Lit

The indicator LED is lit.

This value shall represent that the indicator LED is in a solid on state. If the service does not support this value, it shall reject PATCH or PUT requests containing this value by returning the HTTP 400 Bad Request status code.



Blinking

The indicator LED is blinking.

This value shall represent that the indicator LED is in a blinking state where the LED is being turned on and off in repetition. If the service does not support this value, it shall reject PATCH or PUT requests containing this value by returning the HTTP 400 Bad Request status code.



Off

The indicator LED is off.

This value shall represent that the indicator LED is in a solid off state. If the service does not support this value, it shall reject PATCH or PUT requests containing this value by returning the HTTP 400 Bad Request status code.



UnsupportedValue

Fallback value for values that are not supported by current version of Redfish schema.