pub enum LocationType {
Slot,
Bay,
Connector,
Socket,
Backplane,
Embedded,
UnsupportedValue,
}Expand description
The types of locations for a part within an enclosure.
This enumeration shall list the types of locations for a part within an enclosure.
Variants
Slot
A slot.
This value shall indicate the part is located in a slot.
Bay
A bay.
This value shall indicate the part is located in a bay.
Connector
A connector or port.
This value shall indicate the part is located in a connector or port.
Socket
A socket.
This value shall indicate the part is located in a socket.
Backplane
A backplane.
This value shall indicate the part is a backplane in an enclosure.
Embedded
Embedded within a part.
This value shall indicate the part is embedded or otherwise permanently incorporated into a larger part or device. This value shall not be used for parts that can be removed by a user or are considered field-replaceable.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.