pub struct Identifier {
pub durable_name: Option<Option<String>>,
pub durable_name_format: Option<Option<DurableNameFormat>>,
}Fields
durable_name: Option<Option<String>>The world-wide, persistent name of the resource.
This property shall contain the world-wide unique identifier for the resource. The string shall be
in the format described by the value in the DurableNameFormat property.
durable_name_format: Option<Option<DurableNameFormat>>The format of the durable name property.
This property shall represent the format of the DurableName property.