pub struct Item {
pub base: ItemOrCollection,
pub oem: Option<Oem>,
}Expand description
The base type for resources and members that can be linked to.
Fields
base: ItemOrCollectionBase type
oem: Option<Oem>The OEM extension property.
This property shall contain the OEM extensions. All values for properties that this object contains shall conform to the Redfish Specification-described requirements.