Location

Struct Location 

pub struct Location {
    pub info: Option<Option<String>>,
    pub info_format: Option<Option<String>>,
    pub oem: Option<Oem>,
    pub postal_address: Option<PostalAddress>,
    pub placement: Option<Placement>,
    pub part_location: Option<PartLocation>,
    pub longitude: Option<Option<Decimal>>,
    pub latitude: Option<Option<Decimal>>,
    pub altitude_meters: Option<Option<Decimal>>,
    pub contacts: Option<Option<Vec<ContactInfo>>>,
    pub part_location_context: Option<Option<String>>,
    pub physical_address: Option<PhysicalAddress>,
}

Fields

info: Option<Option<String>>

The location of the resource.

This property shall represent the location of the resource.

info_format: Option<Option<String>>

The format of the Info property.

This property shall represent the Info property format.

oem: Option<Oem>

The OEM extension property.

This property shall contain the OEM extensions. All values for properties contained in this object shall conform to the Redfish Specification-described requirements.

postal_address: Option<PostalAddress>

The postal address of the addressed resource.

This property shall contain a postal address of the resource.

placement: Option<Placement>

A place within the addressed location.

This property shall contain a place within the addressed location.

part_location: Option<PartLocation>

The part location for a resource within an enclosure.

This property shall contain the part location for a resource within an enclosure. This representation shall indicate the location of a part within a location specified by the Placement property.

longitude: Option<Option<Decimal>>

The longitude of the resource in degree units.

This property shall contain the longitude of the resource specified in degree units using a decimal format and not minutes or seconds.

latitude: Option<Option<Decimal>>

The latitude of the resource.

This property shall contain the latitude of the resource specified in degree units using a decimal format and not minutes or seconds.

altitude_meters: Option<Option<Decimal>>

The altitude of the resource in meters.

This property shall contain the altitude of the resource, in meter units, defined as the elevation above sea level.

contacts: Option<Option<Vec<ContactInfo>>>

An array of contact information.

This property shall contain an array of contact information for an individual or organization responsible for this resource.

part_location_context: Option<Option<String>>

Human-readable string to enable differentiation between PartLocation values for parts in the same enclosure, which might include hierarchical information of containing PartLocation values for the part.

This property shall contain a human-readable string to enable differentiation between PartLocation values for parts in the same enclosure, which may include hierarchical information of containing PartLocation values for the part. The value of this property shall not include values of the PartLocation properties for the part itself. The purpose of this value, in conjunction with the PartLocation of the part itself, is to allow clients to determine the physical location of the part without tracing through the PartLocation of multiple resources.

physical_address: Option<PhysicalAddress>

The physical address for a resource.

This property shall contain a physical address for a resource. This property should be present for resources that represent physical objects that can operate without requiring physical containment by another resource. For example, a server chassis might be contained by a rack, but it might also be deployed individually, while a drive is always contained by a chassis and therefore is described by the containing resource.