PhysicalAddress

Struct PhysicalAddress 

pub struct PhysicalAddress {
    pub street_address: Option<Option<String>>,
    pub city: Option<Option<String>>,
    pub state_or_province: Option<Option<String>>,
    pub iso_subdivision_code: Option<Option<String>>,
    pub country: Option<Option<String>>,
    pub iso_country_code: Option<Option<String>>,
    pub postal_code: Option<Option<String>>,
}
The physical address for a resource.

This type shall contain a physical address for a resource.

Fields

street_address: Option<Option<String>>

The street-level address, including building, room, or other identifiers.

This property shall contain the street-level physical address of the resource, including identifiers such as apartment, room, or building to further locate the resource within a given street address.

city: Option<Option<String>>

City, township, or shi (JP).

This property shall contain the city, township, or shi (JP) location for this resource.

state_or_province: Option<Option<String>>

State or province.

This property shall contain the state, province, or territory location within the country for this resource.

iso_subdivision_code: Option<Option<String>>

ISO 3166-2 subdivision code.

This property shall contain the ISO 3166-2-defined state, province, or territory subdivision code for this resource.

country: Option<Option<String>>

The country.

This property shall contain the country location for this resource.

iso_country_code: Option<Option<String>>

The ISO 3166-1 country code.

This property shall contain the ISO 3166-1-defined alpha-2 or alpha-3 country code.

postal_code: Option<Option<String>>

The postal code.

The property shall contain the postal code for this resource. The value shall conform to the RFC5139-defined requirements of the PC field.