Placement

Struct Placement 

pub struct Placement {
    pub row: Option<Option<String>>,
    pub rack: Option<Option<String>>,
    pub rack_offset_units: Option<Option<RackUnits>>,
    pub rack_offset: Option<Option<Int64>>,
    pub additional_info: Option<Option<String>>,
    pub room: Option<Option<String>>,
    pub facility_name: Option<Option<String>>,
}

Fields

row: Option<Option<String>>

The name of the row.

This property shall contain the name of the row.

rack: Option<Option<String>>

The name of a rack location within a row.

This property shall contain the name of the rack within a row.

rack_offset_units: Option<Option<RackUnits>>

The type of rack units in use.

This property shall contain a RackUnit enumeration literal that indicates the type of rack units in use.

rack_offset: Option<Option<Int64>>

The vertical location of the item, in terms of RackOffsetUnits.

The vertical location of the item in the rack, at the lowest point of the unit. Rack offset units shall be measured from bottom to top, starting with 0.

additional_info: Option<Option<String>>

Area designation or other additional info.

This property shall contain additional information, such as Tile, Column (Post), Wall, or other designation that describes a location that cannot be conveyed with other properties defined for the Placement object.

room: Option<Option<String>>

The name or number of the room.

This property shall contain the name or number of the room.

facility_name: Option<Option<String>>

The name of the facility.

This property shall contain the name of the facility.