ReferenceableMember

Struct ReferenceableMember 

pub struct ReferenceableMember {
    pub base: Item,
    pub member_id: String,
}
The base type for addressable members of an array.

References array members by using the value returned in the @odata.id property, which can be a dereferenceable URL. The @odata.id of this entity shall contain the location of this element within an item.

Fields

base: Item

Base type

member_id: String

The unique identifier for the member within an array.

This property shall contain the unique identifier for this member within an array. For services supporting Redfish v1.6 or higher, this value shall contain the zero-based array index.