Status

Struct Status 

pub struct Status {
    pub state: Option<Option<State>>,
    pub health_rollup: Option<Option<Health>>,
    pub health: Option<Option<Health>>,
    pub conditions: Option<Option<Vec<Condition>>>,
    pub oem: Option<Oem>,
}
The status and health of a resource and its children.

This type shall contain any status or health properties of a resource.

Fields

state: Option<Option<State>>

The state of the resource.

This property shall indicate the state of the resource.

health_rollup: Option<Option<Health>>

The overall health state from the view of this resource.

This property shall represent the health state of the resource and its dependent resources. The values shall conform to those defined in the Redfish Specification. For additional property requirements, see the corresponding definition in the Redfish Data Model Specification.

health: Option<Option<Health>>

The health state of this resource in the absence of its dependent resources.

This property shall represent the health state of the resource without considering its dependent resources. The values shall conform to those defined in the Redfish Specification.

conditions: Option<Option<Vec<Condition>>>

Conditions in this resource that require attention.

This property shall represent the active conditions requiring attention in this or a related resource. The conditions may affect the Health or HealthRollup of this resource. The service may roll up multiple conditions originating from a resource, using the ConditionInRelatedResource message from the Base Message Registry. The array order of conditions may change as new conditions occur or as conditions are resolved by the service.

oem: Option<Oem>

The OEM extension property.

This property shall contain the OEM extensions. All values for properties contained in this object shall conform to the Redfish Specification-described requirements.