pub struct ResourceBlock {
pub base: Resource,
}Expand description
The ResourceBlock schema contains definitions of a resource block, its components, and affinity
to composed devices.
This resource shall represent a resource block for a Redfish implementation.
Fields
base: ResourceBase type