SecureBootResetKeysAction

Struct SecureBootResetKeysAction 

pub struct SecureBootResetKeysAction {
    pub reset_keys_type: Option<ResetKeysType>,
}
This action resets the UEFI Secure Boot keys.

This action shall reset the UEFI Secure Boot key databases. The ResetAllKeysToDefault value shall reset all UEFI Secure Boot key databases to their default values. The DeleteAllKeys value shall delete the contents of all UEFI Secure Boot key databases. The DeletePK value shall delete the contents of the PK Secure Boot key database.

Fields

reset_keys_type: Option<ResetKeysType>

The type of reset or delete to perform on the UEFI Secure Boot databases.

This parameter shall specify the type of reset or delete to perform on the UEFI Secure Boot databases.