pub enum ElectricalContext {
Show 18 variants
Line1,
Line2,
Line3,
Neutral,
LineToLine,
Line1toLine2,
Line2toLine3,
Line3toLine1,
LineToNeutral,
Line1toNeutral,
Line2toNeutral,
Line3toNeutral,
Line1toNeutralAndL1l2,
Line2toNeutralAndL1l2,
Line2toNeutralAndL2l3,
Line3toNeutralAndL3l1,
Total,
UnsupportedValue,
}Variants
Line1
The circuits that share the L1 current-carrying conductor.
This value shall represent a circuit that shares the L1 current-carrying conductor, such as circuits with phase wiring types of Two-phase / 3-Wire or 4-Wire, or Three-phase / 4-Wire or 5-Wire.
Line2
The circuits that share the L2 current-carrying conductor.
This value shall represent a circuit that shares the L2 current-carrying conductor, such as circuits with phase wiring types of Two-phase / 4-Wire or Three-phase / 4-Wire or 5-Wire.
Line3
The circuits that share the L3 current-carrying conductor.
This value shall represent a circuit that shares the L3 current-carrying conductor, such as circuits with phase wiring types of Three-phase / 4-Wire or 5-Wire.
Neutral
The grounded current-carrying return circuit of current-carrying conductors.
This value shall represent the grounded current-carrying return circuit of current-carrying conductors, such as circuits with phase wiring types of Single-phase / 3-Wire, Two-phase / 4-Wire, or Three-phase / 5-Wire.
LineToLine
The circuit formed by two current-carrying conductors.
This value shall represent a circuit formed by two current-carrying conductors, such as circuits with phase wiring types of Two-phase / 3-Wire or 4-Wire, or Three-phase / 4-Wire or 5-Wire.
Line1toLine2
The circuit formed by L1 and L2 current-carrying conductors.
This value shall represent a circuit formed by L1 and L2 current-carrying conductors, such as circuits with phase wiring types of Two-phase / 3-Wire or 4-Wire, or Three-phase / 4-Wire or 5-Wire.
Line2toLine3
The circuit formed by L2 and L3 current-carrying conductors.
This value shall represent a circuit formed by L2 and L3 current-carrying conductors, such as circuits with phase wiring types of Three-phase / 4-Wire or 5-Wire.
Line3toLine1
The circuit formed by L3 and L1 current-carrying conductors.
This value shall represent a circuit formed by L3 and L1 current-carrying conductors, such as circuits with phase wiring types of Three-phase / 4-Wire or 5-Wire.
LineToNeutral
The circuit formed by a line and neutral current-carrying conductor.
This value shall represent a circuit formed by a line and neutral current-carrying conductor, such as circuits with phase wiring types of Single-phase / 3-Wire, Two-phase / 4-Wire, or Three-phase / 4-Wire or 5-Wire.
Line1toNeutral
The circuit formed by L1 and neutral current-carrying conductors.
This value shall represent a circuit formed by L1 and neutral current-carrying conductors, such as circuits with phase wiring types of Single-phase / 3-Wire, Two-phase / 3-Wire or 4-Wire, or Three-phase / 4-Wire or 5-Wire.
Line2toNeutral
The circuit formed by L2 and neutral current-carrying conductors.
This value shall represent a circuit formed by L2 and neutral current-carrying conductors, such as circuits with phase wiring types of Two-phase / 4-Wire or Three-phase / 5-Wire.
Line3toNeutral
The circuit formed by L3 and neutral current-carrying conductors.
This value shall represent a circuit formed by L3 and neutral current-carrying conductors, such as circuits with a phase wiring type of Three-phase / 5-Wire.
Line1toNeutralAndL1l2
The circuit formed by L1, L2, and neutral current-carrying conductors.
This value shall represent a circuit formed by L1, L2, and neutral current-carrying conductors, such as circuits with phase wiring types of Two-phase/ 4-Wire or Three-phase / 5-Wire.
Line2toNeutralAndL1l2
The circuit formed by L1, L2, and Neutral current-carrying conductors.
This value shall represent a circuit formed by L1, L2, and neutral current-carrying conductors, such as circuits with phase wiring types of Two-phase/ 4-Wire or Three-phase / 5-Wire.
Line2toNeutralAndL2l3
The circuits formed by L2, L3, and neutral current-carrying conductors.
This value shall represent a circuit formed by L2, L3, and neutral current-carrying conductors, such as circuits with a phase wiring type of Three-phase / 5-Wire.
Line3toNeutralAndL3l1
The circuit formed by L3, L1, and neutral current-carrying conductors.
This value shall represent a circuit formed by L3, L1, and neutral current-carrying conductors, such as circuits with a phase wiring type of Three-phase / 5-Wire.
Total
The circuit formed by all current-carrying conductors.
This value shall represent the circuits formed by all current-carrying conductors for any phase wiring type.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.