pub enum ImplementationType {
PhysicalSensor,
Synthesized,
Reported,
UnsupportedValue,
}Variants
PhysicalSensor
The reading is acquired from a physical sensor.
Synthesized
The reading is obtained by applying a calculation on one or more properties or multiple sensors. The calculation is not provided.
Reported
The reading is obtained from software or a device.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.