pub enum ReadingBasisType {
Zero,
Delta,
Headroom,
UnsupportedValue,
}Variants
Zero
A zero-based reading.
This value shall indicate a reading with zero as its reference point.
Delta
A reading that reports the difference between two measurements.
This value shall indicate a reading that reports the difference between two measurements.
Headroom
A reading that decreases as it approaches a defined reference point.
This value shall indicate a reading that decreases in value as it approaches the reference point. If the value crosses the reference point, the value may be reported as a negative number or may report a value of zero.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.