ReadingType

Enum ReadingType 

pub enum ReadingType {
Show 32 variants Temperature, Humidity, Power, EnergykWh, EnergyJoules, EnergyWh, ChargeAh, Voltage, Current, Frequency, Pressure, PressurekPa, PressurePa, LiquidLevel, Rotational, AirFlow, AirFlowCmm, LiquidFlow, LiquidFlowLpm, Barometric, Altitude, Percent, AbsoluteHumidity, Heat, LinearPosition, LinearVelocity, LinearAcceleration, RotationalPosition, RotationalVelocity, RotationalAcceleration, Valve, UnsupportedValue,
}

Variants



Temperature

Temperature (C).

This value shall indicate a temperature measurement, in degree Celsius units. The ReadingUnits property shall contain Cel.



Humidity

Relative humidity (percent).

This value shall indicate a relative humidity measurement, in percent units. The ReadingUnits property shall contain %.



Power

Power (W).

This value shall indicate the arithmetic mean of product terms of instantaneous voltage and current values measured over integer number of line cycles for a circuit, in watt units. The ReadingUnits property shall contain W.



EnergykWh

Energy (kWh).

This value shall indicate the energy, integral of real power over time, of the monitored item. If representing metered power consumption the value shall reflect the power consumption since the sensor metrics were last reset. The value of the Reading property shall be in kilowatt-hour units and the ReadingUnits property shall contain kW.h. This value is used for large-scale energy consumption measurements, while EnergyJoules and EnergyWh are used for device-level consumption measurements.



EnergyJoules

Energy (J).

This value shall indicate the energy, integral of real power over time, of the monitored item. If representing metered power consumption the value shall reflect the power consumption since the sensor metrics were last reset. The value of the Reading property shall be in joule units and the ReadingUnits property shall contain J. This value is used for device-level energy consumption measurements, while EnergykWh is used for large-scale consumption measurements.



EnergyWh

Energy (Wh).

This value shall indicate the energy, integral of real power over time, of the monitored item. If representing metered power consumption the value shall reflect the power consumption since the sensor metrics were last reset. The value of the Reading property shall be in watt-hour units and the ReadingUnits property shall contain W.h. This value is used for device-level energy consumption measurements, while EnergykWh is used for large-scale consumption measurements.



ChargeAh

Charge (Ah).

This value shall indicate the amount of charge, integral of current over time, of the monitored item. If representing metered charge consumption the value shall reflect the charge consumption since the sensor metrics were last reset. The value of the Reading property shall be in ampere-hour units and the ReadingUnits property shall contain A.h.



Voltage

Voltage (VAC or VDC).

This value shall indicate a measurement of the root mean square (RMS) of instantaneous voltage calculated over an integer number of line cycles for a circuit. Voltage is expressed in volt units and the ReadingUnits property shall contain V.



Current

Current (A).

This value shall indicate a measurement of the root mean square (RMS) of instantaneous current calculated over an integer number of line cycles for a circuit. Current is expressed in ampere units and the ReadingUnits property shall contain A.



Frequency

Frequency (Hz).

This value shall indicate a frequency measurement, in hertz units. The ReadingUnits property shall contain Hz.



Pressure

Pressure (Pa).

This value shall indicate a measurement of force, in pascal units, applied perpendicular to the surface of an object per unit area over which that force is distributed. The ReadingUnits property shall contain Pa.



PressurekPa

Pressure (kPa).

This value shall indicate a measurement of pressure, in kilopascal units, relative to atmospheric pressure. The ReadingUnits property shall contain kPa.



PressurePa

Pressure (Pa).

This value shall indicate a measurement of pressure, in pascal units, relative to atmospheric pressure. The ReadingUnits property shall contain Pa.



LiquidLevel

Liquid level (cm).

This value shall indicate a measurement of fluid height, in centimeter units, relative to a specified vertical datum and the ReadingUnits property shall contain cm.



Rotational

Rotational (RPM).

This value shall indicate a measurement of rotational frequency, in revolutions per minute units. The ReadingUnits property shall contain either {rev}/min, which is preferred, or RPM, which is a deprecated value. Services should represent fan speed and pump speed sensors with the ReadingType value Percent.



AirFlow

Air flow (cu ft/min).

This value shall indicate a measurement of a volume of gas per unit of time, in cubic feet per minute units, that flows through a particular junction. The ReadingUnits property shall contain [ft_i]3/min.



AirFlowCmm

Air flow (m^3/min).

This value shall indicate a measurement of a volume of gas per unit of time, in cubic meters per minute units, that flows through a particular junction. The ReadingUnits property shall contain m3/min.



LiquidFlow

Liquid flow (L/s).

This value shall indicate a measurement of a volume of liquid per unit of time, in liters per second units, that flows through a particular junction. The ReadingUnits property shall contain L/s.



LiquidFlowLpm

Liquid flow (L/min).

This value shall indicate a measurement of a volume of liquid per unit of time, in liters per minute units, that flows through a particular junction. The ReadingUnits property shall contain L/min.



Barometric

Barometric pressure (mm).

This value shall indicate a measurement of barometric pressure, in millimeters of a mercury column. The ReadingUnits property shall contain mm[Hg].



Altitude

Altitude (m).

This value shall indicate a measurement of altitude, in meter units, defined as the elevation above sea level. The ReadingUnits property shall contain m.



Percent

Percent (%).

This value shall indicate a percentage measurement, in percent units. The Reading value, while typically 0 to 100, may exceed 100 for rate-of-change or similar readings. The ReadingUnits property shall contain %.



AbsoluteHumidity

Absolute humidity (g/m^3).

This value shall indicate an absolute (volumetric) humidity measurement, in grams per cubic meter units. The ReadingUnits property shall contain g/m3.



Heat

Heat (kW).

This value shall indicate a heat measurement, in kilowatt units. The ReadingUnits property shall contain kW.



LinearPosition

Linear position or distance (m).

This value shall indicate a linear position or distance, in meter units. The ReadingUnits property shall contain m.



LinearVelocity

Linear velocity (m/s).

This value shall indicate a linear velocity, in meters per second units. The ReadingUnits property shall contain m/s.



LinearAcceleration

Linear acceleration (m/s^2).

This value shall indicate a linear acceleration, in meters per square second units. The ReadingUnits property shall contain m/s2.



RotationalPosition

Rotational position (rad).

This value shall indicate a rotational position, in radian units. The ReadingUnits property shall contain rad.



RotationalVelocity

Rotational velocity (rad/s).

This value shall indicate a rotational velocity, in radians per second units. The ReadingUnits property shall contain rad/s.



RotationalAcceleration

Rotational acceleration (rad/s^2).

This value shall indicate a rotational acceleration, in radians per square second units. The ReadingUnits property shall contain rad/s2.



Valve

Valve (% open).

This value shall indicate a valve position, in percent units. The ReadingUnits property shall contain %. A value of 100 shall indicate the valve is completely open, and a value of 0 shall indicate the valve is completely closed.



UnsupportedValue

Fallback value for values that are not supported by current version of Redfish schema.