pub enum ThresholdActivation {
Increasing,
Decreasing,
Either,
Disabled,
UnsupportedValue,
}Variants
Increasing
Value increases above the threshold.
This threshold is activated when the reading changes from a value lower than the threshold to a value higher than the threshold.
Decreasing
Value decreases below the threshold.
This threshold is activated when the reading changes from a value higher than the threshold to a value lower than the threshold.
Either
Value crosses the threshold in either direction.
This threshold is activated when either the increasing or decreasing conditions are met.
Disabled
The threshold is disabled.
This value shall indicate the threshold is disabled and no actions shall be taken as a result of the reading crossing the threshold value.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.