pub struct Links {
pub base: Links,
pub associated_controls: Option<Vec<NavProperty<Control>>>,
}Fields
base: LinksBase type
associated_controls: Option<Vec<NavProperty<Control>>>An array of links to the controls that can affect this sensor.
This property shall contain an array of links to resources of type Control that represent the
controls that can affect this sensor.