pub struct SensorExcerptCurrent {
pub data_source_uri: Option<Option<String>>,
pub reading: Option<Option<Decimal>>,
pub crest_factor: Option<Option<Decimal>>,
pub thd_percent: Option<Option<Decimal>>,
}Fields
data_source_uri: Option<Option<String>>The link to the resource that provides the data for this sensor.
This property shall contain a URI to the resource that provides the source of the excerpt contained within this copy.
reading: Option<Option<Decimal>>The sensor value.
This property shall contain the sensor value. This property shall not be returned if the Enabled
property is supported and contains false.
crest_factor: Option<Option<Decimal>>The crest factor for this sensor.
This property shall contain the ratio of the peak measurement divided by the RMS measurement and calculated over same N line cycles. A sine wave would have a value of 1.414.
thd_percent: Option<Option<Decimal>>The total harmonic distortion percent (% THD).
This property shall contain the total harmonic distortion of the Reading property in percent
units, typically 0 to 100.