SensorExcerptEnergykWh

Struct SensorExcerptEnergykWh 

pub struct SensorExcerptEnergykWh {
    pub data_source_uri: Option<Option<String>>,
    pub reading: Option<Option<Decimal>>,
    pub sensor_reset_time: Option<Option<DateTimeOffset>>,
    pub lifetime_reading: Option<Option<Decimal>>,
    pub apparentk_vah: Option<Option<Decimal>>,
    pub reactivek_varh: Option<Option<Decimal>>,
}

Fields

data_source_uri: Option<Option<String>>

The link to the resource that provides the data for this sensor.

This property shall contain a URI to the resource that provides the source of the excerpt contained within this copy.

reading: Option<Option<Decimal>>

The sensor value.

This property shall contain the sensor value. This property shall not be returned if the Enabled property is supported and contains false.

sensor_reset_time: Option<Option<DateTimeOffset>>

The date and time when the time-based properties were last reset.

This property shall contain the date and time when the ResetMetrics action was last performed or when the service last reset the time-based property values.

lifetime_reading: Option<Option<Decimal>>

The total accumulation value for this sensor.

This property shall contain the total accumulation of the Reading property over the sensor’s lifetime. This value shall not be reset by the ResetMetrics action.

apparentk_vah: Option<Option<Decimal>>

Apparent energy (kVAh).

This property shall contain the apparent energy, in kilovolt-ampere-hour units, for an electrical energy measurement. This property can appear in sensors with a ReadingType containing EnergykWh, and shall not appear in sensors with other ReadingType values.

reactivek_varh: Option<Option<Decimal>>

Reactive energy (kVARh).

This property shall contain the reactive energy, in kilovolt-ampere-hours (reactive) units, for an electrical energy measurement. This property can appear in sensors with a ReadingType containing EnergykWh, and shall not appear in sensors with other ReadingType values.