pub struct SensorExcerptFan {
pub data_source_uri: Option<Option<String>>,
pub reading: Option<Option<Decimal>>,
pub speed_rpm: Option<Option<Decimal>>,
}Fields
data_source_uri: Option<Option<String>>The link to the resource that provides the data for this sensor.
This property shall contain a URI to the resource that provides the source of the excerpt contained within this copy.
reading: Option<Option<Decimal>>The sensor value.
This property shall contain the sensor value. This property shall not be returned if the Enabled
property is supported and contains false.
speed_rpm: Option<Option<Decimal>>The rotational speed.
This property shall contain a reading of the rotational speed of the device in revolutions per minute (RPM) units.