pub struct SensorExcerptFanArray {
pub data_source_uri: Option<Option<String>>,
pub reading: Option<Option<Decimal>>,
pub physical_context: Option<Option<PhysicalContext>>,
pub physical_sub_context: Option<Option<PhysicalSubContext>>,
pub speed_rpm: Option<Option<Decimal>>,
pub device_name: Option<Option<String>>,
}Fields
data_source_uri: Option<Option<String>>The link to the resource that provides the data for this sensor.
This property shall contain a URI to the resource that provides the source of the excerpt contained within this copy.
reading: Option<Option<Decimal>>The sensor value.
This property shall contain the sensor value. This property shall not be returned if the Enabled
property is supported and contains false.
physical_context: Option<Option<PhysicalContext>>The area or device to which this sensor measurement applies.
This property shall contain a description of the affected component or region within the equipment to which this sensor measurement applies.
physical_sub_context: Option<Option<PhysicalSubContext>>The usage or location within a device to which this sensor measurement applies.
This property shall contain a description of the usage or sub-region within the equipment to which
this sensor measurement applies. This property generally differentiates multiple sensors within
the same PhysicalContext instance.
speed_rpm: Option<Option<Decimal>>The rotational speed.
This property shall contain a reading of the rotational speed of the device in revolutions per minute (RPM) units.
device_name: Option<Option<String>>The name of the device.
This property shall contain the name of the device associated with this sensor. If the device is
represented by a resource, the value shall contain the value of the Name property of the
associated resource.