SensorExcerptPower

Struct SensorExcerptPower 

pub struct SensorExcerptPower {
    pub data_source_uri: Option<Option<String>>,
    pub reading: Option<Option<Decimal>>,
    pub apparent_va: Option<Option<Decimal>>,
    pub reactive_var: Option<Option<Decimal>>,
    pub power_factor: Option<Option<Decimal>>,
    pub phase_angle_degrees: Option<Option<Decimal>>,
}

Fields

data_source_uri: Option<Option<String>>

The link to the resource that provides the data for this sensor.

This property shall contain a URI to the resource that provides the source of the excerpt contained within this copy.

reading: Option<Option<Decimal>>

The sensor value.

This property shall contain the sensor value. This property shall not be returned if the Enabled property is supported and contains false.

apparent_va: Option<Option<Decimal>>

The product of voltage and current for an AC circuit, in volt-ampere units.

This property shall contain the product of voltage (RMS) multiplied by current (RMS) for a circuit. This property can appear in sensors of the Power ReadingType, and shall not appear in sensors of other ReadingType values.

reactive_var: Option<Option<Decimal>>

The square root of the difference term of squared apparent VA and squared power (Reading) for a circuit, in VAR units.

This property shall contain the arithmetic mean of product terms of instantaneous voltage and quadrature current measurements calculated over an integer number of line cycles for a circuit. This property can appear in sensors of the Power ReadingType, and shall not appear in sensors of other ReadingType values.

power_factor: Option<Option<Decimal>>

The power factor for this sensor.

This property shall identify the quotient of real power (W) and apparent power (VA) for a circuit. PowerFactor is expressed in unit-less 1/100ths. This property can appear in sensors containing a ReadingType value of Power, and shall not appear in sensors of other ReadingType values.

phase_angle_degrees: Option<Option<Decimal>>

The phase angle (degrees) between the current and voltage waveforms.

This property shall contain the phase angle, in degree units, between the current and voltage waveforms for an electrical measurement. This property can appear in sensors with a ReadingType containing Power, and shall not appear in sensors with other ReadingType values.