Threshold

Struct Threshold 

pub struct Threshold {
    pub reading: Option<Option<Decimal>>,
    pub activation: Option<Option<ThresholdActivation>>,
    pub dwell_time: Option<Option<Duration>>,
    pub hysteresis_reading: Option<Option<Decimal>>,
    pub hysteresis_duration: Option<Option<Duration>>,
}

Fields

reading: Option<Option<Decimal>>

The threshold value.

This property shall indicate the reading for this sensor that activates the threshold. The value of the property shall use the same units as the Reading property.

activation: Option<Option<ThresholdActivation>>

The direction of crossing that activates this threshold.

This property shall indicate the direction of crossing of the reading for this sensor that activates the threshold.

dwell_time: Option<Option<Duration>>

The duration the sensor value must violate the threshold before the threshold is activated.

This property shall indicate the duration the sensor value violates the threshold before the threshold is activated.

hysteresis_reading: Option<Option<Decimal>>

The reading offset from the threshold value required to clear the threshold.

This property shall indicate the offset from the reading for this sensor and the threshold value that deactivates the threshold. For example, a value of -2 indicates the sensor reading shall fall 2 units below an upper threshold value to deactivate the threshold. The value of the property shall use the same units as the Reading property. A value of 0, or if the property is not present in the resource, shall indicate the threshold is deactivated when the sensor value no longer violates the threshold. The threshold shall not deactivate until the conditions of both HysteresisReading and HysteresisDuration are met.

hysteresis_duration: Option<Option<Duration>>

The duration the sensor value must not violate the threshold before the threshold is deactivated.

This property shall indicate the duration the sensor value no longer violates the threshold before the threshold is deactivated. A duration of zero seconds, or if the property is not present in the resource, shall indicate the threshold is deactivated immediately once the sensor value no longer violates the threshold. The threshold shall not deactivate until the conditions of both HysteresisReading and HysteresisDuration are met.