pub struct SensorCollection {
pub base: ResourceCollection,
pub members: Vec<NavProperty<Sensor>>,
}Expand description
The collection of Sensor resource instances.
This resource shall represent a resource collection of Sensor instances for a Redfish
implementation.
Fields
base: ResourceCollectionBase type
members: Vec<NavProperty<Sensor>>The members of this collection.
This property shall contain an array of links to the members of this collection.