pub struct SessionCollection {
pub base: ResourceCollection,
pub members: Vec<NavProperty<Session>>,
}Expand description
The collection of Session resource instances.
This resource shall represent a resource collection of Session instances for a Redfish
implementation.
Fields
base: ResourceCollectionBase type
members: Vec<NavProperty<Session>>The members of this collection.
This property shall contain an array of links to the members of this collection.