pub enum ApplyTime {
Immediate,
OnReset,
AtMaintenanceWindowStart,
InMaintenanceWindowOnReset,
UnsupportedValue,
}Variants
Immediate
Apply immediately. This value might result in an immediate host reset, manager reset, or other side effects.
This value shall indicate the values within the settings resource are applied immediately. This value may result in an immediate host reset, manager reset, or other side effects.
OnReset
Apply on a reset.
This value shall indicate the values within settings resource are applied when the system or service is reset.
AtMaintenanceWindowStart
Apply during a maintenance window as specified by an administrator.
This value shall indicate the values within the settings resource are applied during the
maintenance window specified by the MaintenanceWindowStartTime and
MaintenanceWindowDurationInSeconds properties. A service can perform resets during this
maintenance window.
InMaintenanceWindowOnReset
Apply after a reset but within maintenance window as specified by an administrator.
This value shall indicate the values within the settings resource are applied during the
maintenance window specified by the MaintenanceWindowStartTime and
MaintenanceWindowDurationInSeconds properties, and if a reset occurs within the maintenance
window.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.