PreferredApplyTime

Struct PreferredApplyTime 

pub struct PreferredApplyTime {
    pub apply_time: Option<ApplyTime>,
    pub maintenance_window_start_time: Option<DateTimeOffset>,
    pub maintenance_window_duration_in_seconds: Option<Int64>,
}
The preferred time to apply configuration settings.

This type shall be specified by client to indicate the preferred time to apply the configuration settings.

Fields

apply_time: Option<ApplyTime>

The time when to apply the settings.

This property shall indicate when to apply the values in this settings resource.

maintenance_window_start_time: Option<DateTimeOffset>

The start time of a maintenance window.

This property shall indicate the date and time when the service can start to apply the future configuration as part of a maintenance window. Services shall provide a default value if not configured by a user. This property shall be required if the ApplyTime property is AtMaintenanceWindowStart or InMaintenanceWindowOnReset.

maintenance_window_duration_in_seconds: Option<Int64>

The expiry time of maintenance window in seconds.

This property shall indicate the end of the maintenance window as the number of seconds after the time specified by the MaintenanceWindowStartTime property. This property shall be required if the ApplyTime property is AtMaintenanceWindowStart or InMaintenanceWindowOnReset.