Settings

Struct Settings 

pub struct Settings {
    pub time: Option<Option<DateTimeOffset>>,
    pub etag: Option<Option<String>>,
    pub messages: Option<Vec<Message>>,
    pub supported_apply_times: Option<Vec<ApplyTime>>,
    pub settings_object: Option<ReferenceLeaf>,
    pub maintenance_window_resource: Option<ReferenceLeaf>,
}

Fields

time: Option<Option<DateTimeOffset>>

The time when the settings were applied.

This property shall indicate the time when the settings were applied to the resource.

etag: Option<Option<String>>

The entity tag (ETag) of the resource to which the settings were applied, after the application.

This property shall contain the entity tag (ETag) of the resource to which the settings were applied, after the application. The client can check this value against the ETag of this resource to determine whether the resource had other changes.

messages: Option<Vec<Message>>

An array of messages associated with the settings.

This property shall contain an array of messages associated with the settings.

supported_apply_times: Option<Vec<ApplyTime>>

The time when the settings can be applied.

This property shall contain the supported apply time values a client is allowed to request when configuring the settings apply time. Services that do not support clients configuring the apply time can support this property with a single array member in order to inform the client when the settings will be applied.

settings_object: Option<ReferenceLeaf>maintenance_window_resource: Option<ReferenceLeaf>