pub struct Actions {
pub oem: Option<OemActions>,
pub activate: Option<Action<SoftwareInventoryActivateAction, ()>>,
}Expand description
The available actions for this resource.
This type shall contain the available actions for this resource.
Fields
oem: Option<OemActions>The available OEM-specific actions for this resource.
This property shall contain the available OEM-specific actions for this resource.
activate: Option<Action<SoftwareInventoryActivateAction, ()>>Implementations
Sourceimpl Actions
impl Actions
Sourcepub async fn activate<B: Bmc>(
&self,
bmc: &B,
targets: Option<Vec<Reference>>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn activate<B: Bmc>(
&self,
bmc: &B,
targets: Option<Vec<Reference>>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
This action activates this software inventory instance.
This action shall activate this software inventory instance.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.