AdditionalVersions

Struct AdditionalVersions 

pub struct AdditionalVersions {
    pub bootloader: Option<Option<String>>,
    pub microcode: Option<Option<String>>,
    pub kernel: Option<Option<String>>,
    pub oem: Option<Oem>,
    pub os_distribution: Option<Option<String>>,
    pub factory_configuration: Option<Option<String>>,
    pub boot_parameters: Option<Option<String>>,
}

Fields

bootloader: Option<Option<String>>

The bootloader version contained in this software, such as U-Boot or UEFI.

This property shall contain the bootloader version contained in this software.

microcode: Option<Option<String>>

The microcode version contained in this software, such as processor microcode.

This property shall contain the microcode version contained in this software.

kernel: Option<Option<String>>

The kernel version contained in this software.

This property shall contain the kernel version contained in this software. For strict POSIX software, the value shall contain the output of uname -srm. For Microsoft Windows, the value shall contain the output of ver, from Command Prompt.

oem: Option<Oem>

The OEM extension property.

This property shall contain the OEM extensions. All values for properties contained in this object shall conform to the Redfish Specification-described requirements.

os_distribution: Option<Option<String>>

The operating system name of this software.

This property shall contain the operating system name of this software.

factory_configuration: Option<Option<String>>

The version of the configuration that contains the factory default runtime configuration parameters of this software.

This property shall contain the version of the configuration that contains the factory default runtime configuration parameters of this software.

boot_parameters: Option<Option<String>>

The version of the configuration file that contains the initial boot parameters of this software, such as parameters for U-Boot.

This property shall contain the version of the configuration file that contains the initial boot parameters of this software.