Links

Struct Links 

pub struct Links {
    pub staged_targets: Option<Vec<ReferenceLeaf>>,
    pub active_targets: Option<Vec<ReferenceLeaf>>,
}
The links to other resources that are related to this resource.

This property shall contain links to resources that are related to but are not contained by, or subordinate to, this resource.

Fields

staged_targets: Option<Vec<ReferenceLeaf>>active_targets: Option<Vec<ReferenceLeaf>>