pub struct SoftwareInventoryCollection {
pub base: ResourceCollection,
pub members: Vec<NavProperty<SoftwareInventory>>,
}Expand description
The collection of SoftwareInventory resource instances.
This resource shall represent a resource collection of SoftwareInventory instances for a Redfish
implementation.
Fields
base: ResourceCollectionBase type
members: Vec<NavProperty<SoftwareInventory>>The members of this collection.
This property shall contain an array of links to the members of this collection.