pub enum ConfigurationLock {
Enabled,
Disabled,
Partial,
UnsupportedValue,
}Variants
Enabled
In-band configuration requests are locked as specified by TargetConfigurationLockLevel.
This value shall indicate in-band configuration requests are locked as specified by
TargetConfigurationLockLevel.
Disabled
In-band configuration requests are not locked.
This value shall indicate in-band configuration requests are not locked.
Partial
Some in-band configuration requests are not locked while others are locked. This value is used for status reporting to indicate that the storage subsystem is partially locked and client action is recommended.
This value shall indicate some in-band configuration requests are not locked while others are locked.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.