pub enum EncryptionMode {
Disabled,
UseExternalKey,
UseLocalKey,
PasswordOnly,
PasswordWithExternalKey,
PasswordWithLocalKey,
UnsupportedValue,
}Variants
Disabled
Encryption is disabled on the storage subsystem.
UseExternalKey
The storage subsystem uses one or more external keys for encryption.
UseLocalKey
The storage subsystem uses a local key for encryption.
PasswordOnly
The storage subsystem uses a password, but no keys for encryption.
PasswordWithExternalKey
The storage subsystem uses a password and one or more external keys for encryption.
PasswordWithLocalKey
The storage subsystem uses a password and a local key for encryption.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.