pub enum VolumeAssignmentPolicy {
Unassigned,
Supervisor,
WeightedRoundRobin,
UnsupportedValue,
}Variants
Unassigned
Newly created volumes are not assigned to physical functions, but are added to UnassignedVolumes in the Links property within this resource.
Supervisor
Newly created volumes are assigned to the supervisor function.
WeightedRoundRobin
Newly created volumes are assigned to the physical functions in a round-robin fashion.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.