Actions

Struct Actions 

pub struct Actions {
    pub oem: Option<OemActions>,
    pub freeze_personality: Option<Action<StorageFreezePersonalityAction, ()>>,
    pub get_personality_nonce: Option<Action<StorageGetPersonalityNonceAction, GetPersonalityNonceResponse>>,
    pub import_foreign_drives: Option<Action<StorageImportForeignDrivesAction, ()>>,
    pub rekey_external_key: Option<Action<StorageRekeyExternalKeyAction, ()>>,
    pub reset_to_defaults: Option<Action<StorageResetToDefaultsAction, ()>>,
    pub revert_personalities_to_defaults: Option<Action<StorageRevertPersonalitiesToDefaultsAction, ()>>,
    pub set_controller_password: Option<Action<StorageSetControllerPasswordAction, ()>>,
    pub set_encryption_key: Option<Action<StorageSetEncryptionKeyAction, ()>>,
    pub set_personality_key: Option<Action<StorageSetPersonalityKeyAction, ()>>,
    pub unfreeze_personality: Option<Action<StorageUnfreezePersonalityAction, ()>>,
}
The available actions for this resource.

This type shall contain the available actions for this resource.

Fields

oem: Option<OemActions>

The available OEM-specific actions for this resource.

This property shall contain the available OEM-specific actions for this resource.

freeze_personality: Option<Action<StorageFreezePersonalityAction, ()>>get_personality_nonce: Option<Action<StorageGetPersonalityNonceAction, GetPersonalityNonceResponse>>import_foreign_drives: Option<Action<StorageImportForeignDrivesAction, ()>>rekey_external_key: Option<Action<StorageRekeyExternalKeyAction, ()>>reset_to_defaults: Option<Action<StorageResetToDefaultsAction, ()>>revert_personalities_to_defaults: Option<Action<StorageRevertPersonalitiesToDefaultsAction, ()>>set_controller_password: Option<Action<StorageSetControllerPasswordAction, ()>>set_encryption_key: Option<Action<StorageSetEncryptionKeyAction, ()>>set_personality_key: Option<Action<StorageSetPersonalityKeyAction, ()>>unfreeze_personality: Option<Action<StorageUnfreezePersonalityAction, ()>>

Implementations

Source

impl Actions

pub async fn freeze_personality<B: Bmc>( &self, bmc: &B, personality: Option<Int64>, ) -> Result<ModificationResponse<()>, B::Error>
where B::Error: ActionError,

This action freezes a personality for the NVMe subsystem.

This action shall freeze a personality for the NVMe subsystem as defined by the ‘Configurable Device Personality’ feature in the NVMe Base Specification.

Errors
pub async fn get_personality_nonce<B: Bmc>( &self, bmc: &B, ) -> Result<ModificationResponse<GetPersonalityNonceResponse>, B::Error>
where B::Error: ActionError,

This action obtains a nonce required to unfreeze personalities with a programmed key.

This action shall obtain a nonce required to unfreeze personalities with a programmed key as defined by the ‘CDP Random Nonce Data’ clause in the NVMe Base Specification.

Errors
pub async fn import_foreign_drives<B: Bmc>( &self, bmc: &B, controller_password: Option<String>, drive_encryption_key: Option<String>, drive_encryption_key_identifier: Option<String>, ) -> Result<ModificationResponse<()>, B::Error>
where B::Error: ActionError,

This action imports encrypted foreign drives to a host-based storage controller by supplying encryption access credentials.

This action shall import encrypted foreign drives to a host-based storage controller by supplying encryption access credentials. Upon successful completion, the EncryptionStatus property of the affected Drive shall change from Foreign to Unlocked.

Errors
pub async fn rekey_external_key<B: Bmc>( &self, bmc: &B, ) -> Result<ModificationResponse<()>, B::Error>
where B::Error: ActionError,

This action causes the controllers of the storage subsystem to request new encryption keys managed by an external key service.

This action shall cause the controllers of the storage subsystem to request new encryption keys managed by an external key service.

Errors
pub async fn reset_to_defaults<B: Bmc>( &self, bmc: &B, reset_type: Option<ResetToDefaultsType>, ) -> Result<ModificationResponse<()>, B::Error>
where B::Error: ActionError,

The reset action resets the storage device to factory defaults. This can cause the loss of data.

This action shall reset the storage device. This action can impact other resources.

Errors
pub async fn revert_personalities_to_defaults<B: Bmc>( &self, bmc: &B, ) -> Result<ModificationResponse<()>, B::Error>
where B::Error: ActionError,

This action reverts all personalities to their manufacturing default state for the NVMe subsystem.

This action shall revert all personalities to their manufacturing default state for the NVMe subsystem as defined by the ‘Manufacturing Default Personality’ clause of the NVMe Base Specification.

Errors
pub async fn set_controller_password<B: Bmc>( &self, bmc: &B, current_password: Option<String>, new_password: Option<String>, security_key: Option<String>, ) -> Result<ModificationResponse<()>, B::Error>
where B::Error: ActionError,

This action sets the controller boot password for a host-based storage controller.

This action shall set the controller boot password for a host-based storage controller.

Errors
pub async fn set_encryption_key<B: Bmc>( &self, bmc: &B, encryption_key: Option<String>, encryption_key_identifier: Option<String>, current_encryption_key: Option<String>, ) -> Result<ModificationResponse<()>, B::Error>
where B::Error: ActionError,

This action sets the local encryption key for the storage subsystem.

This action shall set the local encryption key for the storage subsystem.

Errors
pub async fn set_personality_key<B: Bmc>( &self, bmc: &B, algorithm: Option<NmvePersonalityKeyAlgorithm>, key: Option<String>, ) -> Result<ModificationResponse<()>, B::Error>
where B::Error: ActionError,

This action sets the personality key for the NVMe subsystem.

This action shall set the personality key for the NVMe subsystem as defined by the ‘Programmable Key Authentication Considerations’ clause in the NVMe Base Specification.

Errors
pub async fn unfreeze_personality<B: Bmc>( &self, bmc: &B, t: &StorageUnfreezePersonalityAction, ) -> Result<ModificationResponse<()>, B::Error>
where B::Error: ActionError,

This action unfreezes a personality for the NVMe subsystem.

This action shall unfreeze a personality for the NVMe subsystem as defined by the ‘Authenticated Unfreeze Operation’ clause in the NVMe Base Specification.

Errors