pub struct GetPersonalityNonceResponse {
pub nonce: String,
}Expand description
The personality nonce from a drive.
This object shall contain the personality nonce from a drive.
Fields
nonce: StringThe personality nonce.
This property shall contain the personality nonce as a hex-encoded string as defined by the ‘CDP Random Nonce Data’ clause of the NVMe Base Specification.