Mpf

Struct Mpf 

pub struct Mpf {
    pub maximum_supported_physical_functions: Option<Option<Int64>>,
    pub configured_physical_functions: Option<Option<Int64>>,
    pub volume_assignment_policy: Option<Option<VolumeAssignmentPolicy>>,
}
Multiple physical function-related properties for storage controllers in a storage subsystem.

This type shall contain multiple physical function-related properties for storage controllers in a storage subsystem.

Fields

maximum_supported_physical_functions: Option<Option<Int64>>

The maximum number of physical functions supported by the storage controller in this storage subsystem.

This property shall contain the maximum number of physical functions supported by the storage controller in this storage subsystem.

configured_physical_functions: Option<Option<Int64>>

The current number of physical functions configured for the storage controller in this storage subsystem.

This property shall contain the current number of physical functions configured for the storage controller in this storage subsystem.

volume_assignment_policy: Option<Option<VolumeAssignmentPolicy>>

The current volume assignment policy configured for the storage controller in this storage subsystem.

This property shall contain the current volume assignment policy configured for the storage controller in this storage subsystem.