pub struct StorageGetPersonalityNonceAction {}Expand description
This action obtains a nonce required to unfreeze personalities with a programmed key.
This action shall obtain a nonce required to unfreeze personalities with a programmed key as defined by the ‘CDP Random Nonce Data’ clause in the NVMe Base Specification.