StorageImportForeignDrivesAction

Struct StorageImportForeignDrivesAction 

pub struct StorageImportForeignDrivesAction {
    pub controller_password: Option<String>,
    pub drive_encryption_key: Option<String>,
    pub drive_encryption_key_identifier: Option<String>,
}
This action imports encrypted foreign drives to a host-based storage controller by supplying encryption access credentials.

This action shall import encrypted foreign drives to a host-based storage controller by supplying encryption access credentials. Upon successful completion, the EncryptionStatus property of the affected Drive shall change from Foreign to Unlocked.

Fields

controller_password: Option<String>

The current controller password. This parameter is not required if the controller does not currently have a password.

This parameter shall contain the current controller password. Services may reject the action request if this parameter is not provided or the value supplied does not match the current password.

drive_encryption_key: Option<String>

The encryption key to unlock the drives.

This parameter shall contain the encryption key to unlock the drives.

drive_encryption_key_identifier: Option<String>

An encryption key identifier to filter the drives that are imported. If not provided, the controller attempts to import all foreign drives.

This parameter shall contain an encryption key identifier to filter the drives that are imported. If this parameter is not provided, the service shall not perform filtering of foreign drives.