StorageRekeyExternalKeyAction

Struct StorageRekeyExternalKeyAction 

pub struct StorageRekeyExternalKeyAction {}
This action causes the controllers of the storage subsystem to request new encryption keys managed by an external key service.

This action shall cause the controllers of the storage subsystem to request new encryption keys managed by an external key service.