StorageResetToDefaultsAction

Struct StorageResetToDefaultsAction 

pub struct StorageResetToDefaultsAction {
    pub reset_type: Option<ResetToDefaultsType>,
}
The reset action resets the storage device to factory defaults. This can cause the loss of data.

This action shall reset the storage device. This action can impact other resources.

Fields

reset_type: Option<ResetToDefaultsType>

The type of reset to defaults.

This parameter shall contain the type of reset to defaults.