StorageSetControllerPasswordAction

Struct StorageSetControllerPasswordAction 

pub struct StorageSetControllerPasswordAction {
    pub current_password: Option<String>,
    pub new_password: Option<String>,
    pub security_key: Option<String>,
}
This action sets the controller boot password for a host-based storage controller.

This action shall set the controller boot password for a host-based storage controller.

Fields

current_password: Option<String>

The current controller password. This parameter is not needed if the controller does not currently have a password.

This parameter shall contain the current controller password. Services may reject the action request if this parameter is not provided or the value supplied does not match the current password.

new_password: Option<String>

The new password to set for the controller.

This parameter shall contain the new password to set for the controller.

security_key: Option<String>

The security key for the controller. This parameter is not needed if the controller does not have a security key.

This parameter shall contain the controller security key. Services may reject the action request if this parameter is not provided or the value provided does not match the security key for the controller.