pub struct StorageCollection {
pub base: ResourceCollection,
pub members: Vec<NavProperty<Storage>>,
}Expand description
The collection of Storage resource instances.
This resource shall represent a resource collection of Storage instances for a Redfish
implementation.
Fields
base: ResourceCollectionBase type
members: Vec<NavProperty<Storage>>The members of this collection.
This property shall contain an array of links to the members of this collection.