pub enum AnaAccessState {
Optimized,
NonOptimized,
Inaccessible,
PersistentLoss,
UnsupportedValue,
}Variants
Optimized
Commands processed by a controller provide optimized access to any namespace in the ANA group.
NonOptimized
Commands processed by a controller that reports this state for an ANA group provide non-optimized access characteristics, such as lower performance or non-optimal use of subsystem resources, to any namespace in the ANA group.
Inaccessible
Namespaces in this group are inaccessible. Commands are not able to access user data of namespaces in the ANA group.
PersistentLoss
The group is persistently inaccessible. Commands are persistently not able to access user data of namespaces in the ANA group.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.