Actions

Struct Actions 

pub struct Actions {
    pub oem: Option<OemActions>,
    pub attach_namespaces: Option<Action<StorageControllerAttachNamespacesAction, AttachDetachNamespacesResponse>>,
    pub detach_namespaces: Option<Action<StorageControllerDetachNamespacesAction, AttachDetachNamespacesResponse>>,
    pub reset: Option<Action<StorageControllerResetAction, ()>>,
    pub security_receive: Option<Action<StorageControllerSecurityReceiveAction, SecurityReceiveResponse>>,
    pub security_send: Option<Action<StorageControllerSecuritySendAction, ()>>,
}
The available actions for this resource.

This type shall contain the available actions for this resource.

Fields

oem: Option<OemActions>

The available OEM-specific actions for this resource.

This property shall contain the available OEM-specific actions for this resource.

attach_namespaces: Option<Action<StorageControllerAttachNamespacesAction, AttachDetachNamespacesResponse>>detach_namespaces: Option<Action<StorageControllerDetachNamespacesAction, AttachDetachNamespacesResponse>>reset: Option<Action<StorageControllerResetAction, ()>>security_receive: Option<Action<StorageControllerSecurityReceiveAction, SecurityReceiveResponse>>security_send: Option<Action<StorageControllerSecuritySendAction, ()>>

Implementations

Source

impl Actions

pub async fn attach_namespaces<B: Bmc>( &self, bmc: &B, namespaces: Option<Vec<Reference>>, ) -> Result<ModificationResponse<AttachDetachNamespacesResponse>, B::Error>
where B::Error: ActionError,

This action attaches referenced namespaces or volumes to the storage controller. Attached namespaces and volumes are added to the AttachedVolumes property in Links. For NVMe, namespaces are modeled as Volume resources.

This action shall attach referenced namespaces or volumes to the storage controller. For NVMe, namespaces are modeled as Volume resources. Services shall add the attached namespaces and volumes to the AttachedVolumes property in Links.

Errors
pub async fn detach_namespaces<B: Bmc>( &self, bmc: &B, namespaces: Option<Vec<Reference>>, ) -> Result<ModificationResponse<AttachDetachNamespacesResponse>, B::Error>
where B::Error: ActionError,

This action detaches referenced namespaces or volumes from the storage controller. Detached namespaces and volumes are removed from the AttachedVolumes property in Links. For NVMe, namespaces are modeled as Volume resources.

This action shall detach referenced namespaces or volumes from the storage controller. Services shall remove the detached namespaces and volumes from the AttachedVolumes property in Links. For NVMe, namespaces are modeled as Volume resources.

Errors
pub async fn reset<B: Bmc>( &self, bmc: &B, reset_type: Option<ResetType>, ) -> Result<ModificationResponse<()>, B::Error>
where B::Error: ActionError,

This action resets this storage controller.

This action shall reset this storage controller.

Errors
pub async fn security_receive<B: Bmc>( &self, bmc: &B, security_protocol: Option<Int64>, security_protocol_specific: Option<Int64>, allocation_length: Option<Int64>, ) -> Result<ModificationResponse<SecurityReceiveResponse>, B::Error>
where B::Error: ActionError,

This action transfers security protocol data from the controller. The data transferred from the controller contains the status and data result of one or more SecuritySend action requests that were previously submitted to the controller.

This action shall transfer security protocol data from the controller. The contents of the request are specified by the ‘SECURITY PROTOCOL IN command’ section of the SPC-5 Specification.

Errors
pub async fn security_send<B: Bmc>( &self, bmc: &B, security_protocol: Option<Int64>, security_protocol_specific: Option<Int64>, data: Option<String>, ) -> Result<ModificationResponse<()>, B::Error>
where B::Error: ActionError,

This action transfers security protocol data to the controller. The data transferred to the controller contains security protocol-specific commands to be performed by the controller.

This action shall transfer security protocol data to the controller. The contents of the request are specified by the ‘SECURITY PROTOCOL OUT command’ section of the SPC-5 Specification.

Errors