pub struct AnaCharacteristics {
pub access_state: Option<Option<AnaAccessState>>,
pub volume: Option<NavProperty<Volume>>,
}Expand description
The ANA characteristics and volume information for a storage controller.
This type shall contain the ANA characteristics and volume information for a storage controller.
Fields
access_state: Option<Option<AnaAccessState>>Reported ANA access state.
This property shall contain the reported ANA access state.
volume: Option<NavProperty<Volume>>The specified volume.
This property shall contain a link to a resource of type Volume.