AttachDetachNamespacesResponse

Struct AttachDetachNamespacesResponse 

pub struct AttachDetachNamespacesResponse {
    pub attached_volumes: Vec<NavProperty<Volume>>,
}
The response body for the AttachNamespaces and DetachNamespaces actions.

This type shall contain the properties found in the response body for the AttachNamespaces and DetachNamespaces actions.

Fields

attached_volumes: Vec<NavProperty<Volume>>

An array of links to volumes that are attached to this controller instance.

This property shall contain an array of links to resources of type Volume that are attached to this instance of storage controller.