Links

Struct Links 

pub struct Links {
    pub base: Links,
    pub endpoints: Option<Vec<ReferenceLeaf>>,
    pub pcie_functions: Option<Vec<ReferenceLeaf>>,
    pub attached_volumes: Option<Vec<NavProperty<Volume>>>,
    pub network_device_functions: Option<Vec<NavProperty<NetworkDeviceFunction>>>,
    pub batteries: Option<Vec<ReferenceLeaf>>,
    pub nvme_discovered_subsystems: Option<Vec<NavProperty<Storage>>>,
}

Fields

base: Links

Base type

endpoints: Option<Vec<ReferenceLeaf>>pcie_functions: Option<Vec<ReferenceLeaf>>attached_volumes: Option<Vec<NavProperty<Volume>>>

An array of links to volumes that are attached to this controller instance.

This property shall contain an array of links to resources of type Volume that are attached to this instance of storage controller.

network_device_functions: Option<Vec<NavProperty<NetworkDeviceFunction>>>

The network device functions that provide connectivity to this controller.

This property shall contain an array of links to resources of type NetworkDeviceFunction that represent the devices that provide connectivity to this controller.

batteries: Option<Vec<ReferenceLeaf>>nvme_discovered_subsystems: Option<Vec<NavProperty<Storage>>>

The NVMe subsystems discovered by this discovery controller.

This property shall contain an array of links to resources of type Storage that represent the NVMe subsystems discovered by this discovery controller. This property shall only be present if ControllerType in NVMeControllerProperties contains Discovery.