MpfProperties

Struct MpfProperties 

pub struct MpfProperties {
    pub is_supervisor: Option<Option<Boolean>>,
}
The physical function-related properties for a storage controller within a multiple physical function storage controller.

This type shall contain the physical function-related properties for a storage controller within a multiple physical function storage controller.

Fields

is_supervisor: Option<Option<Boolean>>

Indicates whether this physical function is the supervisor, which manages the other physical functions, manages the configuration of the controller, and controls management access.

This property shall indicate whether this physical function is the supervisor, which manages the other physical functions, manages the configuration of the controller, and controls management access.