pub struct SecurityReceiveResponse {
pub data: Option<String>,
}Expand description
The security data transferred from a controller.
This object shall contain the security data transferred from a controller.
Fields
data: Option<String>The Base64-encoded security protocol data.
This property shall contain a Base64-encoded string, with padding characters, of the security protocol data transferred from a controller.