StorageControllerAttachNamespacesAction

Struct StorageControllerAttachNamespacesAction 

pub struct StorageControllerAttachNamespacesAction {
    pub namespaces: Option<Vec<Reference>>,
}
This action attaches referenced namespaces or volumes to the storage controller. Attached namespaces and volumes are added to the AttachedVolumes property in Links. For NVMe, namespaces are modeled as Volume resources.

This action shall attach referenced namespaces or volumes to the storage controller. For NVMe, namespaces are modeled as Volume resources. Services shall add the attached namespaces and volumes to the AttachedVolumes property in Links.

Fields

namespaces: Option<Vec<Reference>>

The namespaces or volumes to attach to the storage controller.

This parameter shall contain an array of links to resources of type Volume that represent the namespaces or volumes to attach to the storage controller.