StorageControllerSecurityReceiveAction

Struct StorageControllerSecurityReceiveAction 

pub struct StorageControllerSecurityReceiveAction {
    pub security_protocol: Option<Int64>,
    pub security_protocol_specific: Option<Int64>,
    pub allocation_length: Option<Int64>,
}
This action transfers security protocol data from the controller. The data transferred from the controller contains the status and data result of one or more SecuritySend action requests that were previously submitted to the controller.

This action shall transfer security protocol data from the controller. The contents of the request are specified by the ‘SECURITY PROTOCOL IN command’ section of the SPC-5 Specification.

Fields

security_protocol: Option<Int64>

The security protocol number.

This parameter shall contain the numeric identifier of the security protocol, as defined by the ‘SECURITY PROTOCOL field in SECURITY PROTOCOL IN command’ table of the SPC-5 Specification, and possibly extended by transport-specific standards. Services shall only accept the values 0, 1, or 2.

security_protocol_specific: Option<Int64>

The security protocol-specific parameter.

This parameter shall contain the security protocol-specific data for the transfer operation. The value is defined by the protocol specified by the SecurityProtocolSpecific parameter.

allocation_length: Option<Int64>

Allocated size for received data.

This parameter shall contain the allocated size of the received data, which imposes a maximum length of the data. The response may contain padding to meet this length.