StorageControllerSecuritySendAction

Struct StorageControllerSecuritySendAction 

pub struct StorageControllerSecuritySendAction {
    pub security_protocol: Option<Int64>,
    pub security_protocol_specific: Option<Int64>,
    pub data: Option<String>,
}
This action transfers security protocol data to the controller. The data transferred to the controller contains security protocol-specific commands to be performed by the controller.

This action shall transfer security protocol data to the controller. The contents of the request are specified by the ‘SECURITY PROTOCOL OUT command’ section of the SPC-5 Specification.

Fields

security_protocol: Option<Int64>

The security protocol number.

This parameter shall contain the numeric identifier of the security protocol, as defined by the ‘SECURITY PROTOCOL field in SECURITY PROTOCOL OUT command’ table of the SPC-5 Specification, and possibly extended by transport-specific standards. Services shall only accept the values 1 or 2.

security_protocol_specific: Option<Int64>

The security protocol-specific parameter.

This parameter shall contain the security protocol-specific data for the transfer operation. The value is defined by the protocol specified by the SecurityProtocolSpecific parameter.

data: Option<String>

The data to transfer.

This parameter shall contain a Base64-encoded string, with padding characters, of the security protocol data to transfer.