StorageControllerMetrics

Struct StorageControllerMetrics 

pub struct StorageControllerMetrics {
    pub base: Resource,
    pub correctable_ecc_error_count: Option<Option<Int64>>,
    pub uncorrectable_ecc_error_count: Option<Option<Int64>>,
    pub correctable_parity_error_count: Option<Option<Int64>>,
    pub uncorrectable_parity_error_count: Option<Option<Int64>>,
    pub state_change_count: Option<Option<Int64>>,
    pub nvme_smart: Option<NvmeSmartMetrics>,
    pub actions: Option<Actions>,
    pub lifetime_start_date_time: Option<Option<DateTimeOffset>>,
}
The usage and health statistics for a storage controller.

The StorageControllerMetrics schema shall contain the usage and health statistics for a storage controller in a Redfish implementation.

Fields

base: Resource

Base type

correctable_ecc_error_count: Option<Option<Int64>>

The number of correctable errors for the lifetime of the memory of the storage controller.

This property shall contain the number of correctable errors for the lifetime of memory of the storage controller.

uncorrectable_ecc_error_count: Option<Option<Int64>>

The number of uncorrectable errors for the lifetime of the memory of the storage controller.

This property shall contain the number of uncorrectable errors for the lifetime of memory of the storage controller.

correctable_parity_error_count: Option<Option<Int64>>

The number of correctable parity errors for the lifetime of the memory of the storage controller.

This property shall contain the number of correctable errors for the lifetime of memory of the storage controller.

uncorrectable_parity_error_count: Option<Option<Int64>>

The number of uncorrectable parity errors for the lifetime of the memory of the storage controller.

This property shall contain the number of uncorrectable errors for the lifetime of memory of the storage controller.

state_change_count: Option<Option<Int64>>

The number of state changes for this storage controller.

This property shall contain the number of times the State property within the Status property of the parent StorageController resource changed.

nvme_smart: Option<NvmeSmartMetrics>

The NVMe SMART metrics for this storage controller.

This property shall contain the NVMe SMART metrics for this storage controller as defined by the NVMe SMART/Health Information log page. This property shall only be present for NVMe storage controllers.

actions: Option<Actions>

The available actions for this resource.

This property shall contain the available actions for this resource.

lifetime_start_date_time: Option<Option<DateTimeOffset>>

The date and time when the storage controller started accumulating data for properties that contain lifetime data, such as UncorrectableECCErrorCount.

This property shall contain the date and time when the storage controller started accumulating data for properties that contain lifetime data, such as UncorrectableECCErrorCount. For physical controllers, this might contain the same value as the production date of the storage controller. For logical controllers, this might contain the creation date of the storage controller.