pub enum TaskState {
Show 14 variants
New,
Starting,
Running,
Suspended,
Interrupted,
Pending,
Stopping,
Completed,
Killed,
Exception,
Service,
Cancelling,
Cancelled,
UnsupportedValue,
}Variants
New
A new task.
This value shall represent that the task is newly created but has not started.
Starting
Task is starting.
This value shall represent that the task is starting.
Running
Task is running normally.
This value shall represent that the task is executing.
Suspended
Task has been suspended.
This value shall represent that the task has been suspended but is expected to restart and is therefore not complete.
Interrupted
Task has been interrupted.
This value shall represent that the task has been interrupted but is expected to restart and is therefore not complete.
Pending
Task is pending and has not started.
This value shall represent that the task is pending some condition and has not yet begun to execute.
Stopping
Task is in the process of stopping.
This value shall represent that the task is stopping but is not yet complete.
Completed
Task was completed.
This value shall represent that the task completed successfully or with warnings.
Killed
Task was terminated.
This value shall represent that the task is complete because an operator killed it.
Exception
Task has stopped due to an exception condition.
This value shall represent that the task completed with errors.
Service
Task is running as a service.
This value shall represent that the task is now running as a service and expected to continue operation until stopped or killed.
Cancelling
Task is in the process of being cancelled.
This value shall represent that the task is in the process of being cancelled.
Cancelled
Task has been cancelled by an operator or internal process.
This value shall represent that either a DELETE operation on a task monitor or Task resource or
by an internal process cancelled the task.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.