pub struct Payload {
pub target_uri: Option<String>,
pub http_operation: Option<String>,
pub http_headers: Option<Vec<String>>,
pub json_body: Option<String>,
}Expand description
The HTTP and JSON payload details for this Task.
This type shall contain information detailing the HTTP and JSON payload information for executing this task.
Fields
target_uri: Option<String>The URI of the target for this task.
This property shall contain a link to the location to use as the target for an HTTP operation.
http_operation: Option<String>The HTTP operation to perform to execute this task.
This property shall contain the HTTP operation to execute for this task.
http_headers: Option<Vec<String>>An array of HTTP headers that this task includes.
This property shall contain an array of HTTP headers that this task includes.
json_body: Option<String>The JSON payload to use in the execution of this task.
This property shall contain the JSON-formatted payload used for this task.