pub struct TaskCollection {
pub base: ResourceCollection,
pub members: Vec<NavProperty<Task>>,
}Expand description
The collection of Task resource instances.
This resource shall represent a resource collection of Task instances for a Redfish
implementation.
Fields
base: ResourceCollectionBase type
members: Vec<NavProperty<Task>>The members of this collection.
This property shall contain an array of links to the members of this collection.