pub struct TaskService {
pub base: Resource,
pub completed_task_over_write_policy: Option<OverWritePolicy>,
pub date_time: Option<Option<DateTimeOffset>>,
pub life_cycle_event_on_task_state_change: Option<Boolean>,
pub service_enabled: Option<Option<Boolean>>,
pub status: Option<Status>,
pub actions: Option<Actions>,
pub task_auto_delete_timeout_minutes: Option<Int64>,
pub task_monitor_auto_expiry_seconds: Option<Option<Int64>>,
pub tasks: Option<NavProperty<TaskCollection>>,
}Expand description
The TaskService schema describes a task service that enables management of long-duration
operations, includes the properties for the task service itself, and has links to the resource
collection of tasks.
This resource contains a task service for a Redfish implementation.
Fields
base: ResourceBase type
completed_task_over_write_policy: Option<OverWritePolicy>The overwrite policy for completed tasks. This property indicates if the task service overwrites completed task information.
This property shall contain the overwrite policy for completed tasks. This property shall indicate if the task service overwrites completed task information.
date_time: Option<Option<DateTimeOffset>>The current date and time, with UTC offset, setting that the task service uses.
This property shall contain the current date and time for the task service, with UTC offset.
life_cycle_event_on_task_state_change: Option<Boolean>An indication of whether a task state change sends an event.
This property shall indicate whether a task state change sends an event. Services should send an event containing a message defined in the Task Event Message Registry when the state of a task changes.
service_enabled: Option<Option<Boolean>>An indication of whether this service is enabled.
This property shall indicate whether this service is enabled.
status: Option<Status>The status and health of the resource and its subordinate or dependent resources.
This property shall contain any status or health properties of the resource.
actions: Option<Actions>The available actions for this resource.
This property shall contain the available actions for this resource.
task_auto_delete_timeout_minutes: Option<Int64>The number of minutes after which a completed task is deleted by the service.
This property shall contain the number of minutes after which a completed task, where TaskState
contains the value Completed, Killed, Cancelled, or Exception, is deleted by the service.
task_monitor_auto_expiry_seconds: Option<Option<Int64>>The number of seconds after reading a task monitor for a completed task until the service deletes the task monitor.
This property shall contain the number of seconds after reading a task monitor for a completed task until the service deletes the task monitor. If the task is cancelled before it completes the task monitor shall be removed at that time.
tasks: Option<NavProperty<TaskCollection>>The links to the collection of tasks.
This property shall contain a link to a resource collection of type TaskCollection.