TelemetryServiceClearTelemetryDataAction

Struct TelemetryServiceClearTelemetryDataAction 

pub struct TelemetryServiceClearTelemetryDataAction {}
The action to clear the telemetry data for this telemetry service.

This action shall delete all entries found in the telemetry data collection for this telemetry service.