pub enum ApplyTime {
Immediate,
OnReset,
AtMaintenanceWindowStart,
InMaintenanceWindowOnReset,
OnStartUpdateRequest,
OnTargetReset,
UnsupportedValue,
}Variants
Immediate
Apply immediately.
This value shall indicate the HttpPushUri-provided software is applied immediately.
OnReset
Apply on a reset.
This value shall indicate the HttpPushUri-provided software is applied when the system or service
is reset.
AtMaintenanceWindowStart
Apply during an administrator-specified maintenance window.
This value shall indicate the HttpPushUri-provided software is applied during the maintenance
window specified by the MaintenanceWindowStartTime and MaintenanceWindowDurationInSeconds
properties. A service may perform resets during this maintenance window.
InMaintenanceWindowOnReset
Apply after a reset but within an administrator-specified maintenance window.
This value shall indicate the HttpPushUri-provided software is applied during the maintenance
window specified by the MaintenanceWindowStartTime and MaintenanceWindowDurationInSeconds
properties, and if a reset occurs within the maintenance window.
OnStartUpdateRequest
Apply when the StartUpdate action of the update service is invoked.
This value shall indicate the HttpPushUri-provided software is applied when the StartUpdate
action of the update service is invoked.
OnTargetReset
Apply when the target for the software update is reset. Targets include devices, services, and systems.
This value shall indicate the HttpPushUri-provided software is applied when the target is reset.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.