HttpPushUriApplyTime

Struct HttpPushUriApplyTime 

pub struct HttpPushUriApplyTime {
    pub apply_time: Option<ApplyTime>,
    pub maintenance_window_start_time: Option<DateTimeOffset>,
    pub maintenance_window_duration_in_seconds: Option<Int64>,
}
The settings for when to apply HttpPushUri-provided software.

The properties in this object shall contain settings for when to apply HttpPushUri-provided software.

Fields

apply_time: Option<ApplyTime>

The time when to apply the HttpPushUri-provided software update.

This property shall indicate the time when to apply the HttpPushUri-provided software update.

maintenance_window_start_time: Option<DateTimeOffset>

The start time of a maintenance window.

This property shall indicate the date and time when the service can start to apply the HttpPushUri-provided software as part of a maintenance window. This property shall be required if the HttpPushUriApplyTime property value is AtMaintenanceWindowStart or InMaintenanceWindowOnReset.

maintenance_window_duration_in_seconds: Option<Int64>

The expiry time, in seconds, of the maintenance window.

This property shall indicate the end of the maintenance window as the number of seconds after the time specified by the MaintenanceWindowStartTime property. This property shall be required if the HttpPushUriApplyTime property value is AtMaintenanceWindowStart or InMaintenanceWindowOnReset.