UpdateServiceSimpleUpdateAction

Struct UpdateServiceSimpleUpdateAction 

pub struct UpdateServiceSimpleUpdateAction {
    pub image_uri: Option<String>,
    pub transfer_protocol: Option<TransferProtocolType>,
    pub targets: Option<Vec<String>>,
    pub username: Option<String>,
    pub password: Option<String>,
    pub force_update: Option<Boolean>,
    pub stage: Option<Boolean>,
    pub local_image: Option<Boolean>,
    pub exclude_targets: Option<Vec<String>>,
}
This action updates software components.

This action shall update installed software components in a software image file located at an ImageURI parameter-specified URI.

Fields

image_uri: Option<String>

The URI of the software image to install.

This parameter shall contain an RFC3986-defined URI that links to a software image that the update service retrieves to install software in that image. This URI should contain a scheme that describes the transfer protocol. If the TransferProtocol parameter is absent or not supported, and a transfer protocol is not specified by a scheme contained within this URI, the service shall use HTTP to get the image.

transfer_protocol: Option<TransferProtocolType>

The network protocol that the update service uses to retrieve the software image file located at the URI specified by the ImageURI parameter. This parameter is ignored if the URI provided in ImageURI contains a scheme.

This parameter shall contain the network protocol that the update service shall use to retrieve the software image located at the URI specified by the ImageURI parameter. Services should ignore this parameter if the URI specified by the ImageURI parameter contains a scheme. If this parameter is not provided (or supported), and a transfer protocol is not specified by a scheme contained within this URI, the service shall use HTTP to retrieve the image.

targets: Option<Vec<String>>

An array of URIs that indicate where to apply the update image.

This parameter shall contain zero or more URIs that indicate where to apply the update image. These targets should correspond to software inventory instances or their related items. If this parameter is not present or contains no targets, the service shall apply the software image to all applicable targets, as determined by the service. If the target specifies a device resource, the software image file shall be applied to the specified device. If the target specifies a resource collection, the software image shall be applied to each applicable member of the specified collection. If the target resource specifies an Aggregate resource, the software image file shall be applied to each applicable element of the specified aggregate. If the target resource specifies a ComputerSystem resource, the software image file shall be applied to the applicable components within the specified computer system.

username: Option<String>

The username to access the URI specified by the ImageURI parameter.

This parameter shall contain the username to access the URI specified by the ImageURI parameter.

password: Option<String>

The password to access the URI specified by the ImageURI parameter.

This parameter shall contain the password to access the URI specified by the ImageURI parameter.

force_update: Option<Boolean>

An indication of whether the service should bypass update policies when applying the provided image. The default is false.

This parameter shall indicate whether the service should bypass update policies when applying the provided image, such as allowing a component to be downgraded. Services may contain update policies that are never bypassed, such as minimum version enforcement. If the client does not provide this parameter, the service shall default this value to false.

stage: Option<Boolean>

An indication of whether the service stages the image on target devices for a client to activate at a later time.

This parameter shall indicate whether the service stages the image on target devices for a client to activate at a later time with the Activate action on the SoftwareInventory resource. If the client does not provide this parameter, the service shall default this value to false.

local_image: Option<Boolean>

An indication of whether the service adds the image to the local image store.

This parameter shall indicate whether the service adds the image to the resource collection referenced by the LocalImageStore property. If the client does not provide this parameter, the service shall default this value to false.

exclude_targets: Option<Vec<String>>

An array of URIs that indicate where not to apply the update image.

This parameter shall contain zero or more URIs that indicate where not to apply the update image. This parameter shall be ignored if the Targets parameter is provided and contains at least one member. These excluded targets should correspond to software inventory instances or their related items. If this parameter is not present or contains no targets, the service shall apply the software image to all applicable targets, as determined by the service. If an excluded target specifies a device resource, the software image file shall not be applied to that specified device. If an excluded target specifies a resource collection, the software image shall not be applied to each applicable member of the specified collection. If an excluded target resource specifies an Aggregate resource, the software image file shall not be applied to each applicable element of the specified aggregate. If an excluded target resource specifies a ComputerSystem resource, the software image file shall not be applied to the applicable components within the specified computer system.