UpdateServiceStartUpdateAction

Struct UpdateServiceStartUpdateAction 

pub struct UpdateServiceStartUpdateAction {}
This action starts updating all images that have been previously invoked using an OperationApplyTime value of OnStartUpdateRequest.

This action shall start an update of software component that have been scheduled with the OperationApplyTime value of OnStartUpdateRequest.