pub enum EncryptionTypes {
NativeDriveEncryption,
ControllerAssisted,
SoftwareAssisted,
UnsupportedValue,
}Variants
NativeDriveEncryption
The volume is utilizing the native drive encryption capabilities of the drive hardware.
ControllerAssisted
The volume is being encrypted by the storage controller entity.
SoftwareAssisted
The volume is being encrypted by software running on the system or the operating system.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.