pub enum InitializeType {
Fast,
Slow,
UnsupportedValue,
}Variants
Fast
The volume is prepared for use quickly, typically by erasing just the beginning and end of the space so that partitioning can be performed.
Slow
The volume is prepared for use slowly, typically by completely erasing the volume.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.