pub enum NamespaceType {
Block,
KeyValue,
Zns,
Computational,
UnsupportedValue,
}Variants
Block
The namespace is configured for use with a block storage interface.
KeyValue
The namespace is configured for use with a KeyValue interface.
Zns
The namespace is configured for use with a zoned storage interface.
Computational
The namespace is configured for use with a computational storage interface.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.