pub enum ReadCachePolicyType {
ReadAhead,
AdaptiveReadAhead,
Off,
UnsupportedValue,
}Variants
ReadAhead
A caching technique in which the controller pre-fetches data anticipating future read requests.
AdaptiveReadAhead
A caching technique in which the controller dynamically determines whether to pre-fetch data anticipating future read requests, based on previous cache hit ratio.
Off
The read cache is disabled.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.