pub enum VolumeType {
RawDevice,
NonRedundant,
Mirrored,
StripedWithParity,
SpannedMirrors,
SpannedStripesWithParity,
UnsupportedValue,
}Variants
RawDevice
The volume is a raw physical device without any RAID or other virtualization applied.
NonRedundant
The volume is a non-redundant storage device.
Mirrored
The volume is a mirrored device.
StripedWithParity
The volume is a device which uses parity to retain redundant information.
SpannedMirrors
The volume is a spanned set of mirrored devices.
SpannedStripesWithParity
The volume is a spanned set of devices which uses parity to retain redundant information.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.