pub enum WriteCachePolicyType {
WriteThrough,
ProtectedWriteBack,
UnprotectedWriteBack,
Off,
UnsupportedValue,
}Variants
WriteThrough
A caching technique in which the completion of a write request is not signaled until data is safely stored on non-volatile media.
A caching technique in which the completion of a write request is not signaled until data is safely stored on non-volatile media.
ProtectedWriteBack
A caching technique in which the completion of a write request is signaled as soon as the data is in cache, and actual writing to non-volatile media is guaranteed to occur at a later time.
A caching technique in which the completion of a write request is signaled as soon as the data is in cache, and actual writing to non-volatile media is guaranteed to occur at a later time.
UnprotectedWriteBack
A caching technique in which the completion of a write request is signaled as soon as the data is in cache; actual writing to non-volatile media is not guaranteed to occur at a later time.
A caching technique in which the completion of a write request is signaled as soon as the data is in cache; actual writing to non-volatile media is not guaranteed to occur at a later time.
Off
The write cache is disabled.
Indicates that the write cache shall be disabled.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.