pub enum WriteCacheStateType {
Unprotected,
Protected,
Degraded,
UnsupportedValue,
}Variants
Unprotected
Indicates that the cache state type in use generally does not protect write requests on non-volatile media.
Indicates that the cache state type in use generally does not protect write requests on non-volatile media.
Protected
Indicates that the cache state type in use generally protects write requests on non-volatile media.
Indicates that the cache state type in use generally protects write requests on non-volatile media.
Degraded
Indicates an issue with the cache state in which the cache space is diminished or disabled due to a failure or an outside influence such as a discharged battery.
Indicates an issue with the cache state in which the cache space is diminished or disabled due to a failure or an outside influence such as a discharged battery.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.