NamespaceFeatures

Struct NamespaceFeatures 

pub struct NamespaceFeatures {
    pub supports_thin_provisioning: Option<Option<Boolean>>,
    pub supports_deallocated_or_unwritten_lb_error: Option<Option<Boolean>>,
    pub supports_nguid_reuse: Option<Option<Boolean>>,
    pub supports_atomic_transaction_size: Option<Option<Boolean>>,
    pub supports_io_performance_hints: Option<Option<Boolean>>,
}

Fields

supports_thin_provisioning: Option<Option<Boolean>>

This property indicates whether or not the NVMe Namespace supports thin provisioning.

This property shall indicate whether or not the NVMe Namespace supports thin provisioning. Specifically, the namespace capacity reported may be less than the namespace size.

supports_deallocated_or_unwritten_lb_error: Option<Option<Boolean>>

This property indicates that the controller supports deallocated or unwritten logical block error for this namespace.

This property shall indicate that the controller supports deallocated or unwritten logical block error for this namespace.

supports_nguid_reuse: Option<Option<Boolean>>

This property indicates that the namespace supports the use of an NGUID (namespace globally unique identifier) value.

This property shall indicate that the namespace supports the use of an NGUID (namespace globally unique identifier) value.

supports_atomic_transaction_size: Option<Option<Boolean>>

Indicates that the NVM fields for Namespace preferred write granularity (NPWG), write alignment (NPWA), deallocate granularity (NPDG), deallocate alignment (NPDA) and optimal write size (NOWS) are defined for this namespace and should be used by the host for I/O optimization.

This property shall indicate whether or not the NVM fields for Namespace preferred write granularity (NPWG), write alignment (NPWA), deallocate granularity (NPDG), deallocate alignment (NPDA) and optimal write size (NOWS) are defined for this namespace and should be used by the host for I/O optimization.

supports_io_performance_hints: Option<Option<Boolean>>

Indicates that the Namespace Atomic Write Unit Normal (NAWUN), Namespace Atomic Write Unit Power Fail (NAWUPF), and Namespace Atomic Compare and Write Unit (NACWU) fields are defined for this namespace and should be used by the host for this namespace instead of the controller-level properties AWUN, AWUPF, and ACWU.

This property shall indicate that the Namespace Atomic Write Unit Normal (NAWUN), Namespace Atomic Write Unit Power Fail (NAWUPF), and Namespace Atomic Compare and Write Unit (NACWU) fields are defined for this namespace and should be used by the host for this namespace instead of the controller-level properties AWUN, AWUPF, and ACWU.