Volume

Struct Volume 

pub struct Volume {
Show 48 fields pub base: Resource, pub status: Option<Status>, pub capacity_bytes: Option<Option<Int64>>, pub volume_type: Option<Option<VolumeType>>, pub encrypted: Option<Option<Boolean>>, pub encryption_types: Option<Vec<EncryptionTypes>>, pub identifiers: Option<Vec<Identifier>>, pub block_size_bytes: Option<Option<Int64>>, pub operations: Option<Vec<Operation>>, pub optimum_io_size_bytes: Option<Option<Int64>>, pub links: Option<Links>, pub actions: Option<Actions>, pub access_capabilities: Option<Option<Vec<StorageAccessCapability>>>, pub max_block_size_bytes: Option<Option<Int64>>, pub capacity: Option<Capacity>, pub low_space_warning_threshold_percents: Option<Option<Vec<Int64>>>, pub manufacturer: Option<Option<String>>, pub model: Option<Option<String>>, pub replica_info: Option<ReplicaInfo>, pub io_statistics: Option<IoStatistics>, pub remaining_capacity_percent: Option<Option<Int64>>, pub recoverable_capacity_source_count: Option<Option<Int64>>, pub raid_type: Option<Option<RaidType>>, pub provisioning_policy: Option<Option<ProvisioningPolicy>>, pub strip_size_bytes: Option<Option<Int64>>, pub read_cache_policy: Option<Option<ReadCachePolicyType>>, pub volume_usage: Option<Option<VolumeUsageType>>, pub write_cache_policy: Option<Option<WriteCachePolicyType>>, pub write_cache_state: Option<Option<WriteCacheStateType>>, pub logical_unit_number: Option<Option<Int64>>, pub media_span_count: Option<Option<Int64>>, pub display_name: Option<Option<String>>, pub write_hole_protection_policy: Option<WriteHoleProtectionPolicyType>, pub deduplicated: Option<Option<Boolean>>, pub compressed: Option<Option<Boolean>>, pub io_perf_mode_enabled: Option<Option<Boolean>>, pub nvme_namespace_properties: Option<Option<NvmeNamespaceProperties>>, pub initialize_method: Option<Option<InitializeMethod>>, pub is_boot_capable: Option<Option<Boolean>>, pub remote_replica_targets: Option<Option<Vec<String>>>, pub replication_enabled: Option<Option<Boolean>>, pub alua: Option<Option<Alua>>, pub capacity_sources: Option<Vec<ReferenceLeaf>>, pub storage_groups: Option<ReferenceLeaf>, pub allocated_pools: Option<ReferenceLeaf>, pub replica_targets: Option<Vec<ReferenceLeaf>>, pub metrics: Option<ReferenceLeaf>, pub connections: Option<Vec<ReferenceLeaf>>,
}
Add RAIDType property.

This resource shall be used to represent a volume, virtual disk, logical disk, LUN, or other logical storage for a Redfish implementation.

Fields

base: Resource

Base type

status: Option<Status>

The property contains the status of the Volume.

The property shall contain the status of the Volume.

capacity_bytes: Option<Option<Int64>>

The size in bytes of this Volume.

This property shall contain the size in bytes of the associated volume.

volume_type: Option<Option<VolumeType>>

The type of this volume.

This property shall contain the type of the associated Volume.

encrypted: Option<Option<Boolean>>

Is this Volume encrypted.

This property shall contain a boolean indicator if the Volume is currently utilizing encryption or not.

encryption_types: Option<Vec<EncryptionTypes>>

The types of encryption used by this Volume.

This property shall contain the types of encryption used by this Volume.

identifiers: Option<Vec<Identifier>>

The Durable names for the volume.

This property shall contain a list of all known durable names for the associated volume.

block_size_bytes: Option<Option<Int64>>

The size of the smallest addressable unit (Block) of this volume in bytes.

This property shall contain size of the smallest addressable unit of the associated volume.

operations: Option<Vec<Operation>>

The operations currently running on the Volume.

This property shall contain a list of all currently running on the Volume.

optimum_io_size_bytes: Option<Option<Int64>>

The size in bytes of this Volume’s optimum IO size.

This property shall contain the optimum IO size to use when performing IO on this volume. For logical disks, this is the stripe size. For physical disks, this describes the physical sector size.

links: Option<Links>

Contains references to other resources that are related to this resource.

The Links property, as described by the Redfish Specification, shall contain references to resources that are related to, but not contained by (subordinate to), this resource.

actions: Option<Actions>

The available actions for this resource.

The Actions property shall contain the available actions for this resource.

access_capabilities: Option<Option<Vec<StorageAccessCapability>>>

Supported IO access capabilities.

Each entry shall specify a current storage access capability.

max_block_size_bytes: Option<Option<Int64>>

Max Block size in bytes.

This property shall contain size of the largest addressable unit of this storage volume.

capacity: Option<Capacity>

Capacity utilization.

Information about the utilization of capacity allocated to this storage volume.

low_space_warning_threshold_percents: Option<Option<Vec<Int64>>>

Low space warning.

Each time the following value is less than one of the values in the array the LOW_SPACE_THRESHOLD_WARNING event shall be triggered: Across all CapacitySources entries, percent = (SUM(AllocatedBytes) - SUM(ConsumedBytes))/SUM(AllocatedBytes).

manufacturer: Option<Option<String>>

The manufacturer or OEM of this storage volume.

This property shall contain a value that represents the manufacturer or implementer of the storage volume.

model: Option<Option<String>>

The model number for this storage volume.

The value is assigned by the manufacturer and shall represents a specific storage volume implementation.

replica_info: Option<ReplicaInfo>

Describes this storage volume in its role as a target replica.

This property shall describe the replica relationship between this storage volume and a corresponding source volume.

io_statistics: Option<IoStatistics>

Statistics for this volume.

The value shall represent IO statistics for this volume.

remaining_capacity_percent: Option<Option<Int64>>

The percentage of the capacity remaining in the Volume.

If present, this value shall return {[(SUM(AllocatedBytes) - SUM(ConsumedBytes)]/SUM(AllocatedBytes)}*100 represented as an integer value.

recoverable_capacity_source_count: Option<Option<Int64>>

Current number of capacity source resources that are available as replacements.

The value is the number of available capacity source resources currently available in the event that an equivalent capacity source resource fails.

raid_type: Option<Option<RaidType>>

The RAID type of this volume.

This property shall contain the RAID type of the associated Volume.

provisioning_policy: Option<Option<ProvisioningPolicy>>

This property specifies the volume’s storage allocation, or provisioning policy.

This property shall specify the volume’s supported storage allocation policy.

strip_size_bytes: Option<Option<Int64>>

The number of blocks (bytes) in a strip in a disk array that uses striped data mapping.

The number of consecutively addressed virtual disk blocks (bytes) mapped to consecutively addressed blocks on a single member extent of a disk array. Synonym for stripe depth and chunk size.

read_cache_policy: Option<Option<ReadCachePolicyType>>

Indicates the read cache policy setting for the Volume.

This property shall contain a boolean indicator of the read cache policy for the Volume.

volume_usage: Option<Option<VolumeUsageType>>

Indicates the Volume usage type setting for the Volume.

This property shall contain the volume usage type for the Volume.

write_cache_policy: Option<Option<WriteCachePolicyType>>

Indicates the write cache policy setting for the Volume.

This property shall contain a boolean indicator of the write cache policy for the Volume.

write_cache_state: Option<Option<WriteCacheStateType>>

Indicates the WriteCacheState policy setting for the Volume.

This property shall contain the WriteCacheState policy setting for the Volume.

logical_unit_number: Option<Option<Int64>>

Indicates the host-visible LogicalUnitNumber assigned to this Volume.

This property shall contain host-visible LogicalUnitNumber assigned to this Volume. This property shall only be used when in a single connect configuration and no StorageGroup configuration is used.

media_span_count: Option<Option<Int64>>

Indicates the number of media elements used per span in the secondary RAID for a hierarchical RAID type.

This property shall indicate the number of media elements used per span in the secondary RAID for a hierarchical RAID type.

display_name: Option<Option<String>>

A user-configurable string to name the volume.

This property shall contain a user-configurable string to name the volume.

write_hole_protection_policy: Option<WriteHoleProtectionPolicyType>

The policy that the RAID volume is using to address the write hole issue.

This property specifies the policy that is enabled to address the write hole issue on the RAID volume. If no policy is enabled at the moment, this property shall be set to ‘Off’.

deduplicated: Option<Option<Boolean>>

Indicator of whether or not the Volume has deduplication enabled.

This property shall contain a boolean indicator if the Volume is currently utilizing deduplication or not.

compressed: Option<Option<Boolean>>

Indicator of whether or not the Volume has compression enabled.

This property shall contain a boolean indicator if the Volume is currently utilizing compression or not.

io_perf_mode_enabled: Option<Option<Boolean>>

Indicates the IO performance mode setting for the volume.

This property shall indicate whether IO performance mode is enabled for the volume.

nvme_namespace_properties: Option<Option<NvmeNamespaceProperties>>

This property contains properties to use when Volume is used to describe an NVMe Namespace.

This property shall contain properties to use when Volume is used to describe an NVMe Namespace.

initialize_method: Option<Option<InitializeMethod>>

Indicates the Initialization Method used for this volume. If InitializeMethod is not specified, the InitializeMethod should be Foreground.

This property shall indicate the initialization method used for this volume. If InitializeMethod is not specified, the InitializeMethod should be Foreground. This value reflects the most recently used Initialization Method, and may be changed using the Initialize Action.

is_boot_capable: Option<Option<Boolean>>

This property indicates whether or not the Volume contains a boot image and is capable of booting.

This property shall indicate whether or not the Volume contains a boot image and is capable of booting. This property may be settable by an admin or client with visibility into the contents of the volume. This property should only be set to true when VolumeUsage is either not specified, or when VolumeUsage is set to Data or SystemData.

remote_replica_targets: Option<Option<Vec<String>>>

URIs to the resources that are remote target replicas of this source.

The value shall reference the URIs to the remote target replicas that are sourced by this replica. Remote indicates that the replica is managed by a separate Swordfish service instance.

replication_enabled: Option<Option<Boolean>>

Indicates whether or not replication is enabled on the volume.

The property shall indicate whether or not replication is enabled on the volume. This property shall be consistent with the state reflected at the storage pool level.

alua: Option<Option<Alua>>

ALUA properties for this volume.

This shall identify the ALUA properties for this volume.

capacity_sources: Option<Vec<ReferenceLeaf>>storage_groups: Option<ReferenceLeaf>allocated_pools: Option<ReferenceLeaf>replica_targets: Option<Vec<ReferenceLeaf>>metrics: Option<ReferenceLeaf>connections: Option<Vec<ReferenceLeaf>>