VolumeChangeRAIDLayoutAction

Struct VolumeChangeRAIDLayoutAction 

pub struct VolumeChangeRAIDLayoutAction {
    pub raid_type: Option<RaidType>,
    pub strip_size_bytes: Option<Int64>,
    pub media_span_count: Option<Int64>,
    pub drives: Option<Vec<Reference>>,
}
Request system change the RAID layout of the volume.

This action shall request the system to change the RAID layout of the volume. Depending on the combination of the submitted parameters, this could be changing the RAID type, changing the span count, changing the number of drives used by the volume, or another configuration change supported by the system. Note that usage of this action while online may potentially cause data loss if the available capacity is reduced.

Fields

raid_type: Option<RaidType>

The requested RAID type for the volume.

This parameter shall contain the requested RAID type for the volume.

strip_size_bytes: Option<Int64>

The number of blocks (bytes) requested for new strip size.

This parameter shall contain the number of blocks (bytes) requested for the strip size.

media_span_count: Option<Int64>

The requested number of media elements used per span in the secondary RAID for a hierarchical RAID type.

This parameter shall contain the requested number of media elements used per span in the secondary RAID for a hierarchical RAID type.

drives: Option<Vec<Reference>>

An array of the drives to be used by the volume.

This parameter shall contain an array of the drives to be used by the volume.