VolumeCheckConsistencyAction

Struct VolumeCheckConsistencyAction 

pub struct VolumeCheckConsistencyAction {}
This action is used to force a check of the Volume’s parity or redundant data to ensure it matches calculated values.

This defines the name of the custom action supported on this resource.