VolumeCreateReplicaTargetAction

Struct VolumeCreateReplicaTargetAction 

pub struct VolumeCreateReplicaTargetAction {
    pub replica_update_mode: Option<ReplicaUpdateMode>,
    pub volume_name: Option<String>,
    pub target_storage_pool: Option<String>,
    pub replica_type: Option<ReplicaType>,
}
This action is used to create a new volume resource to provide expanded data protection through a replica relationship with the specified source volume.

This action shall be used to create a new volume resource to provide expanded data protection through a replica relationship with the specified source volume.

Fields

replica_update_mode: Option<ReplicaUpdateMode>

The replica update mode (synchronous vs asynchronous).

This parameter shall specify the replica update mode.

volume_name: Option<String>

The Name for the new target volume.

This parameter shall contain the Name for the target volume.

target_storage_pool: Option<String>

The Uri to the existing target Storage Pool.

This parameter shall contain the Uri to the existing StoragePool in which to create the target volume.

replica_type: Option<ReplicaType>

The type of replica relationship to be created.

This parameter shall contain the type of replica relationship to be created (e.g., Clone, Mirror, Snap).