VolumeForceEnableAction

Struct VolumeForceEnableAction 

pub struct VolumeForceEnableAction {}
Request system force the volume to an enabled state regardless of data loss.

This action shall request the system to force the volume to enabled state regardless of data loss scenarios.