VolumeInitializeAction

Struct VolumeInitializeAction 

pub struct VolumeInitializeAction {
    pub initialize_method: Option<InitializeMethod>,
    pub initialize_type: Option<InitializeType>,
}
This action is used to prepare the contents of the volume for use by the system. If InitializeMethod is not specified in the request body, but the property InitializeMethod is specified, the property InitializeMethod value should be used. If neither is specified, the InitializeMethod should be Foreground.

This defines the name of the custom action supported on this resource. If InitializeMethod is not specified in the request body, but the property InitializeMethod is specified, the property InitializeMethod value should be used. If neither is specified, the InitializeMethod should be Foreground.

Fields

initialize_method: Option<InitializeMethod>

The type of initialization to be performed.

This defines the property name for the action.

initialize_type: Option<InitializeType>

The type of initialization to be performed.

This defines the property name for the action.