pub struct VolumeResumeReplicationAction {
pub target_volume: Option<String>,
}Expand description
This action is used to resume the active data synchronization between a source and target volume, without otherwise altering the replication relationship.
This action shall be used to resume the active data synchronization between a source and target volume, without otherwise altering the replication relationship.
Fields
target_volume: Option<String>The Uri to the existing target volume.
This parameter shall contain the Uri to the existing target volume.