pub struct VolumeSplitReplicationAction {
pub target_volume: Option<String>,
}Expand description
This action is used to split the replication relationship and suspend data synchronization between a source and target volume.
This action shall be used to split the replication relationship and suspend data synchronization between a source and target volume.
Fields
target_volume: Option<String>The Uri to the existing target volume.
This parameter shall contain the Uri to the existing target volume.