pub struct VolumeCollection {
pub base: ResourceCollection,
pub members: Vec<NavProperty<Volume>>,
}Expand description
A Collection of Volume resource instances.
This collection shall contain references to all Volume resource instances sharing the same parent resource.
Fields
base: ResourceCollectionBase type
members: Vec<NavProperty<Volume>>The value of each member references a Volume resource.
The value of each member entry shall reference a Volume resource.