pub enum SessionTypes {
HostConsole,
ManagerConsole,
Ipmi,
Kvmip,
Oem,
Redfish,
VirtualMedia,
WebUi,
OutboundConnection,
}Variants
HostConsole
The host’s console, which could be connected through Telnet, SSH, or another protocol.
This value shall indicate the session is the host’s console, which could be connected through Telnet, SSH, or another protocol. If this session is terminated or deleted, the service shall close the connection for the respective host console session.
ManagerConsole
The manager’s console, which could be connected through Telnet, SSH, SM CLP, or another protocol.
This value shall indicate the session is the manager’s console, which could be connected through Telnet, SSH, SM CLP, or another protocol. If this session is terminated or deleted, the service shall close the connection for the respective manager console session.
Ipmi
Intelligent Platform Management Interface.
This value shall indicate the session is an Intelligent Platform Management Interface session. If this session is terminated or deleted, the service shall close the connection for the respective IPMI session.
Kvmip
A Keyboard-Video-Mouse over IP session.
This value shall indicate the session is a Keyboard-Video-Mouse over IP session. If this session is terminated or deleted, the service shall close the connection for the respective KVM-IP session.
Oem
OEM type. For OEM session types, see the OemSessionType property.
This value shall indicate the session is an OEM-specific session and is further described by the
OemSessionType property.
Redfish
A Redfish session.
This value shall indicate the session is a Redfish session defined by the ‘Redfish session login authentication’ clause of the Redfish Specification. If this session is terminated or deleted, the service shall invalidate the respective session token.
VirtualMedia
Virtual media.
This value shall indicate the session is a virtual media session. If this session is terminated or deleted, the service shall close the connection for the respective virtual media session and make the media inaccessible to the host.
WebUi
A non-Redfish web user interface session, such as a graphical interface or another web-based protocol.
This value shall indicate the session is a non-Redfish web user interface session. If this session is terminated or deleted, the service shall invalidate the respective session token.
OutboundConnection
A Redfish Specification-defined outbound connection. See the ‘Outbound connections’ clause of the Redfish Specification.
This value shall indicate the session is an outbound connection defined by the ‘Outbound
connections’ clause of the Redfish Specification. The OutboundConnection property inside the
Links property shall contain the link to the outbound connection configuration. If this session
is terminated or deleted, the service shall disable the associated OutboundConnection resource.