pub struct SessionService<B: Bmc> { /* private fields */ }Expand description
Session service.
Provides access to the session collection and individual session resources.
Implementations
Sourceimpl<B: Bmc> SessionService<B>
impl<B: Bmc> SessionService<B>
Sourcepub fn raw(&self) -> Arc<SessionServiceSchema>
pub fn raw(&self) -> Arc<SessionServiceSchema>
Get the raw schema data for this session service.
Returns an Arc to the underlying schema, allowing cheap cloning
and sharing of the data.