pub struct TaskService<B: Bmc> { /* private fields */ }Expand description
Task service.
Provides task links for task locations returned by asynchronous operations.
Example
ⓘ
let Some(task_service) = root.task_service().await? else {
return Ok(());
};
let task_link = task_service.task_link(async_task)?;
let task = task_link.fetch().await?;
println!("{:?}", task.task_state);Implementations
Sourceimpl<B: Bmc> TaskService<B>
impl<B: Bmc> TaskService<B>
Sourcepub fn raw(&self) -> Arc<TaskServiceSchema> ⓘ
pub fn raw(&self) -> Arc<TaskServiceSchema> ⓘ
Get the raw schema data for this task service.
Sourcepub fn task_link(&self, task: AsyncTask) -> Result<TaskLink<B>, Error<B>>
pub fn task_link(&self, task: AsyncTask) -> Result<TaskLink<B>, Error<B>>
Create a task link from an asynchronous operation result.
The task location must be a child of this service’s Tasks collection,
such as /redfish/v1/TaskService/Tasks/{id}. The returned link does not
fetch the task until TaskLink::fetch is called.
Errors
Returns error if the task location is not a child of this service’s Tasks collection.