pub type TaskLink<B> = EntityLink<B, Task>;Expand description
Link to a Redfish Task returned by an asynchronous operation.
Aliased Type
pub struct TaskLink<B> { /* private fields */ }pub type TaskLink<B> = EntityLink<B, Task>;Link to a Redfish Task returned by an asynchronous operation.
pub struct TaskLink<B> { /* private fields */ }