pub struct TelemetryService<B: Bmc> { /* private fields */ }Expand description
Telemetry service.
Provides access to metric reports and metric definitions.
Implementations
Sourceimpl<B: Bmc> TelemetryService<B>
impl<B: Bmc> TelemetryService<B>
Sourcepub fn raw(&self) -> Arc<TelemetryServiceSchema>
pub fn raw(&self) -> Arc<TelemetryServiceSchema>
Get the raw schema data for this telemetry service.
Sourcepub async fn metric_reports(
&self,
) -> Result<Option<Vec<MetricReportRef<B>>>, Error<B>>
pub async fn metric_reports( &self, ) -> Result<Option<Vec<MetricReportRef<B>>>, Error<B>>
Get Vec<MetricReportRef> associated with this telemetry service.
Fetches the metric report collection and returns a list of
MetricReportRef handles.
Errors
Returns an error if:
- the telemetry service does not expose a
MetricReportscollection - retrieving the collection fails
Sourcepub async fn metric_definitions(
&self,
) -> Result<Option<Vec<MetricDefinition<B>>>, Error<B>>
pub async fn metric_definitions( &self, ) -> Result<Option<Vec<MetricDefinition<B>>>, Error<B>>
Get Vec<MetricDefinition> associated with this telemetry service.
Fetches the metric definition collection and returns a list of MetricDefinition handles.
Errors
Returns an error if:
- the telemetry service does not expose a
MetricDefinitionscollection - retrieving the collection fails
Sourcepub async fn metric_report_definitions(
&self,
) -> Result<Option<Vec<MetricReportDefinition<B>>>, Error<B>>
pub async fn metric_report_definitions( &self, ) -> Result<Option<Vec<MetricReportDefinition<B>>>, Error<B>>
Get Vec<MetricReportDefinition> associated with this telemetry service.
Fetches the metric report definition collection and returns a list of
MetricReportDefinition handles.
Errors
Returns an error if:
- the telemetry service does not expose a
MetricReportDefinitionscollection - retrieving the collection fails
Sourcepub async fn create_metric_definition(
&self,
create: &MetricDefinitionCreate,
) -> Result<Option<MetricDefinition<B>>, Error<B>>
pub async fn create_metric_definition( &self, create: &MetricDefinitionCreate, ) -> Result<Option<MetricDefinition<B>>, Error<B>>
Create a metric definition.
Errors
Returns an error if:
- the telemetry service does not expose a
MetricDefinitionscollection - creating the entity fails
Sourcepub async fn create_metric_report_definition(
&self,
create: &MetricReportDefinitionCreate,
) -> Result<Option<MetricReportDefinition<B>>, Error<B>>
pub async fn create_metric_report_definition( &self, create: &MetricReportDefinitionCreate, ) -> Result<Option<MetricReportDefinition<B>>, Error<B>>
Create a metric report definition.
Errors
Returns an error if:
- the telemetry service does not expose a
MetricReportDefinitionscollection - creating the entity fails