pub struct SoftwareInventory<B: Bmc> { /* private fields */ }Expand description
Represents a software inventory item in the update service.
Provides access to software version information and metadata.
Implementations
Sourceimpl<B: Bmc> SoftwareInventory<B>
impl<B: Bmc> SoftwareInventory<B>
Sourcepub fn raw(&self) -> Arc<SoftwareInventorySchema>
pub fn raw(&self) -> Arc<SoftwareInventorySchema>
Get the raw schema data for this software inventory item.
Returns an Arc to the underlying schema, allowing cheap cloning
and sharing of the data.
Sourcepub fn version(&self) -> Option<VersionRef<'_>>
pub fn version(&self) -> Option<VersionRef<'_>>
Get the version of software inventory item.
Sourcepub fn release_date(
&self,
) -> Option<TaggedType<EdmDateTimeOffset, ReleaseDateTag>>
pub fn release_date( &self, ) -> Option<TaggedType<EdmDateTimeOffset, ReleaseDateTag>>
Get the release date of the software inventory item.