pub enum AccountTypes {
Redfish,
Snmp,
Oem,
HostConsole,
ManagerConsole,
Ipmi,
Kvmip,
VirtualMedia,
WebUi,
ControlPanel,
}Variants
Redfish
Allow access to the Redfish service.
This value shall indicate the account is allowed to access Redfish services. If the version of the
ManagerAccount resource is lower than the schema version when another enumeration value in this
list was added, the implementation may include that functionality as part of the Redfish value.
Snmp
Allow access to SNMP services.
This value shall indicate the account is allowed to access SNMP services.
Oem
OEM account type. See the OEMAccountTypes property.
This value shall indicate the account is allowed to access the services listed in the
OEMAccountTypes property.
HostConsole
Allow access to the host’s console, which could be connected through Telnet, SSH, or another protocol.
This value shall indicate the account is allowed to access the host console.
ManagerConsole
Allow access to the manager’s console, which could be connected through Telnet, SSH, SM CLP, or another protocol.
This value shall indicate the account is allowed to access the manager console.
Ipmi
Allow access to the Intelligent Platform Management Interface service.
This value shall indicate the account is allowed to access the Intelligent Platform Management Interface service.
Kvmip
Allow access to a Keyboard-Video-Mouse over IP session.
This value shall indicate the account is allowed to access the Keyboard-Video-Mouse over IP session service.
VirtualMedia
Allow access to control virtual media.
This value shall indicate the account is allowed to control virtual media.
WebUi
Allow access to a web user interface session, such as a graphical interface or another web-based protocol.
This value shall indicate the account is allowed to access the web interface.
ControlPanel
Allow PIN-based access via an external control panel, such as a keypad, touchscreen, or other human interface.
This value shall indicate the account is used to allow PIN-based access via an external control
panel. If this value is specified, the AccountTypes property should not contain other values for
the same ManagerAccount resource. If this value is specified, Password shall contain the PIN
to enable access, and may not follow other password-related rules. The ChangePassword action, if
supported, may be used to update the PIN.