pub struct Account<B: Bmc> { /* private fields */ }Expand description
Represents a Redfish ManagerAccount.
Implementations
Sourceimpl<B: Bmc> Account<B>
impl<B: Bmc> Account<B>
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Account is enabled.
Sourcepub async fn update(
&self,
update: &ManagerAccountUpdate,
) -> Result<Option<Self>, Error<B>>
pub async fn update( &self, update: &ManagerAccountUpdate, ) -> Result<Option<Self>, Error<B>>
Update the account.
Returns the new (updated) account.
Errors
Returns an error if the server responds with an error or if the response cannot be parsed.
Sourcepub async fn update_password(
&self,
password: String,
) -> Result<Option<Self>, Error<B>>
pub async fn update_password( &self, password: String, ) -> Result<Option<Self>, Error<B>>
Update the account’s password.
Returns the new (updated) account.
Errors
Returns an error if the server responds with an error or if the response cannot be parsed.