pub struct Evicted<K, V> {
pub key: K,
pub value: V,
}Expand description
Information about an evicted cache entry.
When an entry is evicted from the cache, this struct holds both the key and value of the evicted entry. This is particularly useful for cleaning up related resources (like ETags) when entries are evicted.
Fields
key: KThe key of the evicted entry
value: VThe value of the evicted entry