pub struct NetworkAdapter<B: Bmc> { /* private fields */ }Expand description
Network Adapter.
Provides functions to access log entries and perform log operations.
Implementations
Sourceimpl<B: Bmc> NetworkAdapter<B>
impl<B: Bmc> NetworkAdapter<B>
Sourcepub fn raw(&self) -> Arc<NetworkAdapterSchema>
pub fn raw(&self) -> Arc<NetworkAdapterSchema>
Get the raw schema data for this ethernet adapter.
Sourcepub fn hardware_id(&self) -> HardwareIdRef<'_, NetworkAdapterTag>
pub fn hardware_id(&self) -> HardwareIdRef<'_, NetworkAdapterTag>
Get hardware identifier of the network adpater.
Sourcepub async fn network_device_functions(
&self,
) -> Result<Option<NetworkDeviceFunctionCollection<B>>, Error<B>>
pub async fn network_device_functions( &self, ) -> Result<Option<NetworkDeviceFunctionCollection<B>>, Error<B>>
Get network device functions for this adapter.
Returns Ok(None) when the network device functions link is absent.
Errors
Returns an error if fetching network device functions data fails.