ComputerSystem

Struct ComputerSystem 

pub struct ComputerSystem<B: Bmc> { /* private fields */ }
Represents a computer system in the BMC.

Provides access to system information and sub-resources such as processors.

Implementations

Source

impl<B: Bmc> ComputerSystem<B>

pub fn raw(&self) -> Arc<ComputerSystemSchema>

Get the raw schema data for this computer system.

Returns an Arc to the underlying schema, allowing cheap cloning and sharing of the data.

pub fn hardware_id(&self) -> HardwareIdRef<'_, ComputerSystemTag>

Get hardware identifier of the network adpater.

pub fn sku(&self) -> Option<TaggedType<&String, ComputerSystemSkuTag>>

The manufacturer SKU for this system.

pub fn power_state(&self) -> Option<PowerState>

Power state of this system.

pub fn boot_order(&self) -> Option<Vec<BootOptionReference<&String>>>

An array of BootOptionReference strings that represent the persistent boot order for with this computer system.

pub async fn bios(&self) -> Result<Bios<B>, Error<B>>

Bios associated with this system.

Fetches the BIOS settings.

Errors

Returns an error if:

  • The system does not provide bios settings
  • Fetching bios data fails
pub async fn processors(&self) -> Result<Vec<Processor<B>>, Error<B>>

Get processors associated with this system.

Fetches the processor collection and returns a list of Processor handles.

Errors

Returns an error if:

  • The system does not have a processors collection
  • Fetching processor data fails
pub async fn secure_boot(&self) -> Result<SecureBoot<B>, Error<B>>

Get secure boot resource associated with this system.

Errors

Returns an error if:

  • The system does not have a secure boot resource
  • Fetching of secure boot data fails
pub async fn storage_controllers(&self) -> Result<Vec<Storage<B>>, Error<B>>

Get storage controllers associated with this system.

Fetches the storage collection and returns a list of Storage handles.

Errors

Returns an error if:

  • The system does not have a storage collection
  • Fetching storage data fails
pub async fn memory_modules(&self) -> Result<Vec<Memory<B>>, Error<B>>

Get memory modules associated with this system.

Fetches the memory collection and returns a list of Memory handles.

Errors

Returns an error if:

  • The system does not have a memory collection
  • Fetching memory data fails
pub async fn log_services(&self) -> Result<Vec<LogService<B>>, Error<B>>

Get log services for this computer system.

Errors

Returns an error if:

  • The computer system does not have log services
  • Fetching log service data fails
pub async fn ethernet_interfaces( &self, ) -> Result<EthernetInterfaceCollection<B>, Error<B>>

Get ethernet interfaces for this computer system.

Errors

Returns an error if:

  • The systems does not have / provide ethernet interfaces
  • Fetching ethernet internet data fails
pub async fn boot_options(&self) -> Result<BootOptionCollection<B>, Error<B>>

Get collection of the UEFI boot options associated with this computer system.

Errors

Returns an error if:

  • The systems does not have / provide boot options
  • Fetching boot options data fails
pub async fn oem_nvidia_bluefield( &self, ) -> Result<NvidiaComputerSystem<B>, Error<B>>

NVIDIA Bluefield OEM extension

Errors

Returns an error if:

  • Error::NvidiaComputerSystemNotAvailable if the systems does not have / provide NVIDIA OEM extension
  • Fetching data fails