pub struct ComputerSystem<B: Bmc> { /* private fields */ }Expand description
Represents a computer system in the BMC.
Provides access to system information and sub-resources such as processors.
Implementations
Sourceimpl<B: Bmc> ComputerSystem<B>
impl<B: Bmc> ComputerSystem<B>
Sourcepub fn raw(&self) -> Arc<ComputerSystemSchema>
pub fn raw(&self) -> Arc<ComputerSystemSchema>
Get the raw schema data for this computer system.
Returns an Arc to the underlying schema, allowing cheap cloning
and sharing of the data.
Sourcepub fn hardware_id(&self) -> HardwareIdRef<'_, ComputerSystemTag>
pub fn hardware_id(&self) -> HardwareIdRef<'_, ComputerSystemTag>
Get hardware identifier of the network adpater.
Sourcepub fn sku(&self) -> Option<TaggedType<&String, ComputerSystemSkuTag>>
pub fn sku(&self) -> Option<TaggedType<&String, ComputerSystemSkuTag>>
The manufacturer SKU for this system.
Sourcepub fn power_state(&self) -> Option<PowerState>
pub fn power_state(&self) -> Option<PowerState>
Power state of this system.
Sourcepub fn boot_order(&self) -> Option<Vec<BootOptionReference<&String>>>
pub fn boot_order(&self) -> Option<Vec<BootOptionReference<&String>>>
An array of BootOptionReference strings that represent the persistent boot order for with this
computer system.
Sourcepub async fn bios(&self) -> Result<Bios<B>, Error<B>>
pub async fn bios(&self) -> Result<Bios<B>, Error<B>>
Bios associated with this system.
Fetches the BIOS settings.
Errors
Returns an error if:
- The system does not provide bios settings
- Fetching bios data fails
Sourcepub async fn secure_boot(&self) -> Result<SecureBoot<B>, Error<B>>
pub async fn secure_boot(&self) -> Result<SecureBoot<B>, Error<B>>
Get secure boot resource associated with this system.
Errors
Returns an error if:
- The system does not have a secure boot resource
- Fetching of secure boot data fails
Sourcepub async fn log_services(&self) -> Result<Vec<LogService<B>>, Error<B>>
pub async fn log_services(&self) -> Result<Vec<LogService<B>>, Error<B>>
Get log services for this computer system.
Errors
Returns an error if:
- The computer system does not have log services
- Fetching log service data fails
Sourcepub async fn ethernet_interfaces(
&self,
) -> Result<EthernetInterfaceCollection<B>, Error<B>>
pub async fn ethernet_interfaces( &self, ) -> Result<EthernetInterfaceCollection<B>, Error<B>>
Get ethernet interfaces for this computer system.
Errors
Returns an error if:
- The systems does not have / provide ethernet interfaces
- Fetching ethernet internet data fails
Sourcepub async fn boot_options(&self) -> Result<BootOptionCollection<B>, Error<B>>
pub async fn boot_options(&self) -> Result<BootOptionCollection<B>, Error<B>>
Get collection of the UEFI boot options associated with this computer system.
Errors
Returns an error if:
- The systems does not have / provide boot options
- Fetching boot options data fails
Sourcepub async fn oem_nvidia_bluefield(
&self,
) -> Result<NvidiaComputerSystem<B>, Error<B>>
pub async fn oem_nvidia_bluefield( &self, ) -> Result<NvidiaComputerSystem<B>, Error<B>>
NVIDIA Bluefield OEM extension
Errors
Returns an error if:
Error::NvidiaComputerSystemNotAvailableif the systems does not have / provide NVIDIA OEM extension- Fetching data fails