pub struct Drive<B: Bmc> { /* private fields */ }Expand description
Represents a drive (disk) in a storage controller.
Provides access to drive information and associated metrics/sensors.
Implementations
Sourceimpl<B: Bmc> Drive<B>
impl<B: Bmc> Drive<B>
Sourcepub fn raw(&self) -> Arc<DriveSchema> ⓘ
pub fn raw(&self) -> Arc<DriveSchema> ⓘ
Get the raw schema data for this drive.
Returns an Arc to the underlying schema, allowing cheap cloning
and sharing of the data.
Sourcepub async fn metrics(&self) -> Result<Option<Arc<DriveMetrics>>, Error<B>>
pub async fn metrics(&self) -> Result<Option<Arc<DriveMetrics>>, Error<B>>
Get drive metrics.
Returns the drive’s performance and state metrics if available.
Errors
Returns an error if:
- The drive does not have metrics
- Fetching metrics data fails
Sourcepub async fn environment_sensor_links(
&self,
) -> Result<Vec<SensorLink<B>>, Error<B>>
pub async fn environment_sensor_links( &self, ) -> Result<Vec<SensorLink<B>>, Error<B>>
Get the environment sensors for this drive.
Returns a vector of Sensor<B> obtained from environment metrics, if available.
Errors
Returns an error if get of environment metrics failed.