pub struct ActionTarget(/* private fields */);Expand description
URI reference for the target field of an action.
The Bmc implementation resolves this value when the action is run and
may reject values that violate its outbound request policy before transport.
Implementations
Sourceimpl ActionTarget
impl ActionTarget