ActionError

Trait ActionError 

pub trait ActionError {
    // Required method
    fn not_supported() -> Self;
}
Action error trait. Needed in generated code when an action function is called for an action that wasn’t specified by the server.

Required Methods

fn not_supported() -> Self

Create an error when the action is not supported.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors