pub trait ActionError {
// Required method
fn not_supported() -> Self;
}Expand description
Action error trait. Needed in generated code when an action function is called for an action that wasn’t specified by the server.
Required Methods
Sourcefn not_supported() -> Self
fn not_supported() -> Self
Create an error when the action is not supported.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".