pub struct Event {
pub base: Resource,
pub events: Vec<NavProperty<EventRecord>>,
}Expand description
The Event schema describes the JSON payload received by an event destination, which has
subscribed to event notification, when events occur. This resource contains data about events,
including descriptions, severity, and a MessageId reference to a message registry that can be
accessed for further information. For standard message definitions, see DSP2065.
This resource contains an event for a Redfish implementation.
Fields
base: ResourceBase type
events: Vec<NavProperty<EventRecord>>Each event in this array has a set of properties that describe the event. Because this is an array, more than one event can be sent simultaneously.
This property shall contain an array of objects that represent the occurrence of one or more events.