pub struct Manager<B: Bmc> { /* private fields */ }Expand description
Represents a manager (BMC) in the system.
Provides access to manager information and associated services.
Implementations
Sourceimpl<B: Bmc> Manager<B>
impl<B: Bmc> Manager<B>
Sourcepub fn raw(&self) -> Arc<ManagerSchema>
pub fn raw(&self) -> Arc<ManagerSchema>
Get the raw schema data for this manager.
Returns an Arc to the underlying schema, allowing cheap cloning
and sharing of the data.
Sourcepub async fn ethernet_interfaces(
&self,
) -> Result<Option<EthernetInterfaceCollection<B>>, Error<B>>
pub async fn ethernet_interfaces( &self, ) -> Result<Option<EthernetInterfaceCollection<B>>, Error<B>>
Get ethernet interfaces for this manager.
Returns Ok(None) when the ethernet interfaces link is absent.
Errors
Returns an error if fetching ethernet interfaces data fails.
Sourcepub async fn host_interfaces(
&self,
) -> Result<Option<HostInterfaceCollection<B>>, Error<B>>
pub async fn host_interfaces( &self, ) -> Result<Option<HostInterfaceCollection<B>>, Error<B>>
Get host interfaces for this manager.
Returns Ok(None) when the host interfaces link is absent.
Errors
Returns an error if fetching host interfaces data fails.
Sourcepub async fn log_services(&self) -> Result<Option<Vec<LogService<B>>>, Error<B>>
pub async fn log_services(&self) -> Result<Option<Vec<LogService<B>>>, Error<B>>
Get log services for this manager.
Returns Ok(None) when the log services link is absent.
Errors
Returns an error if fetching log service data fails.
Sourcepub async fn oem_dell_attributes(
&self,
) -> Result<Option<DellAttributes<B>>, Error<B>>
pub async fn oem_dell_attributes( &self, ) -> Result<Option<DellAttributes<B>>, Error<B>>
Get Dell Manager attributes for this manager.
Returns Ok(None) when the manager does not include Oem.Dell.
Errors
Returns an error if fetching manager attributes data fails.
Sourcepub fn oem_lenovo(&self) -> Result<Option<LenovoManager<B>>, Error<B>>
pub fn oem_lenovo(&self) -> Result<Option<LenovoManager<B>>, Error<B>>
Get Lenovo Manager OEM.
Returns Ok(None) when the manager does not include Oem.Lenovo.
Errors
Returns an error if parsing Lenovo manager OEM data fails.
Sourcepub fn oem_hpe(&self) -> Result<Option<HpeManager<B>>, Error<B>>
pub fn oem_hpe(&self) -> Result<Option<HpeManager<B>>, Error<B>>
Get HPE Manager OEM.
Returns Ok(None) when the manager does not include Oem.Hpe.
Errors
Returns an error if parsing HPE manager OEM data fails.
Sourcepub fn oem_supermicro(&self) -> Result<Option<SupermicroManager<B>>, Error<B>>
pub fn oem_supermicro(&self) -> Result<Option<SupermicroManager<B>>, Error<B>>
Get Supermicro Manager OEM.
Returns Ok(None) when the manager does not include Oem.Supermicro.
Errors
Returns an error if parsing Supermicro manager OEM data fails.
Sourcepub async fn oem_ami_config_bmc(
&self,
) -> Result<Option<AmiConfigBmc<B>>, Error<B>>
pub async fn oem_ami_config_bmc( &self, ) -> Result<Option<AmiConfigBmc<B>>, Error<B>>
Get AMI Manager ConfigBMC OEM extension.
Returns Ok(None) when the manager does not include Oem.Ami or Oem.ConfigBMC.
Errors
Returns an error if retrieving BMC config data fails.