pub struct NvidiaComputerSystem {
pub base: OemObject,
pub ist_mode_enabled: Option<Option<Boolean>>,
pub processor_debug_capabilities: Option<Option<DebugCapabilities>>,
pub dotcak_initialization: Option<Option<DotcakInitializationState>>,
pub cpu_debug_token: Option<NavProperty<NvidiaDebugToken>>,
pub system_config_profile: Option<NavProperty<NvidiaSystemConfigProfile>>,
}Fields
base: OemObjectBase type
ist_mode_enabled: Option<Option<Boolean>>An indication of whether In-Silicon Test (IST) mode is enabled for the GPUs associated with this system.
This property shall indicate whether In-Silicon Test (IST) mode is enabled for the GPUs associated with this system.
processor_debug_capabilities: Option<Option<DebugCapabilities>>Debug capability of the system resource.
This property shall specify the debug capability of the system resource.
dotcak_initialization: Option<Option<DotcakInitializationState>>The current state of CAK initialization process.
This property shall indicate the current state of the device ownership transfer (DOT) CAK initialization process.
cpu_debug_token: Option<NavProperty<NvidiaDebugToken>>A link to the resource which implements the debug token.
This property shall indicate a link to the resource which implement the debug token applicable for the computer system resource. The token can be used to put CPUs belonging to the computer system in debug mode.
system_config_profile: Option<NavProperty<NvidiaSystemConfigProfile>>A link to the resource which implements the system profile.
This property shall indicate a link to the resource which implement the system profile that can set configuration across the bluefield system