pub struct Attributes {
pub dynamic_properties: DynamicProperties<PrimitiveType>,
}Expand description
The list of BIOS attributes and their values as determined by the manufacturer or provider.
This property shall contain the list of BIOS attributes and their values as determined by the
manufacturer or provider. This object shall describe BIOS attribute settings as additional
properties. If the object specifies a BIOS attribute registry, attributes shall be looked up in
that attribute registry by their attribute name. Attributes in this attribute registry with the
AttributeType of Enumeration shall use valid ValueName values in this object, as listed in
that attribute registry.
Fields
dynamic_properties: DynamicProperties<PrimitiveType>Trait Implementations
Sourceimpl Debug for Attributes
impl Debug for Attributes
Sourceimpl<'de> Deserialize<'de> for Attributes
impl<'de> Deserialize<'de> for Attributes
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more