pub struct BootOption {
pub base: Resource,
pub boot_option_reference: Option<String>,
pub display_name: Option<Option<String>>,
pub boot_option_enabled: Option<Option<Boolean>>,
pub uefi_device_path: Option<Option<String>>,
pub alias: Option<Option<BootSource>>,
pub actions: Option<Actions>,
pub related_item: Option<Vec<ReferenceLeaf>>,
}Expand description
The BootOption schema reports information about a single boot option in a system. It represents
the properties of a bootable device available in the system.
This resource shall represent a single boot option within a system.
Fields
base: ResourceBase type
boot_option_reference: Option<String>The unique boot option.
This property shall correspond to the boot option or device. For UEFI systems, this string shall
match the UEFI boot option variable name, such as Boot####. The BootOrder array of a computer
system resource contains this value.
display_name: Option<Option<String>>The user-readable display name of the boot option that appears in the boot order list in the user interface.
This property shall contain a user-readable boot option name, as it should appear in the boot order list in the user interface.
boot_option_enabled: Option<Option<Boolean>>An indication of whether the boot option is enabled. If true, it is enabled. If false, the
boot option that the boot order array on the computer system contains is skipped. In the UEFI
context, this property influences the load option active flag for the boot option.
This property shall indicate whether the boot option is enabled. If true, it is enabled. If
false, the boot option that the boot order array on the computer system contains shall be
skipped. In the UEFI context, this property shall influence the load option active flag for the
boot option.
uefi_device_path: Option<Option<String>>The UEFI device path to access this UEFI boot option.
This property shall contain the UEFI Specification-defined UEFI device path that identifies and locates the device for this boot option.
alias: Option<Option<BootSource>>The alias of this boot source.
This property shall contain the string alias of this boot source that describes the type of boot.
actions: Option<Actions>The available actions for this resource.
This property shall contain the available actions for this resource.