Capacity

Struct Capacity 

pub struct Capacity {
    pub data: Option<CapacityInfo>,
    pub metadata: Option<CapacityInfo>,
    pub snapshot: Option<CapacityInfo>,
    pub is_thin_provisioned: Option<Option<Boolean>>,
}
This is the schema definition for the Capacity of a device. It represents the properties for capacity for any data store.

This composition may be used to represent storage capacity. The sum of the values in Data, Metadata, and Snapshot shall be equal to the total capacity for the data store.

Fields

data: Option<CapacityInfo>

The capacity information relating to the user data.

The value shall be capacity information relating to provisioned user data.

metadata: Option<CapacityInfo>

The capacity information relating to metadata.

The value shall be capacity information relating to provisioned system (non-user accessible) data.

snapshot: Option<CapacityInfo>

The capacity information relating to snapshot or backup data.

The value shall be capacity information relating to provisioned snapshot or backup data.

is_thin_provisioned: Option<Option<Boolean>>

Marks that the capacity is not necessarily fully allocated.

If the value is false, the capacity shall be fully allocated. The default value shall be false.