CapacityInfo

Struct CapacityInfo 

pub struct CapacityInfo {
    pub consumed_bytes: Option<Option<Int64>>,
    pub allocated_bytes: Option<Option<Int64>>,
    pub guaranteed_bytes: Option<Option<Int64>>,
    pub provisioned_bytes: Option<Option<Int64>>,
}
The capacity of specific data type in a data store.

This composition may be used to represent the utilization of storage capacity.

Fields

consumed_bytes: Option<Option<Int64>>

The number of bytes consumed in this data store for this data type.

The value shall be the number of logical bytes currently consumed in this data store for this data type.

allocated_bytes: Option<Option<Int64>>

The number of bytes currently allocated by the storage system in this data store for this data type.

The value shall be the number of bytes currently allocated by the storage system in this data store for this data type.

guaranteed_bytes: Option<Option<Int64>>

The number of bytes the storage system guarantees can be allocated in this data store for this data type.

The value shall be the number of bytes the storage system guarantees can be allocated in this data store for this data type.

provisioned_bytes: Option<Option<Int64>>

The maximum number of bytes that can be allocated in this data store for this data type.

The value shall be the maximum number of bytes that can be allocated in this data store for this data type.