pub enum ChassisType {
Show 25 variants
Rack,
Blade,
Enclosure,
StandAlone,
RackMount,
Card,
Cartridge,
Row,
Pod,
Expansion,
Sidecar,
Zone,
Sled,
Shelf,
Drawer,
Module,
Component,
IpBasedDrive,
RackGroup,
StorageEnclosure,
ImmersionTank,
HeatExchanger,
PowerStrip,
Other,
UnsupportedValue,
}Variants
Rack
An equipment rack, typically a 19-inch wide freestanding unit.
Blade
An enclosed or semi-enclosed, typically vertically-oriented, system chassis that must be plugged into a multi-system chassis to function normally.
Enclosure
A generic term for a chassis that does not fit any other description.
StandAlone
A single, free-standing system, commonly called a tower or desktop chassis.
RackMount
A single-system chassis designed specifically for mounting in an equipment rack.
Card
A loose device or circuit board intended to be installed in a system or other enclosure.
Cartridge
A small self-contained system intended to be plugged into a multi-system chassis.
Row
A collection of equipment racks.
Pod
A collection of equipment racks in a large, likely transportable, container.
Expansion
A chassis that expands the capabilities or capacity of another chassis.
Sidecar
A chassis that mates mechanically with another chassis to expand its capabilities or capacity.
Zone
A logical division or portion of a physical chassis that contains multiple devices or systems that cannot be physically separated.
Sled
An enclosed or semi-enclosed, system chassis that must be plugged into a multi-system chassis to function normally similar to a blade type chassis.
Shelf
An enclosed or semi-enclosed, typically horizontally-oriented, system chassis that must be plugged into a multi-system chassis to function normally.
Drawer
An enclosed or semi-enclosed, typically horizontally-oriented, system chassis that can be slid into a multi-system chassis.
Module
A small, typically removable, chassis or card that contains devices for a particular subsystem or function.
Component
A small chassis, card, or device that contains devices for a particular subsystem or function.
IpBasedDrive
A chassis in a drive form factor with IP-based network connections.
RackGroup
A group of racks that form a single entity or share infrastructure.
StorageEnclosure
A chassis that encloses storage.
ImmersionTank
An immersion cooling tank.
HeatExchanger
A heat exchanger.
PowerStrip
A power strip, typically placed in the zero-U space of a rack.
Other
A chassis that does not fit any of these definitions.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.