pub enum LastResetCauses {
PowerButtonPress,
ManagementCommand,
PowerRestorePolicy,
RtcWakeup,
WatchdogExpiration,
OsSoftRestart,
SystemCrash,
ThermalEvent,
PowerEvent,
Unknown,
UnsupportedValue,
}Variants
PowerButtonPress
System start or restart via a power button press.
This value shall indicate the system start or restart was due to a power button press.
ManagementCommand
System start or restart via an external command to the management controller or BMC.
This value shall indicate the system start or restart was due to an external command to the
management controller or BMC. Examples include the Redfish Reset action for the ComputerSystem
resource or the IPMI ‘Chassis Control’ command.
PowerRestorePolicy
System start or restart due to the power restore policy.
This value shall indicate the system automatically powered-up on AC being applied due the
PowerRestorePolicy property containing AlwaysOn or LastState.
RtcWakeup
System power-up via an RTC (system real time clock) wakeup.
This value shall indicate the system powered-up via an RTC (system real time clock) wakeup.
WatchdogExpiration
System start or restart caused by a watchdog expiration.
This value shall indicate the system start or restart was caused by a watchdog expiration.
OsSoftRestart
System start or restart via an OS soft restart.
This value shall indicate the system start or restart was due to an OS soft restart. Examples include ‘CTRL-ALT-DEL’, ‘init 6’, or ‘reboot’.
SystemCrash
System start or restart caused by a system crash.
This value shall indicate the system start or restart was caused by a system crash. Examples include an OS panic, hardware fault, or firmware fault.
ThermalEvent
System start or restart caused by a thermal event triggering a system shutdown.
This value shall indicate the system start or restart was caused by a thermal event triggering a system shutdown.
PowerEvent
System start or restart caused by a power event triggering a system shutdown.
This value shall indicate the system start or restart was caused by a power event triggering a system shutdown.
Unknown
System start or restart detected, but the cause is unknown.
This value shall indicate the system start or restart cause is unknown.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.