PowerMode

Enum PowerMode 

pub enum PowerMode {
    MaximumPerformance,
    BalancedPerformance,
    PowerSaving,
    Static,
    OsControlled,
    Oem,
    EfficiencyFavorPower,
    EfficiencyFavorPerformance,
    UnsupportedValue,
}

Variants



MaximumPerformance

The system performs at the highest speeds possible.

This value shall indicate the system performs at the highest speeds possible. This mode should be used when performance is the top priority.



BalancedPerformance

The system performs at the highest speeds while utilization is high and performs at reduced speeds when the utilization is low.

This value shall indicate the system performs at the highest speeds possible when the utilization is high and performs at reduced speeds when the utilization is low to save power. This mode is a compromise between MaximumPerformance and PowerSaving.



PowerSaving

The system performs at reduced speeds to save power.

This value shall indicate the system performs at reduced speeds to save power. This mode should be used when power saving is the top priority.



Static

The system power mode is static.

This value shall indicate the system performs at a static base speed.



OsControlled

The system power mode is controlled by the operating system.

This value shall indicate the system performs at an operating system-controlled power mode.



Oem

The system power mode is OEM-defined.

This value shall indicate the system performs at an OEM-defined power mode.



EfficiencyFavorPower

The system performs at reduced speeds at all utilizations to save power at the cost of performance. This mode differs from PowerSaving in that more performance is retained and less power is saved. This mode differs from EfficiencyFavorPerformance in that less performance is retained but more power is saved.

This value shall indicate the system performs at reduced speeds at all utilizations to save power at the cost of performance. This mode differs from PowerSaving in that more performance is retained and less power is saved. This mode differs from EfficiencyFavorPerformance in that less performance is retained but more power is saved. This mode differs from ‘BalancedPerformance’ in that power saving occurs at all utilizations.



EfficiencyFavorPerformance

The system performs at reduced speeds at all utilizations to save power while attempting to maintain performance. This mode differs from EfficiencyFavorPower in that more performance is retained but less power is saved.

This value shall indicate the system performs at reduced speeds at all utilizations to save power while attempting to maintain performance. This mode differs from EfficiencyFavorPower in that more performance is retained but less power is saved. This mode differs from ‘MaximumPerformance’ in that power is saved at the cost of some performance. This mode differs from ‘BalancedPerformance’ in that power saving occurs at all utilizations.



UnsupportedValue

Fallback value for values that are not supported by current version of Redfish schema.