pub struct Actions {
pub oem: Option<OemActions>,
pub add_resource_block: Option<Action<ComputerSystemAddResourceBlockAction, ()>>,
pub decommission: Option<Action<ComputerSystemDecommissionAction, ()>>,
pub export_configuration: Option<Action<ComputerSystemExportConfigurationAction, ()>>,
pub remove_resource_block: Option<Action<ComputerSystemRemoveResourceBlockAction, ()>>,
pub reset: Option<Action<ComputerSystemResetAction, ()>>,
pub set_default_boot_order: Option<Action<ComputerSystemSetDefaultBootOrderAction, ()>>,
}Expand description
The available actions for this resource.
This type shall contain the available actions for this resource.
Fields
oem: Option<OemActions>The available OEM-specific actions for this resource.
This property shall contain the available OEM-specific actions for this resource.
add_resource_block: Option<Action<ComputerSystemAddResourceBlockAction, ()>>decommission: Option<Action<ComputerSystemDecommissionAction, ()>>export_configuration: Option<Action<ComputerSystemExportConfigurationAction, ()>>remove_resource_block: Option<Action<ComputerSystemRemoveResourceBlockAction, ()>>reset: Option<Action<ComputerSystemResetAction, ()>>set_default_boot_order: Option<Action<ComputerSystemSetDefaultBootOrderAction, ()>>Implementations
Sourceimpl Actions
impl Actions
Sourcepub async fn add_resource_block<B: Bmc>(
&self,
bmc: &B,
resource_block: Option<Reference>,
resource_block_etag: Option<String>,
computer_system_etag: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn add_resource_block<B: Bmc>(
&self,
bmc: &B,
resource_block: Option<Reference>,
resource_block_etag: Option<String>,
computer_system_etag: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
This action adds a resource block to a system.
This action shall add a resource block to a system.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn decommission<B: Bmc>(
&self,
bmc: &B,
t: &ComputerSystemDecommissionAction,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn decommission<B: Bmc>(
&self,
bmc: &B,
t: &ComputerSystemDecommissionAction,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
This action decommissions a system.
This action shall remove all specified data from a system in preparation to decommission the system.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn export_configuration<B: Bmc>(
&self,
bmc: &B,
t: &ComputerSystemExportConfigurationAction,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn export_configuration<B: Bmc>(
&self,
bmc: &B,
t: &ComputerSystemExportConfigurationAction,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
This action exports the configuration of a system in a vendor-specific format.
This action shall export the specified configuration of a system in a vendor-specific format. Upon
successful completion of the action and any asynchronous processing, the Location header in the
response shall contain a URI to a file that contains the configuration data.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn remove_resource_block<B: Bmc>(
&self,
bmc: &B,
resource_block: Option<Reference>,
resource_block_etag: Option<String>,
computer_system_etag: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn remove_resource_block<B: Bmc>(
&self,
bmc: &B,
resource_block: Option<Reference>,
resource_block_etag: Option<String>,
computer_system_etag: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
This action removes a resource block from a system.
This action shall remove a resource block from a system.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn reset<B: Bmc>(
&self,
bmc: &B,
reset_type: Option<ResetType>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn reset<B: Bmc>(
&self,
bmc: &B,
reset_type: Option<ResetType>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
This action resets the system.
This action shall reset the system represented by the resource. For systems that implement ACPI
Power Button functionality, the PushPowerButton value shall perform or emulate an ACPI Power
Button Push, and the ForceOff value shall perform an ACPI Power Button Override, commonly known
as a four-second hold of the power button.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn set_default_boot_order<B: Bmc>(
&self,
bmc: &B,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn set_default_boot_order<B: Bmc>(
&self,
bmc: &B,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
This action sets the BootOrder property to the default settings.
This action shall set the BootOrder array to the default settings.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.