pub struct BootProgress {
pub last_state: Option<Option<BootProgressTypes>>,
pub last_state_time: Option<Option<DateTimeOffset>>,
pub oem_last_state: Option<Option<String>>,
pub oem: Option<Oem>,
pub last_boot_time_seconds: Option<Option<Decimal>>,
}Fields
last_state: Option<Option<BootProgressTypes>>The last boot progress state.
This property shall contain the last boot progress state.
last_state_time: Option<Option<DateTimeOffset>>The date and time when the last boot state was updated.
This property shall contain the date and time when the last boot state was updated.
oem_last_state: Option<Option<String>>The OEM-specific last state, if the LastState type is OEM.
This property shall represent the OEM-specific LastState of the BootProgress. This property
shall only be present if LastState is OEM.
oem: Option<Oem>The OEM extension property.
This property shall contain the OEM extensions. All values for properties contained in this object shall conform to the Redfish Specification-described requirements.
last_boot_time_seconds: Option<Option<Decimal>>The number of seconds the system spent booting to the operating system during the last boot.
This property shall contain the number of seconds that elapsed between system reset or power on and
LastState transitioning to OSRunning. If LastState contains OSRunning, this property shall
contain the most recent boot time. For other values of LastState, this property shall contain
the boot time for the previous boot.