pub struct ComputerSystemAddResourceBlockAction {
pub resource_block: Option<Reference>,
pub resource_block_etag: Option<String>,
pub computer_system_etag: Option<String>,
}Expand description
This action adds a resource block to a system.
This action shall add a resource block to a system.
Fields
resource_block: Option<Reference>The resource block to add to the system.
This parameter shall contain a link to the specified resource block to add to the system.
resource_block_etag: Option<String>The current ETag of the resource block to add to the system.
This parameter shall contain the current ETag of the resource block to add to the system. If the
client-provided ETag does not match the current ETag of the resource block that the ResourceBlock
parameter specifies, the service shall return the HTTP 428 Precondition Required status code to
reject the request.
computer_system_etag: Option<String>The current ETag of the system.
This parameter shall contain the current ETag of the system. If the client-provided ETag does not
match the current ETag of the system, the service shall return the HTTP 428 Precondition Required
status code to reject the request.