pub struct IpmiHostInterface {
pub service_enabled: Option<Boolean>,
}Expand description
The information about the in-band IPMI service for this system.
This type shall describe the in-band IPMI service for a computer system.
Fields
service_enabled: Option<Boolean>An indication of whether the service is enabled for this system.
This property shall indicate whether the protocol for the service is enabled.