pub struct ProcessorSummary {
pub count: Option<Option<Int64>>,
pub model: Option<Option<String>>,
pub status: Option<Status>,
pub logical_processor_count: Option<Option<Int64>>,
pub core_count: Option<Option<Int64>>,
pub threading_enabled: Option<Boolean>,
pub metrics: Option<NavProperty<ProcessorMetrics>>,
}Fields
count: Option<Option<Int64>>The number of physical processors in the system.
This property shall contain the total number of physical central processors in the system.
model: Option<Option<String>>The processor model for the primary or majority of processors in this system.
This property shall contain the processor model for the central processors in the system, per the description in the Processor Information - Processor Family section of the SMBIOS Specification DSP0134 2.8 or later.
status: Option<Status>The status and health of the resource and its subordinate or dependent resources.
This property shall contain any status or health properties of the resource.
logical_processor_count: Option<Option<Int64>>The number of logical processors in the system.
This property shall contain the total number of logical central processors in the system.
core_count: Option<Option<Int64>>The number of processor cores in the system.
This property shall contain the total number of central processor cores in the system.
threading_enabled: Option<Boolean>An indication of whether threading is enabled on all processors in this system.
The value of this property shall indicate that all Processor resources in this system where the
ProcessorType property contains CPU have multiple threading support enabled.
metrics: Option<NavProperty<ProcessorMetrics>>The link to the metrics associated with all processors in this system.
This property shall contain a link to the metrics associated with all processors in this system.