pub struct WatchdogTimer {
pub function_enabled: Option<Boolean>,
pub warning_action: Option<Option<WatchdogWarningActions>>,
pub timeout_action: Option<WatchdogTimeoutActions>,
pub status: Option<Status>,
pub oem: Option<Oem>,
}Expand description
This type describes the host watchdog timer functionality for this system.
This type shall contain properties that describe the host watchdog timer functionality for this system.
Fields
function_enabled: Option<Boolean>An indication of whether a user has enabled the host watchdog timer functionality. This property indicates only that a user has enabled the timer. To activate the timer, installation of additional host-based software is necessary; an update to this property does not initiate the timer.
This property shall indicate whether a user has enabled the host watchdog timer functionality. This property indicates only that a user has enabled the timer. To activate the timer, installation of additional host-based software is necessary; an update to this property does not initiate the timer.
warning_action: Option<Option<WatchdogWarningActions>>The action to perform when the watchdog timer is close to reaching its timeout value. This action typically occurs from three to ten seconds before to the timeout value, but the exact timing is dependent on the implementation.
This property shall contain the action to perform before the watchdog timer expires. This action typically occurs from three to ten seconds before to the timeout value, but the exact timing is dependent on the implementation.
timeout_action: Option<WatchdogTimeoutActions>The action to perform when the watchdog timer reaches its timeout value.
This property shall contain the action to perform when the watchdog timer reaches its timeout value.
status: Option<Status>The status and health of the resource and its subordinate or dependent resources.
This property shall contain any status or health properties of the resource.
oem: Option<Oem>The OEM extension property.
This property shall contain the OEM extensions. All values for properties contained in this object shall conform to the Redfish Specification-described requirements.