pub struct ControlExcerptSingle {
pub data_source_uri: Option<Option<String>>,
pub control_mode: Option<Option<ControlMode>>,
pub set_point: Option<Option<Decimal>>,
pub allowable_max: Option<Option<Decimal>>,
pub allowable_min: Option<Option<Decimal>>,
pub reading: Option<Option<Decimal>>,
pub default_set_point: Option<Option<Decimal>>,
}Fields
data_source_uri: Option<Option<String>>The link to the resource that provides the data for this control.
This property shall contain a URI to the resource that provides the source of the excerpt contained within this copy. If no source resource is implemented, meaning the excerpt represents the only available data, this property shall not be present.
control_mode: Option<Option<ControlMode>>The current operating mode of the control.
This property shall contain the operating mode of the control.
set_point: Option<Option<Decimal>>The desired set point of the control.
This property shall contain the desired set point control value. The units shall follow the value
of SetPointUnits. If the DefaultSetPoint property is not supported and if a user-defined set
point is not configured, the property may contain null in responses.
allowable_max: Option<Option<Decimal>>The maximum possible setting for this control.
This property shall indicate the maximum possible value of the SetPoint or SettingMax
properties for this control. Services shall not accept values for SetPoint or SettingMax above
this value.
allowable_min: Option<Option<Decimal>>The minimum possible setting for this control.
This property shall indicate the minimum possible value of the SetPoint or SettingMin
properties for this control. Services shall not accept values for SetPoint or SettingMin below
this value.
reading: Option<Option<Decimal>>The reading of the sensor associated with this control.
This property shall contain the value of the Reading property of the Sensor resource directly
associated with this control. This property shall not be present if multiple sensors are
associated with a single control.
default_set_point: Option<Option<Decimal>>The default set point of the control.
This property shall contain the default set point control value. The units shall follow the value
of SetPointUnits. Services apply this value to the SetPoint property under certain conditions,
such as a reset of the manager or a ResetToDefaults action.