pub enum RoutingScope {
External,
HostOnly,
Internal,
Limited,
UnsupportedValue,
}Variants
External
Externally accessible.
This value shall indicate this interface is externally accessible as if it were physically on the same network as the hosting system.
HostOnly
Only accessible to a dedicated interface on the host.
This value shall indicate this interface is only accessible to a dedicated interface on the hosting system.
Internal
Only accessible to internal networking on the host, such as when virtual machines or containers are allowed to communicate with each other on the same host system as well as a dedicated interface on the hosting system.
This value shall indicate this interface is only accessible to internal networking on the host, such as when virtual machines or containers are allowed to communicate with each other on the same host system as well as a dedicated interface on the hosting system.
Limited
Accessible through IP translation provided by the hosting system.
This value shall indicate this interface is accessible through IP translation provided by the hosting system, such as a NAT (network address translation).
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.