pub enum SmtpAuthenticationMethods {
None,
AutoDetect,
Plain,
Login,
CramMd5,
UnsupportedValue,
}Variants
None
No authentication.
This value shall indicate authentication is not required.
AutoDetect
Auto-detect.
This value shall indicate authentication is auto-detected.
Plain
PLAIN authentication.
This value shall indicate authentication conforms to the RFC4954-defined AUTH PLAIN mechanism.
Login
LOGIN authentication.
This value shall indicate authentication conforms to the RFC4954-defined AUTH LOGIN mechanism.
CramMd5
CRAM-MD5 authentication.
This value shall indicate authentication conforms to the RFC4954-defined AUTH CRAM-MD5 mechanism.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.