pub struct EventService {Show 21 fields
pub base: Resource,
pub service_enabled: Option<Option<Boolean>>,
pub delivery_retry_attempts: Option<Int64>,
pub delivery_retry_interval_seconds: Option<Int64>,
pub event_types_for_subscription: Option<Vec<EventType>>,
pub actions: Option<Actions>,
pub status: Option<Status>,
pub server_sent_event_uri: Option<String>,
pub registry_prefixes: Option<Option<Vec<String>>>,
pub resource_types: Option<Option<Vec<String>>>,
pub subordinate_resources_supported: Option<Option<Boolean>>,
pub event_format_types: Option<Option<Vec<EventFormatType>>>,
pub sse_filter_properties_supported: Option<SseFilterPropertiesSupported>,
pub smtp: Option<Smtp>,
pub include_origin_of_condition_supported: Option<Option<Boolean>>,
pub exclude_registry_prefix: Option<Boolean>,
pub exclude_message_id: Option<Boolean>,
pub severities: Option<Option<Vec<Health>>>,
pub sse_include_origin_of_condition_supported: Option<Option<Boolean>>,
pub origin_resources_supported: Option<Option<Boolean>>,
pub subscriptions: Option<ReferenceLeaf>,
}Expand description
The EventService schema contains properties for managing event subscriptions and generates the
events sent to subscribers. The resource has links to the actual collection of subscriptions,
which are called event destinations.
This resource shall represent an event service for a Redfish implementation.
Fields
base: ResourceBase type
service_enabled: Option<Option<Boolean>>An indication of whether this service is enabled. If false, events are no longer published, new
SSE connections cannot be established, and existing SSE connections are terminated.
This property shall indicate whether this service is enabled. If false, events are no longer
published, new SSE connections cannot be established, and existing SSE connections are terminated.
delivery_retry_attempts: Option<Int64>The number of times that the POST of an event is retried before the subscription terminates or is
suspended. This retry occurs at the service level, which means that the HTTP POST to the event
destination fails with an HTTP 4XX or 5XX status code or an HTTP timeout occurs this many times
before the event destination subscription terminates or is suspended.
This property shall contain the number of times that the POST of an event is retried before the
subscription terminates or is suspended. This retry occurs at the service level, which means that
the HTTP POST to the event destination fails with an HTTP 4XX or 5XX status code or an HTTP
timeout occurs this many times before the event destination subscription terminates or is
suspended. The service shall delete the EventDestination resource to terminate the subscription.
The service shall set the value of the State property within Status of the EventDestination
resource to Disabled for a suspended subscription.
delivery_retry_interval_seconds: Option<Int64>The interval, in seconds, between retry attempts for sending any event.
This property shall contain the interval, in seconds, between the retry attempts for any event sent to the subscription destination.
event_types_for_subscription: Option<Vec<EventType>>The types of events to which a client can subscribe.
This property shall contain the types of events to which a client can subscribe. The semantics associated with the enumeration values are defined in the Redfish Specification.
actions: Option<Actions>The available actions for this resource.
This property shall contain the available actions for this resource.
status: Option<Status>The status and health of the resource and its subordinate or dependent resources.
This property shall contain any status or health properties of the resource.
server_sent_event_uri: Option<String>The link to a URI for receiving Server-Sent Event representations for the events that this service generates.
This property shall contain a URI that specifies an HTML5 Server-Sent Event-conformant endpoint.
registry_prefixes: Option<Option<Vec<String>>>The list of the prefixes of the message registries that can be used for the RegistryPrefixes or
ExcludeRegistryPrefixes properties on a subscription. If this property is absent or contains an
empty array, the service does not support registry prefix-based subscriptions.
This property shall contain the array of the prefixes of the message registries that shall be allowed or excluded for an event subscription.
resource_types: Option<Option<Vec<String>>>The list of @odata.type values, or schema names, that can be specified in the ResourceTypes
array in a subscription. If this property is absent or contains an empty array, the service does
not support resource type-based subscriptions.
This property shall specify an array of the valid @odata.type values that can be used for an
event subscription.
subordinate_resources_supported: Option<Option<Boolean>>An indication of whether the service supports the SubordinateResources property on both event
subscriptions and generated events.
This property shall indicate whether the service supports the SubordinateResources property on
both event subscriptions and generated events.
event_format_types: Option<Option<Vec<EventFormatType>>>The content types of the message that this service can send to the event destination.
This property shall contain the content types of the message that this service can send to the
event destination. If this property is not present, the EventFormatType shall be assumed to be
Event.
sse_filter_properties_supported: Option<SseFilterPropertiesSupported>The set of properties that are supported in the $filter query parameter for the
ServerSentEventUri.
This property shall contain the properties that are supported in the $filter query parameter for
the URI indicated by the ServerSentEventUri property, as described by the Redfish Specification.
smtp: Option<Smtp>Settings for SMTP event delivery.
This property shall contain settings for SMTP event delivery.
include_origin_of_condition_supported: Option<Option<Boolean>>An indication of whether the service supports including the resource payload of the origin of condition in the event payload.
This property shall indicate whether the service supports including the resource payload of the
origin of condition in the event payload. If true, event subscriptions are allowed to specify
the IncludeOriginOfCondition property.
exclude_registry_prefix: Option<Boolean>An indication of whether the service supports filtering by the ExcludeRegistryPrefixes property.
This property shall indicate whether this service supports filtering by the
ExcludeRegistryPrefixes property.
exclude_message_id: Option<Boolean>An indication of whether the service supports filtering by the ExcludeMessageIds property.
This property shall indicate whether this service supports filtering by the ExcludeMessageIds
property.
severities: Option<Option<Vec<Health>>>The list of severities that can be specified in the Severities array in a subscription.
This property shall specify an array of the allowable severities that can be used for an event subscription. If this property is absent or contains an empty array, the service does not support severity-based subscriptions.
sse_include_origin_of_condition_supported: Option<Option<Boolean>>An indication of whether the service supports the includeoriginofcondition query parameter for
the ServerSentEventUri.
This property shall indicate whether the service supports the includeoriginofcondition query
parameter for the ServerSentEventUri, as described by the Redfish Specification.
origin_resources_supported: Option<Option<Boolean>>An indication of whether the service supports filtering by the OriginResources property.
This property shall indicate whether this service supports filtering by the OriginResources
property.
subscriptions: Option<ReferenceLeaf>Trait Implementations
Sourceimpl Debug for EventService
impl Debug for EventService
Sourceimpl<'de> Deserialize<'de> for EventService
impl<'de> Deserialize<'de> for EventService
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl EntityTypeRef for EventService
impl EntityTypeRef for EventService
Sourceimpl Expandable for EventService
impl Expandable for EventService
Sourceimpl RedfishSettings<EventService> for EventService
impl RedfishSettings<EventService> for EventService
Sourcefn settings_object(&self) -> Option<NavProperty<Self>>
fn settings_object(&self) -> Option<NavProperty<Self>>
impl Send for EventService
SAFETY: All generated data types are Send
impl Sync for EventService
SAFETY: All generated data types are Sync