HostInterface

Struct HostInterface 

pub struct HostInterface {
Show 17 fields pub base: Resource, pub host_interface_type: Option<Option<HostInterfaceType>>, pub status: Option<Status>, pub interface_enabled: Option<Option<Boolean>>, pub externally_accessible: Option<Option<Boolean>>, pub authentication_modes: Option<Vec<AuthenticationMode>>, pub kernel_auth_role_id: Option<String>, pub kernel_auth_enabled: Option<Option<Boolean>>, pub firmware_auth_role_id: Option<String>, pub firmware_auth_enabled: Option<Option<Boolean>>, pub links: Option<Links>, pub actions: Option<Actions>, pub auth_none_role_id: Option<String>, pub credential_bootstrapping: Option<CredentialBootstrapping>, pub host_ethernet_interfaces: Option<NavProperty<EthernetInterfaceCollection>>, pub manager_ethernet_interface: Option<NavProperty<EthernetInterface>>, pub network_protocol: Option<ReferenceLeaf>,
}
The HostInterface schema contains properties associated with a Redfish host interface. A Redfish host interface is a connection between host software and a Redfish service.

This resource shall represent a Redfish host interface as part of the Redfish Specification.

Fields

base: Resource

Base type

host_interface_type: Option<Option<HostInterfaceType>>

The host interface type for this interface.

This property shall contain the host interface type for this interface.

status: Option<Status>

The status and health of the resource and its subordinate or dependent resources.

This property shall contain any status or health properties of the resource.

interface_enabled: Option<Option<Boolean>>

An indication of whether this interface is enabled.

This property shall indicate whether this interface is enabled. Modifying this property may modify the InterfaceEnabled property in the EthernetInterface resource for this host interface.

externally_accessible: Option<Option<Boolean>>

An indication of whether external entities can access this interface. External entities are non-host entities. For example, if the host and manager are connected through a switch and the switch also exposes an external port on the system, external clients can also use the interface, and this property value is true.

This property shall indicate whether external entities can access this interface. External entities are non-host entities. For example, if the host and manager are connected through a switch and the switch also exposes an external port on the system, external clients can also use the interface, and this property value is true.

authentication_modes: Option<Vec<AuthenticationMode>>

The authentication modes available on this interface.

This property shall contain an array consisting of the authentication modes allowed on this interface.

kernel_auth_role_id: Option<String>

The Redfish role used for kernel authentication on this interface.

This property shall contain the Id property of the Role resource that is configured for kernel authentication on this interface.

kernel_auth_enabled: Option<Option<Boolean>>

An indication of whether this kernel authentication is enabled for this interface.

This property shall indicate whether kernel authentication is enabled for this interface.

firmware_auth_role_id: Option<String>

The Redfish role used for firmware authentication on this interface.

This property shall contain the Id property of the Role resource that is configured for firmware authentication on this interface.

firmware_auth_enabled: Option<Option<Boolean>>

An indication of whether this firmware authentication is enabled for this interface.

This property shall indicate whether firmware authentication is enabled for this interface.

links: Option<Links>

The links to other resources that are related to this resource.

This property shall contain links to resources that are related to but are not contained by, or subordinate to, this resource.

actions: Option<Actions>

The available actions for this resource.

This property shall contain the available actions for this resource.

auth_none_role_id: Option<String>

The role when no authentication on this interface is used.

This property shall contain the Id property of the Role resource that is used when no authentication on this interface is performed. This property shall be absent if AuthNone is not supported by the service for the AuthenticationModes property.

credential_bootstrapping: Option<CredentialBootstrapping>

The credential bootstrapping settings for this interface.

This property shall contain settings for the Redfish Host Interface Specification-defined ‘credential bootstrapping via IPMI commands’ feature for this interface. This property shall be absent if credential bootstrapping is not supported by the service.

host_ethernet_interfaces: Option<NavProperty<EthernetInterfaceCollection>>

A link to the collection of network interface controllers or cards (NICs) that a computer system uses to communicate with this host interface.

This property shall contain a link to a resource collection of type EthernetInterfaceCollection that computer systems use as the host interface to this manager.

manager_ethernet_interface: Option<NavProperty<EthernetInterface>>

A link to a single network interface controllers or cards (NIC) that this manager uses for network communication with this host interface.

This property shall contain a link to a resource of type EthernetInterface that represents the network interface that this manager uses as the host interface.

network_protocol: Option<ReferenceLeaf>