LogEntry

Struct LogEntry 

pub struct LogEntry {
Show 45 fields pub base: Resource, pub severity: Option<Option<EventSeverity>>, pub created: Option<DateTimeOffset>, pub entry_type: LogEntryType, pub oem_record_format: Option<Option<String>>, pub entry_code: Option<Option<LogEntryCode>>, pub sensor_type: Option<Option<SensorType>>, pub sensor_number: Option<Option<Int64>>, pub message: Option<Option<String>>, pub message_id: Option<String>, pub message_args: Option<Vec<String>>, pub links: Option<Links>, pub event_type: Option<EventType>, pub event_id: Option<String>, pub event_timestamp: Option<DateTimeOffset>, pub actions: Option<Actions>, pub oem_log_entry_code: Option<Option<String>>, pub oem_sensor_type: Option<Option<String>>, pub event_group_id: Option<Option<Int64>>, pub generator_id: Option<Option<String>>, pub modified: Option<DateTimeOffset>, pub additional_data_size_bytes: Option<Option<Int64>>, pub additional_data_uri: Option<Option<String>>, pub diagnostic_data_type: Option<Option<LogDiagnosticDataTypes>>, pub oem_diagnostic_data_type: Option<Option<String>>, pub resolved: Option<Option<Boolean>>, pub service_provider_notified: Option<Option<Boolean>>, pub resolution: Option<String>, pub originator: Option<String>, pub originator_type: Option<OriginatorTypes>, pub specific_event_exists_in_group: Option<Boolean>, pub overflow_error_count: Option<Int64>, pub first_overflow_timestamp: Option<DateTimeOffset>, pub last_overflow_timestamp: Option<DateTimeOffset>, pub cxl_entry_type: Option<CxlEntryType>, pub persistency: Option<Boolean>, pub cper: Option<Cper>, pub diagnostic_data: Option<Option<String>>, pub resolution_steps: Option<Vec<ResolutionStep>>, pub username: Option<Option<String>>, pub user_authentication_source: Option<Option<String>>, pub serial_number: Option<Option<String>>, pub part_number: Option<Option<String>>, pub origin_of_condition_unavailable: Option<Option<Boolean>>, pub origin_address: Option<Option<String>>,
}
The LogEntry schema defines the record format for a log. It is designed for Redfish event logs, which utilize messages defined in a Message Registry and referenced by a MessageId. For standard message definitions, see DSP2065. Other log formats, including OEM-specific definitions and the IPMI System Event Log (SEL) are also supported. The EntryType field indicates the type of log and the resource includes several additional properties dependent on the EntryType.

This resource shall represent the log format for log services in a Redfish implementation.

Fields

base: Resource

Base type

severity: Option<Option<EventSeverity>>

The severity of the log entry.

This property shall contain the severity of the condition that created the log entry. If EntryType contains Event, services can replace the value defined in the message registry with a value more applicable to the implementation.

created: Option<DateTimeOffset>

The date and time when the log entry was created.

This property shall contain the date and time when the log entry was created.

entry_type: LogEntryType

The type of log entry.

This property shall represent the type of log entry. If the resource represents an IPMI SEL entry, the value shall contain SEL. If the resource represents a Redfish event log entry, the value shall contain Event. If the resource represents a CXL event record, the value shall contain CXL. If the resource represents an OEM log entry format, the value shall contain Oem.

oem_record_format: Option<Option<String>>

The OEM-specific format of the entry. If the entry type is Oem, this property contains more information about the record format from the OEM.

This property shall represent the OEM-specific format of the entry. This property shall be required if the EntryType value is Oem.

entry_code: Option<Option<LogEntryCode>>

The entry code for the log entry if the entry type is SEL.

This property shall contain the entry code for the log entry if the EntryType is SEL. Tables 42-1 and 42-2 of the IPMI Specification v2.0 revision 1.1 describe these enumerations.

sensor_type: Option<Option<SensorType>>

The sensor type to which the log entry pertains if the entry type is SEL.

This property shall contain the sensor type to which the log entry pertains if the entry type is SEL. Table 42-3, Sensor Type Codes, in the IPMI Specification v2.0 revision 1.1 describes these enumerations.

sensor_number: Option<Option<Int64>>

The IPMI-defined sensor number.

This property shall contain the IPMI sensor number if the value of the EntryType property is SEL. This property should not appear in the resource for other values of EntryType.

message: Option<Option<String>>

The message of the log entry. This property decodes from the entry type. If the entry type is Event, this property contains a message. If the entry type is SEL, this property contains an SEL-specific message. If the entry type is CXL, this property contains a CXL event record. Otherwise, this property contains an OEM-specific log entry. In most cases, this property contains the actual log entry.

This property shall contain the message of the log entry. This property decodes from the entry type. If the entry type is Event, this property contains a message. If the entry type is SEL, this property contains an SEL-specific message, following the format specified in Table 32-1, SEL Event Records, in the IPMI Specification v2.0 revision 1.1. If the entry type is CXL, this property contains the CXL event record as a string of hex bytes in the pattern ^([a-fA-F0-9]{2})+$. Otherwise, this property contains an OEM-specific log entry. In most cases, this property contains the actual log entry.

message_id: Option<String>

The MessageId, event data, or OEM-specific information. This property decodes from the entry type. If the entry type is Event, this property contains a Redfish Specification-defined MessageId. If the entry type is SEL, this property contains the Event Data. Otherwise, this property contains OEM-specific information.

This property shall contain the MessageId, event data, or OEM-specific information. This property decodes from the entry type. If the entry type is Event, this property contains a Redfish Specification-defined MessageId property of the event. If the entry type is SEL, the format should follow the pattern ^0[xX](([a-fA-F]|[0-9]){2}){4}$, which results in a string in the form ‘0xNNaabbcc’, where ‘NN’ is the EventDir/EventType byte, ‘aa’ is the Event Data 1 byte, ‘bb’ is Event Data 2 byte, ‘cc’ is Event Data 3 byte, corresponding with bytes 13-16 in the IPMI SEL Event Record. If the entry type is CXL, this property shall not be present. Otherwise, this property contains OEM-specific information.

message_args: Option<Vec<String>>

An array of message arguments that are substituted for the arguments in the message when looked up in the message registry.

This property shall contain an array of message arguments that are substituted for the arguments in the message when looked up in the message registry. It has the same semantics as the MessageArgs property in the Redfish MessageRegistry schema. If the corresponding ParamType value contains number, the service shall convert the number to a string representation of the number.

links: Option<Links>

The links to other resources that are related to this resource.

This property shall contain links to resources that are related to but are not contained by, or subordinate to, this resource.

event_type: Option<EventType>

The type of event recorded in this log.

If present, this LogEntry records an event and the value shall indicate the type of event.

event_id: Option<String>

The unique instance identifier for an event.

If present, this LogEntry records an Event and the value shall indicate a unique identifier for the event, the format of which is implementation dependent.

event_timestamp: Option<DateTimeOffset>

The date and time when the event occurred.

If present, this LogEntry records an event and the value shall contain the date and time when the event occurred.

actions: Option<Actions>

The available actions for this resource.

This property shall contain the available actions for this resource.

oem_log_entry_code: Option<Option<String>>

The OEM-specific entry code, if the LogEntryCode type is OEM.

This property shall represent the OEM-specific Log Entry Code type of the Entry. This property shall only be present if EntryType is SEL and LogEntryCode is OEM.

oem_sensor_type: Option<Option<String>>

The OEM-specific sensor type if the sensor type is OEM.

This property shall represent the OEM-specific sensor type of the entry. This property shall only be used if EntryType is SEL and SensorType is OEM.

event_group_id: Option<Option<Int64>>

An identifier that correlates events with the same cause.

This property shall indicate that events are related and shall have the same value in the case where multiple event messages are produced by the same root cause. Implementations shall use separate values for events with separate root cause. There shall not be ordering of events implied by this property’s value.

generator_id: Option<Option<String>>

An identifier of the device that has generated the IPMI SEL Event Record.

If EntryType is SEL, this property shall contain the ‘Generator ID’ field of the IPMI SEL Event Record. If EntryType is not SEL, this property should not be present.

modified: Option<DateTimeOffset>

The date and time when the log entry was last modified.

This property shall contain the date and time when the log entry was last modified. This property shall not appear if the log entry has not been modified since it was created.

additional_data_size_bytes: Option<Option<Int64>>

The size of the additional data for this log entry.

This property shall contain the size of the additional data retrieved from the URI specified by the AdditionalDataURI property for this log entry.

additional_data_uri: Option<Option<String>>

The URI at which to access the additional data for this log entry, such as diagnostic data, image captures, or other files.

This property shall contain the URI at which to access the additional data for this log entry, using the Redfish protocol and authentication methods. If both DiagnosticData and AdditionalDataURI are present, DiagnosticData shall contain a Base64-encoded string, with padding characters, of the data retrieved from the URI specified by the AdditionalDataURI property.

diagnostic_data_type: Option<Option<LogDiagnosticDataTypes>>

The type of data available in the DiagnosticData property or retrieved from the URI specified by the AdditionalDataURI property.

This property shall contain the type of data available in the DiagnosticData property or retrieved from the URI specified by the AdditionalDataURI property. The OriginOfCondition property, if present, shall contain a link to the resource that represents the device from which the diagnostic data was collected.

oem_diagnostic_data_type: Option<Option<String>>

The OEM-defined type of data available in the DiagnosticData property or retrieved from the URI specified by the AdditionalDataURI property.

This property shall contain the OEM-defined type of data available in the DiagnosticData property or retrieved from the URI specified by the AdditionalDataURI property. This property shall be present if DiagnosticDataType is OEM.

resolved: Option<Option<Boolean>>

Indicates if the cause of the log entry has been resolved or repaired.

This property shall contain an indication if the cause of the log entry has been resolved or repaired. The value true shall indicate if the cause of the log entry has been resolved or repaired. This property shall contain the value false if the log entry is still active. The value false shall be the initial state. Clients should ignore this property if Severity contains OK.

service_provider_notified: Option<Option<Boolean>>

Indicates if the log entry has been sent to the service provider.

This property shall contain an indication if the log entry has been sent to the service provider.

resolution: Option<String>

Used to provide suggestions on how to resolve the situation that caused the log entry.

This property shall contain the resolution of the log entry. Services should replace the resolution defined in the message registry with a more specific resolution in a log entry.

originator: Option<String>

The source of the log entry.

This property shall contain the source of the log entry.

originator_type: Option<OriginatorTypes>

The type of originator data.

This property shall contain the type of originator data.

specific_event_exists_in_group: Option<Boolean>

Indicates this log entry is equivalent to a more specific log entry within the same EventGroupId.

This property shall indicate that this log entry is equivalent to another log entry, with a more specific definition, within the same EventGroupId. For example, the DriveFailed message from the Storage Device Message Registry is more specific than the ResourceStatusChangedCritical message from the Resource Event Message Registry, when both occur with the same EventGroupId. This property shall contain true if a more specific event is available, and shall contain false if no equivalent event exists in the same EventGroupId. If this property is absent, the value shall be assumed to be false.

overflow_error_count: Option<Int64>

The count of overflow errors that occurred after this log entry.

This property shall contain the count of overflow errors that occurred after this log entry. If this log entry is the most recent log entry in the log service, this property shall not be present if no overflow errors occurred after the time of this log entry. If this log entry is not the most recent log entry in the log service, this property shall not be present if no overflow errors occurred between the time of this log entry and the time of the next log entry.

first_overflow_timestamp: Option<DateTimeOffset>

The timestamp of the first overflow captured after this log entry.

This property shall contain the timestamp of the first overflow captured after this log entry. If this log entry is the most recent log entry in the log service, this property shall not be present if no overflow errors occurred after the time of this log entry. If this log entry is not the most recent log entry in the log service, this property shall not be present if no overflow errors occurred between the time of this log entry and the time of the next log entry.

last_overflow_timestamp: Option<DateTimeOffset>

The timestamp of the last overflow captured after this log entry.

This property shall contain the timestamp of the last overflow captured after this log entry. If this log entry is the most recent log entry in the log service, this property shall not be present if no overflow errors occurred after the time of this log entry. If this log entry is not the most recent log entry in the log service, this property shall not be present if no overflow errors occurred between the time of this log entry and the time of the next log entry.

cxl_entry_type: Option<CxlEntryType>

The specific CXL entry type.

This property shall contain the specific CXL entry type. This property shall only be present if EntryType contains CXL.

persistency: Option<Boolean>

Indicates whether the log entry is persistent across a cold reset of the device.

This property shall indicate whether the log entry is persistent across a cold reset of the device.

cper: Option<Cper>

Details for a CPER section or record associated with this log entry.

This property shall contain the details for a CPER section or record that is the source of this log entry.

diagnostic_data: Option<Option<String>>

A Base64-encoded set of diagnostic data associated with this log entry.

This property shall contain a Base64-encoded string, with padding characters, that represents diagnostic data associated with this log entry. The contents shall depend on the value of the DiagnosticDataType property. The length of the value should not exceed 4 KB. Larger diagnostic data payloads should omit this property and use the AdditionalDataURI property to reference the data. If both DiagnosticData and AdditionalDataURI are present, DiagnosticData shall contain the Base64-encoding of the data retrieved from the URI specified by the AdditionalDataURI property.

resolution_steps: Option<Vec<ResolutionStep>>

The list of recommended steps to resolve the cause of the log entry.

This property shall contain an array of recommended steps to resolve the cause of the log entry. This property shall not be present if the Severity property contains OK. A client can stop executing the resolution steps once the Resolved property resource contains true or the Health property in the associated resource referenced by the OriginOfCondition property contains OK.

username: Option<Option<String>>

The username of the account associated with the log entry.

This property shall contain the username of the account associated with the log entry. This should be used for audit logs that result from a user action.

user_authentication_source: Option<Option<String>>

The source of authentication for the username property associated with the log entry.

This property shall contain the URL to the authentication service that is associated with the username property. This should be used for audit logs that result from a user action.

serial_number: Option<Option<String>>

The serial number associated with the source of this log entry.

This property shall contain a manufacturer-allocated number that identifies the source of this log entry.

part_number: Option<Option<String>>

The part number associated with the source of this log entry.

This property shall contain the manufacturer-provided part number for the source of this log entry.

origin_of_condition_unavailable: Option<Option<Boolean>>

Indicates whether the OriginOfCondition link is unavailable, such as after the deletion of the resource.

This property shall indicate whether the OriginOfCondition link is unavailable. If true, services shall not expand the OriginOfCondition link. If this property is not present, the value shall be assumed to be false.

origin_address: Option<Option<String>>

The IP address, with scheme, of the user associated with the log entry.

This property shall contain the IP address, with scheme, of the user associated with the log entry. This should be used for audit logs that result from a user action.