Manager

Struct Manager 

pub struct Manager {
Show 49 fields pub base: Resource, pub manager_type: Option<ManagerType>, pub links: Option<Links>, pub service_entry_point_uuid: Option<Option<Uuid>>, pub uuid: Option<Option<Uuid>>, pub model: Option<Option<String>>, pub date_time: Option<Option<DateTimeOffset>>, pub date_time_local_offset: Option<Option<String>>, pub firmware_version: Option<Option<String>>, pub serial_console: Option<SerialConsole>, pub command_shell: Option<CommandShell>, pub graphical_console: Option<GraphicalConsole>, pub actions: Option<Actions>, pub status: Option<Status>, pub power_state: Option<Option<PowerState>>, pub auto_dst_enabled: Option<Boolean>, pub remote_redfish_service_uri: Option<Option<String>>, pub manufacturer: Option<Option<String>>, pub serial_number: Option<Option<String>>, pub part_number: Option<Option<String>>, pub last_reset_time: Option<DateTimeOffset>, pub time_zone_name: Option<String>, pub location: Option<Location>, pub location_indicator_active: Option<Option<Boolean>>, pub spare_part_number: Option<Option<String>>, pub measurements: Option<Vec<MeasurementBlock>>, pub service_identification: Option<Option<String>>, pub additional_firmware_versions: Option<AdditionalVersions>, pub version: Option<Option<String>>, pub daylight_saving_time: Option<DaylightSavingTime>, pub date_time_source: Option<Option<DateTimeSource>>, pub security_mode: Option<SecurityModeTypes>, pub oem_security_mode: Option<Option<String>>, pub ready_to_remove: Option<Option<Boolean>>, pub service_use_notification: Option<Option<String>>, pub ethernet_interfaces: Option<NavProperty<EthernetInterfaceCollection>>, pub serial_interfaces: Option<ReferenceLeaf>, pub network_protocol: Option<ReferenceLeaf>, pub log_services: Option<NavProperty<LogServiceCollection>>, pub virtual_media: Option<ReferenceLeaf>, pub redundancy: Option<Vec<ReferenceLeaf>>, pub host_interfaces: Option<NavProperty<HostInterfaceCollection>>, pub remote_account_service: Option<NavProperty<AccountService>>, pub usb_ports: Option<ReferenceLeaf>, pub certificates: Option<ReferenceLeaf>, pub manager_diagnostic_data: Option<ReferenceLeaf>, pub dedicated_network_ports: Option<ReferenceLeaf>, pub shared_network_ports: Option<ReferenceLeaf>, pub security_policy: Option<ReferenceLeaf>,
}
In Redfish, a manager is a systems management entity that can implement or provide access to a Redfish service. Examples of managers are BMCs (baseboard management controllers), enclosure managers, management controllers, and other subsystems that are assigned manageability functions. An implementation can have multiple managers, which might be directly accessible through a Redfish-defined interface.

This resource shall represent a management subsystem for a Redfish implementation.

Fields

base: Resource

Base type

manager_type: Option<ManagerType>

The type of manager that this resource represents.

This property shall describe the function of this manager. The ManagementController value shall be used if none of the other enumerations apply.

links: Option<Links>

The links to other resources that are related to this resource.

This property shall contain links to resources that are related to but are not contained by, or subordinate to, this resource.

service_entry_point_uuid: Option<Option<Uuid>>

The UUID of the Redfish service that is hosted by this manager.

This property shall contain the UUID of the Redfish service that is hosted by this manager. Each manager providing an entry point to the same Redfish service shall report the same UUID value, even though the name of the property may imply otherwise. This property shall not be present if this manager does not provide a Redfish service entry point.

uuid: Option<Option<Uuid>>

The UUID for this manager.

This property shall contain the UUID for the manager.

model: Option<Option<String>>

The model information of this manager, as defined by the manufacturer.

This property shall contain the information about how the manufacturer refers to this manager.

date_time: Option<Option<DateTimeOffset>>

The current date and time with UTC offset of the manager.

This property shall contain the current date and time with UTC offset of the manager.

date_time_local_offset: Option<Option<String>>

The time offset from UTC that the DateTime property is in +HH:MM format.

This property shall contain the offset from UTC time that the DateTime property contains. If both DateTime and DateTimeLocalOffset are provided in modification requests, services shall apply DateTimeLocalOffset after DateTime is applied.

firmware_version: Option<Option<String>>

The firmware version of this manager.

This property shall contain the firmware version as defined by the manufacturer for the associated manager.

serial_console: Option<SerialConsole>

The serial console service that this manager provides.

This property shall contain information about the serial console service of this manager.

command_shell: Option<CommandShell>

The manager’s command line user interface or command shell service.

This property shall describe a command line user interface or command shell service provided by this manager. The command shell refers to an interface used to interact with the manager itself, not a dedicated console session redirected from a host operating system. For redirected serial or host operating system consoles, see the SerialConsole property in the ComputerSystem resource.

graphical_console: Option<GraphicalConsole>

The manager’s graphical console service.

This property shall contain the information about the graphical console (KVM-IP) service of this manager. This property should be used to describe a service for the manager’s console or operating system, not a service provided on behalf of a host operating system. Implementations representing host OS consoles, known generally as a KVM-IP feature, should use the GraphicalConsole property in the ComputerSystem resource.

actions: Option<Actions>

The available actions for this resource.

This property shall contain the available actions for this resource.

status: Option<Status>

The status and health of the resource and its subordinate or dependent resources.

This property shall contain any status or health properties of the resource.

power_state: Option<Option<PowerState>>

The current power state of the manager.

This property shall contain the power state of the manager.

auto_dst_enabled: Option<Boolean>

An indication of whether the manager is configured for automatic Daylight Saving Time (DST) adjustment.

This property shall indicate whether the manager is configured for automatic Daylight Saving Time (DST) adjustment.

remote_redfish_service_uri: Option<Option<String>>

The URI of the Redfish service root for the remote manager that this resource represents.

This property shall contain the URI of the Redfish service root for the remote manager that this resource represents. This property shall only be present when providing aggregation of Redfish services.

manufacturer: Option<Option<String>>

The manufacturer of this manager.

This property shall contain the name of the organization responsible for producing the manager. This organization may be the entity from whom the manager is purchased, but this is not necessarily true.

serial_number: Option<Option<String>>

The serial number of the manager.

This property shall contain a manufacturer-allocated number that identifies the manager.

part_number: Option<Option<String>>

The part number of the manager.

This property shall contain a part number assigned by the organization that is responsible for producing or manufacturing the manager.

last_reset_time: Option<DateTimeOffset>

The date and time when the manager was last reset or rebooted.

This property shall contain the date and time when the manager last came out of a reset or was rebooted.

time_zone_name: Option<String>

The time zone of the manager.

This property shall contain the time zone of the manager. The time zone shall be either the ‘Name’ or the ‘Format’ for the zone as defined in the IANA Time Zone Database. The value of this property is used for display purposes, especially to enhance the display of time. A Redfish service may not be able to ensure accuracy and consistency between the DateTimeOffset property and this property. Therefore, to specify the correct time zone offset, see the DateTimeOffset property.

location: Option<Location>

The location of the manager.

This property shall contain the location information of the associated manager.

location_indicator_active: Option<Option<Boolean>>

An indicator allowing an operator to physically locate this resource.

This property shall contain the state of the indicator used to physically identify or locate this resource. A write to this property shall update the value of IndicatorLED in this resource, if supported, to reflect the implementation of the locating function.

spare_part_number: Option<Option<String>>

The spare part number of the manager.

This property shall contain the spare part number of the manager.

measurements: Option<Vec<MeasurementBlock>>

An array of DSP0274-defined measurement blocks.

This property shall contain an array of DSP0274-defined measurement blocks.

service_identification: Option<Option<String>>

A product instance identifier displayed in the Redfish service root.

This property shall contain a vendor-provided or user-provided value that identifies and associates a discovered Redfish service with a particular product instance. If this manager provides the Redfish service, the ServiceIdentification property in the ServiceRoot resource shall contain the value of this property. This property shall only be present if the manager provides the Redfish service. The value of this property is used in conjunction with the Product and Vendor properties in ServiceRoot to match user credentials or other a priori product instance information necessary for initial deployment to the correct, matching Redfish service.

additional_firmware_versions: Option<AdditionalVersions>

The additional firmware versions of the manager.

This property shall contain the additional firmware versions of the manager.

version: Option<Option<String>>

The hardware version of this manager.

This property shall contain the hardware version of this manager as determined by the vendor or supplier.

daylight_saving_time: Option<DaylightSavingTime>

The daylight saving time settings for this manager.

This property shall contain the daylight saving time settings for this manager.

date_time_source: Option<Option<DateTimeSource>>

The source of the date and time of this manager, such as NTP, RTC, or firmware.

This property shall contain the source of the DateTime property of this manager. The service shall update this property if the source changes internally, for example if an NTP server is unavailable and the source falls back to the time stored by the RTC.

security_mode: Option<SecurityModeTypes>

The security compliance mode that the manager is currently configured to enforce.

This property shall contain the security compliance mode that the manager is currently configured to enforce.

oem_security_mode: Option<Option<String>>

The OEM-specific security compliance mode(s) that the manager is currently configured to enforce.

This property shall the OEM-specific security compliance mode(s) that the manager is currently configured to enforce. This property shall only be present if SecurityMode contains OEM.

ready_to_remove: Option<Option<Boolean>>

An indication of whether the manager is prepared by the system for removal.

This property shall indicate whether the manager is ready for removal. Setting the value to true shall cause the service to perform appropriate actions to quiesce the device. A task may spawn while the device is quiescing.

service_use_notification: Option<Option<String>>

The usage notification message displayed in the Redfish service root.

This property shall contain the usage notification message for this manager. If this manager provides the Redfish service, the ServiceUseNotification property in the ServiceRoot resource shall contain the value of this property. This property shall only be present if the manager provides the Redfish service.

ethernet_interfaces: Option<NavProperty<EthernetInterfaceCollection>>

The link to a collection of NICs that this manager uses for network communication.

This property shall contain a link to a resource collection of type EthernetInterfaceCollection.

serial_interfaces: Option<ReferenceLeaf>network_protocol: Option<ReferenceLeaf>log_services: Option<NavProperty<LogServiceCollection>>

The link to a collection of logs that the manager uses.

This property shall contain a link to a resource collection of type LogServiceCollection that this manager uses.

virtual_media: Option<ReferenceLeaf>redundancy: Option<Vec<ReferenceLeaf>>host_interfaces: Option<NavProperty<HostInterfaceCollection>>

The link to a collection of host interfaces that this manager uses for local host communication. Clients can find host interface configuration options and settings in this navigation property.

This property shall contain a link to a resource collection of type HostInterfaceCollection.

remote_account_service: Option<NavProperty<AccountService>>

The link to the account service resource for the remote manager that this resource represents.

This property shall contain a link to the account service resource for the remote manager that this resource represents. This property shall only be present when providing aggregation of a remote manager.

usb_ports: Option<ReferenceLeaf>certificates: Option<ReferenceLeaf>manager_diagnostic_data: Option<ReferenceLeaf>dedicated_network_ports: Option<ReferenceLeaf>shared_network_ports: Option<ReferenceLeaf>security_policy: Option<ReferenceLeaf>