pub struct ManagerService {
pub service_enabled: Option<Boolean>,
pub max_concurrent_sessions: Option<Int64>,
}Expand description
The manager services, such as serial console, command shell, or graphical console service.
Fields
service_enabled: Option<Boolean>An indication of whether the service is enabled for this manager.
This property shall indicate whether the protocol for the service is enabled.
max_concurrent_sessions: Option<Int64>The maximum number of service sessions, regardless of protocol, that this manager can support.
This property shall contain the maximum number of concurrent service sessions that this implementation supports.