pub struct ManagerNetworkProtocol {Show 25 fields
pub base: Resource,
pub host_name: Option<Option<String>>,
pub fqdn: Option<Option<String>>,
pub http: Option<Protocol>,
pub https: Option<Protocol>,
pub snmp: Option<Protocol>,
pub virtual_media: Option<Protocol>,
pub telnet: Option<Protocol>,
pub ssdp: Option<SsdProtocol>,
pub ipmi: Option<Protocol>,
pub ssh: Option<Protocol>,
pub kvmip: Option<Protocol>,
pub status: Option<Status>,
pub dhcp: Option<Protocol>,
pub ntp: Option<NtpProtocol>,
pub actions: Option<Actions>,
pub dhcpv6: Option<Protocol>,
pub rdp: Option<Protocol>,
pub rfb: Option<Protocol>,
pub proxy: Option<ProxyConfiguration>,
pub ftp: Option<Protocol>,
pub sftp: Option<Protocol>,
pub ftps: Option<Protocol>,
pub mdns: Option<Protocol>,
pub modbus: Option<ModbusProtocol>,
}Expand description
The network service settings for the manager.
This resource shall represent the network service settings for the manager.
Fields
base: ResourceBase type
host_name: Option<Option<String>>The DNS host name of this manager, without any domain information.
This property shall contain the host name without any domain information.
fqdn: Option<Option<String>>The fully qualified domain name for the manager obtained by DNS including the host name and top-level domain name.
This property shall contain the fully qualified domain name for the manager.
http: Option<Protocol>The settings for this manager’s HTTP protocol support.
This object shall contain the HTTP protocol settings for the manager. The default Port property
value should be 80 for compatibility with established client implementations.
https: Option<Protocol>The settings for this manager’s HTTPS protocol support.
This object shall contain the HTTPS/SSL protocol settings for this manager. The default Port
property value should be 443 for compatibility with established client implementations.
snmp: Option<Protocol>The settings for this manager’s SNMP support.
This object shall contain the SNMP protocol settings for this manager. The default Port property
value should be 161 for compatibility with established client implementations.
virtual_media: Option<Protocol>The settings for this manager’s virtual media support that apply to all system instances controlled by this manager.
This object shall contain the virtual media protocol settings for this manager. The Port
property shall contain the TCP port assigned for virtual media usage. If multiple systems are
supported by this manager, these properties, if present, apply to all instances of virtual media
controlled by this manager.
telnet: Option<Protocol>The settings for this manager’s Telnet protocol support.
This object shall contain the Telnet protocol settings for this manager. The default Port
property value should be 23 for compatibility with established client implementations.
ssdp: Option<SsdProtocol>The settings for this manager’s SSDP support.
This object shall contain the SSDP protocol settings for this manager. Simple Service Discovery
Protocol (SSDP) is for network discovery of devices supporting the Redfish Service. The default
Port property value should be 1900 for compatibility with established client implementations.
ipmi: Option<Protocol>The settings for this manager’s IPMI-over-LAN protocol support.
This object shall contain the IPMI over LAN protocol settings for the manager. The default Port
property value should be 623 for compatibility with established client implementations.
ssh: Option<Protocol>The settings for this manager’s Secure Shell (SSH) protocol support.
This object shall contain the Secure Shell (SSH) protocol settings for the manager. The default
value should be 22 for compatibility with established client implementations.
kvmip: Option<Protocol>The settings for this manager’s KVM-IP protocol support that apply to all system instances controlled by this manager.
This object shall contain the KVM-IP (Keyboard, Video, Mouse over IP) protocol settings for the manager. If multiple systems are supported by this manager, these properties, if present, apply to all instances of KVM-IP controlled by this manager.
status: Option<Status>The status and health of the resource and its subordinate or dependent resources.
This property shall contain any status or health properties of the resource.
dhcp: Option<Protocol>The settings for this manager’s DHCPv4 protocol support.
This object shall contain the DHCPv4 protocol settings for the manager.
ntp: Option<NtpProtocol>The settings for this manager’s NTP protocol support.
This object shall contain the NTP protocol settings for the manager.
actions: Option<Actions>The available actions for this resource.
This property shall contain the available actions for this resource.
dhcpv6: Option<Protocol>The settings for this manager’s DHCPv6 protocol support.
This object shall contain the DHCPv6 protocol settings for the manager.
rdp: Option<Protocol>The settings for this manager’s Remote Desktop Protocol support.
This object shall contain the Remote Desktop Protocol settings for the manager.
rfb: Option<Protocol>The settings for this manager’s Remote Frame Buffer protocol support, which can support VNC.
This object shall contain the Remote Frame Buffer protocol settings for the manager.
proxy: Option<ProxyConfiguration>The HTTP/HTTPS proxy information for this manager.
This property shall contain the HTTP/HTTPS proxy configuration for this manager.
ftp: Option<Protocol>The settings for this manager’s FTP protocol support.
This object shall contain the File Transfer Protocol (FTP) settings for the manager. The default
Port property value should be 21 for compatibility with established client implementations.
sftp: Option<Protocol>The settings for this manager’s Secure Shell File Transfer Protocol (SFTP) support.
This object shall contain the Secure Shell File Transfer Protocol (SFTP) protocol settings for the
manager. The default value should be 22 for compatibility with established client
implementations.
ftps: Option<Protocol>The settings for this manager’s FTP over SSL (FTPS) protocol support that apply to all system instances controlled by this manager.
This object shall contain the File Transfer Protocol over SSL (FTPS) settings for the manager. The
default value should be 21 for compatibility with established client implementations.
mdns: Option<Protocol>The settings for this manager’s Multicast Domain Name Service (mDNS) protocol support.
This object shall contain the Multicast Domain Name Service (mDNS) settings for the manager. The
default Port property value should be 5353 for compatibility with established client
implementations.
modbus: Option<ModbusProtocol>The settings for this manager’s Modbus TCP protocol support.
This object shall contain the Modbus TCP protocol settings for the manager.