pub struct ModbusProtocol {
pub base: Protocol,
pub server_id: Option<Option<Int64>>,
pub maximum_connected_clients: Option<Option<Int64>>,
pub number_of_connected_clients: Option<Option<Int64>>,
pub read_only: Option<Option<Boolean>>,
pub restrict_access_to_allowed_clients: Option<Option<Boolean>>,
pub allowed_clients: Option<Option<Vec<String>>>,
}Fields
base: ProtocolBase type
server_id: Option<Option<Int64>>The server identifier for this Modbus TCP protocol interface.
This property shall contain the Modbus Messaging On TCP/IP Implementation Guide-defined ‘Unit Identifier’ that identifies this Modbus TCP protocol server.
maximum_connected_clients: Option<Option<Int64>>The maximum number of simultaneously connected clients.
This property shall contain the maximum number of simultaneously connected clients to this Modbus TCP server.
number_of_connected_clients: Option<Option<Int64>>The current number of connected clients.
This property shall contain the current number of connected clients to this Modbus TCP server.
read_only: Option<Option<Boolean>>Indicates if the interface is read only.
This property shall indicate if the Modbus TCP server protocol interface is read only. If true,
the Modbus TCP server service on this manager shall reject or ignore Modbus requests that modify
data.
restrict_access_to_allowed_clients: Option<Option<Boolean>>Indicates if access to this Modbus TCP server protocol interface is restricted to allowed clients.
This property shall indicate if access to the Modbus TCP server protocol interface is restricted to
allowed clients. If true, the Modbus TCP server service on this manager shall restrict access to
the list of clients defined by the AllowedClients property.
allowed_clients: Option<Option<Vec<String>>>Indicates the list of allowed clients for this Modbus TCP server interface.
This property shall contain all the clients allowed to access this Modbus TCP server interface. If
RestrictAccessToAllowedClients contains true, the service shall enforce this restriction. If
RestrictAccessToAllowedClients contains false, the service shall not enforce this restriction.
This property may contain FQDN, IPv4 addresses, IPv6 addresses, or any combination of those
formats. Services may reject unsupported formats.