pub struct ProxyConfiguration {
pub enabled: Option<Boolean>,
pub proxy_server_uri: Option<String>,
pub username: Option<String>,
pub password_set: Option<Boolean>,
pub exclude_addresses: Option<Option<Vec<String>>>,
pub proxy_auto_config_uri: Option<Option<String>>,
}Expand description
The HTTP/HTTPS proxy information for a manager.
This property shall contain the HTTP/HTTPS proxy configuration for a manager.
Fields
enabled: Option<Boolean>Indicates if the manager uses the proxy server.
This property shall indicate if the proxy server is used for communications.
proxy_server_uri: Option<String>The URI of the proxy server, including the scheme and any non-default port value.
This property shall contain the URI of the proxy server. The value shall contain the scheme for accessing the server, and shall include the port if the value is not the default port for the specified scheme.
username: Option<String>The username for the proxy.
This property shall contain the username for this proxy.
password_set: Option<Boolean>Indicates if the Password property is set.
This property shall contain true if a valid value was provided for the Password property.
Otherwise, the property shall contain false.
exclude_addresses: Option<Option<Vec<String>>>Addresses that do not require the proxy server to access.
This property shall contain a list of hostnames or IP addresses that do not require a connection through the proxy server to access.
proxy_auto_config_uri: Option<Option<String>>The URI used to access a proxy auto-configuration (PAC) file.
This property shall contain the URI at which to access a proxy auto-configuration (PAC) file containing one or more JavaScript functions for configuring proxy usage for this manager.