pub struct SsdProtocol {
pub base: Protocol,
pub notify_multicast_interval_seconds: Option<Option<Int64>>,
pub notify_ttl: Option<Option<Int64>>,
pub notify_ipv6scope: Option<Option<NotifyIpv6scope>>,
}Fields
base: ProtocolBase type
notify_multicast_interval_seconds: Option<Option<Int64>>The time interval, in seconds, between transmissions of the multicast NOTIFY ALIVE message from this service for SSDP.
This property shall contain the time interval, in seconds, between transmissions of the multicast NOTIFY ALIVE message. A setting of 0 seconds shall disable this functionality. The recommended value is 600 seconds. When disabled, other NOTIFY messages are also disabled due to their dependency on previously sent NOTIFY ALIVE messages.
notify_ttl: Option<Option<Int64>>The time-to-live hop count for SSDP multicast NOTIFY messages.
This property shall contain the time-to-live hop count used for multicast NOTIFY messages. The recommended value is 2.
notify_ipv6scope: Option<Option<NotifyIpv6scope>>The IPv6 scope for multicast NOTIFY messages for SSDP.
This property shall contain the IPv6 scope for multicast NOTIFY messages. The valid enumerations are a subset of the available IPv6 scope types.