pub struct Cxl {
pub label_storage_size_bytes: Option<Int64>,
pub staged_volatile_size_mi_b: Option<Int64>,
pub staged_non_volatile_size_mi_b: Option<Int64>,
}Expand description
CXL properties for a memory device.
This type shall contain CXL-specific properties for a memory device.
Fields
label_storage_size_bytes: Option<Int64>The size of the label storage area in bytes of this memory device.
This property shall contain the size of the label storage area in bytes of this memory device.
staged_volatile_size_mi_b: Option<Int64>Total device volatile memory capacity in MiB staged for next activation. This value is in multiples of 256 MiB.
The value of this property shall indicate the total device volatile memory capacity in mebibytes staged for next activation. This value shall be in multiples of 256 mebibytes.
staged_non_volatile_size_mi_b: Option<Int64>Total device non-volatile memory capacity in MiB staged for next activation. The value is in multiples of 256 MiB.
The value of this property shall indicate the total device non-volatile memory capacity in mebibytes. The value shall be in multiples of 256 mebibytes.