MemoryLocation

Struct MemoryLocation 

pub struct MemoryLocation {
    pub socket: Option<Option<Int64>>,
    pub memory_controller: Option<Option<Int64>>,
    pub channel: Option<Option<Int64>>,
    pub slot: Option<Option<Int64>>,
}
Memory connection information to sockets and memory controllers.

This type shall contain properties that describe the memory connection information to sockets and memory controllers.

Fields

socket: Option<Option<Int64>>

The socket number to which the memory device is connected.

This property shall contain the socket number to which the memory device is connected.

memory_controller: Option<Option<Int64>>

The memory controller number to which the memory device is connected.

This property shall contain the memory controller number to which the memory device is connected.

channel: Option<Option<Int64>>

The channel number to which the memory device is connected.

This property shall contain the channel number to which the memory device is connected.

slot: Option<Option<Int64>>

The slot number to which the memory device is connected.

This property shall contain the slot number to which the memory device is connected.