pub struct MemorySetMasterPassphraseAction {
pub region_id: Option<String>,
pub passphrase: Option<String>,
}Expand description
Sets the master passphrase for the given region.
This action shall set the supplied master passphrase to the supplied region.
Fields
region_id: Option<String>The memory region ID to which to apply the master passphrase.
This parameter shall contain the memory region ID to which to apply the master passphrase.
passphrase: Option<String>The master passphrase to set for the specified region.
This parameter shall contain the master passphrase to set for the specified region.