SecurityCapabilities

Struct SecurityCapabilities 

pub struct SecurityCapabilities {
    pub passphrase_capable: Option<Option<Boolean>>,
    pub max_passphrase_count: Option<Option<Int64>>,
    pub security_states: Option<Vec<SecurityStates>>,
    pub configuration_lock_capable: Option<Option<Boolean>>,
    pub data_lock_capable: Option<Option<Boolean>>,
    pub passphrase_lock_limit: Option<Option<Int64>>,
}

Fields

passphrase_capable: Option<Option<Boolean>>

An indication of whether the memory device is passphrase capable.

This property shall indicate whether the memory device is passphrase capable.

max_passphrase_count: Option<Option<Int64>>

Maximum number of passphrases supported for this memory device.

This property shall contain the maximum number of passphrases supported for this memory device.

security_states: Option<Vec<SecurityStates>>

Security states supported by the memory device.

This property shall contain the security states supported by the memory device.

configuration_lock_capable: Option<Option<Boolean>>

An indication of whether this memory device supports the locking, or freezing, of the configuration.

This property shall indicate whether this memory device supports the locking, or freezing, of the configuration.

data_lock_capable: Option<Option<Boolean>>

An indication of whether this memory device supports data locking.

This property shall indicate whether this memory device supports the locking of data access.

passphrase_lock_limit: Option<Option<Int64>>

The maximum number of incorrect passphrase attempts allowed before memory device is locked.

This property shall contain the maximum number of incorrect passphrase access attempts allowed before access to data is locked. If 0, the number of attempts is infinite.