AlertCapabilities

Struct AlertCapabilities 

pub struct AlertCapabilities {
    pub temperature: Option<Option<Boolean>>,
    pub spare_block: Option<Option<Boolean>>,
    pub uncorrectable_ecc_error: Option<Option<Boolean>>,
    pub correctable_ecc_error: Option<Option<Boolean>>,
}
The conditions that would generate an alert to the CXL Fabric Manager or host.

This type shall contain the conditions that would generate an alert to the CXL Fabric Manager or host.

Fields

temperature: Option<Option<Boolean>>

Indicates whether temperature conditions generate an alert to the CXL Fabric Manager or host.

This property shall indicate whether temperature conditions generate an alert to the CXL Fabric Manager or host.

spare_block: Option<Option<Boolean>>

Indicates whether spare block conditions generate an alert to the CXL Fabric Manager or host.

This property shall indicate whether spare block conditions generate an alert to the CXL Fabric Manager or host.

uncorrectable_ecc_error: Option<Option<Boolean>>

Indicates whether uncorrectable ECC errors generate an alert to the CXL Fabric Manager or host.

This property shall indicate whether uncorrectable ECC errors generate an alert to the CXL Fabric Manager or host.

correctable_ecc_error: Option<Option<Boolean>>

Indicates whether correctable ECC errors generate an alert to the CXL Fabric Manager or host.

This property shall indicate whether correctable ECC errors generate an alert to the CXL Fabric Manager or host.