Message

Struct Message 

pub struct Message {
    pub message_id: String,
    pub message: Option<String>,
    pub related_properties: Option<Vec<String>>,
    pub message_args: Option<Vec<String>>,
    pub severity: Option<String>,
    pub resolution: Option<String>,
    pub oem: Option<Oem>,
    pub message_severity: Option<Health>,
    pub resolution_steps: Option<Vec<ResolutionStep>>,
    pub username: Option<Option<String>>,
    pub user_authentication_source: Option<Option<String>>,
}

Fields

message_id: String

The identifier for the message.

This property shall contain a MessageId, as defined in the ‘MessageId format’ clause of the Redfish Specification.

message: Option<String>

The human-readable message.

This property shall contain a human-readable message.

related_properties: Option<Vec<String>>

A set of properties described by the message.

This property shall contain an array of RFC6901-defined JSON pointers indicating the properties described by the message, if appropriate for the message.

message_args: Option<Vec<String>>

An array of message arguments that are substituted for the arguments in the message when looked up in the message registry.

This property shall contain an array of message arguments that are substituted for the arguments in the message when looked up in the message registry. It has the same semantics as the MessageArgs property in the Redfish MessageRegistry schema. If the corresponding ParamType value contains number, the service shall convert the number to a string representation of the number.

severity: Option<String>

The severity of the message.

This property shall contain the severity of the message, as defined in the ‘Status’ clause of the Redfish Specification. Services can replace the value defined in the message registry with a value more applicable to the implementation.

resolution: Option<String>

Used to provide suggestions on how to resolve the situation that caused the message.

This property shall contain the resolution of the message. Services can replace the resolution defined in the message registry with a more specific resolution in message payloads.

oem: Option<Oem>

The OEM extension property.

This property shall contain the OEM extensions. All values for properties contained in this object shall conform to the Redfish Specification-described requirements.

message_severity: Option<Health>

The severity of the message.

This property shall contain the severity of the message. Services can replace the value defined in the message registry with a value more applicable to the implementation.

resolution_steps: Option<Vec<ResolutionStep>>

The list of recommended steps to resolve the situation that caused the message.

This property shall contain an array of recommended steps to resolve the situation that caused the message. This property shall not be present if the MessageSeverity or Severity properties contain OK.

username: Option<Option<String>>

The username of the account associated with the message.

This property shall contain the username of the account associated with the message. This should be used for messages that result from a user action.

user_authentication_source: Option<Option<String>>

The source of authentication for the username property associated with the message.

This property shall contain the URL to the authentication service that is associated with the username property. This should be used for messages that result from a user action.