pub struct ControllerLinks {
pub base: Links,
pub pcie_devices: Option<Vec<NavProperty<PcieDevice>>>,
pub network_ports: Option<Vec<ReferenceLeaf>>,
pub network_device_functions: Option<Vec<NavProperty<NetworkDeviceFunction>>>,
pub ports: Option<Vec<ReferenceLeaf>>,
pub active_software_image: Option<NavProperty<SoftwareInventory>>,
pub software_images: Option<Vec<NavProperty<SoftwareInventory>>>,
}Fields
base: LinksBase type
pcie_devices: Option<Vec<NavProperty<PcieDevice>>>An array of links to the PCIe devices associated with this network controller.
This property shall contain an array of links to resources of type PCIeDevice that represent the
PCIe devices associated with this network controller.
network_ports: Option<Vec<ReferenceLeaf>>network_device_functions: Option<Vec<NavProperty<NetworkDeviceFunction>>>An array of links to the network device functions associated with this network controller.
This property shall contain an array of links to resources of type NetworkDeviceFunction that
represent the network device functions associated with this network controller.
ports: Option<Vec<ReferenceLeaf>>active_software_image: Option<NavProperty<SoftwareInventory>>The link to the software inventory resource that represents the active firmware image for this controller.
This property shall contain a link to a resource of type SoftwareInventory that represents the
active firmware image for this controller.
software_images: Option<Vec<NavProperty<SoftwareInventory>>>The images that are associated with this controller.
This property shall contain an array of links to resource of type SoftwareInventory that
represent the firmware images that apply to this controller.