pub struct DataCenterBridging {
pub capable: Option<Option<Boolean>>,
}Expand description
Data center bridging (DCB) for capabilities of a controller.
This type shall describe the capability, status, and configuration values related to data center bridging (DCB) for a controller.
Fields
capable: Option<Option<Boolean>>An indication of whether this controller is capable of data center bridging (DCB).
This property shall indicate whether this controller is capable of data center bridging (DCB).