pub struct VirtualFunction {
pub device_max_count: Option<Option<Int64>>,
pub network_port_max_count: Option<Option<Int64>>,
pub min_assignment_group_size: Option<Option<Int64>>,
}Expand description
A virtual function of a controller.
This type shall describe the capability, status, and configuration values related to a virtual function for a controller.
Fields
device_max_count: Option<Option<Int64>>The maximum number of virtual functions supported by this controller.
This property shall contain the maximum number of virtual functions supported by this controller.
network_port_max_count: Option<Option<Int64>>The maximum number of virtual functions supported per network port for this controller.
This property shall contain the maximum number of virtual functions supported per network port for this controller.
min_assignment_group_size: Option<Option<Int64>>The minimum number of virtual functions that can be allocated or moved between physical functions for this controller.
This property shall contain the minimum number of virtual functions that can be allocated or moved between physical functions for this controller.