Generated schema of NetworkDeviceFunction namespace
Structs
- Actions
- The available actions for this resource.
- Boot
Targets - A Fibre Channel boot target configured for a network device function.
- Boot
Targets Update - Update struct corresponding to
BootTargets - Ethernet
- Ethernet
Update - Update struct corresponding to
Ethernet - Fibre
Channel - Fibre
Channel Update - Update struct corresponding to
FibreChannel - Http
Boot - The HTTP and HTTPS boot capabilities, status, and configuration for a network device function.
- Http
Boot Update - Update struct corresponding to
HttpBoot - Infini
Band - This type describes InfiniBand capabilities, status, and configuration of a network device function.
- Infini
Band Update - Update struct corresponding to
InfiniBand - Iscsi
Boot - The iSCSI boot capabilities, status, and configuration for a network device function.
- Iscsi
Boot Update - Update struct corresponding to
IscsiBoot - Limit
- This type describes the packet and byte limit of a network device function.
- Limit
Update - Update struct corresponding to
Limit - Links
- Network
Device Function - The
NetworkDeviceFunctionschema represents a logical interface that a network adapter exposes. - Network
Device Function Update - Update struct corresponding to
NetworkDeviceFunction - OemActions
- The available OEM-specific actions for this resource.