BootTargets

Struct BootTargets 

pub struct BootTargets {
    pub wwpn: Option<Option<String>>,
    pub lunid: Option<Option<String>>,
    pub boot_priority: Option<Option<Int64>>,
}
A Fibre Channel boot target configured for a network device function.

This type shall describe a Fibre Channel boot target configured for a network device function.

Fields

wwpn: Option<Option<String>>

The World Wide Port Name (WWPN) from which to boot.

This property shall contain World Wide Port Name (WWPN) from which to boot.

lunid: Option<Option<String>>

The logical unit number (LUN) ID from which to boot on the device to which the corresponding WWPN refers.

This property shall contain the logical unit number (LUN) ID from which to boot on the device to which the corresponding WWPN refers.

boot_priority: Option<Option<Int64>>

The relative priority for this entry in the boot targets array.

This property shall contain the relative priority for this entry in the boot targets array. Lower numbers shall represent higher priority, with zero being the highest priority. The BootPriority shall be unique for all entries of the BootTargets array.