FibreChannel

Struct FibreChannel 

pub struct FibreChannel {
    pub permanent_wwpn: Option<Option<String>>,
    pub permanent_wwnn: Option<Option<String>>,
    pub wwpn: Option<Option<String>>,
    pub wwnn: Option<Option<String>>,
    pub wwn_source: Option<Option<WwnSource>>,
    pub fco_elocal_vlanid: Option<Option<Int64>>,
    pub allow_fipvlan_discovery: Option<Option<Boolean>>,
    pub fco_eactive_vlanid: Option<Option<Int64>>,
    pub boot_targets: Option<Option<Vec<BootTargets>>>,
    pub fibre_channel_id: Option<Option<String>>,
}

Fields

permanent_wwpn: Option<Option<String>>

The permanent World Wide Port Name (WWPN) address assigned to this function.

This property shall contain the permanent World Wide Port Name (WWPN) of this function. Typically, this value is programmed during manufacturing. This address is not assignable.

permanent_wwnn: Option<Option<String>>

The permanent World Wide Node Name (WWNN) address assigned to this function.

This property shall contain the permanent World Wide Node Name (WWNN) of this function. Typically, this value is programmed during manufacturing. This address is not assignable.

wwpn: Option<Option<String>>

The currently configured World Wide Port Name (WWPN) address of this function.

This property shall contain the effective current World Wide Port Name (WWPN) of this function. If an assignable WWPN is not supported, this is a read-only alias of the permanent WWPN.

wwnn: Option<Option<String>>

The currently configured World Wide Node Name (WWNN) address of this function.

This property shall contain the effective current World Wide Node Name (WWNN) of this function. If an assignable WWNN is not supported, this is a read-only alias of the permanent WWNN.

wwn_source: Option<Option<WwnSource>>

The configuration source of the World Wide Names (WWN) for this World Wide Node Name (WWNN) and World Wide Port Name (WWPN) connection.

This property shall contain the configuration source of the World Wide Name (WWN) for this World Wide Node Name (WWNN) and World Wide Port Name (WWPN) connection.

fco_elocal_vlanid: Option<Option<Int64>>

The locally configured FCoE VLAN ID.

For FCoE connections, this property shall contain the VLAN ID configured locally by setting this property. This value shall be used for FCoE traffic to this network device function during boot unless AllowFIPVLANDiscovery is true and a valid FCoE VLAN ID is found through the FIP VLAN Discovery Protocol.

allow_fipvlan_discovery: Option<Option<Boolean>>

An indication of whether the FCoE Initialization Protocol (FIP) populates the FCoE VLAN ID.

For FCoE connections, this boolean property shall indicate whether the FIP VLAN Discovery Protocol determines the FCoE VLAN ID selected by the network device function for the FCoE connection. If true and the FIP VLAN discovery succeeds, the FCoEActiveVLANId property shall reflect the FCoE VLAN ID to use for all FCoE traffic. If false or if the FIP VLAN Discovery protocol fails, the FCoELocalVLANId shall be used for all FCoE traffic and the FCoEActiveVLANId shall reflect the FCoELocalVLANId.

fco_eactive_vlanid: Option<Option<Int64>>

The active FCoE VLAN ID.

For FCoE connections, this property shall contain null or a VLAN ID currently being used for FCoE traffic. When the FCoE link is down this value shall be null. When the FCoE link is up this value shall be either the FCoELocalVLANId property or a VLAN discovered through the FIP protocol.

boot_targets: Option<Option<Vec<BootTargets>>>

An array of Fibre Channel boot targets configured for this network device function.

This property shall contain an array of Fibre Channel boot targets configured for this network device function.

fibre_channel_id: Option<Option<String>>

The Fibre Channel ID that the switch assigns for this interface.

This property shall indicate the Fibre Channel ID that the switch assigns for this interface.