Limit

Struct Limit 

pub struct Limit {
    pub direction: Option<Option<DataDirection>>,
    pub sustained_packets_per_second: Option<Option<Int64>>,
    pub burst_packets_per_second: Option<Option<Int64>>,
    pub sustained_bytes_per_second: Option<Option<Int64>>,
    pub burst_bytes_per_second: Option<Option<Int64>>,
}
This type describes the packet and byte limit of a network device function.

This type shall describe a single array element of the packet and byte limits of a network device function.

Fields

direction: Option<Option<DataDirection>>

Indicates the direction of the data to which this limit applies.

This property shall indicate the direction of the data to which this limit applies for this network device function.

sustained_packets_per_second: Option<Option<Int64>>

The maximum number of sustained packets per second for this network device function.

This property shall contain the maximum number of sustained packets per second allowed for this network device function.

burst_packets_per_second: Option<Option<Int64>>

The maximum number of packets per second in a burst for this network device function.

This property shall contain the maximum number of packets per second in a burst allowed for this network device function.

sustained_bytes_per_second: Option<Option<Int64>>

The maximum number of sustained bytes per second for this network device function.

This property shall contain the maximum number of sustained bytes per second allowed for this network device function.

burst_bytes_per_second: Option<Option<Int64>>

The maximum number of bytes per second in a burst for this network device function.

This property shall contain the maximum number of bytes per second in a burst allowed for this network device function.