pub struct NetworkDeviceFunction {Show 24 fields
pub base: Resource,
pub status: Option<Status>,
pub net_dev_func_type: Option<Option<NetworkDeviceTechnology>>,
pub device_enabled: Option<Option<Boolean>>,
pub net_dev_func_capabilities: Option<Option<Vec<NetworkDeviceTechnology>>>,
pub ethernet: Option<Ethernet>,
pub iscsi_boot: Option<IscsiBoot>,
pub fibre_channel: Option<FibreChannel>,
pub boot_mode: Option<Option<BootMode>>,
pub virtual_functions_enabled: Option<Option<Boolean>>,
pub max_virtual_functions: Option<Option<Int64>>,
pub links: Option<Links>,
pub actions: Option<Actions>,
pub infini_band: Option<InfiniBand>,
pub savi_enabled: Option<Option<Boolean>>,
pub limits: Option<Option<Vec<Limit>>>,
pub http_boot: Option<HttpBoot>,
pub virtual_function_allocation: Option<Int64>,
pub assignable_physical_ports: Option<Vec<ReferenceLeaf>>,
pub physical_port_assignment: Option<ReferenceLeaf>,
pub assignable_physical_network_ports: Option<Vec<ReferenceLeaf>>,
pub physical_network_port_assignment: Option<ReferenceLeaf>,
pub metrics: Option<ReferenceLeaf>,
pub allow_deny: Option<ReferenceLeaf>,
}Expand description
The NetworkDeviceFunction schema represents a logical interface that a network adapter exposes.
This resource shall represent a logical interface that a network adapter exposes in a Redfish implementation.
Fields
base: ResourceBase type
status: Option<Status>The status and health of the resource and its subordinate or dependent resources.
This property shall contain any status or health properties of the resource.
net_dev_func_type: Option<Option<NetworkDeviceTechnology>>The configured capability of this network device function.
This property shall contain the configured capability of this network device function.
device_enabled: Option<Option<Boolean>>An indication of whether the network device function is enabled.
This property shall indicate whether the network device function is enabled. The operating system shall not enumerate or see disabled network device functions.
net_dev_func_capabilities: Option<Option<Vec<NetworkDeviceTechnology>>>An array of capabilities for this network device function.
This property shall contain an array of capabilities for this network device function.
ethernet: Option<Ethernet>The Ethernet capabilities, status, and configuration values for this network device function.
This property shall contain Ethernet capabilities, status, and configuration values for this network device function.
iscsi_boot: Option<IscsiBoot>The iSCSI boot capabilities, status, and configuration values for this network device function.
This property shall contain iSCSI boot capabilities, status, and configuration values for this network device function.
fibre_channel: Option<FibreChannel>The Fibre Channel capabilities, status, and configuration values for this network device function.
This property shall contain Fibre Channel capabilities, status, and configuration values for this network device function.
boot_mode: Option<Option<BootMode>>The boot mode configured for this network device function.
This property shall contain the boot mode configured for this network device function. If the
value is not Disabled, this network device function shall be configured for boot by using the
specified technology.
virtual_functions_enabled: Option<Option<Boolean>>An indication of whether single root input/output virtualization (SR-IOV) virtual functions are enabled for this network device function.
This property shall indicate whether single root input/output virtualization (SR-IOV) virtual functions are enabled for this network device function.
max_virtual_functions: Option<Option<Int64>>The number of virtual functions that are available for this network device function.
This property shall contain the number of virtual functions that are available for this network device function.
links: Option<Links>The links to other resources that are related to this resource.
This property shall contain links to resources that are related to but are not contained by, or subordinate to, this resource.
actions: Option<Actions>The available actions for this resource.
This property shall contain the available actions for this resource.
infini_band: Option<InfiniBand>The InfiniBand capabilities, status, and configuration values for this network device function.
This property shall contain InfiniBand capabilities, status, and configuration values for this network device function.
savi_enabled: Option<Option<Boolean>>Indicates if Source Address Validation Improvement (SAVI) is enabled for this network device function.
This property shall indicate if the RFC7039-defined Source Address Validation Improvement (SAVI) is enabled for this network device function.
limits: Option<Option<Vec<Limit>>>The byte and packet limits for this network device function.
This property shall contain an array of byte and packet limits for this network device function.
http_boot: Option<HttpBoot>The HTTP and HTTPS boot capabilities, status, and configuration values for this network device function.
This property shall contain HTTP and HTTPS boot capabilities, status, and configuration values for this network device function.
virtual_function_allocation: Option<Int64>The number of virtual functions allocated to this device.
This property shall contain the number virtual functions allocated to this device. This property
should contain a value that is a multiple of the value contained by the MinAssignmentGroupSize
property of the corresponding Controllers array member within the parent NetworkAdapter
resource. The value shall not exceed the value contained in the MaxVirtualFunctions property.
assignable_physical_ports: Option<Vec<ReferenceLeaf>>physical_port_assignment: Option<ReferenceLeaf>assignable_physical_network_ports: Option<Vec<ReferenceLeaf>>physical_network_port_assignment: Option<ReferenceLeaf>metrics: Option<ReferenceLeaf>allow_deny: Option<ReferenceLeaf>