pub struct PowerControl {Show 13 fields
pub base: ReferenceableMember,
pub name: Option<Option<String>>,
pub power_consumed_watts: Option<Option<Decimal>>,
pub power_requested_watts: Option<Option<Decimal>>,
pub power_available_watts: Option<Option<Decimal>>,
pub power_capacity_watts: Option<Option<Decimal>>,
pub power_allocated_watts: Option<Option<Decimal>>,
pub power_metrics: Option<PowerMetric>,
pub power_limit: Option<PowerLimit>,
pub status: Option<Status>,
pub actions: Option<PowerControlActions>,
pub physical_context: Option<PhysicalContext>,
pub related_item: Option<Vec<ReferenceLeaf>>,
}Fields
base: ReferenceableMemberBase type
name: Option<Option<String>>The power control function name.
This property shall contain the name of the power control function name.
power_consumed_watts: Option<Option<Decimal>>The actual power that the chassis consumes, in watt units.
This property shall represent the actual power that the chassis consumes, in watt units.
power_requested_watts: Option<Option<Decimal>>The potential power, in watt units, that the chassis requests, which might be higher than the current level being consumed because the requested power includes a budget that the chassis wants for future use.
This property shall represent the amount of power, in watt units, that the chassis currently requests to be budgeted for future use.
power_available_watts: Option<Option<Decimal>>The amount of reserve power capacity, in watt units, that remains. This value is the
PowerCapacityWatts value minus the PowerAllocatedWatts value.
This property shall represent the amount of reserve power capacity, in watt units, that remains.
This value is the PowerCapacityWatts value minus the PowerAllocatedWatts value.
power_capacity_watts: Option<Option<Decimal>>The total amount of power that can be allocated to the chassis. This value can be either the power supply capacity or the power budget that an upstream chassis assigns to this chassis.
This property shall represent the total power capacity that can be allocated to the chassis.
power_allocated_watts: Option<Option<Decimal>>The total amount of power that has been allocated or budgeted to chassis.
This property shall represent the total power currently allocated or budgeted to the chassis.
power_metrics: Option<PowerMetric>The power readings for this chassis.
This property shall contain power metrics for power readings, such as interval, minimum, maximum, and average power consumption, for the chassis.
power_limit: Option<PowerLimit>The power limit status and configuration information for this chassis.
This property shall contain power limit status and configuration information for this chassis.
status: Option<Status>The status and health of the resource and its subordinate or dependent resources.
This property shall contain any status or health properties of the resource.
actions: Option<PowerControlActions>The available actions for this resource.
This property shall contain the available actions for this resource.
physical_context: Option<PhysicalContext>The area, device, or set of devices to which this power control applies.
This property shall contain a description of the affected device(s) or region within the chassis to which this power control applies.