pub struct PowerAllocation {
pub requested_watts: Option<Option<Decimal>>,
pub allocated_watts: Option<Option<Decimal>>,
}Expand description
Power allocation for a subsystem.
This type shall contain the set of properties describing the allocation of power for a subsystem.
Fields
requested_watts: Option<Option<Decimal>>The potential power, in watt units, that the subsystem requests, which might be higher than the current level being consumed because the requested power includes a budget that the subsystem wants for future use.
This property shall represent the amount of power, in watt units, that the subsystem currently requests to be budgeted for future use.
allocated_watts: Option<Option<Decimal>>The total amount of power that has been allocated or budgeted to this subsystem.
This property shall represent the total power currently allocated or budgeted to this subsystem.