pub struct PowerSubsystem {
pub base: Resource,
pub status: Option<Status>,
pub capacity_watts: Option<Option<Decimal>>,
pub allocation: Option<PowerAllocation>,
pub power_supply_redundancy: Option<Vec<RedundantGroup>>,
pub actions: Option<Actions>,
pub power_supplies: Option<NavProperty<PowerSupplyCollection>>,
pub batteries: Option<ReferenceLeaf>,
}Expand description
This PowerSubsystem schema contains the definition for the power subsystem of a chassis.
This resource shall represent a power subsystem for a Redfish implementation.
Fields
base: ResourceBase type
status: Option<Status>The status and health of the resource and its subordinate or dependent resources.
This property shall contain any status or health properties of the resource.
capacity_watts: Option<Option<Decimal>>The total amount of power that can be allocated to this subsystem. This value can be either the power supply capacity or the power budget that an upstream chassis assigns to this subsystem.
This property shall represent the total power capacity that can be allocated to this subsystem.
allocation: Option<PowerAllocation>Power allocation for this subsystem when it represents a subset of the power infrastructure for the chassis or its upstream chassis, such as a chassis containing multiple server blades.
This property shall contain the set of properties describing the allocation of power for this subsystem as part of the power infrastructure for the chassis or an upstream chassis. This property should not be present in resources that are not part of a shared power infrastructure.
power_supply_redundancy: Option<Vec<RedundantGroup>>The redundancy information for the set of power supplies in this subsystem.
This property shall contain redundancy information for the set of power supplies in this subsystem.
The values of the RedundancyGroup array shall reference resources of type PowerSupply.
actions: Option<Actions>The available actions for this resource.
The Actions property shall contain the available actions for this resource.
power_supplies: Option<NavProperty<PowerSupplyCollection>>The link to the collection of power supplies within this subsystem.
This property shall contain a link to a resource collection of type PowerSupplyCollection.
batteries: Option<ReferenceLeaf>Trait Implementations
Sourceimpl Debug for PowerSubsystem
impl Debug for PowerSubsystem
Sourceimpl<'de> Deserialize<'de> for PowerSubsystem
impl<'de> Deserialize<'de> for PowerSubsystem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl EntityTypeRef for PowerSubsystem
impl EntityTypeRef for PowerSubsystem
Sourceimpl Expandable for PowerSubsystem
impl Expandable for PowerSubsystem
Sourceimpl RedfishSettings<PowerSubsystem> for PowerSubsystem
impl RedfishSettings<PowerSubsystem> for PowerSubsystem
Sourcefn settings_object(&self) -> Option<NavProperty<Self>>
fn settings_object(&self) -> Option<NavProperty<Self>>
impl Send for PowerSubsystem
SAFETY: All generated data types are Send
impl Sync for PowerSubsystem
SAFETY: All generated data types are Sync