pub struct InputRange {
pub nominal_voltage_type: Option<Option<NominalVoltageType>>,
pub capacity_watts: Option<Option<Decimal>>,
}Expand description
This type describes an input range for a power supply.
This type shall describe an input range that the associated power supply can utilize.
Fields
nominal_voltage_type: Option<Option<NominalVoltageType>>The input voltage range.
This property shall contain the input voltage type of the associated range.
capacity_watts: Option<Option<Decimal>>The maximum capacity of this power supply when operating in this input range.
This property shall contain the maximum amount of power, in watt units, that the associated power supply is rated to deliver while operating in this input range.