Generated schema of Processor namespace
Structs
- Actions
- The available actions for this resource.
- Ethernet
Interface - This type defines an Ethernet interface.
- Ethernet
Interface Update - Update struct corresponding to
EthernetInterface - Fpga
- The properties of the FPGA device.
- Fpga
Reconfiguration Slot - This type describes the FPGA reconfiguration slot. An FPGA uses a reconfiguration slot to contain an acceleration function that can change as the FPGA is provisioned.
- Fpga
Reconfiguration Slot Update - Update struct corresponding to
FpgaReconfigurationSlot - Fpga
Update - Update struct corresponding to
Fpga - Links
- Memory
Summary - Memory
Summary Update - Update struct corresponding to
MemorySummary - OemActions
- The available OEM-specific actions for this resource.
- Processor
- The
Processorschema describes the information about a single processor that a system contains. A processor includes both performance characteristics, clock speed, architecture, core count, and so on, and compatibility, such as the CPU ID instruction results. It also describes the location, such as a slot, socket, or bay, where a unit can be installed, by populating a resource instance with an absent state if a unit is not present. - Processor
Id - Processor
Interface - This type describes an interface between the system, or external connection, and the processor.
- Processor
Interface Update - Update struct corresponding to
ProcessorInterface - Processor
Memory - This type describes the memory directly attached or integrated within a processor.
- Processor
Reset Action - This action resets the processor.
- Processor
Reset ToDefaults Action - The action resets the values of writable properties to factory defaults.
- Processor
Update - Update struct corresponding to
Processor - UaLink
- The UALink attributes of a processor.
- UaLink
Update - Update struct corresponding to
UaLink
Enums
- Base
Speed Priority State - Fpga
Type - Processor
Memory Type - Processor
Type - System
Interface Type - Throttle
Cause - Turbo
State