pub struct Fpga {
pub fpga_type: Option<FpgaType>,
pub model: Option<String>,
pub firmware_id: Option<String>,
pub firmware_manufacturer: Option<String>,
pub firmware_version: Option<String>,
pub host_interface: Option<ProcessorInterface>,
pub external_interfaces: Option<Vec<ProcessorInterface>>,
pub pcie_virtual_functions: Option<Int64>,
pub programmable_from_host: Option<Option<Boolean>>,
pub reconfiguration_slots: Option<Vec<FpgaReconfigurationSlot>>,
pub oem: Option<Oem>,
}Expand description
The properties of the FPGA device.
This object shall contain the properties of the FPGA device represented by a processor.
Fields
fpga_type: Option<FpgaType>The FPGA type.
This property shall contain a type of the FPGA device.
model: Option<String>The FPGA model.
This property shall contain a model of the FPGA device.
firmware_id: Option<String>The FPGA firmware identifier.
This property shall contain a string describing the FPGA firmware identifier.
firmware_manufacturer: Option<String>The FPGA firmware manufacturer.
This property shall contain a string describing the FPGA firmware manufacturer.
firmware_version: Option<String>The FPGA firmware version.
This property shall contain a string describing the FPGA firmware version.
host_interface: Option<ProcessorInterface>The FPGA interface to the host.
This property shall contain an object that describes the connectivity to the host for system software to use.
external_interfaces: Option<Vec<ProcessorInterface>>An array of the FPGA external interfaces.
This property shall contain an array of objects that describe the external connectivity of the FPGA.
pcie_virtual_functions: Option<Int64>The number of PCIe Virtual Functions.
This property shall contain an integer that describes the number of PCIe Virtual Functions configured within the FPGA.
programmable_from_host: Option<Option<Boolean>>An indication of whether the FPGA firmware can be reprogrammed from the host by using system software.
This property shall indicate whether the FPGA firmware can be reprogrammed from the host by using
system software. If false, system software shall not be able to program the FPGA firmware from
the system interface. In either state, a management controller may be able to program the FPGA
firmware by using the sideband interface.
reconfiguration_slots: Option<Vec<FpgaReconfigurationSlot>>An array of the FPGA reconfiguration slots. An FPGA uses a reconfiguration slot to contain an acceleration function that can change as the FPGA is provisioned.
This property shall contain an array of the structures that describe the FPGA reconfiguration slots that the acceleration functions can program.
oem: Option<Oem>The OEM extension property.
This property shall contain the OEM extensions. All values for properties contained in this object shall conform to the Redfish Specification-described requirements.