pub struct Links {
pub base: Links,
pub chassis: Option<NavProperty<Chassis>>,
pub endpoints: Option<Vec<ReferenceLeaf>>,
pub connected_processors: Option<Vec<NavProperty<Processor>>>,
pub pcie_device: Option<NavProperty<PcieDevice>>,
pub pcie_functions: Option<Vec<ReferenceLeaf>>,
pub memory: Option<Vec<NavProperty<Memory>>>,
pub graphics_controller: Option<ReferenceLeaf>,
pub network_device_functions: Option<Vec<NavProperty<NetworkDeviceFunction>>>,
pub fabric_adapters: Option<Vec<ReferenceLeaf>>,
}Fields
base: LinksBase type
chassis: Option<NavProperty<Chassis>>The link to the chassis that contains this processor.
This property shall contain a link to a resource of type Chassis that represents the physical
container associated with this processor.
endpoints: Option<Vec<ReferenceLeaf>>connected_processors: Option<Vec<NavProperty<Processor>>>An array of links to the processors directly connected to this processor.
This property shall contain an array of links to resources of type Processor that are directly
connected to this processor.
pcie_device: Option<NavProperty<PcieDevice>>The link to the PCIe device associated with this processor.
This property shall contain a link to a resource of type PCIeDevice that represents the PCIe
device associated with this processor.
pcie_functions: Option<Vec<ReferenceLeaf>>memory: Option<Vec<NavProperty<Memory>>>An array of links to the memory associated with this processor.
This property shall contain an array of links to resources of type Memory that are associated
with this processor.
graphics_controller: Option<ReferenceLeaf>network_device_functions: Option<Vec<NavProperty<NetworkDeviceFunction>>>The network device functions to which this processor performs offload computation, such as with a SmartNIC.
This property shall contain an array of links to resources of type NetworkDeviceFunction that
represent the network device functions to which this processor performs offload computation, such
as with a SmartNIC.
fabric_adapters: Option<Vec<ReferenceLeaf>>