ProcessorId

Struct ProcessorId 

pub struct ProcessorId {
    pub vendor_id: Option<Option<String>>,
    pub identification_registers: Option<Option<String>>,
    pub effective_family: Option<Option<String>>,
    pub effective_model: Option<Option<String>>,
    pub step: Option<Option<String>>,
    pub microcode_info: Option<Option<String>>,
    pub protected_identification_number: Option<Option<String>>,
}

Fields

vendor_id: Option<Option<String>>

The vendor identification for this processor.

This property shall contain the vendor identification information as provided by the manufacturer of this processor. If this property represents raw register data, as determined by the value of the ProcessorArchitecture property, the service shall encode the value as a hex-encoded string following the regular expression pattern ^0x[0-9A-Fa-f]+$ or a decimal-encoded string following the regular expression pattern ^\d+$. For additional property requirements, see the corresponding definition in the Redfish Data Model Specification.

identification_registers: Option<Option<String>>

The raw manufacturer-provided processor identification registers for this processor.

This property shall contain the raw manufacturer-provided processor-specific identification registers of this processor’s features. For additional property requirements, see the corresponding definition in the Redfish Data Model Specification.

effective_family: Option<Option<String>>

The effective family for this processor.

This property shall contain the effective family information as provided by the manufacturer of this processor. If this property represents raw register data, as determined by the value of the ProcessorArchitecture property, the service shall encode the value as a hex-encoded string following the regular expression pattern ^0x[0-9A-Fa-f]+$ or a decimal-encoded string following the regular expression pattern ^\d+$. For additional property requirements, see the corresponding definition in the Redfish Data Model Specification.

effective_model: Option<Option<String>>

The effective model for this processor.

This property shall contain the effective model information as provided by the manufacturer of this processor. If this property represents raw register data, as determined by the value of the ProcessorArchitecture property, the service shall encode the value as a hex-encoded string following the regular expression pattern ^0x[0-9A-Fa-f]+$ or a decimal-encoded string following the regular expression pattern ^\d+$. For additional property requirements, see the corresponding definition in the Redfish Data Model Specification.

step: Option<Option<String>>

The step value for this processor.

This property shall contain the step or revision information as provided by the manufacturer of this processor. If this property represents raw register data, as determined by the value of the ProcessorArchitecture property, the service shall encode the value as a hex-encoded string following the regular expression pattern ^0x[0-9A-Fa-f]+$ or a decimal-encoded string following the regular expression pattern ^\d+$. For additional property requirements, see the corresponding definition in the Redfish Data Model Specification.

microcode_info: Option<Option<String>>

The microcode information for this processor.

This property shall contain the microcode information as provided by the manufacturer of this processor. If this property represents raw register data, as determined by the value of the ProcessorArchitecture property, the service shall encode the value as a hex-encoded string following the regular expression pattern ^0x[0-9A-Fa-f]+$ or a decimal-encoded string following the regular expression pattern ^\d+$. For additional property requirements, see the corresponding definition in the Redfish Data Model Specification.

protected_identification_number: Option<Option<String>>

The Protected Processor Identification Number (PPIN) for this processor.

This property shall contain the Protected Processor Identification Number (PPIN) for this processor.