ProcessorInterface

Struct ProcessorInterface 

pub struct ProcessorInterface {
    pub interface_type: Option<Option<SystemInterfaceType>>,
    pub pcie: Option<PcieInterface>,
    pub ethernet: Option<EthernetInterface>,
}
This type describes an interface between the system, or external connection, and the processor.

This type shall contain information about the system interface, or external connection, to the processor.

Fields

interface_type: Option<Option<SystemInterfaceType>>

The interface type.

This property shall contain an enumerated value that describes the type of interface between the system, or external connection, and the processor.

pcie: Option<PcieInterface>

The PCIe-related information for this interface.

This property shall contain an object the describes the PCIe-related information for this interface.

ethernet: Option<EthernetInterface>

The Ethernet-related information for this interface.

This property shall contain an object the describes the Ethernet-related information for this interface.