pub struct ProcessorMemory {
pub integrated_memory: Option<Option<Boolean>>,
pub memory_type: Option<Option<ProcessorMemoryType>>,
pub capacity_mi_b: Option<Option<Int64>>,
pub speed_mhz: Option<Option<Int64>>,
}Expand description
This type describes the memory directly attached or integrated within a processor.
This type shall contain information about memory directly attached or integrated within a processor.
Fields
integrated_memory: Option<Option<Boolean>>An indication of whether this memory is integrated within the processor.
This property shall indicate whether this memory is integrated within the processor. Otherwise, it is discrete memory attached to the processor.
memory_type: Option<Option<ProcessorMemoryType>>The type of memory used by this processor.
This property shall contain a type of the processor memory type.
capacity_mi_b: Option<Option<Int64>>The memory capacity in MiB.
This property shall contain the memory capacity in MiB.
speed_mhz: Option<Option<Int64>>The operating speed of the memory in MHz.
This property shall contain the operating speed of the memory in MHz.