pub struct CoreMetrics {
pub core_id: Option<Option<String>>,
pub instructions_per_cycle: Option<Option<Decimal>>,
pub unhalted_cycles: Option<Option<Decimal>>,
pub memory_stall_count: Option<Option<Decimal>>,
pub io_stall_count: Option<Option<Decimal>>,
pub core_cache: Option<Vec<CacheMetrics>>,
pub cstate_residency: Option<Vec<CstateResidency>>,
pub correctable_core_error_count: Option<Option<Int64>>,
pub uncorrectable_core_error_count: Option<Option<Int64>>,
pub correctable_other_error_count: Option<Option<Int64>>,
pub uncorrectable_other_error_count: Option<Option<Int64>>,
}Fields
core_id: Option<Option<String>>The processor core identifier.
This property shall contain the identifier of the core within the processor.
instructions_per_cycle: Option<Option<Decimal>>The number of instructions per clock cycle of this core.
This property shall contain the number of instructions per clock cycle of this core in the processor.
unhalted_cycles: Option<Option<Decimal>>The unhalted cycles count of this core.
This property shall contain the number of unhalted cycles of this core in the processor.
memory_stall_count: Option<Option<Decimal>>The number of stalled cycles due to memory operations.
This property shall contain the number of stalled cycles due to memory operations of this core in the processor.
io_stall_count: Option<Option<Decimal>>The number of stalled cycles due to I/O operations.
This property shall contain the number of stalled cycles due to I/O operations of this core in the processor.
core_cache: Option<Vec<CacheMetrics>>The cache metrics of this core in the processor.
This property shall contain properties that describe the cache metrics of this core in the processor.
cstate_residency: Option<Vec<CstateResidency>>The C-state residency of this core in the processor.
This property shall contain properties that describe the C-state residency of this core in the processor.
correctable_core_error_count: Option<Option<Int64>>The number of correctable core errors.
This property shall contain the number of correctable core errors, such as TLB or cache errors.
When this resource is subordinate to the ProcessorSummary object, this property shall be the sum
of CorrectableCoreErrorCount over all processors.
uncorrectable_core_error_count: Option<Option<Int64>>The number of uncorrectable core errors.
This property shall contain the number of uncorrectable core errors, such as TLB or cache errors.
When this resource is subordinate to the ProcessorSummary object, this property shall be the sum
of UncorrectableCoreErrorCount over all processors.
correctable_other_error_count: Option<Option<Int64>>The number of correctable errors of all other components.
This property shall contain the number of correctable errors of all other components. When this
resource is subordinate to the ProcessorSummary object, this property shall be the sum of
CorrectableOtherErrorCount over all processors.
uncorrectable_other_error_count: Option<Option<Int64>>The number of uncorrectable errors of all other components.
This property shall contain the number of uncorrectable errors of all other components. When this
resource is subordinate to the ProcessorSummary object, this property shall be the sum of
UncorrectableOtherErrorCount over all processors.