pub struct CurrentPeriod {
pub correctable_ecc_error_count: Option<Option<Int64>>,
pub uncorrectable_ecc_error_count: Option<Option<Int64>>,
}Expand description
The cache memory metrics since the last system reset or ClearCurrentPeriod action for a
processor.
This type shall describe the cache memory metrics since last system reset or ClearCurrentPeriod
action for a processor.
Fields
correctable_ecc_error_count: Option<Option<Int64>>The number of correctable errors of cache memory since reset or ClearCurrentPeriod action for
this processor.
This property shall contain the number of correctable errors of cache memory since reset or
ClearCurrentPeriod action for this processor. When this resource is subordinate to the
ProcessorSummary object, this property shall be the sum of CorrectableECCErrorCount over all
processors.
uncorrectable_ecc_error_count: Option<Option<Int64>>The number of uncorrectable errors of cache memory since reset or ClearCurrentPeriod action for
this processor.
This property shall contain the number of uncorrectable errors of cache memory since reset or
ClearCurrentPeriod action for this processor. When this resource is subordinate to the
ProcessorSummary object, this property shall be the sum of UncorrectableECCErrorCount over all
processors.