pub struct LifeTime {
pub correctable_ecc_error_count: Option<Option<Int64>>,
pub uncorrectable_ecc_error_count: Option<Option<Int64>>,
}Expand description
The cache memory metrics for the lifetime for a processor.
This type shall describe the cache memory metrics since manufacturing for a processor.
Fields
correctable_ecc_error_count: Option<Option<Int64>>The number of correctable errors for the lifetime of the cache memory.
This property shall contain the number of correctable errors for the lifetime of the cache memory.
When this resource is subordinate to the ProcessorSummary object, this property shall be the sum
of CorrectableECCErrorCount over all processors.
uncorrectable_ecc_error_count: Option<Option<Int64>>The number of uncorrectable errors for the lifetime of the cache memory.
This property shall contain the number of uncorrectable errors for the lifetime of the cache
memory. When this resource is subordinate to the ProcessorSummary object, this property shall be
the sum of UncorrectableECCErrorCount over all processors.