ProcessorMetrics

Struct ProcessorMetrics 

pub struct ProcessorMetrics {
Show 25 fields pub base: Resource, pub bandwidth_percent: Option<Option<Decimal>>, pub average_frequency_mhz: Option<Option<Decimal>>, pub throttling_celsius: Option<Option<Decimal>>, pub temperature_celsius: Option<Option<Decimal>>, pub consumed_power_watt: Option<Option<Decimal>>, pub frequency_ratio: Option<Option<Decimal>>, pub cache: Option<Vec<CacheMetrics>>, pub local_memory_bandwidth_bytes: Option<Option<Int64>>, pub remote_memory_bandwidth_bytes: Option<Option<Int64>>, pub kernel_percent: Option<Option<Decimal>>, pub user_percent: Option<Option<Decimal>>, pub core_metrics: Option<Vec<CoreMetrics>>, pub actions: Option<Actions>, pub operating_speed_mhz: Option<Option<Int64>>, pub cache_metrics_total: Option<CacheMetricsTotal>, pub pcie_errors: Option<PcieErrors>, pub correctable_core_error_count: Option<Option<Int64>>, pub uncorrectable_core_error_count: Option<Option<Int64>>, pub correctable_other_error_count: Option<Option<Int64>>, pub uncorrectable_other_error_count: Option<Option<Int64>>, pub power_limit_throttle_duration: Option<Option<Duration>>, pub thermal_limit_throttle_duration: Option<Option<Duration>>, pub lifetime_start_date_time: Option<Option<DateTimeOffset>>, pub core_voltage: Option<SensorExcerptVoltage>,
}
The ProcessorMetrics schema contains usage and health statistics for a processor.

This resource contains the processor metrics for a single processor in a Redfish implementation.

Fields

base: Resource

Base type

bandwidth_percent: Option<Option<Decimal>>

The bandwidth usage of this processor as a percentage.

This property shall contain the bandwidth usage of the processor as a percentage, typically 0 to 100. When this resource is subordinate to the ProcessorSummary object, this property shall be the CPU utilization over all processors as a percentage.

average_frequency_mhz: Option<Option<Decimal>>

The average frequency of the processor.

This property shall contain average frequency in MHz, across all enabled cores in the processor. When this resource is subordinate to the ProcessorSummary object, this property is not applicable.

throttling_celsius: Option<Option<Decimal>>

The CPU margin to throttle (temperature offset in degree Celsius units).

This property shall contain the CPU margin to throttle based on an offset between the maximum temperature in which the processor can operate, and the processor’s current temperature. When this resource is subordinate to the ProcessorSummary object, this property is not applicable.

temperature_celsius: Option<Option<Decimal>>

The temperature of the processor.

This property shall contain the temperature, in degree Celsius units, of the processor. When this resource is subordinate to the ProcessorSummary object, this property shall be the average temperature, in Celsius, over all processors.

consumed_power_watt: Option<Option<Decimal>>

The power, in watt units, that the processor has consumed.

This property shall contain the power, in watt units, that the processor has consumed. When this resource is subordinate to the ProcessorSummary object, this property shall be the sum of power, in watt units, that all processors have consumed.

frequency_ratio: Option<Option<Decimal>>

The frequency relative to the nominal processor frequency ratio.

This property shall contain the frequency relative to the nominal processor frequency ratio of this processor. When this resource is subordinate to the ProcessorSummary object, this property shall be the average FrequencyRatio over all processors.

cache: Option<Vec<CacheMetrics>>

The processor cache metrics.

This property shall contain properties that describe this processor’s cache. When this resource is subordinate to the ProcessorSummary object, this property is not applicable.

local_memory_bandwidth_bytes: Option<Option<Int64>>

The local memory bandwidth usage in bytes.

This property shall contain the local memory bandwidth usage of this processor in bytes. When this resource is subordinate to the ProcessorSummary object, this property shall be the sum of LocalMemoryBandwidthBytes over all processors.

remote_memory_bandwidth_bytes: Option<Option<Int64>>

The remote memory bandwidth usage in bytes.

This property shall contain the remote memory bandwidth usage of this processor in bytes. When this resource is subordinate to the ProcessorSummary object, this property shall be the sum of RemoteMemoryBandwidthBytes over all processors.

kernel_percent: Option<Option<Decimal>>

The percentage of time spent in kernel mode.

This property shall contain total percentage of time, 0 to 100, the processor has spent in kernel mode. When this resource is subordinate to the ProcessorSummary object, this property shall be the average KernelPercent over all processors.

user_percent: Option<Option<Decimal>>

The percentage of time spent in user mode.

This property shall contain total percentage of time, 0 to 100, the processor has spent in user mode. When this resource is subordinate to the ProcessorSummary object, this property shall be the average UserPercent over all processors.

core_metrics: Option<Vec<CoreMetrics>>

The processor core metrics.

This property shall contain properties that describe the cores of this processor. When this resource is subordinate to the ProcessorSummary object, this property is not applicable.

actions: Option<Actions>

The available actions for this resource.

This property shall contain the available actions for this resource.

operating_speed_mhz: Option<Option<Int64>>

Operating speed of the processor in MHz.

This property shall contain the operating speed of the processor in MHz. The operating speed of the processor may change more frequently than the manager is able to monitor.

cache_metrics_total: Option<CacheMetricsTotal>

The total cache metrics for this processor.

This property shall contain properties that describe the metrics for all of the cache memory of this processor.

pcie_errors: Option<PcieErrors>

The PCIe errors associated with this processor.

This property shall contain the PCIe errors associated with this processor.

correctable_core_error_count: Option<Option<Int64>>

The number of correctable core errors.

This property shall contain the number of correctable core errors, such as TLB or cache errors. When this resource is subordinate to the ProcessorSummary object, this property shall be the sum of CorrectableCoreErrorCount over all processors.

uncorrectable_core_error_count: Option<Option<Int64>>

The number of uncorrectable core errors.

This property shall contain the number of uncorrectable core errors, such as TLB or cache errors. When this resource is subordinate to the ProcessorSummary object, this property shall be the sum of UncorrectableCoreErrorCount over all processors.

correctable_other_error_count: Option<Option<Int64>>

The number of correctable errors of all other components.

This property shall contain the number of correctable errors of all other components. When this resource is subordinate to the ProcessorSummary object, this property shall be the sum of CorrectableOtherErrorCount over all processors.

uncorrectable_other_error_count: Option<Option<Int64>>

The number of uncorrectable errors of all other components.

This property shall contain the number of uncorrectable errors of all other components. When this resource is subordinate to the ProcessorSummary object, this property shall be the sum of UncorrectableOtherErrorCount over all processors.

power_limit_throttle_duration: Option<Option<Duration>>

The total duration of throttling caused by a power limit of the processor since reset.

This property shall contain the total duration of throttling caused by a power limit of the processor since reset.

thermal_limit_throttle_duration: Option<Option<Duration>>

The total duration of throttling caused by a thermal limit of the processor since reset.

This property shall contain the total duration of throttling caused by a thermal limit of the processor since reset.

lifetime_start_date_time: Option<Option<DateTimeOffset>>

The date and time when the processor started accumulating data for the LifeTime property.

This property shall contain the date and time when the processor started accumulating data for the LifeTime property. This might contain the same value as the production date of the processor.

core_voltage: Option<SensorExcerptVoltage>

The core voltage (V) of this processor.

The value of this property shall contain the core voltage, in volt units, of this processor. The core voltage of the processor may change more frequently than the manager is able to monitor. The value of the DataSourceUri property, if present, shall reference a resource of type Sensor with the ReadingType property containing the value Voltage.