pub enum DurableNameFormat {
Naa,
Iqn,
FcWwn,
Uuid,
Eui,
Nqn,
Nsid,
Nguid,
MacAddress,
Gcxlid,
UnsupportedValue,
}Variants
Naa
The Name Address Authority (NAA) format.
This durable name shall contain a hexadecimal representation of the Name Address Authority
structure, as defined in the T11 Fibre Channel - Framing and Signaling - 3 (FC-FS-3) specification.
The DurableName property shall follow the regular expression pattern
^(([0-9A-Fa-f]{2}){8}){1,2}$, where the most significant octet is first.
Iqn
The iSCSI Qualified Name (iQN).
This durable name shall be in the iSCSI Qualified Name (iQN) format, as defined in RFC3720 and RFC3721.
FcWwn
The Fibre Channel (FC) World Wide Name (WWN).
This durable name shall contain a hexadecimal representation of the World-Wide Name (WWN) format,
as defined in the T11 Fibre Channel Physical and Signaling Interface Specification. The
DurableName property shall follow the regular expression pattern
^([0-9A-Fa-f]{2}[:-]){7}([0-9A-Fa-f]{2})$, where the most significant octet is first.
Uuid
The Universally Unique Identifier (UUID).
This durable name shall contain the hexadecimal representation of the UUID, as defined by RFC4122.
The DurableName property shall follow the regular expression pattern
‘([0-9a-fA-F]{8}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{4}-[0-9a-fA-F]{12})’.
Eui
The IEEE-defined 64-bit Extended Unique Identifier (EUI).
This durable name shall contain the hexadecimal representation of the IEEE-defined 64-bit Extended
Unique Identifier (EUI), as defined in the IEEE’s Guidelines for 64-bit Global Identifier (EUI-64)
Specification. The DurableName property shall follow the regular expression pattern
^([0-9A-Fa-f]{2}[:-]){7}([0-9A-Fa-f]{2})$, where the most significant octet is first.
Nqn
The NVMe Qualified Name (NQN).
This durable name shall be in the NVMe Qualified Name (NQN) format, as defined in the NVN Express over Fabric Specification.
Nsid
The NVM Namespace Identifier (NSID).
This durable name shall be in the NVM Namespace Identifier (NSID) format, as defined in the NVN Express Specification.
Nguid
The Namespace Globally Unique Identifier (NGUID).
This durable name shall be in the Namespace Globally Unique Identifier (NGUID), as defined in the
NVN Express Specification. The DurableName property shall follow the regular expression pattern
^([0-9A-Fa-f]{2}){16}$, where the most significant octet is first.
MacAddress
The media access control address (MAC address).
This durable name shall be a media access control address (MAC address), which is a unique
identifier assigned to a network interface controller (NIC) for use as a network address. This
value should not be used if a more specific type of identifier is available. The DurableName
property shall follow the regular expression pattern ^([0-9A-Fa-f]{2}[:-]){5}([0-9A-Fa-f]{2})$,
where the most significant octet is first.
Gcxlid
The globally unique CXL logical device identifier (GCXLID).
This durable name shall be in the globally unique CXL logical device identifier (GCXLID). The
DurableName property shall follow the regular expression pattern
^([0-9A-Fa-f]{2}-){7}[0-9A-Fa-f]{2}:([0-9A-Fa-f]{4})$, where the first eight hyphen-delimited
octets contain the PCIe serial number, where the most significant octet is first, and the remaining
16-bit field contains the CXL Logical Device Identifier, with the most significant byte first.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.