pub enum Reference {
Top,
Bottom,
Front,
Rear,
Left,
Right,
Middle,
UnsupportedValue,
}Expand description
The reference areas for the location of the part within an enclosure.
This enumeration shall list the reference areas for the location of the part within an enclosure.
Variants
Top
The part is in the top of the unit.
This value shall indicate the part is in the top of the unit.
Bottom
The part is in the bottom of the unit.
This value shall indicate the part is in the bottom of the unit.
Front
The part is in the front of the unit.
This value shall indicate the part is in the front of the unit.
Rear
The part is in the rear of the unit.
This value shall indicate the part is in the rear of the unit.
Left
The part is on the left side of the unit.
This value shall indicate the part is on the left side of the unit.
Right
The part is on the right side of the unit.
This value shall indicate the part is on the right side of the unit.
Middle
The part is in the middle of the unit.
This value shall indicate the part is in the middle of the unit.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.