pub enum ResetType {
Show 14 variants
On,
ForceOff,
GracefulShutdown,
GracefulRestart,
ForceRestart,
Nmi,
ForceOn,
PushPowerButton,
PowerCycle,
Suspend,
Pause,
Resume,
FullPowerCycle,
UnsupportedValue,
}Variants
On
Turn on the unit.
This value shall indicate the resource will transition to a power on state. Upon successful
completion, the PowerState property, if supported, shall contain the value On.
ForceOff
Turn off the unit immediately (non-graceful shutdown).
This value shall indicate the resource will transition to a power off state. The transition will
start immediately. Upon successful completion, the PowerState property, if supported, shall
contain the value Off.
GracefulShutdown
Shut down gracefully and power off.
This value shall indicate the resource will transition to a power off state. The transition will
start after first performing tasks to safely shut down the resource. For example, when shutting
down a computer system, the host operating system is allowed to safely shut down processes and
close connections. Upon successful completion, the PowerState property, if supported, shall
contain the value Off.
GracefulRestart
Shut down gracefully and restart the unit.
This value shall indicate the resource will transition to a power on state, after transiting
through a restart. The transition will start after first performing tasks to safely shut down the
resource. For example, when shutting down a computer system, the host operating system is allowed
to safely shut down processes and close connections. Upon successful completion, the PowerState
property, if supported, shall contain the value On.
ForceRestart
Shut down immediately and non-gracefully and restart the unit.
This value shall indicate the resource will transition to a power on state, after transiting
through a restart. The transition will start immediately. Upon successful completion, the
PowerState property, if supported, shall contain the value On.
Nmi
Generate a diagnostic interrupt, which is usually an NMI on x86 systems, to stop normal operations, complete diagnostic actions, and, typically, halt the system.
This value shall indicate the resource will generate a diagnostic interrupt.
ForceOn
Turn on the unit immediately.
This value shall indicate the resource will transition to a power on state. The transition will
start immediately. Upon successful completion, the PowerState property shall contain the value
On.
PushPowerButton
Simulate the pressing of the physical power button on this unit.
This value shall indicate the resource will behave as if the physical power button is pressed. The behavior of pressing the physical power button may be dependent on the state of the unit and the behavior may be configurable.
PowerCycle
Power cycle the unit immediately (non-graceful). Behaves like a power removal, followed by a power restore to the resource.
This value shall indicate the resource will perform a power cycle. The transition will start
immediately. This is different from FullPowerCycle in that it typically performs localized power
sequencing of the resource while external power is still present. For example, turning DC voltage
regulators off and then turning DC voltage regulators back on. If currently in the power on state,
the resource will transition to a power off state, then transition to a power on state. If
currently in the power off state, the resource will transition to a power on state. Upon
successful completion, the PowerState property, if supported, shall contain the value On.
Suspend
Write the state of the unit to disk before powering off. This allows for the state to be restored when powered back on.
This value shall indicate the resource will have any state information written to persistent memory
and then transition to a power off state. Upon successful completion, the PowerState property,
if supported, shall contain the value Off.
Pause
Pause execution on the unit but do not remove power. This is typically a feature of virtual machine hypervisors.
This value shall indicate the resource will transition to a paused state. Upon successful
completion, the PowerState property, if supported, shall contain the value Paused.
Resume
Resume execution on the paused unit. This is typically a feature of virtual machine hypervisors.
This value shall indicate the resource will transition to a power on state. Upon successful
completion, the PowerState property, if supported, shall contain the value On.
FullPowerCycle
Full power cycle the unit immediately (non-graceful). Behaves like removing utility lines, followed by restoring utility lines to the resource.
This value shall indicate the resource will perform a full power cycle as if utility lines to the
resource are removed and restored. The transition will start immediately. This is different from
PowerCycle in that it’s as close to a true power cycle as possible. For example, removing AC
power cables from an enclosure and then restoring the AC power cables. If currently in the power
on state, the resource will transition to a power off state, then transition to a power on state.
If currently in the power off state, the resource will transition to a power on state. Upon
successful completion, the PowerState property, if supported, shall contain the value On. If a
service supports this value but there are no other distinct power cycle flows, the service shall
support PowerCycle as an alias to FullPowerCycle. This type of reset may cause the manager
providing the Redfish service to power cycle. If the manager providing the Redfish service is
affected by this type of reset, the service shall send the action response before resetting to
prevent client timeouts.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.