Condition

Struct Condition 

pub struct Condition {
Show 13 fields pub timestamp: Option<DateTimeOffset>, pub message_id: String, pub message_args: Option<Vec<String>>, pub message: Option<String>, pub severity: Option<Health>, pub resolution: Option<String>, pub resolution_steps: Option<Vec<ResolutionStep>>, pub username: Option<Option<String>>, pub user_authentication_source: Option<Option<String>>, pub condition_type: Option<Option<ConditionType>>, pub oem: Option<Oem>, pub origin_of_condition: Option<ReferenceLeaf>, pub log_entry: Option<NavProperty<LogEntry>>,
}
A condition that requires attention.

This type shall contain the description and details of a condition that exists within this resource or a related resource that requires attention.

Fields

timestamp: Option<DateTimeOffset>

The time the condition occurred.

This property shall indicate the time the condition occurred.

message_id: String

The identifier for the message.

This property shall contain a MessageId, as defined in the ‘MessageId format’ clause of the Redfish Specification.

message_args: Option<Vec<String>>

An array of message arguments that are substituted for the arguments in the message when looked up in the message registry.

This property shall contain an array of message arguments that are substituted for the arguments in the message when looked up in the message registry. It has the same semantics as the MessageArgs property in the Redfish MessageRegistry schema.

message: Option<String>

The human-readable message for this condition.

This property shall contain a human-readable message describing this condition.

severity: Option<Health>

The severity of the condition.

This property shall contain the severity of the condition. Services can replace the value defined in the message registry with a value more applicable to the implementation.

resolution: Option<String>

Suggestions on how to resolve the condition.

This property shall contain the resolution of the condition. Services should replace the resolution defined in the message registry with a more specific resolution.

resolution_steps: Option<Vec<ResolutionStep>>

The list of recommended steps to resolve the condition.

This property shall contain an array of recommended steps to resolve the condition. A client can stop executing the resolution steps once the condition is removed from the resource.

username: Option<Option<String>>

The username of the account associated with the condition.

This property shall contain the username of the account associated with the condition. This should be used for conditions that result from a user action.

user_authentication_source: Option<Option<String>>

The source of authentication for the username property associated with the condition.

This property shall contain the URL to the authentication service that is associated with the username property. This should be used for conditions that result from a user action.

condition_type: Option<Option<ConditionType>>

The type of condition.

This property shall contain the type of condition.

oem: Option<Oem>

The OEM extension property.

This property shall contain the OEM extensions. All values for properties contained in this object shall conform to the Redfish Specification-described requirements.

origin_of_condition: Option<ReferenceLeaf>log_entry: Option<NavProperty<LogEntry>>

The link to the log entry created for this condition.

This property shall contain a link to a resource of type LogEntry that represents the log entry created for this condition.