pub struct PartLocation {
pub service_label: Option<Option<String>>,
pub location_type: Option<Option<LocationType>>,
pub location_ordinal_value: Option<Option<Int64>>,
pub reference: Option<Option<Reference>>,
pub orientation: Option<Option<Orientation>>,
}Expand description
The part location for a resource within an enclosure.
This type shall describe a location for a resource within an enclosure.
Fields
service_label: Option<Option<String>>The label of the part location, such as a silk-screened name or a printed label.
This property shall contain the label assigned for service at the part location.
location_type: Option<Option<LocationType>>The type of location of the part.
This property shall contain the type of location of the part.
location_ordinal_value: Option<Option<Int64>>The number that represents the location of the part. For example, if LocationType is Slot and
this unit is in slot 2, the LocationOrdinalValue is 2.
This property shall contain the number that represents the location of the part based on the
LocationType. LocationOrdinalValue shall be measured based on the Orientation value starting
with 0.
reference: Option<Option<Reference>>The reference point for the part location. Provides guidance about the general location of the part.
This property shall contain the general location within the unit of the part.
orientation: Option<Option<Orientation>>The orientation for the ordering of the slot enumeration used by the LocationOrdinalValue
property.
This property shall contain the orientation for the ordering used by the LocationOrdinalValue
property.