pub struct PostalAddress {Show 33 fields
pub country: Option<Option<String>>,
pub territory: Option<Option<String>>,
pub district: Option<Option<String>>,
pub city: Option<Option<String>>,
pub division: Option<Option<String>>,
pub neighborhood: Option<Option<String>>,
pub leading_street_direction: Option<Option<String>>,
pub street: Option<Option<String>>,
pub trailing_street_suffix: Option<Option<String>>,
pub street_suffix: Option<Option<String>>,
pub house_number: Option<Option<Int64>>,
pub house_number_suffix: Option<Option<String>>,
pub landmark: Option<Option<String>>,
pub location: Option<Option<String>>,
pub floor: Option<Option<String>>,
pub name: Option<Option<String>>,
pub postal_code: Option<Option<String>>,
pub building: Option<Option<String>>,
pub unit: Option<Option<String>>,
pub room: Option<Option<String>>,
pub seat: Option<Option<String>>,
pub place_type: Option<Option<String>>,
pub community: Option<Option<String>>,
pub po_box: Option<Option<String>>,
pub additional_code: Option<Option<String>>,
pub road: Option<Option<String>>,
pub road_section: Option<Option<String>>,
pub road_branch: Option<Option<String>>,
pub road_sub_branch: Option<Option<String>>,
pub road_pre_modifier: Option<Option<String>>,
pub road_post_modifier: Option<Option<String>>,
pub gps_coords: Option<Option<String>>,
pub additional_info: Option<Option<String>>,
}Fields
country: Option<Option<String>>The country.
The value shall conform to the RFC5139-defined requirements of the Country field.
territory: Option<Option<String>>A top-level subdivision within a country.
The value shall conform to the RFC5139-defined requirements of the A1 field when it names a territory, state, region, province, or prefecture within a country.
district: Option<Option<String>>A county, parish, gun (JP), or district (IN).
The value shall conform to the RFC5139-defined requirements of the A2 field. Names a county, parish, gun (JP), or district (IN).
city: Option<Option<String>>City, township, or shi (JP).
The value shall conform to the RFC5139-defined requirements of the A3 field. Names a city, township, or shi (JP).
division: Option<Option<String>>City division, borough, city district, ward, or chou (JP).
The value shall conform to the RFC5139-defined requirements of the A4 field. Names a city division, borough, city district, ward, or chou (JP).
neighborhood: Option<Option<String>>Neighborhood or block.
The value shall conform to the RFC5139-defined requirements of the A5 field. Names a neighborhood or block.
leading_street_direction: Option<Option<String>>A leading street direction.
The value shall conform to the requirements of the PRD field as defined in RFC5139. Names a leading street direction, (N, W, or SE).
street: Option<Option<String>>Street name.
The value shall conform to the RFC5139-defined requirements of the A6 field. Names a street.
trailing_street_suffix: Option<Option<String>>A trailing street suffix.
The value shall conform to the RFC5139-defined requirements of the POD field. Names a trailing street suffix.
street_suffix: Option<Option<String>>Avenue, Platz, Street, Circle.
The value shall conform to the RFC5139-defined requirements of the STS field. Names a street suffix.
house_number: Option<Option<Int64>>The numeric portion of house number.
The value shall conform to the RFC5139-defined requirements of the HNO field. The numeric portion of the house number.
house_number_suffix: Option<Option<String>>The house number suffix.
The value shall conform to the RFC5139-defined requirements of the HNS field. Provides a suffix to a house number, (F, B, or 1/2).
landmark: Option<Option<String>>The landmark.
The value shall conform to the RFC5139-defined requirements of the LMK field. Identifies a landmark or vanity address.
location: Option<Option<String>>The room designation or other additional information.
The value shall conform to the RFC5139-defined requirements of the LOC field. Provides additional information.
floor: Option<Option<String>>The floor.
The value shall conform to the RFC5139-defined requirements of the FLR field. Provides a floor designation.
name: Option<Option<String>>The name.
The value shall conform to the RFC5139-defined requirements of the NAM field. Names the occupant.
postal_code: Option<Option<String>>The postal code or zip code.
The value shall conform to the RFC5139-defined requirements of the PC field. A postal code (or zip code).
building: Option<Option<String>>The name of the building.
The value shall conform to the RFC5139-defined requirements of the BLD field. Names the building.
unit: Option<Option<String>>The name or number of the apartment unit or suite.
The value shall conform to the RFC5139-defined requirements of the UNIT field. The name or number of a unit, such as the apartment or suite, to locate the resource.
room: Option<Option<String>>The name or number of the room.
The value shall conform to the RFC5139-defined requirements of the ROOM field. A name or number of a room to locate the resource within the unit.
seat: Option<Option<String>>The seat, such as the desk, cubicle, or workstation.
The value shall conform to the RFC5139-defined requirements of the SEAT field. A name or number of a seat, such as the desk, cubicle, or workstation.
place_type: Option<Option<String>>The description of the type of place that is addressed.
The value shall conform to the RFC5139-defined requirements of the PLC field. Examples include office and residence.
community: Option<Option<String>>The postal community name.
The value shall conform to the RFC5139-defined requirements of the PCN field. A postal community name.
po_box: Option<Option<String>>The post office box (PO box).
The value shall conform to the RFC5139-defined requirements of the POBOX field. A post office box (PO box).
additional_code: Option<Option<String>>The additional code.
The value shall conform to the RFC5139-defined requirements of the ADDCODE field.
road: Option<Option<String>>The primary road or street.
The value shall conform to the RFC5139-defined requirements of the RD field. Designates a primary road or street.
road_section: Option<Option<String>>The road section.
The value shall conform to the RFC5139-defined requirements of the RDSEC field. A road section.
road_branch: Option<Option<String>>The road branch.
The value shall conform to the RFC5139-defined requirements of the RDBR field. Shall contain a post office box (PO box) road branch.
road_sub_branch: Option<Option<String>>The road sub branch.
The value shall conform to the RFC5139-defined requirements of the RDSUBBR field.
road_pre_modifier: Option<Option<String>>The road pre-modifier.
The value shall conform to the RFC5139-defined requirements of the PRM field. For example, Old or New.
road_post_modifier: Option<Option<String>>The road post-modifier.
The value shall conform to the RFC5139-defined requirements of the POM field. For example, Extended.
gps_coords: Option<Option<String>>The GPS coordinates of the part.
The value shall conform to the RFC5139-defined requirements of the ADDCODE field. Shall contain
the GPS coordinates of the location. If furnished, expressed in the [-][nn]n.nnnnnn, [-][nn]n.nnnnn format. For example, two comma-separated positive or negative numbers with six
decimal places of precision.
additional_info: Option<Option<String>>The room designation or other additional information.
The value shall conform to the requirements of the LOC field as defined in RFC5139. Provides additional information.