pub struct Actions {
pub oem: Option<OemActions>,
pub reset_keys: Option<Action<SecureBootResetKeysAction, ()>>,
}Expand description
The available actions for this resource.
This type shall contain the available actions for this resource.
Fields
oem: Option<OemActions>The available OEM-specific actions for this resource.
This property shall contain the available OEM-specific actions for this resource.
reset_keys: Option<Action<SecureBootResetKeysAction, ()>>Implementations
Sourceimpl Actions
impl Actions
Sourcepub async fn reset_keys<B: Bmc>(
&self,
bmc: &B,
reset_keys_type: Option<ResetKeysType>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn reset_keys<B: Bmc>(
&self,
bmc: &B,
reset_keys_type: Option<ResetKeysType>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
This action resets the UEFI Secure Boot keys.
This action shall reset the UEFI Secure Boot key databases. The ResetAllKeysToDefault value
shall reset all UEFI Secure Boot key databases to their default values. The DeleteAllKeys value
shall delete the contents of all UEFI Secure Boot key databases. The DeletePK value shall delete
the contents of the PK Secure Boot key database.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.