pub struct SecureBoot {
pub base: Resource,
pub secure_boot_enable: Option<Option<Boolean>>,
pub secure_boot_current_boot: Option<Option<SecureBootCurrentBootType>>,
pub secure_boot_mode: Option<Option<SecureBootModeType>>,
pub actions: Option<Actions>,
pub secure_boot_databases: Option<ReferenceLeaf>,
}Expand description
The SecureBoot schema contains UEFI Secure Boot information and represents properties for
managing the UEFI Secure Boot functionality of a system.
This resource contains UEFI Secure Boot information for a Redfish implementation.
Fields
base: ResourceBase type
secure_boot_enable: Option<Option<Boolean>>An indication of whether UEFI Secure Boot is enabled.
This property shall indicate whether the UEFI Secure Boot takes effect on next boot. This property can be enabled in UEFI boot mode only.
secure_boot_current_boot: Option<Option<SecureBootCurrentBootType>>The UEFI Secure Boot state during the current boot cycle.
This property shall indicate the UEFI Secure Boot state during the current boot cycle.
secure_boot_mode: Option<Option<SecureBootModeType>>The current UEFI Secure Boot Mode.
This property shall contain the current UEFI Secure Boot mode, as defined in the UEFI Specification.
actions: Option<Actions>The available actions for this resource.
This property shall contain the available actions for this resource.
secure_boot_databases: Option<ReferenceLeaf>Trait Implementations
Sourceimpl Debug for SecureBoot
impl Debug for SecureBoot
Sourceimpl<'de> Deserialize<'de> for SecureBoot
impl<'de> Deserialize<'de> for SecureBoot
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl EntityTypeRef for SecureBoot
impl EntityTypeRef for SecureBoot
Sourceimpl Expandable for SecureBoot
impl Expandable for SecureBoot
Sourceimpl RedfishSettings<SecureBoot> for SecureBoot
impl RedfishSettings<SecureBoot> for SecureBoot
Sourcefn settings_object(&self) -> Option<NavProperty<Self>>
fn settings_object(&self) -> Option<NavProperty<Self>>
Sourceimpl Updatable<SecureBootUpdate> for SecureBoot
impl Updatable<SecureBootUpdate> for SecureBoot
impl Send for SecureBoot
SAFETY: All generated data types are Send
impl Sync for SecureBoot
SAFETY: All generated data types are Sync