pub struct SensorExcerpt {Show 16 fields
pub data_source_uri: Option<Option<String>>,
pub reading: Option<Option<Decimal>>,
pub physical_context: Option<Option<PhysicalContext>>,
pub physical_sub_context: Option<Option<PhysicalSubContext>>,
pub apparent_va: Option<Option<Decimal>>,
pub reactive_var: Option<Option<Decimal>>,
pub power_factor: Option<Option<Decimal>>,
pub sensor_reset_time: Option<Option<DateTimeOffset>>,
pub crest_factor: Option<Option<Decimal>>,
pub thd_percent: Option<Option<Decimal>>,
pub lifetime_reading: Option<Option<Decimal>>,
pub speed_rpm: Option<Option<Decimal>>,
pub device_name: Option<Option<String>>,
pub apparentk_vah: Option<Option<Decimal>>,
pub reactivek_varh: Option<Option<Decimal>>,
pub phase_angle_degrees: Option<Option<Decimal>>,
}Fields
data_source_uri: Option<Option<String>>The link to the resource that provides the data for this sensor.
This property shall contain a URI to the resource that provides the source of the excerpt contained within this copy.
reading: Option<Option<Decimal>>The sensor value.
This property shall contain the sensor value. This property shall not be returned if the Enabled
property is supported and contains false.
physical_context: Option<Option<PhysicalContext>>The area or device to which this sensor measurement applies.
This property shall contain a description of the affected component or region within the equipment to which this sensor measurement applies.
physical_sub_context: Option<Option<PhysicalSubContext>>The usage or location within a device to which this sensor measurement applies.
This property shall contain a description of the usage or sub-region within the equipment to which
this sensor measurement applies. This property generally differentiates multiple sensors within
the same PhysicalContext instance.
apparent_va: Option<Option<Decimal>>The product of voltage and current for an AC circuit, in volt-ampere units.
This property shall contain the product of voltage (RMS) multiplied by current (RMS) for a circuit.
This property can appear in sensors of the Power ReadingType, and shall not appear in sensors
of other ReadingType values.
reactive_var: Option<Option<Decimal>>The square root of the difference term of squared apparent VA and squared power (Reading) for a circuit, in VAR units.
This property shall contain the arithmetic mean of product terms of instantaneous voltage and
quadrature current measurements calculated over an integer number of line cycles for a circuit.
This property can appear in sensors of the Power ReadingType, and shall not appear in sensors
of other ReadingType values.
power_factor: Option<Option<Decimal>>The power factor for this sensor.
This property shall identify the quotient of real power (W) and apparent power (VA) for a circuit.
PowerFactor is expressed in unit-less 1/100ths. This property can appear in sensors containing a
ReadingType value of Power, and shall not appear in sensors of other ReadingType values.
sensor_reset_time: Option<Option<DateTimeOffset>>The date and time when the time-based properties were last reset.
This property shall contain the date and time when the ResetMetrics action was last performed or
when the service last reset the time-based property values.
crest_factor: Option<Option<Decimal>>The crest factor for this sensor.
This property shall contain the ratio of the peak measurement divided by the RMS measurement and calculated over same N line cycles. A sine wave would have a value of 1.414.
thd_percent: Option<Option<Decimal>>The total harmonic distortion percent (% THD).
This property shall contain the total harmonic distortion of the Reading property in percent
units, typically 0 to 100.
lifetime_reading: Option<Option<Decimal>>The total accumulation value for this sensor.
This property shall contain the total accumulation of the Reading property over the sensor’s
lifetime. This value shall not be reset by the ResetMetrics action.
speed_rpm: Option<Option<Decimal>>The rotational speed.
This property shall contain a reading of the rotational speed of the device in revolutions per minute (RPM) units.
device_name: Option<Option<String>>The name of the device.
This property shall contain the name of the device associated with this sensor. If the device is
represented by a resource, the value shall contain the value of the Name property of the
associated resource.
apparentk_vah: Option<Option<Decimal>>Apparent energy (kVAh).
This property shall contain the apparent energy, in kilovolt-ampere-hour units, for an electrical
energy measurement. This property can appear in sensors with a ReadingType containing
EnergykWh, and shall not appear in sensors with other ReadingType values.
reactivek_varh: Option<Option<Decimal>>Reactive energy (kVARh).
This property shall contain the reactive energy, in kilovolt-ampere-hours (reactive) units, for an
electrical energy measurement. This property can appear in sensors with a ReadingType containing
EnergykWh, and shall not appear in sensors with other ReadingType values.
phase_angle_degrees: Option<Option<Decimal>>The phase angle (degrees) between the current and voltage waveforms.
This property shall contain the phase angle, in degree units, between the current and voltage
waveforms for an electrical measurement. This property can appear in sensors with a ReadingType
containing Power, and shall not appear in sensors with other ReadingType values.