pub struct SensorResetMetricsAction {}Expand description
Resets metrics related to this sensor.
This action shall reset any time intervals or counted values for this sensor. The
SensorResetTime property shall be updated to reflect the time that this action was performed.