Thresholds

Struct Thresholds 

pub struct Thresholds {
    pub upper_caution: Option<Threshold>,
    pub upper_critical: Option<Threshold>,
    pub upper_fatal: Option<Threshold>,
    pub lower_caution: Option<Threshold>,
    pub lower_critical: Option<Threshold>,
    pub lower_fatal: Option<Threshold>,
    pub upper_caution_user: Option<Threshold>,
    pub upper_critical_user: Option<Threshold>,
    pub lower_caution_user: Option<Threshold>,
    pub lower_critical_user: Option<Threshold>,
}

Fields

upper_caution: Option<Threshold>

The value at which the reading is above normal range.

This property shall contain the value at which the Reading property is above the normal range. The value of the property shall use the same units as the Reading property.

upper_critical: Option<Threshold>

The value at which the reading is above normal range but not yet fatal.

This property shall contain the value at which the Reading property is above the normal range but is not yet fatal. The value of the property shall use the same units as the Reading property.

upper_fatal: Option<Threshold>

The value at which the reading is above normal range and fatal.

This property shall contain the value at which the Reading property is above the normal range and is fatal. The value of the property shall use the same units as the Reading property.

lower_caution: Option<Threshold>

The value at which the reading is below normal range.

This property shall contain the value at which the Reading property is below normal range. The value of the property shall use the same units as the Reading property.

lower_critical: Option<Threshold>

The value at which the reading is below normal range but not yet fatal.

This property shall contain the value at which the Reading property is below the normal range but is not yet fatal. The value of the property shall use the same units as the Reading property.

lower_fatal: Option<Threshold>

The value at which the reading is below normal range and fatal.

This property shall contain the value at which the Reading property is below the normal range and is fatal. The value of the property shall use the same units as the Reading property.

upper_caution_user: Option<Threshold>

A user-defined value at which the reading is considered above normal range.

This property shall contain a user-defined value at which the Reading property is considered above the normal range. The value of the property shall use the same units as the Reading property. The Reading property shall be considered above normal range if either the UpperCaution or UpperCautionUser threshold has been violated. This property is used to provide an additional, user-defined threshold value when the UpperCaution threshold is implemented as read-only to reflect a service-defined value that cannot be changed.

upper_critical_user: Option<Threshold>

A user-defined value at which the reading is considered above normal range but not yet fatal.

This property shall contain a user-defined value at which the Reading property is considered above the normal range but is not yet fatal. The value of the property shall use the same units as the Reading property. The Reading property shall be considered above normal range if either the UpperCritical or UpperCriticalUser threshold has been violated. This property is used to provide an additional, user-defined threshold value when the UpperCritical threshold is implemented as read-only to reflect a service-defined value that cannot be changed.

lower_caution_user: Option<Threshold>

A user-defined value at which the reading is considered below normal range.

This property shall contain a user-defined value at which the Reading property is considered below the normal range. The value of the property shall use the same units as the Reading property. The Reading property shall be considered below normal range if either the LowerCaution or LowerCautionUser threshold has been violated. This property is used to provide an additional, user-defined threshold value when the LowerCaution threshold is implemented as read-only to reflect a service-defined value that cannot be changed.

lower_critical_user: Option<Threshold>

A user-defined value at which the reading is considered below normal range but not yet fatal.

This property shall contain a user-defined value at which the Reading property is considered below the normal range but is not yet fatal. The value of the property shall use the same units as the Reading property. The Reading property shall be considered below normal range if either the LowerCritical or LowerCriticalUser threshold has been violated. This property is used to provide an additional, user-defined threshold value when the LowerCritical threshold is implemented as read-only to reflect a service-defined value that cannot be changed.