pub struct DeepOperations {
pub deep_patch: Option<Boolean>,
pub deep_post: Option<Boolean>,
pub max_levels: Option<Int64>,
}Expand description
The information about deep operations that the service supports.
This type shall contain information about deep operations that the service supports.
Fields
deep_patch: Option<Boolean>An indication of whether the service supports the deep PATCH operation.
This property shall indicate whether this service supports the Redfish Specification-defined deep
PATCH operation.
deep_post: Option<Boolean>An indication of whether the service supports the deep POST operation.
This property shall indicate whether this service supports the Redfish Specification-defined deep
POST operation.
max_levels: Option<Int64>The maximum levels of resources allowed in deep operations.
This property shall contain the maximum levels of resources allowed in deep operations.