ProtocolFeaturesSupported

Struct ProtocolFeaturesSupported 

pub struct ProtocolFeaturesSupported {
    pub expand_query: Option<Expand>,
    pub filter_query: Option<Boolean>,
    pub select_query: Option<Boolean>,
    pub excerpt_query: Option<Boolean>,
    pub only_member_query: Option<Boolean>,
    pub deep_operations: Option<DeepOperations>,
    pub multiple_http_requests: Option<Boolean>,
    pub top_skip_query: Option<Boolean>,
    pub filter_query_comparison_operations: Option<Boolean>,
    pub filter_query_compound_operations: Option<Boolean>,
    pub include_origin_of_condition_query: Option<Boolean>,
}

Fields

expand_query: Option<Expand>

The information about the use of $expand in the service.

This property shall contain information about the support of the $expand query parameter by the service.

filter_query: Option<Boolean>

An indication of whether the service supports the $filter query parameter.

This property shall indicate whether this service supports the $filter query parameter.

select_query: Option<Boolean>

An indication of whether the service supports the $select query parameter.

This property shall indicate whether this service supports the $select query parameter.

excerpt_query: Option<Boolean>

An indication of whether the service supports the excerpt query parameter.

This property shall indicate whether this service supports the excerpt query parameter.

only_member_query: Option<Boolean>

An indication of whether the service supports the only query parameter.

This property shall indicate whether this service supports the only query parameter.

deep_operations: Option<DeepOperations>

The information about deep operations that the service supports.

This property shall contain information about deep operations that the service supports.

multiple_http_requests: Option<Boolean>

An indication of whether the service supports multiple outstanding HTTP requests.

This property shall indicate whether this service supports multiple outstanding HTTP requests.

top_skip_query: Option<Boolean>

An indication of whether the service supports both the $top and $skip query parameters.

This property shall indicate whether this service supports both the $top and $skip query parameters.

filter_query_comparison_operations: Option<Boolean>

An indication of whether the service supports the eq, ge, gt, le, lt, and ne options for the $filter query parameter.

This property shall indicate whether the service supports the eq, ge, gt, le, lt, and ne options for the $filter query parameter. This property shall not be present if FilterQuery contains false.

filter_query_compound_operations: Option<Boolean>

An indication of whether the service supports the (), and, not, and or options for the $filter query parameter.

This property shall indicate whether the service supports the Redfish Specification-defined grouping operators (), and, not, and or options for the $filter query parameter. This property shall not be present if FilterQuery contains false.

include_origin_of_condition_query: Option<Boolean>

An indication of whether the service supports the includeoriginofcondition query parameter.

This property shall indicate whether the service supports the includeoriginofcondition query parameter.