pub struct ServiceRoot {Show 40 fields
pub base: Resource,
pub redfish_version: Option<String>,
pub uuid: Option<Option<Guid>>,
pub links: Links,
pub product: Option<Option<String>>,
pub protocol_features_supported: Option<ProtocolFeaturesSupported>,
pub vendor: Option<Option<String>>,
pub service_identification: Option<String>,
pub service_use_notification: Option<String>,
pub systems: Option<NavProperty<ComputerSystemCollection>>,
pub chassis: Option<NavProperty<ChassisCollection>>,
pub managers: Option<NavProperty<ManagerCollection>>,
pub tasks: Option<ReferenceLeaf>,
pub session_service: Option<NavProperty<SessionService>>,
pub account_service: Option<NavProperty<AccountService>>,
pub event_service: Option<NavProperty<EventService>>,
pub registries: Option<ReferenceLeaf>,
pub json_schemas: Option<ReferenceLeaf>,
pub storage_systems: Option<ReferenceLeaf>,
pub storage_services: Option<ReferenceLeaf>,
pub fabrics: Option<ReferenceLeaf>,
pub update_service: Option<NavProperty<UpdateService>>,
pub composition_service: Option<ReferenceLeaf>,
pub job_service: Option<ReferenceLeaf>,
pub telemetry_service: Option<NavProperty<TelemetryService>>,
pub certificate_service: Option<ReferenceLeaf>,
pub resource_blocks: Option<ReferenceLeaf>,
pub power_equipment: Option<ReferenceLeaf>,
pub facilities: Option<ReferenceLeaf>,
pub aggregation_service: Option<ReferenceLeaf>,
pub storage: Option<NavProperty<StorageCollection>>,
pub nvme_domains: Option<ReferenceLeaf>,
pub key_service: Option<ReferenceLeaf>,
pub cables: Option<ReferenceLeaf>,
pub license_service: Option<ReferenceLeaf>,
pub service_conditions: Option<ReferenceLeaf>,
pub component_integrity: Option<ReferenceLeaf>,
pub registered_clients: Option<ReferenceLeaf>,
pub thermal_equipment: Option<ReferenceLeaf>,
pub automation_nodes: Option<ReferenceLeaf>,
}Expand description
The ServiceRoot schema describes the root of the Redfish service, located at the ‘/redfish/v1’
URI. All other resources accessible through the Redfish interface on this device are linked
directly or indirectly from the service root.
This resource shall represent the root of the Redfish service.
Fields
base: ResourceBase type
redfish_version: Option<String>The version of the Redfish service.
This property shall represent the Redfish protocol version, as specified in the ‘Protocol version’ clause of the Redfish Specification, to which this service conforms.
uuid: Option<Option<Guid>>Unique identifier for a service instance. When SSDP is used, this value contains the same UUID
returned in an HTTP 200 OK response from an SSDP M-SEARCH request during discovery.
This property shall contain the identifier of the Redfish service instance. If SSDP is used, this
value shall contain the same UUID returned in an HTTP 200 OK response from an SSDP M-SEARCH
request during discovery. RFC4122 describes methods to use to create a UUID value. The value
should be considered to be opaque. Client software should only treat the overall value as a
universally unique identifier and should not interpret any subfields within the UUID.
links: LinksThe links to other resources that are related to this resource.
This property shall contain links to resources that are related to but are not contained by, or subordinate to, this resource.
product: Option<Option<String>>The product associated with this Redfish service.
This property shall include the name of the product represented by this Redfish service.
protocol_features_supported: Option<ProtocolFeaturesSupported>The information about protocol features that the service supports.
This property shall contain information about protocol features that the service supports.
vendor: Option<Option<String>>The vendor or manufacturer associated with this Redfish service.
This property shall include the name of the manufacturer or vendor represented by this Redfish
service. If this property is supported, the vendor name shall not be included in the Product
property value.
service_identification: Option<String>The vendor or user-provided product and service identifier.
This property shall contain a vendor-provided or user-provided value that identifies and associates
a discovered Redfish service with a particular product instance. The value of the property shall
contain the value of the ServiceIdentification property in the Manager resource providing the
Redfish service root resource. The value of this property is used in conjunction with the
Product and Vendor properties to match user credentials or other a priori product instance
information necessary for initial deployment to the correct, matching Redfish service. This
property shall not be present if the value of the ServiceIdentification property in the Manager
resource providing the Redfish service root resource is an empty string or null.
service_use_notification: Option<String>The usage notification message for this service.
This property shall contain the usage notification message for this service. The value of the
property shall contain the value of the ServiceUseNotification property in the Manager resource
providing the Redfish service root resource. This property shall not be present if the value of
the ServiceUseNotification property in the Manager resource providing the Redfish service root
resource is an empty string or null.
systems: Option<NavProperty<ComputerSystemCollection>>The link to a collection of systems.
This property shall contain a link to a resource collection of type ComputerSystemCollection.
chassis: Option<NavProperty<ChassisCollection>>The link to a collection of chassis.
This property shall contain a link to a resource collection of type ChassisCollection.
managers: Option<NavProperty<ManagerCollection>>The link to a collection of managers.
This property shall contain a link to a resource collection of type ManagerCollection.
tasks: Option<ReferenceLeaf>session_service: Option<NavProperty<SessionService>>The link to the sessions service.
This property shall contain a link to a resource of type SessionService.
account_service: Option<NavProperty<AccountService>>The link to the account service.
This property shall contain a link to a resource of type AccountService.
event_service: Option<NavProperty<EventService>>The link to the event service.
This property shall contain a link to a resource of type EventService.
registries: Option<ReferenceLeaf>json_schemas: Option<ReferenceLeaf>storage_systems: Option<ReferenceLeaf>storage_services: Option<ReferenceLeaf>fabrics: Option<ReferenceLeaf>update_service: Option<NavProperty<UpdateService>>The link to the update service.
This property shall contain a link to a resource of type UpdateService.
composition_service: Option<ReferenceLeaf>job_service: Option<ReferenceLeaf>telemetry_service: Option<NavProperty<TelemetryService>>The link to the telemetry service.
This property shall contain a link to a resource of type TelemetryService.
certificate_service: Option<ReferenceLeaf>resource_blocks: Option<ReferenceLeaf>power_equipment: Option<ReferenceLeaf>facilities: Option<ReferenceLeaf>aggregation_service: Option<ReferenceLeaf>storage: Option<NavProperty<StorageCollection>>The link to a collection of storage subsystems.
This property shall contain a link to a resource collection of type StorageCollection.
nvme_domains: Option<ReferenceLeaf>key_service: Option<ReferenceLeaf>cables: Option<ReferenceLeaf>license_service: Option<ReferenceLeaf>service_conditions: Option<ReferenceLeaf>component_integrity: Option<ReferenceLeaf>registered_clients: Option<ReferenceLeaf>thermal_equipment: Option<ReferenceLeaf>automation_nodes: Option<ReferenceLeaf>