Session

Struct Session 

pub struct Session {
Show 13 fields pub base: Resource, pub user_name: Option<Option<String>>, pub password: Option<Option<String>>, pub actions: Option<Actions>, pub session_type: Option<Option<SessionTypes>>, pub oem_session_type: Option<Option<String>>, pub client_origin_ip_address: Option<Option<String>>, pub created_time: Option<Option<DateTimeOffset>>, pub context: Option<Option<String>>, pub token: Option<Option<String>>, pub roles: Option<Option<Vec<String>>>, pub links: Option<Links>, pub expiration_time: Option<DateTimeOffset>,
}
The Session resource describes a single connection (session) between a client and a Redfish service instance.

This resource shall represent a session for a Redfish implementation.

Fields

base: Resource

Base type

user_name: Option<Option<String>>

The username for the account for this session.

This property shall contain the username that matches an account recognized by the account service. When a creating a session through a Redfish host interface using an AuthNone role, the property shall contain an empty string in the request body.

password: Option<Option<String>>

The password for this session. The value is null in responses.

This property shall contain the password for this session. The value shall be null in responses. When creating a session through a Redfish host interface using an AuthNone role, the property shall contain an empty string in the request body.

actions: Option<Actions>

The available actions for this resource.

This property shall contain the available actions for this resource.

session_type: Option<Option<SessionTypes>>

The active session type.

This property shall represent the type of session that is currently active.

oem_session_type: Option<Option<String>>

The active OEM-defined session type.

This property shall contain the OEM-specific session type that is currently active if SessionType contains OEM.

client_origin_ip_address: Option<Option<String>>

The IP address of the client that created the session.

This property shall contain the IP address of the client that created the session.

created_time: Option<Option<DateTimeOffset>>

The date and time when the session was created.

This property shall contain the date and time when the session was created.

context: Option<Option<String>>

A client-supplied string that is stored with the session.

This property shall contain a client-supplied context that remains with the session through the session’s lifetime.

token: Option<Option<String>>

The multi-factor authentication token for this session. The value is null in responses.

This property shall contain the multi-factor authentication token for this session. The value shall be null in responses.

roles: Option<Option<Vec<String>>>

The Redfish roles that contain the privileges of this session.

This property shall contain the Redfish roles that contain the privileges of this session.

links: Option<Links>

The links to other resources that are related to this resource.

This property shall contain links to resources that are related to but are not contained by, or subordinate to, this resource.

expiration_time: Option<DateTimeOffset>

The date and time when the session expires regardless of session activity.

This property shall contain the date and time when the session expires regardless of session activity. The service shall delete this resource when the expiration time is reached. If this property is not present, the session does not expire based on an absolute time.