pub struct SessionService {
pub base: Resource,
pub status: Option<Status>,
pub service_enabled: Option<Option<Boolean>>,
pub session_timeout: Option<Int64>,
pub actions: Option<Actions>,
pub absolute_session_timeout: Option<Int64>,
pub absolute_session_timeout_enabled: Option<Boolean>,
pub sessions: Option<NavProperty<SessionCollection>>,
}Expand description
The SessionService schema describes the session service and its properties, with links to the
actual list of sessions.
This resource contains the session service properties for a Redfish implementation.
Fields
base: ResourceBase type
status: Option<Status>The status and health of the resource and its subordinate or dependent resources.
This property shall contain any status or health properties of the resource.
service_enabled: Option<Option<Boolean>>An indication of whether this service is enabled. If true, this service is enabled. If false,
it is disabled, and new sessions cannot be created, old sessions cannot be deleted, and established
sessions can continue operating.
This property shall indicate whether this service is enabled. If true, this service is enabled.
If false, it is disabled, and new sessions shall not be created, old sessions shall not be
deleted, and established sessions can continue operating.
session_timeout: Option<Int64>The number of seconds of inactivity that a session can have before the session service closes the session due to inactivity.
This property shall contain the threshold of time in seconds between requests on a specific session at which point the session service shall close the session due to inactivity. The session service shall support any value between the schema-specified minimum and maximum terms.
actions: Option<Actions>The available actions for this resource.
This property shall contain the available actions for this resource.
absolute_session_timeout: Option<Int64>The maximum number of seconds that a session is open before the service closes the session regardless of activity.
This property shall contain the maximum number of seconds that a session is open before the service closes the session regardless of activity.
absolute_session_timeout_enabled: Option<Boolean>An indication of whether an absolute session timeout is applied to sessions.
This property shall indicate whether an absolute session timeout is applied to sessions. If
true, the service shall close sessions that are open for the number of seconds specified by the
AbsoluteSessionTimeout property regardless of session activity. If false or if this property
is not present, the service shall not apply an absolute session timeout.
sessions: Option<NavProperty<SessionCollection>>The link to a collection of sessions.
This property shall contain a link to a resource collection of type SessionCollection.