pub enum VersionScheme {
SemVer,
DotIntegerNotation,
Oem,
UnsupportedValue,
}Variants
SemVer
Version follows Semantic Versioning 2.0 rules.
This value shall indicate that the value of the Version property conforms to the format and rules
of the Semantic Version 2.0 specification, and may include pre-release or build metadata.
DotIntegerNotation
Version formatted as dot-separated integers.
This value shall indicate that the value of the Version property contains a sequence of integers
separated by period (dot) characters, and shall follow the pattern ^\d+(\.\d+)*$. Leading zeros
in the sequence shall be ignored.
Oem
Version follows OEM-defined format.
This value shall indicate that the value of the Version property follows a format and rules as
defined by the vendor or manufacturer.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.