pub struct Links {
pub staged_targets: Option<Vec<ReferenceLeaf>>,
pub active_targets: Option<Vec<ReferenceLeaf>>,
}Expand description
The links to other resources that are related to this resource.
This property shall contain links to resources that are related to but are not contained by, or subordinate to, this resource.
Fields
staged_targets: Option<Vec<ReferenceLeaf>>active_targets: Option<Vec<ReferenceLeaf>>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for Links
impl<'de> Deserialize<'de> for Links
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Send for Links
SAFETY: All generated data types are Send
impl Sync for Links
SAFETY: All generated data types are Sync