pub struct MeasurementBlock {
pub measurement_specification: Option<Option<Int64>>,
pub measurement_size: Option<Option<Int64>>,
pub measurement: Option<Option<String>>,
pub measurement_index: Option<Option<Int64>>,
}Fields
measurement_specification: Option<Option<Int64>>The DSP0274-defined ‘MeasurementSpecification’ field of the measurement block.
This property shall contain the value of the DSP0274-defined ‘MeasurementSpecification’ field of the measurement block.
measurement_size: Option<Option<Int64>>The DSP0274-defined ‘MeasurementSize’ field of the measurement block.
This property shall contain the value of the DSP0274-defined ‘MeasurementSize’ field of the measurement block.
measurement: Option<Option<String>>The hexadecimal string representation of the numeric value of the DSP0274-defined ‘Measurement’ field of the measurement block.
This property shall contain the value of the hexadecimal string representation of the numeric value of the DSP0274-defined ‘Measurement’ field of the measurement block.
measurement_index: Option<Option<Int64>>The DSP0274-defined ‘Index’ field of the measurement block.
This property shall contain the value of the DSP0274-defined ‘Index’ field of the measurement block.