pub struct SoftwareInventory {Show 23 fields
pub base: Resource,
pub status: Option<Status>,
pub version: Option<Option<String>>,
pub updateable: Option<Option<Boolean>>,
pub actions: Option<Actions>,
pub software_id: Option<String>,
pub lowest_supported_version: Option<Option<String>>,
pub uefi_device_paths: Option<Option<Vec<String>>>,
pub manufacturer: Option<Option<String>>,
pub release_date: Option<Option<DateTimeOffset>>,
pub write_protected: Option<Option<Boolean>>,
pub measurement: Option<MeasurementBlock>,
pub additional_versions: Option<AdditionalVersions>,
pub version_scheme: Option<Option<VersionScheme>>,
pub release_type: Option<Option<ReleaseType>>,
pub associated_physical_context: Option<PhysicalContext>,
pub active: Option<Option<Boolean>>,
pub staged: Option<Option<Boolean>>,
pub reset_required_on_update: Option<Option<Boolean>>,
pub links: Option<Links>,
pub image_data_uri: Option<Option<String>>,
pub size_bytes: Option<Option<Int64>>,
pub related_item: Option<Vec<ReferenceLeaf>>,
}Expand description
The SoftwareInventory schema contains an inventory of software components. This can include
software components such as BIOS, BMC firmware, firmware for other devices, system drivers, or
provider software.
This resource contains a single software component that this Redfish service manages.
Fields
base: ResourceBase type
status: Option<Status>The status and health of the resource and its subordinate or dependent resources.
This property shall contain any status or health properties of the resource.
version: Option<Option<String>>The version of this software.
This property shall contain the version of this software.
updateable: Option<Option<Boolean>>An indication of whether the update service can update this software.
This property shall indicate whether the update service can update this software. If true, the
service can update this software. If false, the service cannot update this software and the
software is for reporting purposes only.
actions: Option<Actions>The available actions for this resource.
This property shall contain the available actions for this resource.
software_id: Option<String>The implementation-specific label that identifies this software.
This property shall represent an implementation-specific label that identifies this software. This string correlates with a component repository or database.
lowest_supported_version: Option<Option<String>>The lowest supported version of this software.
This property shall represent the lowest supported version of this software. This string is
formatted using the same format used for the Version property.
uefi_device_paths: Option<Option<Vec<String>>>The list of UEFI device paths of the components associated with this software inventory item.
This property shall contain a list UEFI device paths of the components associated with this software inventory item. The UEFI device paths shall be formatted as defined by the UEFI Specification.
manufacturer: Option<Option<String>>The manufacturer or producer of this software.
This property shall represent the name of the manufacturer or producer of this software.
release_date: Option<Option<DateTimeOffset>>The release date of this software.
This property shall contain the date of release or production for this software. If the time of
day is unknown, the time of day portion of the property shall contain 00:00:00Z.
write_protected: Option<Option<Boolean>>Indicates if the software is write-protected.
This property shall indicate whether the software image can be overwritten, where a value true
shall indicate that the software cannot be altered or overwritten.
measurement: Option<MeasurementBlock>A DSP0274-defined measurement block.
This property shall contain a DSP0274-defined measurement block.
additional_versions: Option<AdditionalVersions>The additional versions of this software.
This property shall contain the additional versions of this software.
version_scheme: Option<Option<VersionScheme>>The format of the version.
This property shall describe the scheme used to format the value of the Version property.
release_type: Option<Option<ReleaseType>>The type of release.
This property shall describe the type of release for the software.
associated_physical_context: Option<PhysicalContext>The area or device to which the software applies. Used to distinguish when different parts of a device have different software components.
This property shall contain a description of the physical context for the software inventory data.
active: Option<Option<Boolean>>This image is active on one or more devices.
This property shall indicate that the software image is currently in use on one or more devices.
staged: Option<Option<Boolean>>This image is ready to be activated to one or more devices.
This property shall indicate that the software image is ready to be activated to one or more devices.
reset_required_on_update: Option<Option<Boolean>>An indication of whether a reset is required to apply an update to this software.
This property shall indicate whether a reset is required to apply an update to this software. If
true, a reset is required and clients should expect a disruption in communication to targets
utilizing this software while applying an update. If false, a reset is not required and
communication can be maintained to targets utilizing this software throughout an update.
links: Option<Links>The links to other resources that are related to this resource.
This property shall contain links to resources that are related to but are not contained by, or subordinate to, this resource.
image_data_uri: Option<Option<String>>The URI at which to access the software inventory image.
This property shall contain the URI at which to access the image data for this software inventory, using the Redfish protocol and authentication methods. This image should be the original vendor-provided image suitable for update operations.
size_bytes: Option<Option<Int64>>The size of the software image in bytes.
This property shall contain the size of the software image in bytes.