SoftwareInventoryActivateAction

Struct SoftwareInventoryActivateAction 

pub struct SoftwareInventoryActivateAction {
    pub targets: Option<Vec<Reference>>,
}
This action activates this software inventory instance.

This action shall activate this software inventory instance.

Fields

targets: Option<Vec<Reference>>

The target devices to activate this software image. If not specified, the service activates this software image on all applicable devices.

This parameter shall contain an array of target devices to activate this software image. If not specified, the service shall activate this software image on all applicable devices.