pub struct NvmeConfigurationLockState {
pub firmware_commit: Option<Option<ConfigLockOptions>>,
pub lockdown: Option<Option<ConfigLockOptions>>,
pub security_send: Option<Option<ConfigLockOptions>>,
pub firmware_image_download: Option<Option<ConfigLockOptions>>,
pub vpd_write: Option<Option<ConfigLockOptions>>,
}Expand description
The configurable features that are able to be locked on an NVMe subsystem and their current lock state.
This type shall contain the configurable features that are able to be locked on an NVMe subsystem and their current lock state.
Fields
firmware_commit: Option<Option<ConfigLockOptions>>The lock state of the NVMe-defined Firmware Commit command.
This property shall contain the lock state of the NVMe-defined Firmware Commit command.
lockdown: Option<Option<ConfigLockOptions>>The lock state of the NVMe-defined Lockdown command.
This property shall contain the lock state of the NVMe-defined Lockdown command.
security_send: Option<Option<ConfigLockOptions>>The lock state of the NVMe-defined Security Send command.
This property shall contain the lock state of the NVMe-defined Security Send command.
firmware_image_download: Option<Option<ConfigLockOptions>>The lock state of the NVMe-defined Firmware Image Download command.
This property shall contain the lock state of the NVMe-defined Firmware Image Download command.
vpd_write: Option<Option<ConfigLockOptions>>The lock state of the NVMe-MI-defined VPD Write command.
This property shall contain the lock state of the NVMe-MI-defined VPD Write command.