pub struct StorageSetEncryptionKeyAction {
pub encryption_key: Option<String>,
pub encryption_key_identifier: Option<String>,
pub current_encryption_key: Option<String>,
}Expand description
This action sets the local encryption key for the storage subsystem.
This action shall set the local encryption key for the storage subsystem.
Fields
encryption_key: Option<String>The local encryption key to set on the storage subsystem.
This parameter shall contain the local encryption key to set on the storage subsystem.
encryption_key_identifier: Option<String>The local encryption key identifier used by the storage subsystem.
This property shall contain the local encryption key identifier used by the storage subsystem.
current_encryption_key: Option<String>The current local encryption key on the storage subsystem. This parameter is not needed if the controller does not currently have an encryption key.
This parameter shall contain the current local encryption key on the storage subsystem. Services may reject the action request if this parameter is not provided or the value supplied does not match the current encryption key.