pub struct CacheSummary {
pub total_cache_size_mi_b: Option<Int64>,
pub persistent_cache_size_mi_b: Option<Option<Int64>>,
pub status: Option<Status>,
}Expand description
This type describes the cache memory of the storage controller in general detail.
This type shall contain properties that describe the cache memory for a storage controller.
Fields
total_cache_size_mi_b: Option<Int64>The total configured cache memory, measured in MiB.
This property shall contain the amount of configured cache memory as measured in mebibytes.
persistent_cache_size_mi_b: Option<Option<Int64>>The portion of the cache memory that is persistent, measured in MiB.
This property shall contain the amount of cache memory that is persistent as measured in mebibytes.
This size shall be less than or equal to the TotalCacheSizeMiB.
status: Option<Status>The status and health of the resource and its subordinate or dependent resources.
This property shall contain any status or health properties of the resource.