pub struct NvmeControllerAttributes {
pub reports_uuid_list: Option<Option<Boolean>>,
pub supports_sq_associations: Option<Option<Boolean>>,
pub reports_namespace_granularity: Option<Option<Boolean>>,
pub supports_traffic_based_keep_alive: Option<Option<Boolean>>,
pub supports_predictable_latency_mode: Option<Option<Boolean>>,
pub supports_endurance_groups: Option<Option<Boolean>>,
pub supports_read_recovery_levels: Option<Option<Boolean>>,
pub supports_nvm_sets: Option<Option<Boolean>>,
pub supports_exceeding_power_of_non_operational_state: Option<Option<Boolean>>,
pub supports128bit_host_id: Option<Option<Boolean>>,
pub supports_reservations: Option<Option<Boolean>>,
}Fields
reports_uuid_list: Option<Option<Boolean>>Indicates whether or not the controller supports reporting of a UUID list.
This property shall indicate whether or not the controller supports reporting of a UUID list.
supports_sq_associations: Option<Option<Boolean>>Indicates whether or not the controller supports SQ Associations.
This property shall indicate whether or not the controller supports SQ Associations.
reports_namespace_granularity: Option<Option<Boolean>>Indicates whether or not the controller supports reporting of Namespace Granularity.
This property shall indicate whether or not the controller supports reporting of Namespace Granularity.
supports_traffic_based_keep_alive: Option<Option<Boolean>>Indicates whether or not the controller supports restarting the Keep Alive Timer if traffic is processed from an admin command or I/O during a Keep Alive Timeout interval.
This property shall indicate whether or not the controller supports restarting the Keep Alive Timer if traffic is processed from an admin command or I/O during a Keep Alive Timeout interval.
supports_predictable_latency_mode: Option<Option<Boolean>>Indicates whether or not the controller supports Predictable Latency Mode.
This property shall indicate whether or not the controller supports Predictable Latency Mode.
supports_endurance_groups: Option<Option<Boolean>>Indicates whether or not the controller supports Endurance Groups.
This property shall indicate whether or not the controller supports Endurance Groups.
supports_read_recovery_levels: Option<Option<Boolean>>Indicates whether or not the controller supports Read Recovery Levels.
This property shall indicate whether or not the controller supports Read Recovery Levels.
supports_nvm_sets: Option<Option<Boolean>>Indicates whether or not the controller supports NVM Sets.
This property shall indicate whether or not the controller supports NVM Sets.
supports_exceeding_power_of_non_operational_state: Option<Option<Boolean>>Indicates whether or not the controller supports exceeding Power of Non-Operational State in order to execute controller-initiated background operations in a non-operational power state.
This property shall indicate whether or not the controller supports exceeding Power of Non-Operational State in order to execute controller-initiated background operations in a non-operational power state.
supports128bit_host_id: Option<Option<Boolean>>Indicates whether or not the controller supports a 128-bit Host Identifier.
This property shall indicate whether or not the controller supports a 128-bit Host Identifier.
supports_reservations: Option<Option<Boolean>>Indicates if the controller supports reservations.
This property shall indicate if the controller supports reservations.