pub struct NvmeControllerProperties {
pub controller_type: Option<Option<NvmeControllerType>>,
pub nvme_version: Option<Option<String>>,
pub nvme_controller_attributes: Option<Option<NvmeControllerAttributes>>,
pub max_queue_size: Option<Option<Int64>>,
pub ana_characteristics: Option<Option<Vec<AnaCharacteristics>>>,
pub nvme_smart_critical_warnings: Option<Option<NvmeSmartCriticalWarnings>>,
pub allocated_submission_queues: Option<Option<Int64>>,
pub allocated_completion_queues: Option<Option<Int64>>,
pub max_attached_namespaces: Option<Option<Int64>>,
pub discovery_transport_service_id: Option<Option<Int64>>,
}Fields
controller_type: Option<Option<NvmeControllerType>>The type of NVMe controller.
This property shall contain the type of NVMe controller.
nvme_version: Option<Option<String>>The version of the NVMe Base Specification supported.
This property shall contain the version of the NVMe Base Specification supported.
nvme_controller_attributes: Option<Option<NvmeControllerAttributes>>The NVMe controller attributes.
This property shall contain NVMe controller attributes.
max_queue_size: Option<Option<Int64>>The maximum individual queue size that an NVMe I/O controller supports.
This property shall contain the maximum individual queue entry size supported per queue. This is a zero-based value, where the minimum value is one, indicating two entries. For PCIe, this applies to both submission and completion queues. For NVMe-oF, this applies only to submission queues.
ana_characteristics: Option<Option<Vec<AnaCharacteristics>>>The ANA characteristics and volume information.
This property shall contain the ANA characteristics and volume information.
nvme_smart_critical_warnings: Option<Option<NvmeSmartCriticalWarnings>>The NVMe SMART Critical Warnings for this storage controller. This property contains possible triggers for the predictive drive failure warning for the corresponding drive.
This property shall contain the NVMe SMART Critical Warnings for this storage controller. This property can contain possible triggers for the predictive drive failure warning for the corresponding drive.
allocated_submission_queues: Option<Option<Int64>>The number of I/O submission queues allocated to this NVMe I/O controller.
This property shall contain the number of I/O submission queues allocated to this NVMe I/O controller.
allocated_completion_queues: Option<Option<Int64>>The number of I/O completion queues allocated to this NVMe I/O controller.
This property shall contain the number of I/O completion queues allocated to this NVMe I/O controller.
max_attached_namespaces: Option<Option<Int64>>The maximum number of attached namespaces allowed by this NVMe I/O controller.
This property shall contain the maximum number of attached namespaces allowed by this NVMe I/O controller.
discovery_transport_service_id: Option<Option<Int64>>The NVMe discovery transport service identifier for the discovery controller.
This property shall contain the NVMe discovery transport service identifier for the discovery
controller. This property shall only be present if ControllerType contains Discovery. For
NVMe/TCP, the default value should be 8009.