pub struct Rates {
pub rebuild_rate_percent: Option<Option<Int64>>,
pub transformation_rate_percent: Option<Option<Int64>>,
pub consistency_check_rate_percent: Option<Option<Int64>>,
}Expand description
This type describes the various controller rates used for processes such as volume rebuild or consistency checks.
This type shall contain all the rate settings available on the controller.
Fields
rebuild_rate_percent: Option<Option<Int64>>The percentage of controller resources used for rebuilding/repairing volumes.
This property shall contain the percentage, 0 to 100, of controller resources used for
rebuilding volumes.
transformation_rate_percent: Option<Option<Int64>>The percentage of controller resources used for transforming volumes from one configuration to another.
This property shall contain the percentage, 0 to 100, of controller resources used for
transforming volumes.
consistency_check_rate_percent: Option<Option<Int64>>The percentage of controller resources used for performing a data consistency check on volumes.
This property shall contain the percentage, 0 to 100, of controller resources used for checking
data consistency on volumes.