pub struct StorageControllerDetachNamespacesAction {
pub namespaces: Option<Vec<Reference>>,
}Expand description
This action detaches referenced namespaces or volumes from the storage controller. Detached
namespaces and volumes are removed from the AttachedVolumes property in Links. For NVMe,
namespaces are modeled as Volume resources.
This action shall detach referenced namespaces or volumes from the storage controller. Services
shall remove the detached namespaces and volumes from the AttachedVolumes property in Links.
For NVMe, namespaces are modeled as Volume resources.
Fields
namespaces: Option<Vec<Reference>>The namespaces or volumes to detach from the storage controller.
This parameter shall contain an array of links to resources of type Volume that represent the
namespaces or volumes to detach from the storage controller.