Task

Struct Task 

pub struct Task {
Show 14 fields pub base: Resource, pub task_state: Option<TaskState>, pub start_time: Option<DateTimeOffset>, pub end_time: Option<DateTimeOffset>, pub task_status: Option<Health>, pub messages: Option<Vec<Message>>, pub actions: Option<Actions>, pub task_monitor: Option<String>, pub payload: Option<Payload>, pub hide_payload: Option<Boolean>, pub percent_complete: Option<Option<Int64>>, pub estimated_duration: Option<Option<Duration>>, pub links: Option<Links>, pub sub_tasks: Option<NavProperty<TaskCollection>>,
}
The Task schema contains information about a task that the Redfish task service schedules or executes. Tasks represent operations that take more time than a client typically wants to wait.

This resource contains a task for a Redfish implementation.

Fields

base: Resource

Base type

task_state: Option<TaskState>

The state of the task.

This property shall indicate the state of the task.

start_time: Option<DateTimeOffset>

The date and time when the task was started.

This property shall indicate the date and time when the task was started.

end_time: Option<DateTimeOffset>

The date and time when the task was completed. This property will only appear when the task is complete.

This property shall indicate the date and time when the task was completed. This property shall not appear if the task is running or otherwise has not been completed. This property shall appear only if the TaskState is Completed, Killed, Cancelled, or Exception.

task_status: Option<Health>

The completion status of the task.

This property shall contain the completion status of the task and shall not be set until the task completes. This property should contain Critical if one or more messages in the Messages array contains the severity Critical. This property should contain Warning if one or more messages in the Messages array contains the severity Warning and if no messages contain the severity Critical. This property should contain OK if all messages in the Messages array contain the severity OK or if the array is empty.

messages: Option<Vec<Message>>

An array of messages associated with the task.

This property shall contain an array of messages associated with the task.

actions: Option<Actions>

The available actions for this resource.

This property shall contain the available actions for this resource.

task_monitor: Option<String>

The URI of the task monitor for this task.

This property shall contain a URI to task monitor as defined in the Redfish Specification.

payload: Option<Payload>

The HTTP and JSON request payload details for this task, unless they are hidden from view by the service.

This object shall contain information detailing the HTTP and JSON request payload information for executing this task. This property shall not be included in the response if the HidePayload property is true.

hide_payload: Option<Boolean>

An indication of whether the contents of the payload are hidden from view after the task has been created. If true, responses do not return the payload. If false, responses return the payload. If this property is not present when the task is created, the default is false.

This property shall indicate whether the contents of the payload should be hidden from view after the task has been created. If true, responses shall not return the Payload property. If false, responses shall return the Payload property. If this property is not present when the task is created, the default is false. This property shall be supported if the Payload property is supported.

percent_complete: Option<Option<Int64>>

The completion percentage of this task.

This property shall indicate the completion progress of the task, reported in percent of completion, 0 to 100. If the task has not been started, the value shall be zero.

estimated_duration: Option<Option<Duration>>

The estimated total time required to complete the task.

This property shall indicate the estimated total time needed to complete the task. The value is not expected to change while the task is in progress, but the service may update the value if it obtains new information that significantly changes the expected duration. Services should be conservative in the reported estimate and clients should treat this value as an estimate.

links: Option<Links>

Contains references to other resources that are related to this resource.

The Links property, as described by the Redfish Specification, shall contain references to resources that are related to but are not contained by, or subordinate to, this resource.

sub_tasks: Option<NavProperty<TaskCollection>>

The link to a collection of sub-tasks for this task.

This property shall contain a link to a resource collection of type TaskCollection. This property shall not be present if this resource represents a sub-task for a task.