pub enum CollectionFunction {
Average,
Maximum,
Minimum,
Summation,
UnsupportedValue,
}Expand description
An operation to perform over the sample.
If present, the metric value shall be computed according to this function.
Variants
Average
An averaging function.
Maximum
A maximum function.
Minimum
A minimum function.
Summation
A summation function.
UnsupportedValue
Fallback value for values that are not supported by current version of Redfish schema.