pub struct CollectTelemetryDataResponse {
pub telemetry_data: Vec<String>,
}Expand description
The response body for the CollectTelemetryData action.
This type shall contain the properties found in the response body for the CollectTelemetryData
action.
Fields
telemetry_data: Vec<String>An array of links to the collected telemetry data.
This property shall contain an array of links to resources of type TelemetryData that represent
the collected telemetry data.