pub struct TelemetryService {Show 15 fields
pub base: Resource,
pub status: Option<Status>,
pub max_reports: Option<Option<Int64>>,
pub min_collection_interval: Option<Option<Duration>>,
pub supported_collection_functions: Option<Option<Vec<CollectionFunction>>>,
pub actions: Option<Actions>,
pub service_enabled: Option<Option<Boolean>>,
pub supported_telemetry_data_types: Option<Option<Vec<TelemetryDataTypes>>>,
pub supported_oem_telemetry_data_types: Option<Option<Vec<String>>>,
pub metric_definitions: Option<NavProperty<MetricDefinitionCollection>>,
pub metric_report_definitions: Option<NavProperty<MetricReportDefinitionCollection>>,
pub metric_reports: Option<NavProperty<MetricReportCollection>>,
pub triggers: Option<ReferenceLeaf>,
pub log_service: Option<NavProperty<LogService>>,
pub telemetry_data: Option<ReferenceLeaf>,
}Expand description
The TelemetryService schema describes a telemetry service. The telemetry service is used for
collecting and reporting metric data within the Redfish service.
This resource contains a telemetry service for a Redfish implementation.
Fields
base: ResourceBase type
status: Option<Status>The status and health of the resource and its subordinate or dependent resources.
This property shall contain any status or health properties of the resource.
max_reports: Option<Option<Int64>>The maximum number of metric reports that this service supports.
This property shall contain the maximum number of metric reports that this service supports.
min_collection_interval: Option<Option<Duration>>The minimum time interval between gathering metric data that this service allows.
This property shall contain the minimum time interval between gathering metric data that this service allows.
supported_collection_functions: Option<Option<Vec<CollectionFunction>>>The functions that can be performed over each metric.
This property shall contain the function to apply over the collection duration.
actions: Option<Actions>The available actions for this resource.
This property shall contain the available actions for this resource.
service_enabled: Option<Option<Boolean>>An indication of whether this service is enabled.
This property shall indicate whether this service is enabled.
supported_telemetry_data_types: Option<Option<Vec<TelemetryDataTypes>>>A list of supported telemetry data types.
This property shall contain a list of supported telemetry data types.
supported_oem_telemetry_data_types: Option<Option<Vec<String>>>A list of supported OEM-defined telemetry data types.
This property shall contain a list of supported OEM-defined telemetry data types.
metric_definitions: Option<NavProperty<MetricDefinitionCollection>>The link to the collection of metric definitions.
This property shall contain a link to a resource collection of type MetricDefinitionCollection.
metric_report_definitions: Option<NavProperty<MetricReportDefinitionCollection>>The link to the collection of metric report definitions.
This property shall contain a link to a resource collection of type
MetricReportDefinitionCollection.
metric_reports: Option<NavProperty<MetricReportCollection>>The link to the collection of metric reports.
This property shall contain a link to a resource collection of type MetricReportCollection.
triggers: Option<ReferenceLeaf>log_service: Option<NavProperty<LogService>>The link to a log service that the telemetry service uses. This service can be a dedicated log service or a pointer to a log service under another resource, such as a manager.
This property shall contain a link to a resource of type LogService that this telemetry service
uses.
telemetry_data: Option<ReferenceLeaf>