pub struct TelemetryServiceClearTelemetryDataAction {}Expand description
The action to clear the telemetry data for this telemetry service.
This action shall delete all entries found in the telemetry data collection for this telemetry service.