pub struct TelemetryServiceCollectTelemetryDataAction {
pub telemetry_data_type: Option<TelemetryDataTypes>,
pub oem_telemetry_data_type: Option<String>,
pub target_devices: Option<Vec<Reference>>,
}Expand description
The action to collect the telemetry data from a device or service. When the telemetry data is collected, a new telemetry data resource will be created.
This action shall collect the telemetry data from a device or service. The Location header in
the response shall contain a URI to a resource of type TelemetryData that contains the telemetry
data. The AdditionalDataURI property in the referenced TelemetryData resource shall contain
the URI to download the telemetry data.
Fields
telemetry_data_type: Option<TelemetryDataTypes>The type of telemetry data to collect.
This parameter shall contain the type of telemetry data to collect.
oem_telemetry_data_type: Option<String>The OEM-defined type of telemetry data to collect.
This parameter shall contain the OEM-defined type of telemetry data to collect. This parameter
shall be required if TelemetryDataType is OEM.
target_devices: Option<Vec<Reference>>An array of devices from which to collect telemetry data.
This parameter shall contain an array of devices from which to collect telemetry data.