pub struct HttpPushUriOptions {
pub http_push_uri_apply_time: Option<HttpPushUriApplyTime>,
pub force_update: Option<Boolean>,
}Fields
http_push_uri_apply_time: Option<HttpPushUriApplyTime>The settings for when to apply HttpPushUri-provided firmware.
This property shall contain settings for when to apply HttpPushUri-provided firmware.
force_update: Option<Boolean>An indication of whether the service should bypass update policies when applying the
HttpPushUri-provided image.
This property shall indicate whether the service should bypass update policies when applying the
HttpPushUri-provided image, such as allowing a component to be downgraded. Services may contain
update policies that are never bypassed, such as minimum version enforcement. If this property is
not present, it shall be assumed to be false.