pub struct UpdateService {Show 24 fields
pub base: Resource,
pub status: Option<Status>,
pub service_enabled: Option<Option<Boolean>>,
pub actions: Option<Actions>,
pub http_push_uri: Option<String>,
pub http_push_uri_targets: Option<Option<Vec<String>>>,
pub http_push_uri_targets_busy: Option<Option<Boolean>>,
pub http_push_uri_options: Option<HttpPushUriOptions>,
pub http_push_uri_options_busy: Option<Option<Boolean>>,
pub max_image_size_bytes: Option<Option<Int64>>,
pub multipart_http_push_uri: Option<String>,
pub verify_remote_server_certificate: Option<Option<Boolean>>,
pub verify_remote_server_ssh_key: Option<Option<Boolean>>,
pub supported_update_image_formats: Option<Option<Vec<SupportedUpdateImageFormatType>>>,
pub local_image_store_available_capacity_bytes: Option<Option<Int64>>,
pub local_image_store_total_capacity_bytes: Option<Option<Int64>>,
pub firmware_inventory: Option<NavProperty<SoftwareInventoryCollection>>,
pub software_inventory: Option<NavProperty<SoftwareInventoryCollection>>,
pub remote_server_certificates: Option<ReferenceLeaf>,
pub client_certificates: Option<ReferenceLeaf>,
pub remote_server_ssh_keys: Option<ReferenceLeaf>,
pub public_identity_ssh_key: Option<ReferenceLeaf>,
pub update_service_capabilities: Option<ReferenceLeaf>,
pub local_image_store: Option<NavProperty<SoftwareInventoryCollection>>,
}Expand description
The UpdateService schema describes the update service and the properties for the service itself
with links to collections of firmware and software inventory. The update service also provides
methods for updating software and firmware of the resources in a Redfish service.
This resource shall represent an update service and the properties that affect the service itself for a Redfish implementation.
Fields
base: ResourceBase type
status: Option<Status>The status and health of the resource and its subordinate or dependent resources.
This property shall contain any status or health properties of the resource.
service_enabled: Option<Option<Boolean>>An indication of whether this service is enabled.
This property shall indicate whether this service is enabled.
actions: Option<Actions>The available actions for this resource.
This property shall contain the available actions for this resource.
http_push_uri: Option<String>The URI used to perform an HTTP or HTTPS push update to the update service. The format of the message is vendor-specific.
This property shall contain a URI at which the update service supports an HTTP or HTTPS POST of a
software image for the purpose of installing software contained within the image. Access to this
URI shall require the same privilege as access to the update service. If the service requires the
Content-Length header for POST requests to this URI, the service should return HTTP 411 Length Required status code if the client does not include this header in the POST request. The value
of this property should not contain a URI of a Redfish resource. See the ‘Redfish-defined URIs and
relative reference rules’ clause in the Redfish Specification.
http_push_uri_targets: Option<Option<Vec<String>>>An array of URIs that indicate where to apply the update image.
This property shall contain zero or more URIs that indicate where to apply the update image when
using the URI specified by the HttpPushUri property to push a software image. These targets
should correspond to software inventory instances or their related items. If this property is not
present or contains no targets, the service shall apply the software image to all applicable
targets, as determined by the service. If the target specifies a device resource, the software
image file shall be applied to the specified device. If the target specifies a resource
collection, the software image shall be applied to each applicable member of the specified
collection. If the target resource specifies an Aggregate resource, the software image file
shall be applied to each applicable element of the specified aggregate. If the target resource
specifies a ComputerSystem resource, the software image file shall be applied to the applicable
components within the specified computer system.
http_push_uri_targets_busy: Option<Option<Boolean>>An indication of whether any client has reserved the HttpPushUriTargets property.
This property shall indicate whether any client has reserved the HttpPushUriTargets property for
firmware updates. A client should set this property to true when it uses HttpPushUriTargets
for firmware updates. A client should set it to false when it no longer uses
HttpPushUriTargets for updates. The property can provide multiple clients a way to negotiate
ownership of HttpPushUriTargets and helps clients determine whether another client is using
HttpPushUriTargets to make firmware updates. This property has no functional requirements for
the service.
http_push_uri_options: Option<HttpPushUriOptions>The options for HttpPushUri-provided software updates.
This property shall contain options and requirements of the service for HttpPushUri-provided
software updates.
http_push_uri_options_busy: Option<Option<Boolean>>An indication of whether a client has reserved the HttpPushUriOptions properties for software
updates.
This property shall indicate whether a client uses the HttpPushUriOptions properties for software
updates. When a client uses any HttpPushUriOptions properties for software updates, it should
set this property to true. When a client no longer uses HttpPushUriOptions properties for
software updates, it should set this property to false. This property can provide multiple
clients a way to negotiate ownership of HttpPushUriOptions properties. Clients can use this
property to determine whether another client uses HttpPushUriOptions properties for software
updates. This property has no functional requirements for the service.
max_image_size_bytes: Option<Option<Int64>>The maximum size in bytes of the software update image that this service supports.
This property shall indicate the maximum size of the software update image that clients can send to this update service.
multipart_http_push_uri: Option<String>The URI used to perform a Redfish Specification-defined multipart HTTP or HTTPS push update to the update service.
This property shall contain a URI used to perform a Redfish Specification-defined multipart HTTP or
HTTPS POST of a software image for the purpose of installing software contained within the image.
The value of this property should not contain a URI of a Redfish resource. See the
‘Redfish-defined URIs and relative reference rules’ clause in the Redfish Specification.
verify_remote_server_certificate: Option<Option<Boolean>>An indication of whether the service will verify the certificate of the server referenced by the
ImageURI parameter in SimpleUpdate prior to sending the transfer request.
This property shall indicate whether the service will verify the certificate of the server
referenced by the ImageURI parameter in SimpleUpdate prior to sending the transfer request with
the certificates found in the collection referenced by the RemoteServerCertificates property. If
this property is not supported by the service, it shall be assumed to be false. This property
should default to false in order to maintain compatibility with older clients. Regardless of the
value of this property, services may perform additional verification based on other factors, such
as the configuration of the SecurityPolicy resource.
verify_remote_server_ssh_key: Option<Option<Boolean>>An indication of whether the service will verify the SSH key of the server referenced by the
ImageURI parameter in SimpleUpdate prior to sending the transfer request.
This property shall indicate whether the service will verify the SSH key of the server referenced
by the ImageURI parameter in SimpleUpdate prior to sending the transfer request with the keys
found in the collection referenced by the RemoteServerSSHKeys property. If this property is not
supported by the service, it shall be assumed to be false. This property should default to
false in order to maintain compatibility with older clients.
supported_update_image_formats: Option<Option<Vec<SupportedUpdateImageFormatType>>>The image format types supported by the service.
This property shall contain the image format types supported by the service.
local_image_store_available_capacity_bytes: Option<Option<Int64>>The number of bytes currently available in the local image store.
This property shall contain the number of bytes currently available in the local image store.
local_image_store_total_capacity_bytes: Option<Option<Int64>>The total number of bytes available to the local image store.
This property shall contain the total number of bytes available to the local image store.
firmware_inventory: Option<NavProperty<SoftwareInventoryCollection>>An inventory of firmware.
This property shall contain a link to a resource collection of type SoftwareInventoryCollection.
The resource collection should contain the set of software components generally referred to as
platform firmware or that does not execute within a host operating system. Software in this
collection is generally updated using platform-specific methods or utilities.
software_inventory: Option<NavProperty<SoftwareInventoryCollection>>An inventory of software.
This property shall contain a link to a resource collection of type SoftwareInventoryCollection.
The resource collection should contain the set of software components executed in the context of a
host operating system. This can include device drivers, applications, or offload workloads.
Software in this collection is generally updated using operating system-centric methods.
remote_server_certificates: Option<ReferenceLeaf>client_certificates: Option<ReferenceLeaf>remote_server_ssh_keys: Option<ReferenceLeaf>public_identity_ssh_key: Option<ReferenceLeaf>update_service_capabilities: Option<ReferenceLeaf>local_image_store: Option<NavProperty<SoftwareInventoryCollection>>An inventory of locally stored images.
This property shall contain a link to a resource collection of type SoftwareInventoryCollection.
The resource collection shall contain the set of images that are stored locally by the service.
This may include operating system images, drivers, or other software components. These images may
be referenced by other features of the service, such as virtual media.