WriteHoleProtectionPolicyType

Enum WriteHoleProtectionPolicyType 

pub enum WriteHoleProtectionPolicyType {
    Off,
    Journaling,
    DistributedLog,
    Oem,
    UnsupportedValue,
}

Variants



Off

The volume is not using any policy to address the write hole issue.

The support for addressing the write hole issue is disabled. The volume is not performing any additional activities to close the RAID write hole.



Journaling

The policy that uses separate block device for write-ahead logging to address write hole issue.

The policy that uses separate block device for write-ahead logging to address write hole issue. All write operations on the RAID volume are first logged on dedicated journaling device that is not part of the volume.



DistributedLog

The policy that distributes additional log among the volume’s capacity sources to address write hole issue.

The policy that distributes additional log (e.q. checksum of the parity) among the volume’s capacity sources to address write hole issue. Additional data is used to detect data corruption on the volume.



Oem

The policy that is Oem specific.

The policy that is Oem specific. The mechanism details are unknown unless provided separately by the Oem.



UnsupportedValue

Fallback value for values that are not supported by current version of Redfish schema.