pub struct Actions {
pub oem: Option<OemActions>,
pub assign_replica_target: Option<Action<VolumeAssignReplicaTargetAction, ()>>,
pub change_raid_layout: Option<Action<VolumeChangeRAIDLayoutAction, ()>>,
pub check_consistency: Option<Action<VolumeCheckConsistencyAction, ()>>,
pub create_replica_target: Option<Action<VolumeCreateReplicaTargetAction, ()>>,
pub force_enable: Option<Action<VolumeForceEnableAction, ()>>,
pub initialize: Option<Action<VolumeInitializeAction, ()>>,
pub remove_replica_relationship: Option<Action<VolumeRemoveReplicaRelationshipAction, ()>>,
pub resume_replication: Option<Action<VolumeResumeReplicationAction, ()>>,
pub reverse_replication_relationship: Option<Action<VolumeReverseReplicationRelationshipAction, ()>>,
pub split_replication: Option<Action<VolumeSplitReplicationAction, ()>>,
pub suspend_replication: Option<Action<VolumeSuspendReplicationAction, ()>>,
}Fields
oem: Option<OemActions>assign_replica_target: Option<Action<VolumeAssignReplicaTargetAction, ()>>change_raid_layout: Option<Action<VolumeChangeRAIDLayoutAction, ()>>check_consistency: Option<Action<VolumeCheckConsistencyAction, ()>>create_replica_target: Option<Action<VolumeCreateReplicaTargetAction, ()>>force_enable: Option<Action<VolumeForceEnableAction, ()>>initialize: Option<Action<VolumeInitializeAction, ()>>remove_replica_relationship: Option<Action<VolumeRemoveReplicaRelationshipAction, ()>>resume_replication: Option<Action<VolumeResumeReplicationAction, ()>>reverse_replication_relationship: Option<Action<VolumeReverseReplicationRelationshipAction, ()>>split_replication: Option<Action<VolumeSplitReplicationAction, ()>>suspend_replication: Option<Action<VolumeSuspendReplicationAction, ()>>Implementations
Sourceimpl Actions
impl Actions
Sourcepub async fn assign_replica_target<B: Bmc>(
&self,
bmc: &B,
replica_update_mode: Option<ReplicaUpdateMode>,
target_volume: Option<String>,
replica_type: Option<ReplicaType>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn assign_replica_target<B: Bmc>(
&self,
bmc: &B,
replica_update_mode: Option<ReplicaUpdateMode>,
target_volume: Option<String>,
replica_type: Option<ReplicaType>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
This action is used to establish a replication relationship by assigning an existing volume to serve as a target replica for an existing source volume.
This action shall be used to establish a replication relationship by assigning an existing volume to serve as a target replica for an existing source volume.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn change_raid_layout<B: Bmc>(
&self,
bmc: &B,
t: &VolumeChangeRAIDLayoutAction,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn change_raid_layout<B: Bmc>(
&self,
bmc: &B,
t: &VolumeChangeRAIDLayoutAction,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
Request system change the RAID layout of the volume.
This action shall request the system to change the RAID layout of the volume. Depending on the combination of the submitted parameters, this could be changing the RAID type, changing the span count, changing the number of drives used by the volume, or another configuration change supported by the system. Note that usage of this action while online may potentially cause data loss if the available capacity is reduced.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn check_consistency<B: Bmc>(
&self,
bmc: &B,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn check_consistency<B: Bmc>(
&self,
bmc: &B,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
This action is used to force a check of the Volume’s parity or redundant data to ensure it matches calculated values.
This defines the name of the custom action supported on this resource.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn create_replica_target<B: Bmc>(
&self,
bmc: &B,
t: &VolumeCreateReplicaTargetAction,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn create_replica_target<B: Bmc>(
&self,
bmc: &B,
t: &VolumeCreateReplicaTargetAction,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
This action is used to create a new volume resource to provide expanded data protection through a replica relationship with the specified source volume.
This action shall be used to create a new volume resource to provide expanded data protection through a replica relationship with the specified source volume.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn force_enable<B: Bmc>(
&self,
bmc: &B,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn force_enable<B: Bmc>(
&self,
bmc: &B,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
Request system force the volume to an enabled state regardless of data loss.
This action shall request the system to force the volume to enabled state regardless of data loss scenarios.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn initialize<B: Bmc>(
&self,
bmc: &B,
initialize_method: Option<InitializeMethod>,
initialize_type: Option<InitializeType>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn initialize<B: Bmc>(
&self,
bmc: &B,
initialize_method: Option<InitializeMethod>,
initialize_type: Option<InitializeType>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
This action is used to prepare the contents of the volume for use by the system. If InitializeMethod is not specified in the request body, but the property InitializeMethod is specified, the property InitializeMethod value should be used. If neither is specified, the InitializeMethod should be Foreground.
This defines the name of the custom action supported on this resource. If InitializeMethod is not specified in the request body, but the property InitializeMethod is specified, the property InitializeMethod value should be used. If neither is specified, the InitializeMethod should be Foreground.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn remove_replica_relationship<B: Bmc>(
&self,
bmc: &B,
target_volume: Option<String>,
delete_target_volume: Option<Boolean>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn remove_replica_relationship<B: Bmc>(
&self,
bmc: &B,
target_volume: Option<String>,
delete_target_volume: Option<Boolean>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
This action is used to disable data synchronization between a source and target volume, remove the replication relationship, and optionally delete the target volume.
This action shall be used to disable data synchronization between a source and target volume, remove the replication relationship, and optionally delete the target volume.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn resume_replication<B: Bmc>(
&self,
bmc: &B,
target_volume: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn resume_replication<B: Bmc>(
&self,
bmc: &B,
target_volume: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
This action is used to resume the active data synchronization between a source and target volume, without otherwise altering the replication relationship.
This action shall be used to resume the active data synchronization between a source and target volume, without otherwise altering the replication relationship.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn reverse_replication_relationship<B: Bmc>(
&self,
bmc: &B,
target_volume: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn reverse_replication_relationship<B: Bmc>(
&self,
bmc: &B,
target_volume: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
This action is used to reverse the replication relationship between a source and target volume.
This action shall be used to reverse the replication relationship between a source and target volume.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn split_replication<B: Bmc>(
&self,
bmc: &B,
target_volume: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn split_replication<B: Bmc>(
&self,
bmc: &B,
target_volume: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
This action is used to split the replication relationship and suspend data synchronization between a source and target volume.
This action shall be used to split the replication relationship and suspend data synchronization between a source and target volume.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.
Sourcepub async fn suspend_replication<B: Bmc>(
&self,
bmc: &B,
target_volume: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
pub async fn suspend_replication<B: Bmc>(
&self,
bmc: &B,
target_volume: Option<String>,
) -> Result<ModificationResponse<()>, B::Error>where
B::Error: ActionError,
This action is used to suspend active data synchronization between a source and target volume, without otherwise altering the replication relationship.
This action shall be used to suspend active data synchronization between a source and target volume, without otherwise altering the replication relationship.
Errors
- Not supported error if reference to action is not supported by the server.
- BMC Action errors if returned by BMC implementation.