pub struct VolumeAssignReplicaTargetAction {
pub replica_update_mode: Option<ReplicaUpdateMode>,
pub target_volume: Option<String>,
pub replica_type: Option<ReplicaType>,
}Expand description
This action is used to establish a replication relationship by assigning an existing volume to serve as a target replica for an existing source volume.
This action shall be used to establish a replication relationship by assigning an existing volume to serve as a target replica for an existing source volume.
Fields
replica_update_mode: Option<ReplicaUpdateMode>The replica update mode (synchronous vs asynchronous).
This parameter shall specify the replica update mode.
target_volume: Option<String>The Uri to the existing target volume.
This parameter shall contain the Uri to the existing target volume.
replica_type: Option<ReplicaType>The type of replica relationship to be created.
This parameter shall contain the type of replica relationship to be created (e.g., Clone, Mirror, Snap).