pub struct ServiceRoot<B: Bmc> {
pub root: Arc<ServiceRoot>,
/* private fields */
}Expand description
Represents ServiceRoot in the BMC model.
Fields
root: Arc<ServiceRoot>Content of the root.
Implementations
Sourceimpl<B: Bmc> ServiceRoot<B>
impl<B: Bmc> ServiceRoot<B>
Sourcepub fn replace_bmc(self, bmc: Arc<B>) -> Self
pub fn replace_bmc(self, bmc: Arc<B>) -> Self
Replace BMC in this root.
Sourcepub fn restrict_expand(self) -> Self
pub fn restrict_expand(self) -> Self
Restrict usage of expand.
Sourcepub fn vendor(&self) -> Option<Vendor<&str>>
pub fn vendor(&self) -> Option<Vendor<&str>>
The vendor or manufacturer associated with this Redfish service.
Sourcepub fn product(&self) -> Option<Product<&str>>
pub fn product(&self) -> Option<Product<&str>>
The product associated with this Redfish service.
Sourcepub fn redfish_version(&self) -> Option<RedfishVersion<'_>>
pub fn redfish_version(&self) -> Option<RedfishVersion<'_>>
The vendor or manufacturer associated with this Redfish service.
Sourcepub async fn account_service(
&self,
) -> Result<Option<AccountService<B>>, Error<B>>
pub async fn account_service( &self, ) -> Result<Option<AccountService<B>>, Error<B>>
Get the account service belonging to the BMC.
Returns Ok(None) when the BMC does not expose AccountService.
Errors
Returns error if retrieving account service data fails.
Sourcepub async fn chassis(&self) -> Result<Option<ChassisCollection<B>>, Error<B>>
pub async fn chassis(&self) -> Result<Option<ChassisCollection<B>>, Error<B>>
Get chassis collection in BMC
Returns Ok(None) when the BMC does not expose Chassis.
Errors
Returns error if retrieving chassis collection data fails.
Sourcepub async fn systems(&self) -> Result<Option<SystemCollection<B>>, Error<B>>
pub async fn systems(&self) -> Result<Option<SystemCollection<B>>, Error<B>>
Get computer system collection in BMC
Returns Ok(None) when the BMC does not expose Systems.
Errors
Returns error if retrieving system collection data fails.
Sourcepub async fn update_service(&self) -> Result<Option<UpdateService<B>>, Error<B>>
pub async fn update_service(&self) -> Result<Option<UpdateService<B>>, Error<B>>
Get update service in BMC
Returns Ok(None) when the BMC does not expose UpdateService.
Errors
Returns error if retrieving update service data fails.
Sourcepub async fn event_service(&self) -> Result<Option<EventService<B>>, Error<B>>
pub async fn event_service(&self) -> Result<Option<EventService<B>>, Error<B>>
Get event service in BMC
Returns Ok(None) when the BMC does not expose EventService.
Errors
Returns error if retrieving event service data fails.
Sourcepub async fn telemetry_service(
&self,
) -> Result<Option<TelemetryService<B>>, Error<B>>
pub async fn telemetry_service( &self, ) -> Result<Option<TelemetryService<B>>, Error<B>>
Get telemetry service in BMC
Returns Ok(None) when the BMC does not expose TelemetryService.
Errors
Returns error if retrieving telemetry service data fails.
Sourcepub async fn session_service(
&self,
) -> Result<Option<SessionService<B>>, Error<B>>
pub async fn session_service( &self, ) -> Result<Option<SessionService<B>>, Error<B>>
Get session service in BMC
Returns Ok(None) when the BMC does not expose SessionService.
Errors
Returns error if retrieving session service data fails.
Sourcepub async fn managers(&self) -> Result<Option<ManagerCollection<B>>, Error<B>>
pub async fn managers(&self) -> Result<Option<ManagerCollection<B>>, Error<B>>
Get manager collection in BMC
Returns Ok(None) when the BMC does not expose Managers.
Errors
Returns error if retrieving manager collection data fails.
Sourcepub fn oem_hpe_ilo_service_ext(
&self,
) -> Result<Option<HpeiLoServiceExt<B>>, Error<B>>
pub fn oem_hpe_ilo_service_ext( &self, ) -> Result<Option<HpeiLoServiceExt<B>>, Error<B>>
Get HPE OEM extension in service root
Returns Ok(None) when the BMC does not expose HPE extension.
Errors
Returns error if retrieving manager collection data fails.