ServiceRoot

Struct ServiceRoot 

pub struct ServiceRoot<B: Bmc> {
    pub root: Arc<ServiceRoot>,
    /* private fields */
}
Represents ServiceRoot in the BMC model.

Fields

root: Arc<ServiceRoot>

Content of the root.

Implementations

Source

impl<B: Bmc> ServiceRoot<B>

pub async fn new(bmc: Arc<B>) -> Result<Self, Error<B>>

Create a new service root.

Errors

Returns error if retrieving the root path via Redfish fails.

pub fn vendor(&self) -> Option<Vendor<&String>>

The vendor or manufacturer associated with this Redfish service.

pub fn product(&self) -> Option<Product<&String>>

The product associated with this Redfish service.

pub async fn account_service(&self) -> Result<AccountService<B>, Error<B>>

Get the account service belonging to the BMC.

Errors

Returns error if retrieving account service data fails.

pub async fn chassis(&self) -> Result<ChassisCollection<B>, Error<B>>

Get chassis collection in BMC

Errors

Returns error if chassis list is not avaiable in BMC

pub async fn systems(&self) -> Result<SystemCollection<B>, Error<B>>

Get computer system collection in BMC

Errors

Returns error if system list is not available in BMC

pub async fn update_service(&self) -> Result<UpdateService<B>, Error<B>>

Get update service in BMC

Errors

Returns error if update service is not available in BMC

pub async fn managers(&self) -> Result<ManagerCollection<B>, Error<B>>

Get manager collection in BMC

Errors

Returns error if manager list is not available in BMC