ServiceRoot

Struct ServiceRoot 

pub struct ServiceRoot<B: Bmc> {
    pub root: Arc<ServiceRoot>,
    /* private fields */
}
Represents ServiceRoot in the BMC model.

Fields

root: Arc<ServiceRoot>

Content of the root.

Implementations

Source

impl<B: Bmc> ServiceRoot<B>

pub async fn new(bmc: Arc<B>) -> Result<Self, Error<B>>

Create a new service root.

Errors

Returns error if retrieving the root path via Redfish fails.

pub fn vendor(&self) -> Option<Vendor<&String>>

The vendor or manufacturer associated with this Redfish service.

pub fn product(&self) -> Option<Product<&String>>

The product associated with this Redfish service.